/* Generated by Cython 0.29.32 */

/* BEGIN: Cython Metadata
{
    "distutils": {
        "define_macros": [
            [
                "CYTHON_TRACE",
                "1"
            ]
        ],
        "depends": [],
        "name": "ttygif.tty.theme",
        "sources": [
            "./ttygif/tty/theme.pyx"
        ]
    },
    "module_name": "ttygif.tty.theme"
}
END: Cython Metadata */

#ifndef PY_SSIZE_T_CLEAN
#define PY_SSIZE_T_CLEAN
#endif /* PY_SSIZE_T_CLEAN */
#include "Python.h"
#ifndef Py_PYTHON_H
    #error Python headers needed to compile C extensions, please install development version of Python.
#elif PY_VERSION_HEX < 0x02060000 || (0x03000000 <= PY_VERSION_HEX && PY_VERSION_HEX < 0x03030000)
    #error Cython requires Python 2.6+ or Python 3.3+.
#else
#define CYTHON_ABI "0_29_32"
#define CYTHON_HEX_VERSION 0x001D20F0
#define CYTHON_FUTURE_DIVISION 0
#include <stddef.h>
#ifndef offsetof
  #define offsetof(type, member) ( (size_t) & ((type*)0) -> member )
#endif
#if !defined(WIN32) && !defined(MS_WINDOWS)
  #ifndef __stdcall
    #define __stdcall
  #endif
  #ifndef __cdecl
    #define __cdecl
  #endif
  #ifndef __fastcall
    #define __fastcall
  #endif
#endif
#ifndef DL_IMPORT
  #define DL_IMPORT(t) t
#endif
#ifndef DL_EXPORT
  #define DL_EXPORT(t) t
#endif
#define __PYX_COMMA ,
#ifndef HAVE_LONG_LONG
  #if PY_VERSION_HEX >= 0x02070000
    #define HAVE_LONG_LONG
  #endif
#endif
#ifndef PY_LONG_LONG
  #define PY_LONG_LONG LONG_LONG
#endif
#ifndef Py_HUGE_VAL
  #define Py_HUGE_VAL HUGE_VAL
#endif
#ifdef PYPY_VERSION
  #define CYTHON_COMPILING_IN_PYPY 1
  #define CYTHON_COMPILING_IN_PYSTON 0
  #define CYTHON_COMPILING_IN_CPYTHON 0
  #define CYTHON_COMPILING_IN_NOGIL 0
  #undef CYTHON_USE_TYPE_SLOTS
  #define CYTHON_USE_TYPE_SLOTS 0
  #undef CYTHON_USE_PYTYPE_LOOKUP
  #define CYTHON_USE_PYTYPE_LOOKUP 0
  #if PY_VERSION_HEX < 0x03050000
    #undef CYTHON_USE_ASYNC_SLOTS
    #define CYTHON_USE_ASYNC_SLOTS 0
  #elif !defined(CYTHON_USE_ASYNC_SLOTS)
    #define CYTHON_USE_ASYNC_SLOTS 1
  #endif
  #undef CYTHON_USE_PYLIST_INTERNALS
  #define CYTHON_USE_PYLIST_INTERNALS 0
  #undef CYTHON_USE_UNICODE_INTERNALS
  #define CYTHON_USE_UNICODE_INTERNALS 0
  #undef CYTHON_USE_UNICODE_WRITER
  #define CYTHON_USE_UNICODE_WRITER 0
  #undef CYTHON_USE_PYLONG_INTERNALS
  #define CYTHON_USE_PYLONG_INTERNALS 0
  #undef CYTHON_AVOID_BORROWED_REFS
  #define CYTHON_AVOID_BORROWED_REFS 1
  #undef CYTHON_ASSUME_SAFE_MACROS
  #define CYTHON_ASSUME_SAFE_MACROS 0
  #undef CYTHON_UNPACK_METHODS
  #define CYTHON_UNPACK_METHODS 0
  #undef CYTHON_FAST_THREAD_STATE
  #define CYTHON_FAST_THREAD_STATE 0
  #undef CYTHON_FAST_PYCALL
  #define CYTHON_FAST_PYCALL 0
  #undef CYTHON_PEP489_MULTI_PHASE_INIT
  #define CYTHON_PEP489_MULTI_PHASE_INIT 0
  #undef CYTHON_USE_TP_FINALIZE
  #define CYTHON_USE_TP_FINALIZE 0
  #undef CYTHON_USE_DICT_VERSIONS
  #define CYTHON_USE_DICT_VERSIONS 0
  #undef CYTHON_USE_EXC_INFO_STACK
  #define CYTHON_USE_EXC_INFO_STACK 0
  #ifndef CYTHON_UPDATE_DESCRIPTOR_DOC
    #define CYTHON_UPDATE_DESCRIPTOR_DOC (PYPY_VERSION_HEX >= 0x07030900)
  #endif
#elif defined(PYSTON_VERSION)
  #define CYTHON_COMPILING_IN_PYPY 0
  #define CYTHON_COMPILING_IN_PYSTON 1
  #define CYTHON_COMPILING_IN_CPYTHON 0
  #define CYTHON_COMPILING_IN_NOGIL 0
  #ifndef CYTHON_USE_TYPE_SLOTS
    #define CYTHON_USE_TYPE_SLOTS 1
  #endif
  #undef CYTHON_USE_PYTYPE_LOOKUP
  #define CYTHON_USE_PYTYPE_LOOKUP 0
  #undef CYTHON_USE_ASYNC_SLOTS
  #define CYTHON_USE_ASYNC_SLOTS 0
  #undef CYTHON_USE_PYLIST_INTERNALS
  #define CYTHON_USE_PYLIST_INTERNALS 0
  #ifndef CYTHON_USE_UNICODE_INTERNALS
    #define CYTHON_USE_UNICODE_INTERNALS 1
  #endif
  #undef CYTHON_USE_UNICODE_WRITER
  #define CYTHON_USE_UNICODE_WRITER 0
  #undef CYTHON_USE_PYLONG_INTERNALS
  #define CYTHON_USE_PYLONG_INTERNALS 0
  #ifndef CYTHON_AVOID_BORROWED_REFS
    #define CYTHON_AVOID_BORROWED_REFS 0
  #endif
  #ifndef CYTHON_ASSUME_SAFE_MACROS
    #define CYTHON_ASSUME_SAFE_MACROS 1
  #endif
  #ifndef CYTHON_UNPACK_METHODS
    #define CYTHON_UNPACK_METHODS 1
  #endif
  #undef CYTHON_FAST_THREAD_STATE
  #define CYTHON_FAST_THREAD_STATE 0
  #undef CYTHON_FAST_PYCALL
  #define CYTHON_FAST_PYCALL 0
  #undef CYTHON_PEP489_MULTI_PHASE_INIT
  #define CYTHON_PEP489_MULTI_PHASE_INIT 0
  #undef CYTHON_USE_TP_FINALIZE
  #define CYTHON_USE_TP_FINALIZE 0
  #undef CYTHON_USE_DICT_VERSIONS
  #define CYTHON_USE_DICT_VERSIONS 0
  #undef CYTHON_USE_EXC_INFO_STACK
  #define CYTHON_USE_EXC_INFO_STACK 0
  #ifndef CYTHON_UPDATE_DESCRIPTOR_DOC
    #define CYTHON_UPDATE_DESCRIPTOR_DOC 0
  #endif
#elif defined(PY_NOGIL)
  #define CYTHON_COMPILING_IN_PYPY 0
  #define CYTHON_COMPILING_IN_PYSTON 0
  #define CYTHON_COMPILING_IN_CPYTHON 0
  #define CYTHON_COMPILING_IN_NOGIL 1
  #ifndef CYTHON_USE_TYPE_SLOTS
    #define CYTHON_USE_TYPE_SLOTS 1
  #endif
  #undef CYTHON_USE_PYTYPE_LOOKUP
  #define CYTHON_USE_PYTYPE_LOOKUP 0
  #ifndef CYTHON_USE_ASYNC_SLOTS
    #define CYTHON_USE_ASYNC_SLOTS 1
  #endif
  #undef CYTHON_USE_PYLIST_INTERNALS
  #define CYTHON_USE_PYLIST_INTERNALS 0
  #ifndef CYTHON_USE_UNICODE_INTERNALS
    #define CYTHON_USE_UNICODE_INTERNALS 1
  #endif
  #undef CYTHON_USE_UNICODE_WRITER
  #define CYTHON_USE_UNICODE_WRITER 0
  #undef CYTHON_USE_PYLONG_INTERNALS
  #define CYTHON_USE_PYLONG_INTERNALS 0
  #ifndef CYTHON_AVOID_BORROWED_REFS
    #define CYTHON_AVOID_BORROWED_REFS 0
  #endif
  #ifndef CYTHON_ASSUME_SAFE_MACROS
    #define CYTHON_ASSUME_SAFE_MACROS 1
  #endif
  #ifndef CYTHON_UNPACK_METHODS
    #define CYTHON_UNPACK_METHODS 1
  #endif
  #undef CYTHON_FAST_THREAD_STATE
  #define CYTHON_FAST_THREAD_STATE 0
  #undef CYTHON_FAST_PYCALL
  #define CYTHON_FAST_PYCALL 0
  #ifndef CYTHON_PEP489_MULTI_PHASE_INIT
    #define CYTHON_PEP489_MULTI_PHASE_INIT 1
  #endif
  #ifndef CYTHON_USE_TP_FINALIZE
    #define CYTHON_USE_TP_FINALIZE 1
  #endif
  #undef CYTHON_USE_DICT_VERSIONS
  #define CYTHON_USE_DICT_VERSIONS 0
  #undef CYTHON_USE_EXC_INFO_STACK
  #define CYTHON_USE_EXC_INFO_STACK 0
#else
  #define CYTHON_COMPILING_IN_PYPY 0
  #define CYTHON_COMPILING_IN_PYSTON 0
  #define CYTHON_COMPILING_IN_CPYTHON 1
  #define CYTHON_COMPILING_IN_NOGIL 0
  #ifndef CYTHON_USE_TYPE_SLOTS
    #define CYTHON_USE_TYPE_SLOTS 1
  #endif
  #if PY_VERSION_HEX < 0x02070000
    #undef CYTHON_USE_PYTYPE_LOOKUP
    #define CYTHON_USE_PYTYPE_LOOKUP 0
  #elif !defined(CYTHON_USE_PYTYPE_LOOKUP)
    #define CYTHON_USE_PYTYPE_LOOKUP 1
  #endif
  #if PY_MAJOR_VERSION < 3
    #undef CYTHON_USE_ASYNC_SLOTS
    #define CYTHON_USE_ASYNC_SLOTS 0
  #elif !defined(CYTHON_USE_ASYNC_SLOTS)
    #define CYTHON_USE_ASYNC_SLOTS 1
  #endif
  #if PY_VERSION_HEX < 0x02070000
    #undef CYTHON_USE_PYLONG_INTERNALS
    #define CYTHON_USE_PYLONG_INTERNALS 0
  #elif !defined(CYTHON_USE_PYLONG_INTERNALS)
    #define CYTHON_USE_PYLONG_INTERNALS 1
  #endif
  #ifndef CYTHON_USE_PYLIST_INTERNALS
    #define CYTHON_USE_PYLIST_INTERNALS 1
  #endif
  #ifndef CYTHON_USE_UNICODE_INTERNALS
    #define CYTHON_USE_UNICODE_INTERNALS 1
  #endif
  #if PY_VERSION_HEX < 0x030300F0 || PY_VERSION_HEX >= 0x030B00A2
    #undef CYTHON_USE_UNICODE_WRITER
    #define CYTHON_USE_UNICODE_WRITER 0
  #elif !defined(CYTHON_USE_UNICODE_WRITER)
    #define CYTHON_USE_UNICODE_WRITER 1
  #endif
  #ifndef CYTHON_AVOID_BORROWED_REFS
    #define CYTHON_AVOID_BORROWED_REFS 0
  #endif
  #ifndef CYTHON_ASSUME_SAFE_MACROS
    #define CYTHON_ASSUME_SAFE_MACROS 1
  #endif
  #ifndef CYTHON_UNPACK_METHODS
    #define CYTHON_UNPACK_METHODS 1
  #endif
  #if PY_VERSION_HEX >= 0x030B00A4
    #undef CYTHON_FAST_THREAD_STATE
    #define CYTHON_FAST_THREAD_STATE 0
  #elif !defined(CYTHON_FAST_THREAD_STATE)
    #define CYTHON_FAST_THREAD_STATE 1
  #endif
  #ifndef CYTHON_FAST_PYCALL
    #define CYTHON_FAST_PYCALL (PY_VERSION_HEX < 0x030A0000)
  #endif
  #ifndef CYTHON_PEP489_MULTI_PHASE_INIT
    #define CYTHON_PEP489_MULTI_PHASE_INIT (PY_VERSION_HEX >= 0x03050000)
  #endif
  #ifndef CYTHON_USE_TP_FINALIZE
    #define CYTHON_USE_TP_FINALIZE (PY_VERSION_HEX >= 0x030400a1)
  #endif
  #ifndef CYTHON_USE_DICT_VERSIONS
    #define CYTHON_USE_DICT_VERSIONS (PY_VERSION_HEX >= 0x030600B1)
  #endif
  #if PY_VERSION_HEX >= 0x030B00A4
    #undef CYTHON_USE_EXC_INFO_STACK
    #define CYTHON_USE_EXC_INFO_STACK 0
  #elif !defined(CYTHON_USE_EXC_INFO_STACK)
    #define CYTHON_USE_EXC_INFO_STACK (PY_VERSION_HEX >= 0x030700A3)
  #endif
  #ifndef CYTHON_UPDATE_DESCRIPTOR_DOC
    #define CYTHON_UPDATE_DESCRIPTOR_DOC 1
  #endif
#endif
#if !defined(CYTHON_FAST_PYCCALL)
#define CYTHON_FAST_PYCCALL  (CYTHON_FAST_PYCALL && PY_VERSION_HEX >= 0x030600B1)
#endif
#if CYTHON_USE_PYLONG_INTERNALS
  #if PY_MAJOR_VERSION < 3
    #include "longintrepr.h"
  #endif
  #undef SHIFT
  #undef BASE
  #undef MASK
  #ifdef SIZEOF_VOID_P
    enum { __pyx_check_sizeof_voidp = 1 / (int)(SIZEOF_VOID_P == sizeof(void*)) };
  #endif
#endif
#ifndef __has_attribute
  #define __has_attribute(x) 0
#endif
#ifndef __has_cpp_attribute
  #define __has_cpp_attribute(x) 0
#endif
#ifndef CYTHON_RESTRICT
  #if defined(__GNUC__)
    #define CYTHON_RESTRICT __restrict__
  #elif defined(_MSC_VER) && _MSC_VER >= 1400
    #define CYTHON_RESTRICT __restrict
  #elif defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L
    #define CYTHON_RESTRICT restrict
  #else
    #define CYTHON_RESTRICT
  #endif
#endif
#ifndef CYTHON_UNUSED
# if defined(__GNUC__)
#   if !(defined(__cplusplus)) || (__GNUC__ > 3 || (__GNUC__ == 3 && __GNUC_MINOR__ >= 4))
#     define CYTHON_UNUSED __attribute__ ((__unused__))
#   else
#     define CYTHON_UNUSED
#   endif
# elif defined(__ICC) || (defined(__INTEL_COMPILER) && !defined(_MSC_VER))
#   define CYTHON_UNUSED __attribute__ ((__unused__))
# else
#   define CYTHON_UNUSED
# endif
#endif
#ifndef CYTHON_MAYBE_UNUSED_VAR
#  if defined(__cplusplus)
     template<class T> void CYTHON_MAYBE_UNUSED_VAR( const T& ) { }
#  else
#    define CYTHON_MAYBE_UNUSED_VAR(x) (void)(x)
#  endif
#endif
#ifndef CYTHON_NCP_UNUSED
# if CYTHON_COMPILING_IN_CPYTHON
#  define CYTHON_NCP_UNUSED
# else
#  define CYTHON_NCP_UNUSED CYTHON_UNUSED
# endif
#endif
#define __Pyx_void_to_None(void_result) ((void)(void_result), Py_INCREF(Py_None), Py_None)
#ifdef _MSC_VER
    #ifndef _MSC_STDINT_H_
        #if _MSC_VER < 1300
           typedef unsigned char     uint8_t;
           typedef unsigned int      uint32_t;
        #else
           typedef unsigned __int8   uint8_t;
           typedef unsigned __int32  uint32_t;
        #endif
    #endif
#else
   #include <stdint.h>
#endif
#ifndef CYTHON_FALLTHROUGH
  #if defined(__cplusplus) && __cplusplus >= 201103L
    #if __has_cpp_attribute(fallthrough)
      #define CYTHON_FALLTHROUGH [[fallthrough]]
    #elif __has_cpp_attribute(clang::fallthrough)
      #define CYTHON_FALLTHROUGH [[clang::fallthrough]]
    #elif __has_cpp_attribute(gnu::fallthrough)
      #define CYTHON_FALLTHROUGH [[gnu::fallthrough]]
    #endif
  #endif
  #ifndef CYTHON_FALLTHROUGH
    #if __has_attribute(fallthrough)
      #define CYTHON_FALLTHROUGH __attribute__((fallthrough))
    #else
      #define CYTHON_FALLTHROUGH
    #endif
  #endif
  #if defined(__clang__ ) && defined(__apple_build_version__)
    #if __apple_build_version__ < 7000000
      #undef  CYTHON_FALLTHROUGH
      #define CYTHON_FALLTHROUGH
    #endif
  #endif
#endif

#ifndef CYTHON_INLINE
  #if defined(__clang__)
    #define CYTHON_INLINE __inline__ __attribute__ ((__unused__))
  #elif defined(__GNUC__)
    #define CYTHON_INLINE __inline__
  #elif defined(_MSC_VER)
    #define CYTHON_INLINE __inline
  #elif defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L
    #define CYTHON_INLINE inline
  #else
    #define CYTHON_INLINE
  #endif
#endif

#if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX < 0x02070600 && !defined(Py_OptimizeFlag)
  #define Py_OptimizeFlag 0
#endif
#define __PYX_BUILD_PY_SSIZE_T "n"
#define CYTHON_FORMAT_SSIZE_T "z"
#if PY_MAJOR_VERSION < 3
  #define __Pyx_BUILTIN_MODULE_NAME "__builtin__"
  #define __Pyx_PyCode_New(a, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)\
          PyCode_New(a+k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)
  #define __Pyx_DefaultClassType PyClass_Type
#else
  #define __Pyx_BUILTIN_MODULE_NAME "builtins"
  #define __Pyx_DefaultClassType PyType_Type
#if PY_VERSION_HEX >= 0x030B00A1
    static CYTHON_INLINE PyCodeObject* __Pyx_PyCode_New(int a, int k, int l, int s, int f,
                                                    PyObject *code, PyObject *c, PyObject* n, PyObject *v,
                                                    PyObject *fv, PyObject *cell, PyObject* fn,
                                                    PyObject *name, int fline, PyObject *lnos) {
        PyObject *kwds=NULL, *argcount=NULL, *posonlyargcount=NULL, *kwonlyargcount=NULL;
        PyObject *nlocals=NULL, *stacksize=NULL, *flags=NULL, *replace=NULL, *call_result=NULL, *empty=NULL;
        const char *fn_cstr=NULL;
        const char *name_cstr=NULL;
        PyCodeObject* co=NULL;
        PyObject *type, *value, *traceback;
        PyErr_Fetch(&type, &value, &traceback);
        if (!(kwds=PyDict_New())) goto end;
        if (!(argcount=PyLong_FromLong(a))) goto end;
        if (PyDict_SetItemString(kwds, "co_argcount", argcount) != 0) goto end;
        if (!(posonlyargcount=PyLong_FromLong(0))) goto end;
        if (PyDict_SetItemString(kwds, "co_posonlyargcount", posonlyargcount) != 0) goto end;
        if (!(kwonlyargcount=PyLong_FromLong(k))) goto end;
        if (PyDict_SetItemString(kwds, "co_kwonlyargcount", kwonlyargcount) != 0) goto end;
        if (!(nlocals=PyLong_FromLong(l))) goto end;
        if (PyDict_SetItemString(kwds, "co_nlocals", nlocals) != 0) goto end;
        if (!(stacksize=PyLong_FromLong(s))) goto end;
        if (PyDict_SetItemString(kwds, "co_stacksize", stacksize) != 0) goto end;
        if (!(flags=PyLong_FromLong(f))) goto end;
        if (PyDict_SetItemString(kwds, "co_flags", flags) != 0) goto end;
        if (PyDict_SetItemString(kwds, "co_code", code) != 0) goto end;
        if (PyDict_SetItemString(kwds, "co_consts", c) != 0) goto end;
        if (PyDict_SetItemString(kwds, "co_names", n) != 0) goto end;
        if (PyDict_SetItemString(kwds, "co_varnames", v) != 0) goto end;
        if (PyDict_SetItemString(kwds, "co_freevars", fv) != 0) goto end;
        if (PyDict_SetItemString(kwds, "co_cellvars", cell) != 0) goto end;
        if (PyDict_SetItemString(kwds, "co_linetable", lnos) != 0) goto end;
        if (!(fn_cstr=PyUnicode_AsUTF8AndSize(fn, NULL))) goto end;
        if (!(name_cstr=PyUnicode_AsUTF8AndSize(name, NULL))) goto end;
        if (!(co = PyCode_NewEmpty(fn_cstr, name_cstr, fline))) goto end;
        if (!(replace = PyObject_GetAttrString((PyObject*)co, "replace"))) goto cleanup_code_too;
        if (!(empty = PyTuple_New(0))) goto cleanup_code_too; // unfortunately __pyx_empty_tuple isn't available here
        if (!(call_result = PyObject_Call(replace, empty, kwds))) goto cleanup_code_too;
        Py_XDECREF((PyObject*)co);
        co = (PyCodeObject*)call_result;
        call_result = NULL;
        if (0) {
            cleanup_code_too:
            Py_XDECREF((PyObject*)co);
            co = NULL;
        }
        end:
        Py_XDECREF(kwds);
        Py_XDECREF(argcount);
        Py_XDECREF(posonlyargcount);
        Py_XDECREF(kwonlyargcount);
        Py_XDECREF(nlocals);
        Py_XDECREF(stacksize);
        Py_XDECREF(replace);
        Py_XDECREF(call_result);
        Py_XDECREF(empty);
        if (type) {
            PyErr_Restore(type, value, traceback);
        }
        return co;
    }
#else
  #define __Pyx_PyCode_New(a, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)\
          PyCode_New(a, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)
#endif
  #define __Pyx_DefaultClassType PyType_Type
#endif
#ifndef Py_TPFLAGS_CHECKTYPES
  #define Py_TPFLAGS_CHECKTYPES 0
#endif
#ifndef Py_TPFLAGS_HAVE_INDEX
  #define Py_TPFLAGS_HAVE_INDEX 0
#endif
#ifndef Py_TPFLAGS_HAVE_NEWBUFFER
  #define Py_TPFLAGS_HAVE_NEWBUFFER 0
#endif
#ifndef Py_TPFLAGS_HAVE_FINALIZE
  #define Py_TPFLAGS_HAVE_FINALIZE 0
#endif
#ifndef METH_STACKLESS
  #define METH_STACKLESS 0
#endif
#if PY_VERSION_HEX <= 0x030700A3 || !defined(METH_FASTCALL)
  #ifndef METH_FASTCALL
     #define METH_FASTCALL 0x80
  #endif
  typedef PyObject *(*__Pyx_PyCFunctionFast) (PyObject *self, PyObject *const *args, Py_ssize_t nargs);
  typedef PyObject *(*__Pyx_PyCFunctionFastWithKeywords) (PyObject *self, PyObject *const *args,
                                                          Py_ssize_t nargs, PyObject *kwnames);
#else
  #define __Pyx_PyCFunctionFast _PyCFunctionFast
  #define __Pyx_PyCFunctionFastWithKeywords _PyCFunctionFastWithKeywords
#endif
#if CYTHON_FAST_PYCCALL
#define __Pyx_PyFastCFunction_Check(func)\
    ((PyCFunction_Check(func) && (METH_FASTCALL == (PyCFunction_GET_FLAGS(func) & ~(METH_CLASS | METH_STATIC | METH_COEXIST | METH_KEYWORDS | METH_STACKLESS)))))
#else
#define __Pyx_PyFastCFunction_Check(func) 0
#endif
#if CYTHON_COMPILING_IN_PYPY && !defined(PyObject_Malloc)
  #define PyObject_Malloc(s)   PyMem_Malloc(s)
  #define PyObject_Free(p)     PyMem_Free(p)
  #define PyObject_Realloc(p)  PyMem_Realloc(p)
#endif
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX < 0x030400A1
  #define PyMem_RawMalloc(n)           PyMem_Malloc(n)
  #define PyMem_RawRealloc(p, n)       PyMem_Realloc(p, n)
  #define PyMem_RawFree(p)             PyMem_Free(p)
#endif
#if CYTHON_COMPILING_IN_PYSTON
  #define __Pyx_PyCode_HasFreeVars(co)  PyCode_HasFreeVars(co)
  #define __Pyx_PyFrame_SetLineNumber(frame, lineno) PyFrame_SetLineNumber(frame, lineno)
#else
  #define __Pyx_PyCode_HasFreeVars(co)  (PyCode_GetNumFree(co) > 0)
  #define __Pyx_PyFrame_SetLineNumber(frame, lineno)  (frame)->f_lineno = (lineno)
#endif
#if !CYTHON_FAST_THREAD_STATE || PY_VERSION_HEX < 0x02070000
  #define __Pyx_PyThreadState_Current PyThreadState_GET()
#elif PY_VERSION_HEX >= 0x03060000
  #define __Pyx_PyThreadState_Current _PyThreadState_UncheckedGet()
#elif PY_VERSION_HEX >= 0x03000000
  #define __Pyx_PyThreadState_Current PyThreadState_GET()
#else
  #define __Pyx_PyThreadState_Current _PyThreadState_Current
#endif
#if PY_VERSION_HEX < 0x030700A2 && !defined(PyThread_tss_create) && !defined(Py_tss_NEEDS_INIT)
#include "pythread.h"
#define Py_tss_NEEDS_INIT 0
typedef int Py_tss_t;
static CYTHON_INLINE int PyThread_tss_create(Py_tss_t *key) {
  *key = PyThread_create_key();
  return 0;
}
static CYTHON_INLINE Py_tss_t * PyThread_tss_alloc(void) {
  Py_tss_t *key = (Py_tss_t *)PyObject_Malloc(sizeof(Py_tss_t));
  *key = Py_tss_NEEDS_INIT;
  return key;
}
static CYTHON_INLINE void PyThread_tss_free(Py_tss_t *key) {
  PyObject_Free(key);
}
static CYTHON_INLINE int PyThread_tss_is_created(Py_tss_t *key) {
  return *key != Py_tss_NEEDS_INIT;
}
static CYTHON_INLINE void PyThread_tss_delete(Py_tss_t *key) {
  PyThread_delete_key(*key);
  *key = Py_tss_NEEDS_INIT;
}
static CYTHON_INLINE int PyThread_tss_set(Py_tss_t *key, void *value) {
  return PyThread_set_key_value(*key, value);
}
static CYTHON_INLINE void * PyThread_tss_get(Py_tss_t *key) {
  return PyThread_get_key_value(*key);
}
#endif
#if CYTHON_COMPILING_IN_CPYTHON || defined(_PyDict_NewPresized)
#define __Pyx_PyDict_NewPresized(n)  ((n <= 8) ? PyDict_New() : _PyDict_NewPresized(n))
#else
#define __Pyx_PyDict_NewPresized(n)  PyDict_New()
#endif
#if PY_MAJOR_VERSION >= 3 || CYTHON_FUTURE_DIVISION
  #define __Pyx_PyNumber_Divide(x,y)         PyNumber_TrueDivide(x,y)
  #define __Pyx_PyNumber_InPlaceDivide(x,y)  PyNumber_InPlaceTrueDivide(x,y)
#else
  #define __Pyx_PyNumber_Divide(x,y)         PyNumber_Divide(x,y)
  #define __Pyx_PyNumber_InPlaceDivide(x,y)  PyNumber_InPlaceDivide(x,y)
#endif
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030500A1 && CYTHON_USE_UNICODE_INTERNALS
#define __Pyx_PyDict_GetItemStr(dict, name)  _PyDict_GetItem_KnownHash(dict, name, ((PyASCIIObject *) name)->hash)
#else
#define __Pyx_PyDict_GetItemStr(dict, name)  PyDict_GetItem(dict, name)
#endif
#if PY_VERSION_HEX > 0x03030000 && defined(PyUnicode_KIND)
  #define CYTHON_PEP393_ENABLED 1
  #if defined(PyUnicode_IS_READY)
  #define __Pyx_PyUnicode_READY(op)       (likely(PyUnicode_IS_READY(op)) ?\
                                              0 : _PyUnicode_Ready((PyObject *)(op)))
  #else
  #define __Pyx_PyUnicode_READY(op)       (0)
  #endif
  #define __Pyx_PyUnicode_GET_LENGTH(u)   PyUnicode_GET_LENGTH(u)
  #define __Pyx_PyUnicode_READ_CHAR(u, i) PyUnicode_READ_CHAR(u, i)
  #define __Pyx_PyUnicode_MAX_CHAR_VALUE(u)   PyUnicode_MAX_CHAR_VALUE(u)
  #define __Pyx_PyUnicode_KIND(u)         PyUnicode_KIND(u)
  #define __Pyx_PyUnicode_DATA(u)         PyUnicode_DATA(u)
  #define __Pyx_PyUnicode_READ(k, d, i)   PyUnicode_READ(k, d, i)
  #define __Pyx_PyUnicode_WRITE(k, d, i, ch)  PyUnicode_WRITE(k, d, i, ch)
  #if defined(PyUnicode_IS_READY) && defined(PyUnicode_GET_SIZE)
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x03090000
  #define __Pyx_PyUnicode_IS_TRUE(u)      (0 != (likely(PyUnicode_IS_READY(u)) ? PyUnicode_GET_LENGTH(u) : ((PyCompactUnicodeObject *)(u))->wstr_length))
  #else
  #define __Pyx_PyUnicode_IS_TRUE(u)      (0 != (likely(PyUnicode_IS_READY(u)) ? PyUnicode_GET_LENGTH(u) : PyUnicode_GET_SIZE(u)))
  #endif
  #else
  #define __Pyx_PyUnicode_IS_TRUE(u)      (0 != PyUnicode_GET_LENGTH(u))
  #endif
#else
  #define CYTHON_PEP393_ENABLED 0
  #define PyUnicode_1BYTE_KIND  1
  #define PyUnicode_2BYTE_KIND  2
  #define PyUnicode_4BYTE_KIND  4
  #define __Pyx_PyUnicode_READY(op)       (0)
  #define __Pyx_PyUnicode_GET_LENGTH(u)   PyUnicode_GET_SIZE(u)
  #define __Pyx_PyUnicode_READ_CHAR(u, i) ((Py_UCS4)(PyUnicode_AS_UNICODE(u)[i]))
  #define __Pyx_PyUnicode_MAX_CHAR_VALUE(u)   ((sizeof(Py_UNICODE) == 2) ? 65535 : 1114111)
  #define __Pyx_PyUnicode_KIND(u)         (sizeof(Py_UNICODE))
  #define __Pyx_PyUnicode_DATA(u)         ((void*)PyUnicode_AS_UNICODE(u))
  #define __Pyx_PyUnicode_READ(k, d, i)   ((void)(k), (Py_UCS4)(((Py_UNICODE*)d)[i]))
  #define __Pyx_PyUnicode_WRITE(k, d, i, ch)  (((void)(k)), ((Py_UNICODE*)d)[i] = ch)
  #define __Pyx_PyUnicode_IS_TRUE(u)      (0 != PyUnicode_GET_SIZE(u))
#endif
#if CYTHON_COMPILING_IN_PYPY
  #define __Pyx_PyUnicode_Concat(a, b)      PyNumber_Add(a, b)
  #define __Pyx_PyUnicode_ConcatSafe(a, b)  PyNumber_Add(a, b)
#else
  #define __Pyx_PyUnicode_Concat(a, b)      PyUnicode_Concat(a, b)
  #define __Pyx_PyUnicode_ConcatSafe(a, b)  ((unlikely((a) == Py_None) || unlikely((b) == Py_None)) ?\
      PyNumber_Add(a, b) : __Pyx_PyUnicode_Concat(a, b))
#endif
#if CYTHON_COMPILING_IN_PYPY && !defined(PyUnicode_Contains)
  #define PyUnicode_Contains(u, s)  PySequence_Contains(u, s)
#endif
#if CYTHON_COMPILING_IN_PYPY && !defined(PyByteArray_Check)
  #define PyByteArray_Check(obj)  PyObject_TypeCheck(obj, &PyByteArray_Type)
#endif
#if CYTHON_COMPILING_IN_PYPY && !defined(PyObject_Format)
  #define PyObject_Format(obj, fmt)  PyObject_CallMethod(obj, "__format__", "O", fmt)
#endif
#define __Pyx_PyString_FormatSafe(a, b)   ((unlikely((a) == Py_None || (PyString_Check(b) && !PyString_CheckExact(b)))) ? PyNumber_Remainder(a, b) : __Pyx_PyString_Format(a, b))
#define __Pyx_PyUnicode_FormatSafe(a, b)  ((unlikely((a) == Py_None || (PyUnicode_Check(b) && !PyUnicode_CheckExact(b)))) ? PyNumber_Remainder(a, b) : PyUnicode_Format(a, b))
#if PY_MAJOR_VERSION >= 3
  #define __Pyx_PyString_Format(a, b)  PyUnicode_Format(a, b)
#else
  #define __Pyx_PyString_Format(a, b)  PyString_Format(a, b)
#endif
#if PY_MAJOR_VERSION < 3 && !defined(PyObject_ASCII)
  #define PyObject_ASCII(o)            PyObject_Repr(o)
#endif
#if PY_MAJOR_VERSION >= 3
  #define PyBaseString_Type            PyUnicode_Type
  #define PyStringObject               PyUnicodeObject
  #define PyString_Type                PyUnicode_Type
  #define PyString_Check               PyUnicode_Check
  #define PyString_CheckExact          PyUnicode_CheckExact
#ifndef PyObject_Unicode
  #define PyObject_Unicode             PyObject_Str
#endif
#endif
#if PY_MAJOR_VERSION >= 3
  #define __Pyx_PyBaseString_Check(obj) PyUnicode_Check(obj)
  #define __Pyx_PyBaseString_CheckExact(obj) PyUnicode_CheckExact(obj)
#else
  #define __Pyx_PyBaseString_Check(obj) (PyString_Check(obj) || PyUnicode_Check(obj))
  #define __Pyx_PyBaseString_CheckExact(obj) (PyString_CheckExact(obj) || PyUnicode_CheckExact(obj))
#endif
#ifndef PySet_CheckExact
  #define PySet_CheckExact(obj)        (Py_TYPE(obj) == &PySet_Type)
#endif
#if PY_VERSION_HEX >= 0x030900A4
  #define __Pyx_SET_REFCNT(obj, refcnt) Py_SET_REFCNT(obj, refcnt)
  #define __Pyx_SET_SIZE(obj, size) Py_SET_SIZE(obj, size)
#else
  #define __Pyx_SET_REFCNT(obj, refcnt) Py_REFCNT(obj) = (refcnt)
  #define __Pyx_SET_SIZE(obj, size) Py_SIZE(obj) = (size)
#endif
#if CYTHON_ASSUME_SAFE_MACROS
  #define __Pyx_PySequence_SIZE(seq)  Py_SIZE(seq)
#else
  #define __Pyx_PySequence_SIZE(seq)  PySequence_Size(seq)
#endif
#if PY_MAJOR_VERSION >= 3
  #define PyIntObject                  PyLongObject
  #define PyInt_Type                   PyLong_Type
  #define PyInt_Check(op)              PyLong_Check(op)
  #define PyInt_CheckExact(op)         PyLong_CheckExact(op)
  #define PyInt_FromString             PyLong_FromString
  #define PyInt_FromUnicode            PyLong_FromUnicode
  #define PyInt_FromLong               PyLong_FromLong
  #define PyInt_FromSize_t             PyLong_FromSize_t
  #define PyInt_FromSsize_t            PyLong_FromSsize_t
  #define PyInt_AsLong                 PyLong_AsLong
  #define PyInt_AS_LONG                PyLong_AS_LONG
  #define PyInt_AsSsize_t              PyLong_AsSsize_t
  #define PyInt_AsUnsignedLongMask     PyLong_AsUnsignedLongMask
  #define PyInt_AsUnsignedLongLongMask PyLong_AsUnsignedLongLongMask
  #define PyNumber_Int                 PyNumber_Long
#endif
#if PY_MAJOR_VERSION >= 3
  #define PyBoolObject                 PyLongObject
#endif
#if PY_MAJOR_VERSION >= 3 && CYTHON_COMPILING_IN_PYPY
  #ifndef PyUnicode_InternFromString
    #define PyUnicode_InternFromString(s) PyUnicode_FromString(s)
  #endif
#endif
#if PY_VERSION_HEX < 0x030200A4
  typedef long Py_hash_t;
  #define __Pyx_PyInt_FromHash_t PyInt_FromLong
  #define __Pyx_PyInt_AsHash_t   __Pyx_PyIndex_AsHash_t
#else
  #define __Pyx_PyInt_FromHash_t PyInt_FromSsize_t
  #define __Pyx_PyInt_AsHash_t   __Pyx_PyIndex_AsSsize_t
#endif
#if PY_MAJOR_VERSION >= 3
  #define __Pyx_PyMethod_New(func, self, klass) ((self) ? ((void)(klass), PyMethod_New(func, self)) : __Pyx_NewRef(func))
#else
  #define __Pyx_PyMethod_New(func, self, klass) PyMethod_New(func, self, klass)
#endif
#if CYTHON_USE_ASYNC_SLOTS
  #if PY_VERSION_HEX >= 0x030500B1
    #define __Pyx_PyAsyncMethodsStruct PyAsyncMethods
    #define __Pyx_PyType_AsAsync(obj) (Py_TYPE(obj)->tp_as_async)
  #else
    #define __Pyx_PyType_AsAsync(obj) ((__Pyx_PyAsyncMethodsStruct*) (Py_TYPE(obj)->tp_reserved))
  #endif
#else
  #define __Pyx_PyType_AsAsync(obj) NULL
#endif
#ifndef __Pyx_PyAsyncMethodsStruct
    typedef struct {
        unaryfunc am_await;
        unaryfunc am_aiter;
        unaryfunc am_anext;
    } __Pyx_PyAsyncMethodsStruct;
#endif

#if defined(_WIN32) || defined(WIN32) || defined(MS_WINDOWS)
  #if !defined(_USE_MATH_DEFINES)
    #define _USE_MATH_DEFINES
  #endif
#endif
#include <math.h>
#ifdef NAN
#define __PYX_NAN() ((float) NAN)
#else
static CYTHON_INLINE float __PYX_NAN() {
  float value;
  memset(&value, 0xFF, sizeof(value));
  return value;
}
#endif
#if defined(__CYGWIN__) && defined(_LDBL_EQ_DBL)
#define __Pyx_truncl trunc
#else
#define __Pyx_truncl truncl
#endif

#define __PYX_MARK_ERR_POS(f_index, lineno) \
    { __pyx_filename = __pyx_f[f_index]; (void)__pyx_filename; __pyx_lineno = lineno; (void)__pyx_lineno; __pyx_clineno = __LINE__; (void)__pyx_clineno; }
#define __PYX_ERR(f_index, lineno, Ln_error) \
    { __PYX_MARK_ERR_POS(f_index, lineno) goto Ln_error; }

#ifndef __PYX_EXTERN_C
  #ifdef __cplusplus
    #define __PYX_EXTERN_C extern "C"
  #else
    #define __PYX_EXTERN_C extern
  #endif
#endif

#define __PYX_HAVE__ttygif__tty__theme
#define __PYX_HAVE_API__ttygif__tty__theme
/* Early includes */
#include <string.h>
#include <stdio.h>
#include "pythread.h"
#include <stdint.h>
#ifdef _OPENMP
#include <omp.h>
#endif /* _OPENMP */

#if defined(PYREX_WITHOUT_ASSERTIONS) && !defined(CYTHON_WITHOUT_ASSERTIONS)
#define CYTHON_WITHOUT_ASSERTIONS
#endif

typedef struct {PyObject **p; const char *s; const Py_ssize_t n; const char* encoding;
                const char is_unicode; const char is_str; const char intern; } __Pyx_StringTabEntry;

#define __PYX_DEFAULT_STRING_ENCODING_IS_ASCII 0
#define __PYX_DEFAULT_STRING_ENCODING_IS_UTF8 0
#define __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT (PY_MAJOR_VERSION >= 3 && __PYX_DEFAULT_STRING_ENCODING_IS_UTF8)
#define __PYX_DEFAULT_STRING_ENCODING ""
#define __Pyx_PyObject_FromString __Pyx_PyBytes_FromString
#define __Pyx_PyObject_FromStringAndSize __Pyx_PyBytes_FromStringAndSize
#define __Pyx_uchar_cast(c) ((unsigned char)c)
#define __Pyx_long_cast(x) ((long)x)
#define __Pyx_fits_Py_ssize_t(v, type, is_signed)  (\
    (sizeof(type) < sizeof(Py_ssize_t))  ||\
    (sizeof(type) > sizeof(Py_ssize_t) &&\
          likely(v < (type)PY_SSIZE_T_MAX ||\
                 v == (type)PY_SSIZE_T_MAX)  &&\
          (!is_signed || likely(v > (type)PY_SSIZE_T_MIN ||\
                                v == (type)PY_SSIZE_T_MIN)))  ||\
    (sizeof(type) == sizeof(Py_ssize_t) &&\
          (is_signed || likely(v < (type)PY_SSIZE_T_MAX ||\
                               v == (type)PY_SSIZE_T_MAX)))  )
static CYTHON_INLINE int __Pyx_is_valid_index(Py_ssize_t i, Py_ssize_t limit) {
    return (size_t) i < (size_t) limit;
}
#if defined (__cplusplus) && __cplusplus >= 201103L
    #include <cstdlib>
    #define __Pyx_sst_abs(value) std::abs(value)
#elif SIZEOF_INT >= SIZEOF_SIZE_T
    #define __Pyx_sst_abs(value) abs(value)
#elif SIZEOF_LONG >= SIZEOF_SIZE_T
    #define __Pyx_sst_abs(value) labs(value)
#elif defined (_MSC_VER)
    #define __Pyx_sst_abs(value) ((Py_ssize_t)_abs64(value))
#elif defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L
    #define __Pyx_sst_abs(value) llabs(value)
#elif defined (__GNUC__)
    #define __Pyx_sst_abs(value) __builtin_llabs(value)
#else
    #define __Pyx_sst_abs(value) ((value<0) ? -value : value)
#endif
static CYTHON_INLINE const char* __Pyx_PyObject_AsString(PyObject*);
static CYTHON_INLINE const char* __Pyx_PyObject_AsStringAndSize(PyObject*, Py_ssize_t* length);
#define __Pyx_PyByteArray_FromString(s) PyByteArray_FromStringAndSize((const char*)s, strlen((const char*)s))
#define __Pyx_PyByteArray_FromStringAndSize(s, l) PyByteArray_FromStringAndSize((const char*)s, l)
#define __Pyx_PyBytes_FromString        PyBytes_FromString
#define __Pyx_PyBytes_FromStringAndSize PyBytes_FromStringAndSize
static CYTHON_INLINE PyObject* __Pyx_PyUnicode_FromString(const char*);
#if PY_MAJOR_VERSION < 3
    #define __Pyx_PyStr_FromString        __Pyx_PyBytes_FromString
    #define __Pyx_PyStr_FromStringAndSize __Pyx_PyBytes_FromStringAndSize
#else
    #define __Pyx_PyStr_FromString        __Pyx_PyUnicode_FromString
    #define __Pyx_PyStr_FromStringAndSize __Pyx_PyUnicode_FromStringAndSize
#endif
#define __Pyx_PyBytes_AsWritableString(s)     ((char*) PyBytes_AS_STRING(s))
#define __Pyx_PyBytes_AsWritableSString(s)    ((signed char*) PyBytes_AS_STRING(s))
#define __Pyx_PyBytes_AsWritableUString(s)    ((unsigned char*) PyBytes_AS_STRING(s))
#define __Pyx_PyBytes_AsString(s)     ((const char*) PyBytes_AS_STRING(s))
#define __Pyx_PyBytes_AsSString(s)    ((const signed char*) PyBytes_AS_STRING(s))
#define __Pyx_PyBytes_AsUString(s)    ((const unsigned char*) PyBytes_AS_STRING(s))
#define __Pyx_PyObject_AsWritableString(s)    ((char*) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsWritableSString(s)    ((signed char*) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsWritableUString(s)    ((unsigned char*) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsSString(s)    ((const signed char*) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsUString(s)    ((const unsigned char*) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_FromCString(s)  __Pyx_PyObject_FromString((const char*)s)
#define __Pyx_PyBytes_FromCString(s)   __Pyx_PyBytes_FromString((const char*)s)
#define __Pyx_PyByteArray_FromCString(s)   __Pyx_PyByteArray_FromString((const char*)s)
#define __Pyx_PyStr_FromCString(s)     __Pyx_PyStr_FromString((const char*)s)
#define __Pyx_PyUnicode_FromCString(s) __Pyx_PyUnicode_FromString((const char*)s)
static CYTHON_INLINE size_t __Pyx_Py_UNICODE_strlen(const Py_UNICODE *u) {
    const Py_UNICODE *u_end = u;
    while (*u_end++) ;
    return (size_t)(u_end - u - 1);
}
#define __Pyx_PyUnicode_FromUnicode(u)       PyUnicode_FromUnicode(u, __Pyx_Py_UNICODE_strlen(u))
#define __Pyx_PyUnicode_FromUnicodeAndLength PyUnicode_FromUnicode
#define __Pyx_PyUnicode_AsUnicode            PyUnicode_AsUnicode
#define __Pyx_NewRef(obj) (Py_INCREF(obj), obj)
#define __Pyx_Owned_Py_None(b) __Pyx_NewRef(Py_None)
static CYTHON_INLINE PyObject * __Pyx_PyBool_FromLong(long b);
static CYTHON_INLINE int __Pyx_PyObject_IsTrue(PyObject*);
static CYTHON_INLINE int __Pyx_PyObject_IsTrueAndDecref(PyObject*);
static CYTHON_INLINE PyObject* __Pyx_PyNumber_IntOrLong(PyObject* x);
#define __Pyx_PySequence_Tuple(obj)\
    (likely(PyTuple_CheckExact(obj)) ? __Pyx_NewRef(obj) : PySequence_Tuple(obj))
static CYTHON_INLINE Py_ssize_t __Pyx_PyIndex_AsSsize_t(PyObject*);
static CYTHON_INLINE PyObject * __Pyx_PyInt_FromSize_t(size_t);
static CYTHON_INLINE Py_hash_t __Pyx_PyIndex_AsHash_t(PyObject*);
#if CYTHON_ASSUME_SAFE_MACROS
#define __pyx_PyFloat_AsDouble(x) (PyFloat_CheckExact(x) ? PyFloat_AS_DOUBLE(x) : PyFloat_AsDouble(x))
#else
#define __pyx_PyFloat_AsDouble(x) PyFloat_AsDouble(x)
#endif
#define __pyx_PyFloat_AsFloat(x) ((float) __pyx_PyFloat_AsDouble(x))
#if PY_MAJOR_VERSION >= 3
#define __Pyx_PyNumber_Int(x) (PyLong_CheckExact(x) ? __Pyx_NewRef(x) : PyNumber_Long(x))
#else
#define __Pyx_PyNumber_Int(x) (PyInt_CheckExact(x) ? __Pyx_NewRef(x) : PyNumber_Int(x))
#endif
#define __Pyx_PyNumber_Float(x) (PyFloat_CheckExact(x) ? __Pyx_NewRef(x) : PyNumber_Float(x))
#if PY_MAJOR_VERSION < 3 && __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
static int __Pyx_sys_getdefaultencoding_not_ascii;
static int __Pyx_init_sys_getdefaultencoding_params(void) {
    PyObject* sys;
    PyObject* default_encoding = NULL;
    PyObject* ascii_chars_u = NULL;
    PyObject* ascii_chars_b = NULL;
    const char* default_encoding_c;
    sys = PyImport_ImportModule("sys");
    if (!sys) goto bad;
    default_encoding = PyObject_CallMethod(sys, (char*) "getdefaultencoding", NULL);
    Py_DECREF(sys);
    if (!default_encoding) goto bad;
    default_encoding_c = PyBytes_AsString(default_encoding);
    if (!default_encoding_c) goto bad;
    if (strcmp(default_encoding_c, "ascii") == 0) {
        __Pyx_sys_getdefaultencoding_not_ascii = 0;
    } else {
        char ascii_chars[128];
        int c;
        for (c = 0; c < 128; c++) {
            ascii_chars[c] = c;
        }
        __Pyx_sys_getdefaultencoding_not_ascii = 1;
        ascii_chars_u = PyUnicode_DecodeASCII(ascii_chars, 128, NULL);
        if (!ascii_chars_u) goto bad;
        ascii_chars_b = PyUnicode_AsEncodedString(ascii_chars_u, default_encoding_c, NULL);
        if (!ascii_chars_b || !PyBytes_Check(ascii_chars_b) || memcmp(ascii_chars, PyBytes_AS_STRING(ascii_chars_b), 128) != 0) {
            PyErr_Format(
                PyExc_ValueError,
                "This module compiled with c_string_encoding=ascii, but default encoding '%.200s' is not a superset of ascii.",
                default_encoding_c);
            goto bad;
        }
        Py_DECREF(ascii_chars_u);
        Py_DECREF(ascii_chars_b);
    }
    Py_DECREF(default_encoding);
    return 0;
bad:
    Py_XDECREF(default_encoding);
    Py_XDECREF(ascii_chars_u);
    Py_XDECREF(ascii_chars_b);
    return -1;
}
#endif
#if __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT && PY_MAJOR_VERSION >= 3
#define __Pyx_PyUnicode_FromStringAndSize(c_str, size) PyUnicode_DecodeUTF8(c_str, size, NULL)
#else
#define __Pyx_PyUnicode_FromStringAndSize(c_str, size) PyUnicode_Decode(c_str, size, __PYX_DEFAULT_STRING_ENCODING, NULL)
#if __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT
static char* __PYX_DEFAULT_STRING_ENCODING;
static int __Pyx_init_sys_getdefaultencoding_params(void) {
    PyObject* sys;
    PyObject* default_encoding = NULL;
    char* default_encoding_c;
    sys = PyImport_ImportModule("sys");
    if (!sys) goto bad;
    default_encoding = PyObject_CallMethod(sys, (char*) (const char*) "getdefaultencoding", NULL);
    Py_DECREF(sys);
    if (!default_encoding) goto bad;
    default_encoding_c = PyBytes_AsString(default_encoding);
    if (!default_encoding_c) goto bad;
    __PYX_DEFAULT_STRING_ENCODING = (char*) malloc(strlen(default_encoding_c) + 1);
    if (!__PYX_DEFAULT_STRING_ENCODING) goto bad;
    strcpy(__PYX_DEFAULT_STRING_ENCODING, default_encoding_c);
    Py_DECREF(default_encoding);
    return 0;
bad:
    Py_XDECREF(default_encoding);
    return -1;
}
#endif
#endif


/* Test for GCC > 2.95 */
#if defined(__GNUC__)     && (__GNUC__ > 2 || (__GNUC__ == 2 && (__GNUC_MINOR__ > 95)))
  #define likely(x)   __builtin_expect(!!(x), 1)
  #define unlikely(x) __builtin_expect(!!(x), 0)
#else /* !__GNUC__ or GCC < 2.95 */
  #define likely(x)   (x)
  #define unlikely(x) (x)
#endif /* __GNUC__ */
static CYTHON_INLINE void __Pyx_pretend_to_initialize(void* ptr) { (void)ptr; }

static PyObject *__pyx_m = NULL;
static PyObject *__pyx_d;
static PyObject *__pyx_b;
static PyObject *__pyx_cython_runtime = NULL;
static PyObject *__pyx_empty_tuple;
static PyObject *__pyx_empty_bytes;
static PyObject *__pyx_empty_unicode;
static int __pyx_lineno;
static int __pyx_clineno = 0;
static const char * __pyx_cfilenm= __FILE__;
static const char *__pyx_filename;


static const char *__pyx_f[] = {
  "stringsource",
  "ttygif/tty/theme.pyx",
  "array.pxd",
  "type.pxd",
  "bool.pxd",
  "complex.pxd",
  "ttygif/tty/image.pxd",
};

/*--- Type declarations ---*/
#ifndef _ARRAYARRAY_H
struct arrayobject;
typedef struct arrayobject arrayobject;
#endif
struct __pyx_obj_6ttygif_3tty_5image_bounds;
struct __pyx_obj_6ttygif_3tty_5image_point;
struct __pyx_obj_6ttygif_3tty_5image_rect;
struct __pyx_obj_6ttygif_3tty_5image_image;
struct __pyx_obj_6ttygif_3tty_5theme_layer;
struct __pyx_obj_6ttygif_3tty_5theme_theme;

/* "image.pxd":10
 * 
 * # sets bounding paramaters for image transformations
 * cdef class bounds:             # <<<<<<<<<<<<<<
 *     cdef public int width
 *     cdef public int height
 */
struct __pyx_obj_6ttygif_3tty_5image_bounds {
  PyObject_HEAD
  struct __pyx_vtabstruct_6ttygif_3tty_5image_bounds *__pyx_vtab;
  int width;
  int height;
  int stride;
  int length;
  int bytes_per_pixel;
};


/* "image.pxd":18
 *     cdef debug(self)
 * 
 * cdef class point:             # <<<<<<<<<<<<<<
 *     cdef int left
 *     cdef int top
 */
struct __pyx_obj_6ttygif_3tty_5image_point {
  PyObject_HEAD
  struct __pyx_vtabstruct_6ttygif_3tty_5image_point *__pyx_vtab;
  int left;
  int top;
};


/* "image.pxd":24
 * 
 * 
 * cdef class rect:             # <<<<<<<<<<<<<<
 *     cdef int left
 *     cdef int top
 */
struct __pyx_obj_6ttygif_3tty_5image_rect {
  PyObject_HEAD
  struct __pyx_vtabstruct_6ttygif_3tty_5image_rect *__pyx_vtab;
  int left;
  int top;
  int right;
  int bottom;
  int width;
  int height;
};


/* "image.pxd":40
 *     cdef debug(self)
 * 
 * cdef class image:             # <<<<<<<<<<<<<<
 *     cdef int         transparent
 *     cdef array.array data
 */
struct __pyx_obj_6ttygif_3tty_5image_image {
  PyObject_HEAD
  struct __pyx_vtabstruct_6ttygif_3tty_5image_image *__pyx_vtab;
  int transparent;
  arrayobject *data;
  struct __pyx_obj_6ttygif_3tty_5image_bounds *dimentions;
  arrayobject *palette;
  int length;
};


/* "ttygif/tty/theme.pxd":9
 * 
 * 
 * cdef class layer:             # <<<<<<<<<<<<<<
 *     cdef int16_t     z_index
 *     cdef str         file
 */
struct __pyx_obj_6ttygif_3tty_5theme_layer {
  PyObject_HEAD
  struct __pyx_vtabstruct_6ttygif_3tty_5theme_layer *__pyx_vtab;
  int16_t z_index;
  PyObject *file;
  PyObject *path;
  PyObject *mode;
  PyObject *name;
  struct __pyx_obj_6ttygif_3tty_5image_rect *outer;
  struct __pyx_obj_6ttygif_3tty_5image_rect *inner;
  struct __pyx_obj_6ttygif_3tty_5image_rect *bounds;
  struct __pyx_obj_6ttygif_3tty_5image_rect *dst;
  PyObject *center;
  PyObject *copy_mode;
  int16_t transparent;
  struct __pyx_obj_6ttygif_3tty_5image_image *image;
};


/* "ttygif/tty/theme.pxd":30
 * 
 * 
 * cdef class theme:             # <<<<<<<<<<<<<<
 *     cdef str         name
 *     cdef int16_t    title_x
 */
struct __pyx_obj_6ttygif_3tty_5theme_theme {
  PyObject_HEAD
  struct __pyx_vtabstruct_6ttygif_3tty_5theme_theme *__pyx_vtab;
  PyObject *name;
  int16_t title_x;
  int16_t title_y;
  int16_t title_foreground;
  int16_t title_background;
  int16_t title_font;
  float title_font_size;
  PyObject *path;
  PyObject *font;
  int16_t width;
  int16_t height;
  int16_t background;
  int16_t foreground;
  int16_t default_background;
  int16_t default_foreground;
  int16_t transparent;
  int16_t colors;
  arrayobject *palette;
  struct __pyx_obj_6ttygif_3tty_5image_rect *padding;
  struct __pyx_obj_6ttygif_3tty_5theme_layer *layer1;
  struct __pyx_obj_6ttygif_3tty_5theme_layer *layer2;
  struct __pyx_obj_6ttygif_3tty_5theme_layer *layer3;
  struct __pyx_obj_6ttygif_3tty_5theme_layer *layer4;
  struct __pyx_obj_6ttygif_3tty_5theme_layer *layer5;
};



/* "image.pxd":10
 * 
 * # sets bounding paramaters for image transformations
 * cdef class bounds:             # <<<<<<<<<<<<<<
 *     cdef public int width
 *     cdef public int height
 */

struct __pyx_vtabstruct_6ttygif_3tty_5image_bounds {
  PyObject *(*debug)(struct __pyx_obj_6ttygif_3tty_5image_bounds *);
};
static struct __pyx_vtabstruct_6ttygif_3tty_5image_bounds *__pyx_vtabptr_6ttygif_3tty_5image_bounds;


/* "image.pxd":18
 *     cdef debug(self)
 * 
 * cdef class point:             # <<<<<<<<<<<<<<
 *     cdef int left
 *     cdef int top
 */

struct __pyx_vtabstruct_6ttygif_3tty_5image_point {
  PyObject *(*debug)(struct __pyx_obj_6ttygif_3tty_5image_point *);
};
static struct __pyx_vtabstruct_6ttygif_3tty_5image_point *__pyx_vtabptr_6ttygif_3tty_5image_point;


/* "image.pxd":24
 * 
 * 
 * cdef class rect:             # <<<<<<<<<<<<<<
 *     cdef int left
 *     cdef int top
 */

struct __pyx_vtabstruct_6ttygif_3tty_5image_rect {
  PyObject *(*update)(struct __pyx_obj_6ttygif_3tty_5image_rect *);
  PyObject *(*percent_x)(struct __pyx_obj_6ttygif_3tty_5image_rect *, float);
  PyObject *(*percent_y)(struct __pyx_obj_6ttygif_3tty_5image_rect *, float);
  PyObject *(*get_x_percent)(struct __pyx_obj_6ttygif_3tty_5image_rect *, float);
  PyObject *(*get_y_percent)(struct __pyx_obj_6ttygif_3tty_5image_rect *, float);
  PyObject *(*point1)(struct __pyx_obj_6ttygif_3tty_5image_rect *);
  PyObject *(*point2)(struct __pyx_obj_6ttygif_3tty_5image_rect *);
  PyObject *(*debug)(struct __pyx_obj_6ttygif_3tty_5image_rect *);
};
static struct __pyx_vtabstruct_6ttygif_3tty_5image_rect *__pyx_vtabptr_6ttygif_3tty_5image_rect;


/* "image.pxd":40
 *     cdef debug(self)
 * 
 * cdef class image:             # <<<<<<<<<<<<<<
 *     cdef int         transparent
 *     cdef array.array data
 */

struct __pyx_vtabstruct_6ttygif_3tty_5image_image {
  struct __pyx_obj_6ttygif_3tty_5image_rect *(*get_rect)(struct __pyx_obj_6ttygif_3tty_5image_image *);
  arrayobject *(*create_buffer)(struct __pyx_obj_6ttygif_3tty_5image_image *, PyObject *, PyObject *);
  uint32_t (*get_position)(struct __pyx_obj_6ttygif_3tty_5image_image *, int, int);
  PyObject *(*get_pixel)(struct __pyx_obj_6ttygif_3tty_5image_image *, int, int);
  uint8_t (*get_pixel_1byte)(struct __pyx_obj_6ttygif_3tty_5image_image *, int, int);
  void (*get_pixel_3byte)(struct __pyx_obj_6ttygif_3tty_5image_image *, int, int, uint8_t *);
  void (*put_pixel)(struct __pyx_obj_6ttygif_3tty_5image_image *, int, int, PyObject *);
  void (*put_pixel_1byte)(struct __pyx_obj_6ttygif_3tty_5image_image *, uint16_t, uint16_t, uint8_t);
  void (*put_pixel_3byte)(struct __pyx_obj_6ttygif_3tty_5image_image *, int, int, uint8_t *);
  PyObject *(*put_pixel_rgb)(struct __pyx_obj_6ttygif_3tty_5image_image *, int, int, int, int, int);
  PyObject *(*clear)(struct __pyx_obj_6ttygif_3tty_5image_image *, uint8_t *);
  PyObject *(*remap_image)(struct __pyx_obj_6ttygif_3tty_5image_image *, arrayobject *, int16_t);
  PyObject *(*match_color_index)(struct __pyx_obj_6ttygif_3tty_5image_image *, int, int, int);
  PyObject *(*copy)(struct __pyx_obj_6ttygif_3tty_5image_image *, struct __pyx_obj_6ttygif_3tty_5image_image *, struct __pyx_obj_6ttygif_3tty_5image_rect *, struct __pyx_obj_6ttygif_3tty_5image_rect *, int16_t);
  PyObject *(*copy_remap)(struct __pyx_obj_6ttygif_3tty_5image_image *, struct __pyx_obj_6ttygif_3tty_5image_image *, struct __pyx_obj_6ttygif_3tty_5image_rect *, struct __pyx_obj_6ttygif_3tty_5image_point *, int16_t);
  PyObject *(*copy_scale)(struct __pyx_obj_6ttygif_3tty_5image_image *, struct __pyx_obj_6ttygif_3tty_5image_image *, struct __pyx_obj_6ttygif_3tty_5image_rect *, struct __pyx_obj_6ttygif_3tty_5image_rect *, int16_t);
  PyObject *(*copy_tile)(struct __pyx_obj_6ttygif_3tty_5image_image *, struct __pyx_obj_6ttygif_3tty_5image_image *, struct __pyx_obj_6ttygif_3tty_5image_rect *, struct __pyx_obj_6ttygif_3tty_5image_rect *, int16_t);
  PyObject *(*copy_9slice)(struct __pyx_obj_6ttygif_3tty_5image_image *, struct __pyx_obj_6ttygif_3tty_5image_image *, struct __pyx_obj_6ttygif_3tty_5image_rect *, struct __pyx_obj_6ttygif_3tty_5image_rect *, struct __pyx_obj_6ttygif_3tty_5image_rect *, int16_t, PyObject *);
  PyObject *(*copy_3slice)(struct __pyx_obj_6ttygif_3tty_5image_image *, struct __pyx_obj_6ttygif_3tty_5image_image *, struct __pyx_obj_6ttygif_3tty_5image_rect *, struct __pyx_obj_6ttygif_3tty_5image_rect *, struct __pyx_obj_6ttygif_3tty_5image_rect *, int16_t, PyObject *);
  PyObject *(*debug)(struct __pyx_obj_6ttygif_3tty_5image_image *);
};
static struct __pyx_vtabstruct_6ttygif_3tty_5image_image *__pyx_vtabptr_6ttygif_3tty_5image_image;


/* "ttygif/tty/theme.pyx":18
 * 
 * 
 * cdef class layer:             # <<<<<<<<<<<<<<
 *     def __cinit__(self):
 *         self.z_index=0
 */

struct __pyx_vtabstruct_6ttygif_3tty_5theme_layer {
  PyObject *(*debug)(struct __pyx_obj_6ttygif_3tty_5theme_layer *);
  PyObject *(*load_file)(struct __pyx_obj_6ttygif_3tty_5theme_layer *, arrayobject *);
};
static struct __pyx_vtabstruct_6ttygif_3tty_5theme_layer *__pyx_vtabptr_6ttygif_3tty_5theme_layer;


/* "ttygif/tty/theme.pyx":100
 * 
 * 
 * cdef class theme:             # <<<<<<<<<<<<<<
 * 
 *     def __cinit__(self,name,width,height):
 */

struct __pyx_vtabstruct_6ttygif_3tty_5theme_theme {
  PyObject *(*init)(struct __pyx_obj_6ttygif_3tty_5theme_theme *);
  PyObject *(*update_layer)(struct __pyx_obj_6ttygif_3tty_5theme_theme *, struct __pyx_obj_6ttygif_3tty_5theme_layer *);
  PyObject *(*__pyx_auto)(struct __pyx_obj_6ttygif_3tty_5theme_theme *);
};
static struct __pyx_vtabstruct_6ttygif_3tty_5theme_theme *__pyx_vtabptr_6ttygif_3tty_5theme_theme;

/* --- Runtime support code (head) --- */
/* Refnanny.proto */
#ifndef CYTHON_REFNANNY
  #define CYTHON_REFNANNY 0
#endif
#if CYTHON_REFNANNY
  typedef struct {
    void (*INCREF)(void*, PyObject*, int);
    void (*DECREF)(void*, PyObject*, int);
    void (*GOTREF)(void*, PyObject*, int);
    void (*GIVEREF)(void*, PyObject*, int);
    void* (*SetupContext)(const char*, int, const char*);
    void (*FinishContext)(void**);
  } __Pyx_RefNannyAPIStruct;
  static __Pyx_RefNannyAPIStruct *__Pyx_RefNanny = NULL;
  static __Pyx_RefNannyAPIStruct *__Pyx_RefNannyImportAPI(const char *modname);
  #define __Pyx_RefNannyDeclarations void *__pyx_refnanny = NULL;
#ifdef WITH_THREAD
  #define __Pyx_RefNannySetupContext(name, acquire_gil)\
          if (acquire_gil) {\
              PyGILState_STATE __pyx_gilstate_save = PyGILState_Ensure();\
              __pyx_refnanny = __Pyx_RefNanny->SetupContext((name), __LINE__, __FILE__);\
              PyGILState_Release(__pyx_gilstate_save);\
          } else {\
              __pyx_refnanny = __Pyx_RefNanny->SetupContext((name), __LINE__, __FILE__);\
          }
#else
  #define __Pyx_RefNannySetupContext(name, acquire_gil)\
          __pyx_refnanny = __Pyx_RefNanny->SetupContext((name), __LINE__, __FILE__)
#endif
  #define __Pyx_RefNannyFinishContext()\
          __Pyx_RefNanny->FinishContext(&__pyx_refnanny)
  #define __Pyx_INCREF(r)  __Pyx_RefNanny->INCREF(__pyx_refnanny, (PyObject *)(r), __LINE__)
  #define __Pyx_DECREF(r)  __Pyx_RefNanny->DECREF(__pyx_refnanny, (PyObject *)(r), __LINE__)
  #define __Pyx_GOTREF(r)  __Pyx_RefNanny->GOTREF(__pyx_refnanny, (PyObject *)(r), __LINE__)
  #define __Pyx_GIVEREF(r) __Pyx_RefNanny->GIVEREF(__pyx_refnanny, (PyObject *)(r), __LINE__)
  #define __Pyx_XINCREF(r)  do { if((r) != NULL) {__Pyx_INCREF(r); }} while(0)
  #define __Pyx_XDECREF(r)  do { if((r) != NULL) {__Pyx_DECREF(r); }} while(0)
  #define __Pyx_XGOTREF(r)  do { if((r) != NULL) {__Pyx_GOTREF(r); }} while(0)
  #define __Pyx_XGIVEREF(r) do { if((r) != NULL) {__Pyx_GIVEREF(r);}} while(0)
#else
  #define __Pyx_RefNannyDeclarations
  #define __Pyx_RefNannySetupContext(name, acquire_gil)
  #define __Pyx_RefNannyFinishContext()
  #define __Pyx_INCREF(r) Py_INCREF(r)
  #define __Pyx_DECREF(r) Py_DECREF(r)
  #define __Pyx_GOTREF(r)
  #define __Pyx_GIVEREF(r)
  #define __Pyx_XINCREF(r) Py_XINCREF(r)
  #define __Pyx_XDECREF(r) Py_XDECREF(r)
  #define __Pyx_XGOTREF(r)
  #define __Pyx_XGIVEREF(r)
#endif
#define __Pyx_XDECREF_SET(r, v) do {\
        PyObject *tmp = (PyObject *) r;\
        r = v; __Pyx_XDECREF(tmp);\
    } while (0)
#define __Pyx_DECREF_SET(r, v) do {\
        PyObject *tmp = (PyObject *) r;\
        r = v; __Pyx_DECREF(tmp);\
    } while (0)
#define __Pyx_CLEAR(r)    do { PyObject* tmp = ((PyObject*)(r)); r = NULL; __Pyx_DECREF(tmp);} while(0)
#define __Pyx_XCLEAR(r)   do { if((r) != NULL) {PyObject* tmp = ((PyObject*)(r)); r = NULL; __Pyx_DECREF(tmp);}} while(0)

/* PyObjectGetAttrStr.proto */
#if CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetAttrStr(PyObject* obj, PyObject* attr_name);
#else
#define __Pyx_PyObject_GetAttrStr(o,n) PyObject_GetAttr(o,n)
#endif

/* GetBuiltinName.proto */
static PyObject *__Pyx_GetBuiltinName(PyObject *name);

/* RaiseArgTupleInvalid.proto */
static void __Pyx_RaiseArgtupleInvalid(const char* func_name, int exact,
    Py_ssize_t num_min, Py_ssize_t num_max, Py_ssize_t num_found);

/* KeywordStringCheck.proto */
static int __Pyx_CheckKeywordStrings(PyObject *kwdict, const char* function_name, int kw_allowed);

/* PyThreadStateGet.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_PyThreadState_declare  PyThreadState *__pyx_tstate;
#define __Pyx_PyThreadState_assign  __pyx_tstate = __Pyx_PyThreadState_Current;
#define __Pyx_PyErr_Occurred()  __pyx_tstate->curexc_type
#else
#define __Pyx_PyThreadState_declare
#define __Pyx_PyThreadState_assign
#define __Pyx_PyErr_Occurred()  PyErr_Occurred()
#endif

/* PyErrFetchRestore.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_PyErr_Clear() __Pyx_ErrRestore(NULL, NULL, NULL)
#define __Pyx_ErrRestoreWithState(type, value, tb)  __Pyx_ErrRestoreInState(PyThreadState_GET(), type, value, tb)
#define __Pyx_ErrFetchWithState(type, value, tb)    __Pyx_ErrFetchInState(PyThreadState_GET(), type, value, tb)
#define __Pyx_ErrRestore(type, value, tb)  __Pyx_ErrRestoreInState(__pyx_tstate, type, value, tb)
#define __Pyx_ErrFetch(type, value, tb)    __Pyx_ErrFetchInState(__pyx_tstate, type, value, tb)
static CYTHON_INLINE void __Pyx_ErrRestoreInState(PyThreadState *tstate, PyObject *type, PyObject *value, PyObject *tb);
static CYTHON_INLINE void __Pyx_ErrFetchInState(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb);
#if CYTHON_COMPILING_IN_CPYTHON
#define __Pyx_PyErr_SetNone(exc) (Py_INCREF(exc), __Pyx_ErrRestore((exc), NULL, NULL))
#else
#define __Pyx_PyErr_SetNone(exc) PyErr_SetNone(exc)
#endif
#else
#define __Pyx_PyErr_Clear() PyErr_Clear()
#define __Pyx_PyErr_SetNone(exc) PyErr_SetNone(exc)
#define __Pyx_ErrRestoreWithState(type, value, tb)  PyErr_Restore(type, value, tb)
#define __Pyx_ErrFetchWithState(type, value, tb)  PyErr_Fetch(type, value, tb)
#define __Pyx_ErrRestoreInState(tstate, type, value, tb)  PyErr_Restore(type, value, tb)
#define __Pyx_ErrFetchInState(tstate, type, value, tb)  PyErr_Fetch(type, value, tb)
#define __Pyx_ErrRestore(type, value, tb)  PyErr_Restore(type, value, tb)
#define __Pyx_ErrFetch(type, value, tb)  PyErr_Fetch(type, value, tb)
#endif

/* Profile.proto */
#ifndef CYTHON_PROFILE
#if CYTHON_COMPILING_IN_PYPY || CYTHON_COMPILING_IN_PYSTON
  #define CYTHON_PROFILE 0
#else
  #define CYTHON_PROFILE 1
#endif
#endif
#ifndef CYTHON_TRACE_NOGIL
  #define CYTHON_TRACE_NOGIL 0
#else
  #if CYTHON_TRACE_NOGIL && !defined(CYTHON_TRACE)
    #define CYTHON_TRACE 1
  #endif
#endif
#ifndef CYTHON_TRACE
  #define CYTHON_TRACE 0
#endif
#if CYTHON_TRACE
  #undef CYTHON_PROFILE_REUSE_FRAME
#endif
#ifndef CYTHON_PROFILE_REUSE_FRAME
  #define CYTHON_PROFILE_REUSE_FRAME 0
#endif
#if CYTHON_PROFILE || CYTHON_TRACE
  #include "compile.h"
  #include "frameobject.h"
  #include "traceback.h"
#if PY_VERSION_HEX >= 0x030b00a6
  #ifndef Py_BUILD_CORE
    #define Py_BUILD_CORE 1
  #endif
  #include "internal/pycore_frame.h"
#endif
  #if CYTHON_PROFILE_REUSE_FRAME
    #define CYTHON_FRAME_MODIFIER static
    #define CYTHON_FRAME_DEL(frame)
  #else
    #define CYTHON_FRAME_MODIFIER
    #define CYTHON_FRAME_DEL(frame) Py_CLEAR(frame)
  #endif
  #define __Pyx_TraceDeclarations\
      static PyCodeObject *__pyx_frame_code = NULL;\
      CYTHON_FRAME_MODIFIER PyFrameObject *__pyx_frame = NULL;\
      int __Pyx_use_tracing = 0;
  #define __Pyx_TraceFrameInit(codeobj)\
      if (codeobj) __pyx_frame_code = (PyCodeObject*) codeobj;
#if PY_VERSION_HEX >= 0x030b00a2
  #define __Pyx_IsTracing(tstate, check_tracing, check_funcs)\
     (unlikely((tstate)->cframe->use_tracing) &&\
         (!(check_tracing) || !(tstate)->tracing) &&\
         (!(check_funcs) || (tstate)->c_profilefunc || (CYTHON_TRACE && (tstate)->c_tracefunc)))
  #define __Pyx_EnterTracing(tstate) PyThreadState_EnterTracing(tstate)
  #define __Pyx_LeaveTracing(tstate) PyThreadState_LeaveTracing(tstate)
#elif PY_VERSION_HEX >= 0x030a00b1
  #define __Pyx_IsTracing(tstate, check_tracing, check_funcs)\
     (unlikely((tstate)->cframe->use_tracing) &&\
         (!(check_tracing) || !(tstate)->tracing) &&\
         (!(check_funcs) || (tstate)->c_profilefunc || (CYTHON_TRACE && (tstate)->c_tracefunc)))
  #define __Pyx_EnterTracing(tstate)\
      do { tstate->tracing++; tstate->cframe->use_tracing = 0; } while (0)
  #define __Pyx_LeaveTracing(tstate)\
      do {\
          tstate->tracing--;\
          tstate->cframe->use_tracing = ((CYTHON_TRACE && tstate->c_tracefunc != NULL)\
                                 || tstate->c_profilefunc != NULL);\
      } while (0)
#else
  #define __Pyx_IsTracing(tstate, check_tracing, check_funcs)\
     (unlikely((tstate)->use_tracing) &&\
         (!(check_tracing) || !(tstate)->tracing) &&\
         (!(check_funcs) || (tstate)->c_profilefunc || (CYTHON_TRACE && (tstate)->c_tracefunc)))
  #define __Pyx_EnterTracing(tstate)\
      do { tstate->tracing++; tstate->use_tracing = 0; } while (0)
  #define __Pyx_LeaveTracing(tstate)\
      do {\
          tstate->tracing--;\
          tstate->use_tracing = ((CYTHON_TRACE && tstate->c_tracefunc != NULL)\
                                         || tstate->c_profilefunc != NULL);\
      } while (0)
#endif
  #ifdef WITH_THREAD
  #define __Pyx_TraceCall(funcname, srcfile, firstlineno, nogil, goto_error)\
  if (nogil) {\
      if (CYTHON_TRACE_NOGIL) {\
          PyThreadState *tstate;\
          PyGILState_STATE state = PyGILState_Ensure();\
          tstate = __Pyx_PyThreadState_Current;\
          if (__Pyx_IsTracing(tstate, 1, 1)) {\
              __Pyx_use_tracing = __Pyx_TraceSetupAndCall(&__pyx_frame_code, &__pyx_frame, tstate, funcname, srcfile, firstlineno);\
          }\
          PyGILState_Release(state);\
          if (unlikely(__Pyx_use_tracing < 0)) goto_error;\
      }\
  } else {\
      PyThreadState* tstate = PyThreadState_GET();\
      if (__Pyx_IsTracing(tstate, 1, 1)) {\
          __Pyx_use_tracing = __Pyx_TraceSetupAndCall(&__pyx_frame_code, &__pyx_frame, tstate, funcname, srcfile, firstlineno);\
          if (unlikely(__Pyx_use_tracing < 0)) goto_error;\
      }\
  }
  #else
  #define __Pyx_TraceCall(funcname, srcfile, firstlineno, nogil, goto_error)\
  {   PyThreadState* tstate = PyThreadState_GET();\
      if (__Pyx_IsTracing(tstate, 1, 1)) {\
          __Pyx_use_tracing = __Pyx_TraceSetupAndCall(&__pyx_frame_code, &__pyx_frame, tstate, funcname, srcfile, firstlineno);\
          if (unlikely(__Pyx_use_tracing < 0)) goto_error;\
      }\
  }
  #endif
  #define __Pyx_TraceException()\
  if (likely(!__Pyx_use_tracing)); else {\
      PyThreadState* tstate = __Pyx_PyThreadState_Current;\
      if (__Pyx_IsTracing(tstate, 0, 1)) {\
          __Pyx_EnterTracing(tstate);\
          PyObject *exc_info = __Pyx_GetExceptionTuple(tstate);\
          if (exc_info) {\
              if (CYTHON_TRACE && tstate->c_tracefunc)\
                  tstate->c_tracefunc(\
                      tstate->c_traceobj, __pyx_frame, PyTrace_EXCEPTION, exc_info);\
              tstate->c_profilefunc(\
                  tstate->c_profileobj, __pyx_frame, PyTrace_EXCEPTION, exc_info);\
              Py_DECREF(exc_info);\
          }\
          __Pyx_LeaveTracing(tstate);\
      }\
  }
  static void __Pyx_call_return_trace_func(PyThreadState *tstate, PyFrameObject *frame, PyObject *result) {
      PyObject *type, *value, *traceback;
      __Pyx_ErrFetchInState(tstate, &type, &value, &traceback);
      __Pyx_EnterTracing(tstate);
      if (CYTHON_TRACE && tstate->c_tracefunc)
          tstate->c_tracefunc(tstate->c_traceobj, frame, PyTrace_RETURN, result);
      if (tstate->c_profilefunc)
          tstate->c_profilefunc(tstate->c_profileobj, frame, PyTrace_RETURN, result);
      CYTHON_FRAME_DEL(frame);
      __Pyx_LeaveTracing(tstate);
      __Pyx_ErrRestoreInState(tstate, type, value, traceback);
  }
  #ifdef WITH_THREAD
  #define __Pyx_TraceReturn(result, nogil)\
  if (likely(!__Pyx_use_tracing)); else {\
      if (nogil) {\
          if (CYTHON_TRACE_NOGIL) {\
              PyThreadState *tstate;\
              PyGILState_STATE state = PyGILState_Ensure();\
              tstate = __Pyx_PyThreadState_Current;\
              if (__Pyx_IsTracing(tstate, 0, 0)) {\
                  __Pyx_call_return_trace_func(tstate, __pyx_frame, (PyObject*)result);\
              }\
              PyGILState_Release(state);\
          }\
      } else {\
          PyThreadState* tstate = __Pyx_PyThreadState_Current;\
          if (__Pyx_IsTracing(tstate, 0, 0)) {\
              __Pyx_call_return_trace_func(tstate, __pyx_frame, (PyObject*)result);\
          }\
      }\
  }
  #else
  #define __Pyx_TraceReturn(result, nogil)\
  if (likely(!__Pyx_use_tracing)); else {\
      PyThreadState* tstate = __Pyx_PyThreadState_Current;\
      if (__Pyx_IsTracing(tstate, 0, 0)) {\
          __Pyx_call_return_trace_func(tstate, __pyx_frame, (PyObject*)result);\
      }\
  }
  #endif
  static PyCodeObject *__Pyx_createFrameCodeObject(const char *funcname, const char *srcfile, int firstlineno);
  static int __Pyx_TraceSetupAndCall(PyCodeObject** code, PyFrameObject** frame, PyThreadState* tstate, const char *funcname, const char *srcfile, int firstlineno);
#else
  #define __Pyx_TraceDeclarations
  #define __Pyx_TraceFrameInit(codeobj)
  #define __Pyx_TraceCall(funcname, srcfile, firstlineno, nogil, goto_error)   if ((1)); else goto_error;
  #define __Pyx_TraceException()
  #define __Pyx_TraceReturn(result, nogil)
#endif
#if CYTHON_TRACE
  static int __Pyx_call_line_trace_func(PyThreadState *tstate, PyFrameObject *frame, int lineno) {
      int ret;
      PyObject *type, *value, *traceback;
      __Pyx_ErrFetchInState(tstate, &type, &value, &traceback);
      __Pyx_PyFrame_SetLineNumber(frame, lineno);
      __Pyx_EnterTracing(tstate);
      ret = tstate->c_tracefunc(tstate->c_traceobj, frame, PyTrace_LINE, NULL);
      __Pyx_LeaveTracing(tstate);
      if (likely(!ret)) {
          __Pyx_ErrRestoreInState(tstate, type, value, traceback);
      } else {
          Py_XDECREF(type);
          Py_XDECREF(value);
          Py_XDECREF(traceback);
      }
      return ret;
  }
  #ifdef WITH_THREAD
  #define __Pyx_TraceLine(lineno, nogil, goto_error)\
  if (likely(!__Pyx_use_tracing)); else {\
      if (nogil) {\
          if (CYTHON_TRACE_NOGIL) {\
              int ret = 0;\
              PyThreadState *tstate;\
              PyGILState_STATE state = PyGILState_Ensure();\
              tstate = __Pyx_PyThreadState_Current;\
              if (__Pyx_IsTracing(tstate, 0, 0) && tstate->c_tracefunc && __pyx_frame->f_trace) {\
                  ret = __Pyx_call_line_trace_func(tstate, __pyx_frame, lineno);\
              }\
              PyGILState_Release(state);\
              if (unlikely(ret)) goto_error;\
          }\
      } else {\
          PyThreadState* tstate = __Pyx_PyThreadState_Current;\
          if (__Pyx_IsTracing(tstate, 0, 0) && tstate->c_tracefunc && __pyx_frame->f_trace) {\
              int ret = __Pyx_call_line_trace_func(tstate, __pyx_frame, lineno);\
              if (unlikely(ret)) goto_error;\
          }\
      }\
  }
  #else
  #define __Pyx_TraceLine(lineno, nogil, goto_error)\
  if (likely(!__Pyx_use_tracing)); else {\
      PyThreadState* tstate = __Pyx_PyThreadState_Current;\
      if (__Pyx_IsTracing(tstate, 0, 0) && tstate->c_tracefunc && __pyx_frame->f_trace) {\
          int ret = __Pyx_call_line_trace_func(tstate, __pyx_frame, lineno);\
          if (unlikely(ret)) goto_error;\
      }\
  }
  #endif
#else
  #define __Pyx_TraceLine(lineno, nogil, goto_error)   if ((1)); else goto_error;
#endif

/* PyObjectCall.proto */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_Call(PyObject *func, PyObject *arg, PyObject *kw);
#else
#define __Pyx_PyObject_Call(func, arg, kw) PyObject_Call(func, arg, kw)
#endif

/* IncludeStringH.proto */
#include <string.h>

/* PyDictVersioning.proto */
#if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_TYPE_SLOTS
#define __PYX_DICT_VERSION_INIT  ((PY_UINT64_T) -1)
#define __PYX_GET_DICT_VERSION(dict)  (((PyDictObject*)(dict))->ma_version_tag)
#define __PYX_UPDATE_DICT_CACHE(dict, value, cache_var, version_var)\
    (version_var) = __PYX_GET_DICT_VERSION(dict);\
    (cache_var) = (value);
#define __PYX_PY_DICT_LOOKUP_IF_MODIFIED(VAR, DICT, LOOKUP) {\
    static PY_UINT64_T __pyx_dict_version = 0;\
    static PyObject *__pyx_dict_cached_value = NULL;\
    if (likely(__PYX_GET_DICT_VERSION(DICT) == __pyx_dict_version)) {\
        (VAR) = __pyx_dict_cached_value;\
    } else {\
        (VAR) = __pyx_dict_cached_value = (LOOKUP);\
        __pyx_dict_version = __PYX_GET_DICT_VERSION(DICT);\
    }\
}
static CYTHON_INLINE PY_UINT64_T __Pyx_get_tp_dict_version(PyObject *obj);
static CYTHON_INLINE PY_UINT64_T __Pyx_get_object_dict_version(PyObject *obj);
static CYTHON_INLINE int __Pyx_object_dict_version_matches(PyObject* obj, PY_UINT64_T tp_dict_version, PY_UINT64_T obj_dict_version);
#else
#define __PYX_GET_DICT_VERSION(dict)  (0)
#define __PYX_UPDATE_DICT_CACHE(dict, value, cache_var, version_var)
#define __PYX_PY_DICT_LOOKUP_IF_MODIFIED(VAR, DICT, LOOKUP)  (VAR) = (LOOKUP);
#endif

/* GetModuleGlobalName.proto */
#if CYTHON_USE_DICT_VERSIONS
#define __Pyx_GetModuleGlobalName(var, name)  {\
    static PY_UINT64_T __pyx_dict_version = 0;\
    static PyObject *__pyx_dict_cached_value = NULL;\
    (var) = (likely(__pyx_dict_version == __PYX_GET_DICT_VERSION(__pyx_d))) ?\
        (likely(__pyx_dict_cached_value) ? __Pyx_NewRef(__pyx_dict_cached_value) : __Pyx_GetBuiltinName(name)) :\
        __Pyx__GetModuleGlobalName(name, &__pyx_dict_version, &__pyx_dict_cached_value);\
}
#define __Pyx_GetModuleGlobalNameUncached(var, name)  {\
    PY_UINT64_T __pyx_dict_version;\
    PyObject *__pyx_dict_cached_value;\
    (var) = __Pyx__GetModuleGlobalName(name, &__pyx_dict_version, &__pyx_dict_cached_value);\
}
static PyObject *__Pyx__GetModuleGlobalName(PyObject *name, PY_UINT64_T *dict_version, PyObject **dict_cached_value);
#else
#define __Pyx_GetModuleGlobalName(var, name)  (var) = __Pyx__GetModuleGlobalName(name)
#define __Pyx_GetModuleGlobalNameUncached(var, name)  (var) = __Pyx__GetModuleGlobalName(name)
static CYTHON_INLINE PyObject *__Pyx__GetModuleGlobalName(PyObject *name);
#endif

/* PyCFunctionFastCall.proto */
#if CYTHON_FAST_PYCCALL
static CYTHON_INLINE PyObject *__Pyx_PyCFunction_FastCall(PyObject *func, PyObject **args, Py_ssize_t nargs);
#else
#define __Pyx_PyCFunction_FastCall(func, args, nargs)  (assert(0), NULL)
#endif

/* PyFunctionFastCall.proto */
#if CYTHON_FAST_PYCALL
#define __Pyx_PyFunction_FastCall(func, args, nargs)\
    __Pyx_PyFunction_FastCallDict((func), (args), (nargs), NULL)
#if 1 || PY_VERSION_HEX < 0x030600B1
static PyObject *__Pyx_PyFunction_FastCallDict(PyObject *func, PyObject **args, Py_ssize_t nargs, PyObject *kwargs);
#else
#define __Pyx_PyFunction_FastCallDict(func, args, nargs, kwargs) _PyFunction_FastCallDict(func, args, nargs, kwargs)
#endif
#define __Pyx_BUILD_ASSERT_EXPR(cond)\
    (sizeof(char [1 - 2*!(cond)]) - 1)
#ifndef Py_MEMBER_SIZE
#define Py_MEMBER_SIZE(type, member) sizeof(((type *)0)->member)
#endif
#if CYTHON_FAST_PYCALL
  static size_t __pyx_pyframe_localsplus_offset = 0;
  #include "frameobject.h"
#if PY_VERSION_HEX >= 0x030b00a6
  #ifndef Py_BUILD_CORE
    #define Py_BUILD_CORE 1
  #endif
  #include "internal/pycore_frame.h"
#endif
  #define __Pxy_PyFrame_Initialize_Offsets()\
    ((void)__Pyx_BUILD_ASSERT_EXPR(sizeof(PyFrameObject) == offsetof(PyFrameObject, f_localsplus) + Py_MEMBER_SIZE(PyFrameObject, f_localsplus)),\
     (void)(__pyx_pyframe_localsplus_offset = ((size_t)PyFrame_Type.tp_basicsize) - Py_MEMBER_SIZE(PyFrameObject, f_localsplus)))
  #define __Pyx_PyFrame_GetLocalsplus(frame)\
    (assert(__pyx_pyframe_localsplus_offset), (PyObject **)(((char *)(frame)) + __pyx_pyframe_localsplus_offset))
#endif // CYTHON_FAST_PYCALL
#endif

/* PyObjectCall2Args.proto */
static CYTHON_UNUSED PyObject* __Pyx_PyObject_Call2Args(PyObject* function, PyObject* arg1, PyObject* arg2);

/* PyObjectCallMethO.proto */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallMethO(PyObject *func, PyObject *arg);
#endif

/* PyObjectCallOneArg.proto */
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallOneArg(PyObject *func, PyObject *arg);

/* RaiseException.proto */
static void __Pyx_Raise(PyObject *type, PyObject *value, PyObject *tb, PyObject *cause);

/* None.proto */
static CYTHON_INLINE void __Pyx_RaiseUnboundLocalError(const char *varname);

/* PyObjectCallNoArg.proto */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallNoArg(PyObject *func);
#else
#define __Pyx_PyObject_CallNoArg(func) __Pyx_PyObject_Call(func, __pyx_empty_tuple, NULL)
#endif

/* DictGetItem.proto */
#if PY_MAJOR_VERSION >= 3 && !CYTHON_COMPILING_IN_PYPY
static PyObject *__Pyx_PyDict_GetItem(PyObject *d, PyObject* key);
#define __Pyx_PyObject_Dict_GetItem(obj, name)\
    (likely(PyDict_CheckExact(obj)) ?\
     __Pyx_PyDict_GetItem(obj, name) : PyObject_GetItem(obj, name))
#else
#define __Pyx_PyDict_GetItem(d, key) PyObject_GetItem(d, key)
#define __Pyx_PyObject_Dict_GetItem(obj, name)  PyObject_GetItem(obj, name)
#endif

/* PyIntBinop.proto */
#if !CYTHON_COMPILING_IN_PYPY
static PyObject* __Pyx_PyInt_SubtractObjC(PyObject *op1, PyObject *op2, long intval, int inplace, int zerodivision_check);
#else
#define __Pyx_PyInt_SubtractObjC(op1, op2, intval, inplace, zerodivision_check)\
    (inplace ? PyNumber_InPlaceSubtract(op1, op2) : PyNumber_Subtract(op1, op2))
#endif

/* ExtTypeTest.proto */
static CYTHON_INLINE int __Pyx_TypeTest(PyObject *obj, PyTypeObject *type);

/* PyIntCompare.proto */
static CYTHON_INLINE PyObject* __Pyx_PyInt_EqObjC(PyObject *op1, PyObject *op2, long intval, long inplace);

/* RaiseDoubleKeywords.proto */
static void __Pyx_RaiseDoubleKeywordsError(const char* func_name, PyObject* kw_name);

/* ParseKeywords.proto */
static int __Pyx_ParseOptionalKeywords(PyObject *kwds, PyObject **argnames[],\
    PyObject *kwds2, PyObject *values[], Py_ssize_t num_pos_args,\
    const char* function_name);

/* PySequenceContains.proto */
static CYTHON_INLINE int __Pyx_PySequence_ContainsTF(PyObject* item, PyObject* seq, int eq) {
    int result = PySequence_Contains(seq, item);
    return unlikely(result < 0) ? result : (result == (eq == Py_EQ));
}

/* BytesEquals.proto */
static CYTHON_INLINE int __Pyx_PyBytes_Equals(PyObject* s1, PyObject* s2, int equals);

/* UnicodeEquals.proto */
static CYTHON_INLINE int __Pyx_PyUnicode_Equals(PyObject* s1, PyObject* s2, int equals);

/* StrEquals.proto */
#if PY_MAJOR_VERSION >= 3
#define __Pyx_PyString_Equals __Pyx_PyUnicode_Equals
#else
#define __Pyx_PyString_Equals __Pyx_PyBytes_Equals
#endif

/* pyobject_as_double.proto */
static double __Pyx__PyObject_AsDouble(PyObject* obj);
#if CYTHON_COMPILING_IN_PYPY
#define __Pyx_PyObject_AsDouble(obj)\
(likely(PyFloat_CheckExact(obj)) ? PyFloat_AS_DOUBLE(obj) :\
 likely(PyInt_CheckExact(obj)) ?\
 PyFloat_AsDouble(obj) : __Pyx__PyObject_AsDouble(obj))
#else
#define __Pyx_PyObject_AsDouble(obj)\
((likely(PyFloat_CheckExact(obj))) ?\
 PyFloat_AS_DOUBLE(obj) : __Pyx__PyObject_AsDouble(obj))
#endif

/* GetItemInt.proto */
#define __Pyx_GetItemInt(o, i, type, is_signed, to_py_func, is_list, wraparound, boundscheck)\
    (__Pyx_fits_Py_ssize_t(i, type, is_signed) ?\
    __Pyx_GetItemInt_Fast(o, (Py_ssize_t)i, is_list, wraparound, boundscheck) :\
    (is_list ? (PyErr_SetString(PyExc_IndexError, "list index out of range"), (PyObject*)NULL) :\
               __Pyx_GetItemInt_Generic(o, to_py_func(i))))
#define __Pyx_GetItemInt_List(o, i, type, is_signed, to_py_func, is_list, wraparound, boundscheck)\
    (__Pyx_fits_Py_ssize_t(i, type, is_signed) ?\
    __Pyx_GetItemInt_List_Fast(o, (Py_ssize_t)i, wraparound, boundscheck) :\
    (PyErr_SetString(PyExc_IndexError, "list index out of range"), (PyObject*)NULL))
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_List_Fast(PyObject *o, Py_ssize_t i,
                                                              int wraparound, int boundscheck);
#define __Pyx_GetItemInt_Tuple(o, i, type, is_signed, to_py_func, is_list, wraparound, boundscheck)\
    (__Pyx_fits_Py_ssize_t(i, type, is_signed) ?\
    __Pyx_GetItemInt_Tuple_Fast(o, (Py_ssize_t)i, wraparound, boundscheck) :\
    (PyErr_SetString(PyExc_IndexError, "tuple index out of range"), (PyObject*)NULL))
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Tuple_Fast(PyObject *o, Py_ssize_t i,
                                                              int wraparound, int boundscheck);
static PyObject *__Pyx_GetItemInt_Generic(PyObject *o, PyObject* j);
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Fast(PyObject *o, Py_ssize_t i,
                                                     int is_list, int wraparound, int boundscheck);

/* SetItemInt.proto */
#define __Pyx_SetItemInt(o, i, v, type, is_signed, to_py_func, is_list, wraparound, boundscheck)\
    (__Pyx_fits_Py_ssize_t(i, type, is_signed) ?\
    __Pyx_SetItemInt_Fast(o, (Py_ssize_t)i, v, is_list, wraparound, boundscheck) :\
    (is_list ? (PyErr_SetString(PyExc_IndexError, "list assignment index out of range"), -1) :\
               __Pyx_SetItemInt_Generic(o, to_py_func(i), v)))
static int __Pyx_SetItemInt_Generic(PyObject *o, PyObject *j, PyObject *v);
static CYTHON_INLINE int __Pyx_SetItemInt_Fast(PyObject *o, Py_ssize_t i, PyObject *v,
                                               int is_list, int wraparound, int boundscheck);

/* SliceObject.proto */
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetSlice(
        PyObject* obj, Py_ssize_t cstart, Py_ssize_t cstop,
        PyObject** py_start, PyObject** py_stop, PyObject** py_slice,
        int has_cstart, int has_cstop, int wraparound);

/* StringJoin.proto */
#if PY_MAJOR_VERSION < 3
#define __Pyx_PyString_Join __Pyx_PyBytes_Join
#define __Pyx_PyBaseString_Join(s, v) (PyUnicode_CheckExact(s) ? PyUnicode_Join(s, v) : __Pyx_PyBytes_Join(s, v))
#else
#define __Pyx_PyString_Join PyUnicode_Join
#define __Pyx_PyBaseString_Join PyUnicode_Join
#endif
#if CYTHON_COMPILING_IN_CPYTHON
    #if PY_MAJOR_VERSION < 3
    #define __Pyx_PyBytes_Join _PyString_Join
    #else
    #define __Pyx_PyBytes_Join _PyBytes_Join
    #endif
#else
static CYTHON_INLINE PyObject* __Pyx_PyBytes_Join(PyObject* sep, PyObject* values);
#endif

/* WriteUnraisableException.proto */
static void __Pyx_WriteUnraisable(const char *name, int clineno,
                                  int lineno, const char *filename,
                                  int full_traceback, int nogil);

/* PyObject_GenericGetAttrNoDict.proto */
#if CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP && PY_VERSION_HEX < 0x03070000
static CYTHON_INLINE PyObject* __Pyx_PyObject_GenericGetAttrNoDict(PyObject* obj, PyObject* attr_name);
#else
#define __Pyx_PyObject_GenericGetAttrNoDict PyObject_GenericGetAttr
#endif

/* PyObject_GenericGetAttr.proto */
#if CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP && PY_VERSION_HEX < 0x03070000
static PyObject* __Pyx_PyObject_GenericGetAttr(PyObject* obj, PyObject* attr_name);
#else
#define __Pyx_PyObject_GenericGetAttr PyObject_GenericGetAttr
#endif

/* SetVTable.proto */
static int __Pyx_SetVtable(PyObject *dict, void *vtable);

/* PyErrExceptionMatches.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_PyErr_ExceptionMatches(err) __Pyx_PyErr_ExceptionMatchesInState(__pyx_tstate, err)
static CYTHON_INLINE int __Pyx_PyErr_ExceptionMatchesInState(PyThreadState* tstate, PyObject* err);
#else
#define __Pyx_PyErr_ExceptionMatches(err)  PyErr_ExceptionMatches(err)
#endif

/* PyObjectGetAttrStrNoError.proto */
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetAttrStrNoError(PyObject* obj, PyObject* attr_name);

/* SetupReduce.proto */
static int __Pyx_setup_reduce(PyObject* type_obj);

/* TypeImport.proto */
#ifndef __PYX_HAVE_RT_ImportType_proto
#define __PYX_HAVE_RT_ImportType_proto
enum __Pyx_ImportType_CheckSize {
   __Pyx_ImportType_CheckSize_Error = 0,
   __Pyx_ImportType_CheckSize_Warn = 1,
   __Pyx_ImportType_CheckSize_Ignore = 2
};
static PyTypeObject *__Pyx_ImportType(PyObject* module, const char *module_name, const char *class_name, size_t size, enum __Pyx_ImportType_CheckSize check_size);
#endif

/* GetVTable.proto */
static void* __Pyx_GetVtable(PyObject *dict);

/* Import.proto */
static PyObject *__Pyx_Import(PyObject *name, PyObject *from_list, int level);

/* ImportFrom.proto */
static PyObject* __Pyx_ImportFrom(PyObject* module, PyObject* name);

/* FetchCommonType.proto */
static PyTypeObject* __Pyx_FetchCommonType(PyTypeObject* type);

/* CythonFunctionShared.proto */
#define __Pyx_CyFunction_USED 1
#define __Pyx_CYFUNCTION_STATICMETHOD  0x01
#define __Pyx_CYFUNCTION_CLASSMETHOD   0x02
#define __Pyx_CYFUNCTION_CCLASS        0x04
#define __Pyx_CyFunction_GetClosure(f)\
    (((__pyx_CyFunctionObject *) (f))->func_closure)
#define __Pyx_CyFunction_GetClassObj(f)\
    (((__pyx_CyFunctionObject *) (f))->func_classobj)
#define __Pyx_CyFunction_Defaults(type, f)\
    ((type *)(((__pyx_CyFunctionObject *) (f))->defaults))
#define __Pyx_CyFunction_SetDefaultsGetter(f, g)\
    ((__pyx_CyFunctionObject *) (f))->defaults_getter = (g)
typedef struct {
    PyCFunctionObject func;
#if PY_VERSION_HEX < 0x030500A0
    PyObject *func_weakreflist;
#endif
    PyObject *func_dict;
    PyObject *func_name;
    PyObject *func_qualname;
    PyObject *func_doc;
    PyObject *func_globals;
    PyObject *func_code;
    PyObject *func_closure;
    PyObject *func_classobj;
    void *defaults;
    int defaults_pyobjects;
    size_t defaults_size;  // used by FusedFunction for copying defaults
    int flags;
    PyObject *defaults_tuple;
    PyObject *defaults_kwdict;
    PyObject *(*defaults_getter)(PyObject *);
    PyObject *func_annotations;
} __pyx_CyFunctionObject;
static PyTypeObject *__pyx_CyFunctionType = 0;
#define __Pyx_CyFunction_Check(obj)  (__Pyx_TypeCheck(obj, __pyx_CyFunctionType))
static PyObject *__Pyx_CyFunction_Init(__pyx_CyFunctionObject* op, PyMethodDef *ml,
                                      int flags, PyObject* qualname,
                                      PyObject *self,
                                      PyObject *module, PyObject *globals,
                                      PyObject* code);
static CYTHON_INLINE void *__Pyx_CyFunction_InitDefaults(PyObject *m,
                                                         size_t size,
                                                         int pyobjects);
static CYTHON_INLINE void __Pyx_CyFunction_SetDefaultsTuple(PyObject *m,
                                                            PyObject *tuple);
static CYTHON_INLINE void __Pyx_CyFunction_SetDefaultsKwDict(PyObject *m,
                                                             PyObject *dict);
static CYTHON_INLINE void __Pyx_CyFunction_SetAnnotationsDict(PyObject *m,
                                                              PyObject *dict);
static int __pyx_CyFunction_init(void);

/* CythonFunction.proto */
static PyObject *__Pyx_CyFunction_New(PyMethodDef *ml,
                                      int flags, PyObject* qualname,
                                      PyObject *closure,
                                      PyObject *module, PyObject *globals,
                                      PyObject* code);

/* CLineInTraceback.proto */
#ifdef CYTHON_CLINE_IN_TRACEBACK
#define __Pyx_CLineForTraceback(tstate, c_line)  (((CYTHON_CLINE_IN_TRACEBACK)) ? c_line : 0)
#else
static int __Pyx_CLineForTraceback(PyThreadState *tstate, int c_line);
#endif

/* CodeObjectCache.proto */
typedef struct {
    PyCodeObject* code_object;
    int code_line;
} __Pyx_CodeObjectCacheEntry;
struct __Pyx_CodeObjectCache {
    int count;
    int max_count;
    __Pyx_CodeObjectCacheEntry* entries;
};
static struct __Pyx_CodeObjectCache __pyx_code_cache = {0,0,NULL};
static int __pyx_bisect_code_objects(__Pyx_CodeObjectCacheEntry* entries, int count, int code_line);
static PyCodeObject *__pyx_find_code_object(int code_line);
static void __pyx_insert_code_object(int code_line, PyCodeObject* code_object);

/* AddTraceback.proto */
static void __Pyx_AddTraceback(const char *funcname, int c_line,
                               int py_line, const char *filename);

/* ArrayAPI.proto */
#ifndef _ARRAYARRAY_H
#define _ARRAYARRAY_H
typedef struct arraydescr {
    int typecode;
    int itemsize;
    PyObject * (*getitem)(struct arrayobject *, Py_ssize_t);
    int (*setitem)(struct arrayobject *, Py_ssize_t, PyObject *);
#if PY_MAJOR_VERSION >= 3
    char *formats;
#endif
} arraydescr;
struct arrayobject {
    PyObject_HEAD
    Py_ssize_t ob_size;
    union {
        char *ob_item;
        float *as_floats;
        double *as_doubles;
        int *as_ints;
        unsigned int *as_uints;
        unsigned char *as_uchars;
        signed char *as_schars;
        char *as_chars;
        unsigned long *as_ulongs;
        long *as_longs;
#if PY_MAJOR_VERSION >= 3
        unsigned long long *as_ulonglongs;
        long long *as_longlongs;
#endif
        short *as_shorts;
        unsigned short *as_ushorts;
        Py_UNICODE *as_pyunicodes;
        void *as_voidptr;
    } data;
    Py_ssize_t allocated;
    struct arraydescr *ob_descr;
    PyObject *weakreflist;
#if PY_MAJOR_VERSION >= 3
        int ob_exports;
#endif
};
#ifndef NO_NEWARRAY_INLINE
static CYTHON_INLINE PyObject * newarrayobject(PyTypeObject *type, Py_ssize_t size,
    struct arraydescr *descr) {
    arrayobject *op;
    size_t nbytes;
    if (size < 0) {
        PyErr_BadInternalCall();
        return NULL;
    }
    nbytes = size * descr->itemsize;
    if (nbytes / descr->itemsize != (size_t)size) {
        return PyErr_NoMemory();
    }
    op = (arrayobject *) type->tp_alloc(type, 0);
    if (op == NULL) {
        return NULL;
    }
    op->ob_descr = descr;
    op->allocated = size;
    op->weakreflist = NULL;
    __Pyx_SET_SIZE(op, size);
    if (size <= 0) {
        op->data.ob_item = NULL;
    }
    else {
        op->data.ob_item = PyMem_NEW(char, nbytes);
        if (op->data.ob_item == NULL) {
            Py_DECREF(op);
            return PyErr_NoMemory();
        }
    }
    return (PyObject *) op;
}
#else
PyObject* newarrayobject(PyTypeObject *type, Py_ssize_t size,
    struct arraydescr *descr);
#endif
static CYTHON_INLINE int resize(arrayobject *self, Py_ssize_t n) {
    void *items = (void*) self->data.ob_item;
    PyMem_Resize(items, char, (size_t)(n * self->ob_descr->itemsize));
    if (items == NULL) {
        PyErr_NoMemory();
        return -1;
    }
    self->data.ob_item = (char*) items;
    __Pyx_SET_SIZE(self, n);
    self->allocated = n;
    return 0;
}
static CYTHON_INLINE int resize_smart(arrayobject *self, Py_ssize_t n) {
    void *items = (void*) self->data.ob_item;
    Py_ssize_t newsize;
    if (n < self->allocated && n*4 > self->allocated) {
        __Pyx_SET_SIZE(self, n);
        return 0;
    }
    newsize = n + (n / 2) + 1;
    if (newsize <= n) {
        PyErr_NoMemory();
        return -1;
    }
    PyMem_Resize(items, char, (size_t)(newsize * self->ob_descr->itemsize));
    if (items == NULL) {
        PyErr_NoMemory();
        return -1;
    }
    self->data.ob_item = (char*) items;
    __Pyx_SET_SIZE(self, n);
    self->allocated = newsize;
    return 0;
}
#endif

/* GCCDiagnostics.proto */
#if defined(__GNUC__) && (__GNUC__ > 4 || (__GNUC__ == 4 && __GNUC_MINOR__ >= 6))
#define __Pyx_HAS_GCC_DIAGNOSTIC
#endif

/* Print.proto */
static int __Pyx_Print(PyObject*, PyObject *, int);
#if CYTHON_COMPILING_IN_PYPY || PY_MAJOR_VERSION >= 3
static PyObject* __pyx_print = 0;
static PyObject* __pyx_print_kwargs = 0;
#endif

/* CIntFromPy.proto */
static CYTHON_INLINE int __Pyx_PyInt_As_int(PyObject *);

/* PrintOne.proto */
static int __Pyx_PrintOne(PyObject* stream, PyObject *o);

/* CIntToPy.proto */
static CYTHON_INLINE PyObject* __Pyx_PyInt_From_int16_t(int16_t value);

/* CIntFromPy.proto */
static CYTHON_INLINE int16_t __Pyx_PyInt_As_int16_t(PyObject *);

/* CIntToPy.proto */
static CYTHON_INLINE PyObject* __Pyx_PyInt_From_long(long value);

/* CIntToPy.proto */
static CYTHON_INLINE PyObject* __Pyx_PyInt_From_int(int value);

/* CIntFromPy.proto */
static CYTHON_INLINE long __Pyx_PyInt_As_long(PyObject *);

/* FastTypeChecks.proto */
#if CYTHON_COMPILING_IN_CPYTHON
#define __Pyx_TypeCheck(obj, type) __Pyx_IsSubtype(Py_TYPE(obj), (PyTypeObject *)type)
static CYTHON_INLINE int __Pyx_IsSubtype(PyTypeObject *a, PyTypeObject *b);
static CYTHON_INLINE int __Pyx_PyErr_GivenExceptionMatches(PyObject *err, PyObject *type);
static CYTHON_INLINE int __Pyx_PyErr_GivenExceptionMatches2(PyObject *err, PyObject *type1, PyObject *type2);
#else
#define __Pyx_TypeCheck(obj, type) PyObject_TypeCheck(obj, (PyTypeObject *)type)
#define __Pyx_PyErr_GivenExceptionMatches(err, type) PyErr_GivenExceptionMatches(err, type)
#define __Pyx_PyErr_GivenExceptionMatches2(err, type1, type2) (PyErr_GivenExceptionMatches(err, type1) || PyErr_GivenExceptionMatches(err, type2))
#endif
#define __Pyx_PyException_Check(obj) __Pyx_TypeCheck(obj, PyExc_Exception)

/* CheckBinaryVersion.proto */
static int __Pyx_check_binary_version(void);

/* InitStrings.proto */
static int __Pyx_InitStrings(__Pyx_StringTabEntry *t);

static PyObject *__pyx_f_6ttygif_3tty_5theme_5layer_load_file(struct __pyx_obj_6ttygif_3tty_5theme_layer *__pyx_v_self, arrayobject *__pyx_v_palette); /* proto*/
static PyObject *__pyx_f_6ttygif_3tty_5theme_5layer_debug(struct __pyx_obj_6ttygif_3tty_5theme_layer *__pyx_v_self); /* proto*/
static PyObject *__pyx_f_6ttygif_3tty_5theme_5theme_update_layer(struct __pyx_obj_6ttygif_3tty_5theme_theme *__pyx_v_self, struct __pyx_obj_6ttygif_3tty_5theme_layer *__pyx_v_temp); /* proto*/
static PyObject *__pyx_f_6ttygif_3tty_5theme_5theme_auto(struct __pyx_obj_6ttygif_3tty_5theme_theme *__pyx_v_self); /* proto*/
static PyObject *__pyx_f_6ttygif_3tty_5theme_5theme_init(struct __pyx_obj_6ttygif_3tty_5theme_theme *__pyx_v_self); /* proto*/

/* Module declarations from 'cpython.version' */

/* Module declarations from '__builtin__' */

/* Module declarations from 'cpython.type' */
static PyTypeObject *__pyx_ptype_7cpython_4type_type = 0;

/* Module declarations from 'libc.string' */

/* Module declarations from 'libc.stdio' */

/* Module declarations from 'cpython.object' */

/* Module declarations from 'cpython.ref' */

/* Module declarations from 'cpython.exc' */

/* Module declarations from 'cpython.module' */

/* Module declarations from 'cpython.mem' */

/* Module declarations from 'cpython.tuple' */

/* Module declarations from 'cpython.list' */

/* Module declarations from 'cpython.sequence' */

/* Module declarations from 'cpython.mapping' */

/* Module declarations from 'cpython.iterator' */

/* Module declarations from 'cpython.number' */

/* Module declarations from 'cpython.int' */

/* Module declarations from '__builtin__' */

/* Module declarations from 'cpython.bool' */
static PyTypeObject *__pyx_ptype_7cpython_4bool_bool = 0;

/* Module declarations from 'cpython.long' */

/* Module declarations from 'cpython.float' */

/* Module declarations from '__builtin__' */

/* Module declarations from 'cpython.complex' */
static PyTypeObject *__pyx_ptype_7cpython_7complex_complex = 0;

/* Module declarations from 'cpython.string' */

/* Module declarations from 'cpython.unicode' */

/* Module declarations from 'cpython.dict' */

/* Module declarations from 'cpython.instance' */

/* Module declarations from 'cpython.function' */

/* Module declarations from 'cpython.method' */

/* Module declarations from 'cpython.weakref' */

/* Module declarations from 'cpython.getargs' */

/* Module declarations from 'cpython.pythread' */

/* Module declarations from 'cpython.pystate' */

/* Module declarations from 'cpython.cobject' */

/* Module declarations from 'cpython.oldbuffer' */

/* Module declarations from 'cpython.set' */

/* Module declarations from 'cpython.buffer' */

/* Module declarations from 'cpython.bytes' */

/* Module declarations from 'cpython.pycapsule' */

/* Module declarations from 'cpython' */

/* Module declarations from 'array' */

/* Module declarations from 'cpython.array' */
static PyTypeObject *__pyx_ptype_7cpython_5array_array = 0;
static CYTHON_INLINE int __pyx_f_7cpython_5array_extend_buffer(arrayobject *, char *, Py_ssize_t); /*proto*/

/* Module declarations from 'libc.stdint' */

/* Module declarations from 'ttygif.tty.image' */
static PyTypeObject *__pyx_ptype_6ttygif_3tty_5image_bounds = 0;
static PyTypeObject *__pyx_ptype_6ttygif_3tty_5image_point = 0;
static PyTypeObject *__pyx_ptype_6ttygif_3tty_5image_rect = 0;
static PyTypeObject *__pyx_ptype_6ttygif_3tty_5image_image = 0;

/* Module declarations from 'ttygif.tty.theme' */
static PyTypeObject *__pyx_ptype_6ttygif_3tty_5theme_layer = 0;
static PyTypeObject *__pyx_ptype_6ttygif_3tty_5theme_theme = 0;
#define __Pyx_MODULE_NAME "ttygif.tty.theme"
extern int __pyx_module_is_main_ttygif__tty__theme;
int __pyx_module_is_main_ttygif__tty__theme = 0;

/* Implementation of 'ttygif.tty.theme' */
static PyObject *__pyx_builtin_TypeError;
static PyObject *__pyx_builtin_open;
static PyObject *__pyx_builtin_range;
static PyObject *__pyx_builtin_MemoryError;
static const char __pyx_k_[] = "";
static const char __pyx_k_1[] = "-1";
static const char __pyx_k_B[] = "B";
static const char __pyx_k_x[] = "x";
static const char __pyx_k_y[] = "y";
static const char __pyx_k__9[] = "~";
static const char __pyx_k_gc[] = "gc";
static const char __pyx_k_os[] = "os";
static const char __pyx_k_Dst[] = "Dst: ";
static const char __pyx_k__13[] = "#";
static const char __pyx_k__14[] = " ";
static const char __pyx_k_end[] = "end";
static const char __pyx_k_get[] = "get";
static const char __pyx_k_key[] = "key";
static const char __pyx_k_res[] = "res";
static const char __pyx_k_top[] = "top";
static const char __pyx_k_var[] = "var";
static const char __pyx_k_auto[] = "auto";
static const char __pyx_k_data[] = "data";
static const char __pyx_k_file[] = "__file__";
static const char __pyx_k_find[] = "find";
static const char __pyx_k_font[] = "font";
static const char __pyx_k_join[] = "join";
static const char __pyx_k_left[] = "left";
static const char __pyx_k_line[] = "line";
static const char __pyx_k_main[] = "__main__";
static const char __pyx_k_mode[] = "mode";
static const char __pyx_k_name[] = "name";
static const char __pyx_k_open[] = "open";
static const char __pyx_k_path[] = "path";
static const char __pyx_k_self[] = "self";
static const char __pyx_k_test[] = "__test__";
static const char __pyx_k_Inner[] = "Inner: ";
static const char __pyx_k_Layer[] = "Layer";
static const char __pyx_k_Outer[] = "Outer: ";
static const char __pyx_k_Width[] = "Width";
static const char __pyx_k_array[] = "array";
static const char __pyx_k_depth[] = "depth";
static const char __pyx_k_image[] = "image";
static const char __pyx_k_index[] = "index";
static const char __pyx_k_isdir[] = "isdir";
static const char __pyx_k_layer[] = "layer";
static const char __pyx_k_print[] = "print";
static const char __pyx_k_range[] = "range";
static const char __pyx_k_right[] = "right";
static const char __pyx_k_scale[] = "scale";
static const char __pyx_k_split[] = "split";
static const char __pyx_k_strip[] = "strip";
static const char __pyx_k_theme[] = ".theme";
static const char __pyx_k_title[] = "title";
static const char __pyx_k_types[] = "types";
static const char __pyx_k_value[] = "value";
static const char __pyx_k_width[] = "width";
static const char __pyx_k_Bounds[] = "Bounds: ";
static const char __pyx_k_Height[] = "Height";
static const char __pyx_k_bottom[] = "bottom";
static const char __pyx_k_center[] = "center";
static const char __pyx_k_colors[] = "colors";
static const char __pyx_k_decode[] = "decode";
static const char __pyx_k_exists[] = "exists";
static const char __pyx_k_file_0[] = "  file:      {0}";
static const char __pyx_k_file_2[] = "file";
static const char __pyx_k_format[] = "format";
static const char __pyx_k_frames[] = "frames";
static const char __pyx_k_header[] = "header";
static const char __pyx_k_height[] = "height";
static const char __pyx_k_import[] = "__import__";
static const char __pyx_k_layer1[] = "layer1";
static const char __pyx_k_layer2[] = "layer2";
static const char __pyx_k_layer3[] = "layer3";
static const char __pyx_k_layer4[] = "layer4";
static const char __pyx_k_layer5[] = "layer5";
static const char __pyx_k_layers[] = "layers";
static const char __pyx_k_mode_0[] = "  mode:      {0}";
static const char __pyx_k_name_0[] = "  name:      {0}";
static const char __pyx_k_name_2[] = "__name__";
static const char __pyx_k_reduce[] = "__reduce__";
static const char __pyx_k_themes[] = "themes";
static const char __pyx_k_tokens[] = "tokens";
static const char __pyx_k_ttygif[] = ".ttygif";
static const char __pyx_k_abspath[] = "abspath";
static const char __pyx_k_dirname[] = "dirname";
static const char __pyx_k_dst_top[] = "dst-top";
static const char __pyx_k_get_var[] = "get_var";
static const char __pyx_k_os_path[] = "os.path";
static const char __pyx_k_padding[] = "padding";
static const char __pyx_k_palette[] = "palette";
static const char __pyx_k_theme_0[] = " - theme: {0}";
static const char __pyx_k_theme_2[] = "theme";
static const char __pyx_k_dst_left[] = "dst-left";
static const char __pyx_k_getstate[] = "__getstate__";
static const char __pyx_k_setstate[] = "__setstate__";
static const char __pyx_k_TypeError[] = "TypeError";
static const char __pyx_k_copy_mode[] = "copy-mode";
static const char __pyx_k_dst_right[] = "dst-right";
static const char __pyx_k_font_size[] = "font_size";
static const char __pyx_k_inner_top[] = "inner-top";
static const char __pyx_k_outer_top[] = "outer-top";
static const char __pyx_k_pyx_state[] = "__pyx_state";
static const char __pyx_k_readlines[] = "readlines";
static const char __pyx_k_reduce_ex[] = "__reduce_ex__";
static const char __pyx_k_z_index_0[] = "  z_index:   {0}";
static const char __pyx_k_ColorIndex[] = "ColorIndex";
static const char __pyx_k_background[] = "background";
static const char __pyx_k_descriptor[] = "descriptor";
static const char __pyx_k_dst_bottom[] = "dst-bottom";
static const char __pyx_k_expanduser[] = "expanduser";
static const char __pyx_k_foreground[] = "foreground";
static const char __pyx_k_get_anyvar[] = "get_anyvar";
static const char __pyx_k_gif_decode[] = "gif.decode";
static const char __pyx_k_inner_left[] = "inner-left";
static const char __pyx_k_outer_left[] = "outer-left";
static const char __pyx_k_pyx_vtable[] = "__pyx_vtable__";
static const char __pyx_k_MemoryError[] = "MemoryError";
static const char __pyx_k_ScreenWidth[] = "ScreenWidth";
static const char __pyx_k_copy_mode_0[] = "copy-mode:   {0}";
static const char __pyx_k_inner_right[] = "inner-right";
static const char __pyx_k_outer_right[] = "outer-right";
static const char __pyx_k_transparent[] = "transparent";
static const char __pyx_k_ScreenHeight[] = "ScreenHeight";
static const char __pyx_k_inner_bottom[] = "inner-bottom";
static const char __pyx_k_outer_bottom[] = "outer-bottom";
static const char __pyx_k_stringsource[] = "stringsource";
static const char __pyx_k_reduce_cython[] = "__reduce_cython__";
static const char __pyx_k_theme_get_var[] = "theme.get_var";
static const char __pyx_k_transparent_0[] = "transparent: {0}";
static const char __pyx_k_setstate_cython[] = "__setstate_cython__";
static const char __pyx_k_theme_get_anyvar[] = "theme.get_anyvar";
static const char __pyx_k_ttygif_tty_theme[] = "ttygif.tty.theme";
static const char __pyx_k_Invalid_theme_file[] = "Invalid theme file";
static const char __pyx_k_cline_in_traceback[] = "cline_in_traceback";
static const char __pyx_k_default_background[] = "default_background";
static const char __pyx_k_default_foreground[] = "default_foreground";
static const char __pyx_k_global_color_table[] = "global_color_table";
static const char __pyx_k_Invalid_image_file_0[] = "Invalid image file: {0}";
static const char __pyx_k_TransparentColorFlag[] = "TransparentColorFlag";
static const char __pyx_k_ttygif_tty_theme_pyx[] = "ttygif/tty/theme.pyx";
static const char __pyx_k_layer___reduce_cython[] = "layer.__reduce_cython__";
static const char __pyx_k_theme___reduce_cython[] = "theme.__reduce_cython__";
static const char __pyx_k_layer___setstate_cython[] = "layer.__setstate_cython__";
static const char __pyx_k_theme___setstate_cython[] = "theme.__setstate_cython__";
static const char __pyx_k_no_default___reduce___due_to_non[] = "no default __reduce__ due to non-trivial __cinit__";
static PyObject *__pyx_kp_s_;
static PyObject *__pyx_kp_s_1;
static PyObject *__pyx_n_s_B;
static PyObject *__pyx_kp_s_Bounds;
static PyObject *__pyx_n_s_ColorIndex;
static PyObject *__pyx_kp_s_Dst;
static PyObject *__pyx_n_s_Height;
static PyObject *__pyx_kp_s_Inner;
static PyObject *__pyx_kp_s_Invalid_image_file_0;
static PyObject *__pyx_kp_s_Invalid_theme_file;
static PyObject *__pyx_n_s_Layer;
static PyObject *__pyx_n_s_MemoryError;
static PyObject *__pyx_kp_s_Outer;
static PyObject *__pyx_n_s_ScreenHeight;
static PyObject *__pyx_n_s_ScreenWidth;
static PyObject *__pyx_n_s_TransparentColorFlag;
static PyObject *__pyx_n_s_TypeError;
static PyObject *__pyx_n_s_Width;
static PyObject *__pyx_kp_s__13;
static PyObject *__pyx_kp_s__14;
static PyObject *__pyx_kp_s__9;
static PyObject *__pyx_n_s_abspath;
static PyObject *__pyx_n_s_array;
static PyObject *__pyx_n_s_auto;
static PyObject *__pyx_n_s_background;
static PyObject *__pyx_n_s_bottom;
static PyObject *__pyx_n_s_center;
static PyObject *__pyx_n_s_cline_in_traceback;
static PyObject *__pyx_n_s_colors;
static PyObject *__pyx_kp_s_copy_mode;
static PyObject *__pyx_kp_s_copy_mode_0;
static PyObject *__pyx_n_s_data;
static PyObject *__pyx_n_s_decode;
static PyObject *__pyx_n_s_default_background;
static PyObject *__pyx_n_s_default_foreground;
static PyObject *__pyx_n_s_depth;
static PyObject *__pyx_n_s_descriptor;
static PyObject *__pyx_n_s_dirname;
static PyObject *__pyx_kp_s_dst_bottom;
static PyObject *__pyx_kp_s_dst_left;
static PyObject *__pyx_kp_s_dst_right;
static PyObject *__pyx_kp_s_dst_top;
static PyObject *__pyx_n_s_end;
static PyObject *__pyx_n_s_exists;
static PyObject *__pyx_n_s_expanduser;
static PyObject *__pyx_n_s_file;
static PyObject *__pyx_kp_s_file_0;
static PyObject *__pyx_n_s_file_2;
static PyObject *__pyx_n_s_find;
static PyObject *__pyx_n_s_font;
static PyObject *__pyx_n_s_font_size;
static PyObject *__pyx_n_s_foreground;
static PyObject *__pyx_n_s_format;
static PyObject *__pyx_n_s_frames;
static PyObject *__pyx_n_s_gc;
static PyObject *__pyx_n_s_get;
static PyObject *__pyx_n_s_get_anyvar;
static PyObject *__pyx_n_s_get_var;
static PyObject *__pyx_n_s_getstate;
static PyObject *__pyx_n_s_gif_decode;
static PyObject *__pyx_n_s_global_color_table;
static PyObject *__pyx_n_s_header;
static PyObject *__pyx_n_s_height;
static PyObject *__pyx_n_s_image;
static PyObject *__pyx_n_s_import;
static PyObject *__pyx_n_s_index;
static PyObject *__pyx_kp_s_inner_bottom;
static PyObject *__pyx_kp_s_inner_left;
static PyObject *__pyx_kp_s_inner_right;
static PyObject *__pyx_kp_s_inner_top;
static PyObject *__pyx_n_s_isdir;
static PyObject *__pyx_n_s_join;
static PyObject *__pyx_n_s_key;
static PyObject *__pyx_n_s_layer;
static PyObject *__pyx_n_s_layer1;
static PyObject *__pyx_n_s_layer2;
static PyObject *__pyx_n_s_layer3;
static PyObject *__pyx_n_s_layer4;
static PyObject *__pyx_n_s_layer5;
static PyObject *__pyx_n_s_layer___reduce_cython;
static PyObject *__pyx_n_s_layer___setstate_cython;
static PyObject *__pyx_n_s_layers;
static PyObject *__pyx_n_s_left;
static PyObject *__pyx_n_s_line;
static PyObject *__pyx_n_s_main;
static PyObject *__pyx_n_s_mode;
static PyObject *__pyx_kp_s_mode_0;
static PyObject *__pyx_n_s_name;
static PyObject *__pyx_kp_s_name_0;
static PyObject *__pyx_n_s_name_2;
static PyObject *__pyx_kp_s_no_default___reduce___due_to_non;
static PyObject *__pyx_n_s_open;
static PyObject *__pyx_n_s_os;
static PyObject *__pyx_n_s_os_path;
static PyObject *__pyx_kp_s_outer_bottom;
static PyObject *__pyx_kp_s_outer_left;
static PyObject *__pyx_kp_s_outer_right;
static PyObject *__pyx_kp_s_outer_top;
static PyObject *__pyx_n_s_padding;
static PyObject *__pyx_n_s_palette;
static PyObject *__pyx_n_s_path;
static PyObject *__pyx_n_s_print;
static PyObject *__pyx_n_s_pyx_state;
static PyObject *__pyx_n_s_pyx_vtable;
static PyObject *__pyx_n_s_range;
static PyObject *__pyx_n_s_readlines;
static PyObject *__pyx_n_s_reduce;
static PyObject *__pyx_n_s_reduce_cython;
static PyObject *__pyx_n_s_reduce_ex;
static PyObject *__pyx_n_s_res;
static PyObject *__pyx_n_s_right;
static PyObject *__pyx_n_s_scale;
static PyObject *__pyx_n_s_self;
static PyObject *__pyx_n_s_setstate;
static PyObject *__pyx_n_s_setstate_cython;
static PyObject *__pyx_n_s_split;
static PyObject *__pyx_kp_s_stringsource;
static PyObject *__pyx_n_s_strip;
static PyObject *__pyx_n_s_test;
static PyObject *__pyx_kp_s_theme;
static PyObject *__pyx_kp_s_theme_0;
static PyObject *__pyx_n_s_theme_2;
static PyObject *__pyx_n_s_theme___reduce_cython;
static PyObject *__pyx_n_s_theme___setstate_cython;
static PyObject *__pyx_n_s_theme_get_anyvar;
static PyObject *__pyx_n_s_theme_get_var;
static PyObject *__pyx_n_s_themes;
static PyObject *__pyx_n_s_title;
static PyObject *__pyx_n_s_tokens;
static PyObject *__pyx_n_s_top;
static PyObject *__pyx_n_s_transparent;
static PyObject *__pyx_kp_s_transparent_0;
static PyObject *__pyx_kp_s_ttygif;
static PyObject *__pyx_n_s_ttygif_tty_theme;
static PyObject *__pyx_kp_s_ttygif_tty_theme_pyx;
static PyObject *__pyx_n_s_types;
static PyObject *__pyx_n_s_value;
static PyObject *__pyx_n_s_var;
static PyObject *__pyx_n_s_width;
static PyObject *__pyx_n_s_x;
static PyObject *__pyx_n_s_y;
static PyObject *__pyx_kp_s_z_index_0;
static int __pyx_pf_6ttygif_3tty_5theme_5layer___cinit__(struct __pyx_obj_6ttygif_3tty_5theme_layer *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6ttygif_3tty_5theme_5layer_2__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_6ttygif_3tty_5theme_layer *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6ttygif_3tty_5theme_5layer_4__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_6ttygif_3tty_5theme_layer *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static int __pyx_pf_6ttygif_3tty_5theme_5theme___cinit__(struct __pyx_obj_6ttygif_3tty_5theme_theme *__pyx_v_self, PyObject *__pyx_v_name, PyObject *__pyx_v_width, PyObject *__pyx_v_height); /* proto */
static PyObject *__pyx_pf_6ttygif_3tty_5theme_5theme_2get_var(CYTHON_UNUSED struct __pyx_obj_6ttygif_3tty_5theme_theme *__pyx_v_self, PyObject *__pyx_v_line, PyObject *__pyx_v_var); /* proto */
static PyObject *__pyx_pf_6ttygif_3tty_5theme_5theme_4get_anyvar(CYTHON_UNUSED struct __pyx_obj_6ttygif_3tty_5theme_theme *__pyx_v_self, PyObject *__pyx_v_line); /* proto */
static PyObject *__pyx_pf_6ttygif_3tty_5theme_5theme_6__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_6ttygif_3tty_5theme_theme *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6ttygif_3tty_5theme_5theme_8__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_6ttygif_3tty_5theme_theme *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static int __pyx_pf_7cpython_5array_5array___getbuffer__(arrayobject *__pyx_v_self, Py_buffer *__pyx_v_info, CYTHON_UNUSED int __pyx_v_flags); /* proto */
static void __pyx_pf_7cpython_5array_5array_2__releasebuffer__(CYTHON_UNUSED arrayobject *__pyx_v_self, Py_buffer *__pyx_v_info); /* proto */
static PyObject *__pyx_tp_new_6ttygif_3tty_5theme_layer(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_6ttygif_3tty_5theme_theme(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_int_0;
static PyObject *__pyx_int_1;
static PyObject *__pyx_int_8;
static PyObject *__pyx_int_18;
static PyObject *__pyx_int_28;
static PyObject *__pyx_int_38;
static PyObject *__pyx_int_48;
static PyObject *__pyx_int_58;
static PyObject *__pyx_int_68;
static PyObject *__pyx_int_78;
static PyObject *__pyx_int_88;
static PyObject *__pyx_int_95;
static PyObject *__pyx_int_98;
static PyObject *__pyx_int_108;
static PyObject *__pyx_int_118;
static PyObject *__pyx_int_128;
static PyObject *__pyx_int_135;
static PyObject *__pyx_int_138;
static PyObject *__pyx_int_148;
static PyObject *__pyx_int_158;
static PyObject *__pyx_int_168;
static PyObject *__pyx_int_175;
static PyObject *__pyx_int_178;
static PyObject *__pyx_int_188;
static PyObject *__pyx_int_192;
static PyObject *__pyx_int_198;
static PyObject *__pyx_int_208;
static PyObject *__pyx_int_215;
static PyObject *__pyx_int_218;
static PyObject *__pyx_int_228;
static PyObject *__pyx_int_238;
static PyObject *__pyx_int_255;
static PyObject *__pyx_int_neg_1;
static PyObject *__pyx_tuple__2;
static PyObject *__pyx_tuple__3;
static PyObject *__pyx_tuple__5;
static PyObject *__pyx_tuple__7;
static PyObject *__pyx_tuple__8;
static PyObject *__pyx_tuple__10;
static PyObject *__pyx_tuple__16;
static PyObject *__pyx_tuple__18;
static PyObject *__pyx_tuple__19;
static PyObject *__pyx_tuple__20;
static PyObject *__pyx_tuple__21;
static PyObject *__pyx_tuple__22;
static PyObject *__pyx_tuple__23;
static PyObject *__pyx_tuple__24;
static PyObject *__pyx_codeobj__4;
static PyObject *__pyx_codeobj__6;
static PyObject *__pyx_codeobj__11;
static PyObject *__pyx_codeobj__12;
static PyObject *__pyx_codeobj__15;
static PyObject *__pyx_codeobj__17;
/* Late includes */

/* "ttygif/tty/theme.pyx":19
 * 
 * cdef class layer:
 *     def __cinit__(self):             # <<<<<<<<<<<<<<
 *         self.z_index=0
 *         self.name=''
 */

/* Python wrapper */
static int __pyx_pw_6ttygif_3tty_5theme_5layer_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_6ttygif_3tty_5theme_5layer_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__cinit__ (wrapper)", 0);
  if (unlikely(PyTuple_GET_SIZE(__pyx_args) > 0)) {
    __Pyx_RaiseArgtupleInvalid("__cinit__", 1, 0, 0, PyTuple_GET_SIZE(__pyx_args)); return -1;}
  if (unlikely(__pyx_kwds) && unlikely(PyDict_Size(__pyx_kwds) > 0) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "__cinit__", 0))) return -1;
  __pyx_r = __pyx_pf_6ttygif_3tty_5theme_5layer___cinit__(((struct __pyx_obj_6ttygif_3tty_5theme_layer *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6ttygif_3tty_5theme_5layer___cinit__(struct __pyx_obj_6ttygif_3tty_5theme_layer *__pyx_v_self) {
  int __pyx_r;
  __Pyx_TraceDeclarations
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__cinit__", 0);
  __Pyx_TraceCall("__cinit__", __pyx_f[1], 19, 0, __PYX_ERR(1, 19, __pyx_L1_error));

  /* "ttygif/tty/theme.pyx":20
 * cdef class layer:
 *     def __cinit__(self):
 *         self.z_index=0             # <<<<<<<<<<<<<<
 *         self.name=''
 *         self.file=None
 */
  __pyx_v_self->z_index = 0;

  /* "ttygif/tty/theme.pyx":21
 *     def __cinit__(self):
 *         self.z_index=0
 *         self.name=''             # <<<<<<<<<<<<<<
 *         self.file=None
 *         self.mode='scale'
 */
  __Pyx_INCREF(__pyx_kp_s_);
  __Pyx_GIVEREF(__pyx_kp_s_);
  __Pyx_GOTREF(__pyx_v_self->name);
  __Pyx_DECREF(__pyx_v_self->name);
  __pyx_v_self->name = __pyx_kp_s_;

  /* "ttygif/tty/theme.pyx":22
 *         self.z_index=0
 *         self.name=''
 *         self.file=None             # <<<<<<<<<<<<<<
 *         self.mode='scale'
 *         self.outer =rect(0,0,0,0)
 */
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->file);
  __Pyx_DECREF(__pyx_v_self->file);
  __pyx_v_self->file = ((PyObject*)Py_None);

  /* "ttygif/tty/theme.pyx":23
 *         self.name=''
 *         self.file=None
 *         self.mode='scale'             # <<<<<<<<<<<<<<
 *         self.outer =rect(0,0,0,0)
 *         self.inner =rect(0,0,0,0)
 */
  __Pyx_INCREF(__pyx_n_s_scale);
  __Pyx_GIVEREF(__pyx_n_s_scale);
  __Pyx_GOTREF(__pyx_v_self->mode);
  __Pyx_DECREF(__pyx_v_self->mode);
  __pyx_v_self->mode = __pyx_n_s_scale;

  /* "ttygif/tty/theme.pyx":24
 *         self.file=None
 *         self.mode='scale'
 *         self.outer =rect(0,0,0,0)             # <<<<<<<<<<<<<<
 *         self.inner =rect(0,0,0,0)
 *         self.bounds=rect(0,0,0,0)
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_6ttygif_3tty_5image_rect), __pyx_tuple__2, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 24, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->outer);
  __Pyx_DECREF(((PyObject *)__pyx_v_self->outer));
  __pyx_v_self->outer = ((struct __pyx_obj_6ttygif_3tty_5image_rect *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "ttygif/tty/theme.pyx":25
 *         self.mode='scale'
 *         self.outer =rect(0,0,0,0)
 *         self.inner =rect(0,0,0,0)             # <<<<<<<<<<<<<<
 *         self.bounds=rect(0,0,0,0)
 *         self.dst   =rect(0,0,-1,-1)
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_6ttygif_3tty_5image_rect), __pyx_tuple__2, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 25, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->inner);
  __Pyx_DECREF(((PyObject *)__pyx_v_self->inner));
  __pyx_v_self->inner = ((struct __pyx_obj_6ttygif_3tty_5image_rect *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "ttygif/tty/theme.pyx":26
 *         self.outer =rect(0,0,0,0)
 *         self.inner =rect(0,0,0,0)
 *         self.bounds=rect(0,0,0,0)             # <<<<<<<<<<<<<<
 *         self.dst   =rect(0,0,-1,-1)
 *         self.transparent=-1
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_6ttygif_3tty_5image_rect), __pyx_tuple__2, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 26, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->bounds);
  __Pyx_DECREF(((PyObject *)__pyx_v_self->bounds));
  __pyx_v_self->bounds = ((struct __pyx_obj_6ttygif_3tty_5image_rect *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "ttygif/tty/theme.pyx":27
 *         self.inner =rect(0,0,0,0)
 *         self.bounds=rect(0,0,0,0)
 *         self.dst   =rect(0,0,-1,-1)             # <<<<<<<<<<<<<<
 *         self.transparent=-1
 *         self.path  =None
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_6ttygif_3tty_5image_rect), __pyx_tuple__3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 27, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->dst);
  __Pyx_DECREF(((PyObject *)__pyx_v_self->dst));
  __pyx_v_self->dst = ((struct __pyx_obj_6ttygif_3tty_5image_rect *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "ttygif/tty/theme.pyx":28
 *         self.bounds=rect(0,0,0,0)
 *         self.dst   =rect(0,0,-1,-1)
 *         self.transparent=-1             # <<<<<<<<<<<<<<
 *         self.path  =None
 * 
 */
  __pyx_v_self->transparent = -1;

  /* "ttygif/tty/theme.pyx":29
 *         self.dst   =rect(0,0,-1,-1)
 *         self.transparent=-1
 *         self.path  =None             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->path);
  __Pyx_DECREF(__pyx_v_self->path);
  __pyx_v_self->path = ((PyObject*)Py_None);

  /* "ttygif/tty/theme.pyx":19
 * 
 * cdef class layer:
 *     def __cinit__(self):             # <<<<<<<<<<<<<<
 *         self.z_index=0
 *         self.name=''
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("ttygif.tty.theme.layer.__cinit__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_TraceReturn(Py_None, 0);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "ttygif/tty/theme.pyx":33
 * 
 * 
 *     cdef load_file(self,array.array palette):             # <<<<<<<<<<<<<<
 *         cdef uint8_t[1] clear_1=[0]
 *         autoloader=None
 */

static PyObject *__pyx_f_6ttygif_3tty_5theme_5layer_load_file(struct __pyx_obj_6ttygif_3tty_5theme_layer *__pyx_v_self, arrayobject *__pyx_v_palette) {
  uint8_t __pyx_v_clear_1[1];
  CYTHON_UNUSED PyObject *__pyx_v_autoloader = NULL;
  PyObject *__pyx_v_path = NULL;
  PyObject *__pyx_v_err = NULL;
  PyObject *__pyx_v_underlay_image = NULL;
  PyObject *__pyx_v_gif_raw = NULL;
  PyObject *__pyx_v_gif_width = NULL;
  PyObject *__pyx_v_gif_height = NULL;
  PyObject *__pyx_v_frame = NULL;
  PyObject *__pyx_v_attribs = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_TraceDeclarations
  __Pyx_RefNannyDeclarations
  uint8_t __pyx_t_1[1];
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  Py_ssize_t __pyx_t_8;
  PyObject *(*__pyx_t_9)(PyObject *);
  int __pyx_t_10;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("load_file", 0);
  __Pyx_TraceCall("load_file", __pyx_f[1], 33, 0, __PYX_ERR(1, 33, __pyx_L1_error));

  /* "ttygif/tty/theme.pyx":34
 * 
 *     cdef load_file(self,array.array palette):
 *         cdef uint8_t[1] clear_1=[0]             # <<<<<<<<<<<<<<
 *         autoloader=None
 *         # try the image given, otherwise tryin the layers folder in the module
 */
  __pyx_t_1[0] = 0;
  memcpy(&(__pyx_v_clear_1[0]), __pyx_t_1, sizeof(__pyx_v_clear_1[0]) * (1));

  /* "ttygif/tty/theme.pyx":35
 *     cdef load_file(self,array.array palette):
 *         cdef uint8_t[1] clear_1=[0]
 *         autoloader=None             # <<<<<<<<<<<<<<
 *         # try the image given, otherwise tryin the layers folder in the module
 * 
 */
  __Pyx_INCREF(Py_None);
  __pyx_v_autoloader = Py_None;

  /* "ttygif/tty/theme.pyx":38
 *         # try the image given, otherwise tryin the layers folder in the module
 * 
 *         if self.path:             # <<<<<<<<<<<<<<
 *             if os.path.isdir(self.path)==True:
 *                 path=os.path.join(self.path,'layers',self.file)
 */
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_v_self->path); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(1, 38, __pyx_L1_error)
  if (__pyx_t_2) {

    /* "ttygif/tty/theme.pyx":39
 * 
 *         if self.path:
 *             if os.path.isdir(self.path)==True:             # <<<<<<<<<<<<<<
 *                 path=os.path.join(self.path,'layers',self.file)
 *                 if os.path.exists(path)==False:
 */
    __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_os); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 39, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_path); if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 39, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_isdir); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 39, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_5 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_5)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
      }
    }
    __pyx_t_3 = (__pyx_t_5) ? __Pyx_PyObject_Call2Args(__pyx_t_4, __pyx_t_5, __pyx_v_self->path) : __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_v_self->path);
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 39, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = PyObject_RichCompare(__pyx_t_3, Py_True, Py_EQ); __Pyx_XGOTREF(__pyx_t_4); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 39, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(1, 39, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (__pyx_t_2) {

      /* "ttygif/tty/theme.pyx":40
 *         if self.path:
 *             if os.path.isdir(self.path)==True:
 *                 path=os.path.join(self.path,'layers',self.file)             # <<<<<<<<<<<<<<
 *                 if os.path.exists(path)==False:
 *                     err="Invalid image file: {0}".format(path)
 */
      __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_os); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 40, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_path); if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 40, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_join); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 40, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = NULL;
      __pyx_t_6 = 0;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
        __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_3);
        if (likely(__pyx_t_5)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
          __Pyx_INCREF(__pyx_t_5);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_3, function);
          __pyx_t_6 = 1;
        }
      }
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_3)) {
        PyObject *__pyx_temp[4] = {__pyx_t_5, __pyx_v_self->path, __pyx_n_s_layers, __pyx_v_self->file};
        __pyx_t_4 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-__pyx_t_6, 3+__pyx_t_6); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 40, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_GOTREF(__pyx_t_4);
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
        PyObject *__pyx_temp[4] = {__pyx_t_5, __pyx_v_self->path, __pyx_n_s_layers, __pyx_v_self->file};
        __pyx_t_4 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-__pyx_t_6, 3+__pyx_t_6); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 40, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_GOTREF(__pyx_t_4);
      } else
      #endif
      {
        __pyx_t_7 = PyTuple_New(3+__pyx_t_6); if (unlikely(!__pyx_t_7)) __PYX_ERR(1, 40, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        if (__pyx_t_5) {
          __Pyx_GIVEREF(__pyx_t_5); PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_5); __pyx_t_5 = NULL;
        }
        __Pyx_INCREF(__pyx_v_self->path);
        __Pyx_GIVEREF(__pyx_v_self->path);
        PyTuple_SET_ITEM(__pyx_t_7, 0+__pyx_t_6, __pyx_v_self->path);
        __Pyx_INCREF(__pyx_n_s_layers);
        __Pyx_GIVEREF(__pyx_n_s_layers);
        PyTuple_SET_ITEM(__pyx_t_7, 1+__pyx_t_6, __pyx_n_s_layers);
        __Pyx_INCREF(__pyx_v_self->file);
        __Pyx_GIVEREF(__pyx_v_self->file);
        PyTuple_SET_ITEM(__pyx_t_7, 2+__pyx_t_6, __pyx_v_self->file);
        __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_7, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 40, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      }
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_v_path = __pyx_t_4;
      __pyx_t_4 = 0;

      /* "ttygif/tty/theme.pyx":41
 *             if os.path.isdir(self.path)==True:
 *                 path=os.path.join(self.path,'layers',self.file)
 *                 if os.path.exists(path)==False:             # <<<<<<<<<<<<<<
 *                     err="Invalid image file: {0}".format(path)
 *                     raise Exception(err)
 */
      __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_os); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 41, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_path); if (unlikely(!__pyx_t_7)) __PYX_ERR(1, 41, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_exists); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 41, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_7 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
        __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_3);
        if (likely(__pyx_t_7)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
          __Pyx_INCREF(__pyx_t_7);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_3, function);
        }
      }
      __pyx_t_4 = (__pyx_t_7) ? __Pyx_PyObject_Call2Args(__pyx_t_3, __pyx_t_7, __pyx_v_path) : __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_v_path);
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 41, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_3 = PyObject_RichCompare(__pyx_t_4, Py_False, Py_EQ); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 41, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(1, 41, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(__pyx_t_2)) {

        /* "ttygif/tty/theme.pyx":42
 *                 path=os.path.join(self.path,'layers',self.file)
 *                 if os.path.exists(path)==False:
 *                     err="Invalid image file: {0}".format(path)             # <<<<<<<<<<<<<<
 *                     raise Exception(err)
 *         else:
 */
        __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_kp_s_Invalid_image_file_0, __pyx_n_s_format); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 42, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __pyx_t_7 = NULL;
        if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
          __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_4);
          if (likely(__pyx_t_7)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
            __Pyx_INCREF(__pyx_t_7);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_4, function);
          }
        }
        __pyx_t_3 = (__pyx_t_7) ? __Pyx_PyObject_Call2Args(__pyx_t_4, __pyx_t_7, __pyx_v_path) : __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_v_path);
        __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
        if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 42, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __pyx_v_err = __pyx_t_3;
        __pyx_t_3 = 0;

        /* "ttygif/tty/theme.pyx":43
 *                 if os.path.exists(path)==False:
 *                     err="Invalid image file: {0}".format(path)
 *                     raise Exception(err)             # <<<<<<<<<<<<<<
 *         else:
 *             path=self.file
 */
        __pyx_t_3 = __Pyx_PyObject_CallOneArg(((PyObject *)(&((PyTypeObject*)PyExc_Exception)[0])), __pyx_v_err); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 43, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_Raise(__pyx_t_3, 0, 0, 0);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __PYX_ERR(1, 43, __pyx_L1_error)

        /* "ttygif/tty/theme.pyx":41
 *             if os.path.isdir(self.path)==True:
 *                 path=os.path.join(self.path,'layers',self.file)
 *                 if os.path.exists(path)==False:             # <<<<<<<<<<<<<<
 *                     err="Invalid image file: {0}".format(path)
 *                     raise Exception(err)
 */
      }

      /* "ttygif/tty/theme.pyx":39
 * 
 *         if self.path:
 *             if os.path.isdir(self.path)==True:             # <<<<<<<<<<<<<<
 *                 path=os.path.join(self.path,'layers',self.file)
 *                 if os.path.exists(path)==False:
 */
    }

    /* "ttygif/tty/theme.pyx":38
 *         # try the image given, otherwise tryin the layers folder in the module
 * 
 *         if self.path:             # <<<<<<<<<<<<<<
 *             if os.path.isdir(self.path)==True:
 *                 path=os.path.join(self.path,'layers',self.file)
 */
    goto __pyx_L3;
  }

  /* "ttygif/tty/theme.pyx":45
 *                     raise Exception(err)
 *         else:
 *             path=self.file             # <<<<<<<<<<<<<<
 * 
 *         cdef image temp_image
 */
  /*else*/ {
    __pyx_t_3 = __pyx_v_self->file;
    __Pyx_INCREF(__pyx_t_3);
    __pyx_v_path = __pyx_t_3;
    __pyx_t_3 = 0;
  }
  __pyx_L3:;

  /* "ttygif/tty/theme.pyx":48
 * 
 *         cdef image temp_image
 *         underlay_image=decode(path)             # <<<<<<<<<<<<<<
 *         gif_raw=underlay_image.get()
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_decode); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 48, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (unlikely(!__pyx_v_path)) { __Pyx_RaiseUnboundLocalError("path"); __PYX_ERR(1, 48, __pyx_L1_error) }
  __pyx_t_7 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
    }
  }
  __pyx_t_3 = (__pyx_t_7) ? __Pyx_PyObject_Call2Args(__pyx_t_4, __pyx_t_7, __pyx_v_path) : __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_v_path);
  __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
  if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 48, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_v_underlay_image = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "ttygif/tty/theme.pyx":49
 *         cdef image temp_image
 *         underlay_image=decode(path)
 *         gif_raw=underlay_image.get()             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_underlay_image, __pyx_n_s_get); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 49, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_7 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
    }
  }
  __pyx_t_3 = (__pyx_t_7) ? __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_t_7) : __Pyx_PyObject_CallNoArg(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
  if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 49, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_v_gif_raw = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "ttygif/tty/theme.pyx":53
 * 
 * 
 *         gif_width =gif_raw['header'].ScreenWidth             # <<<<<<<<<<<<<<
 *         gif_height=gif_raw['header'].ScreenHeight
 * 
 */
  __pyx_t_3 = __Pyx_PyObject_Dict_GetItem(__pyx_v_gif_raw, __pyx_n_s_header); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 53, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_ScreenWidth); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 53, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_v_gif_width = __pyx_t_4;
  __pyx_t_4 = 0;

  /* "ttygif/tty/theme.pyx":54
 * 
 *         gif_width =gif_raw['header'].ScreenWidth
 *         gif_height=gif_raw['header'].ScreenHeight             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_t_4 = __Pyx_PyObject_Dict_GetItem(__pyx_v_gif_raw, __pyx_n_s_header); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 54, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_ScreenHeight); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 54, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_v_gif_height = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "ttygif/tty/theme.pyx":57
 * 
 * 
 *         for frame in gif_raw['frames']:             # <<<<<<<<<<<<<<
 *             if frame['image']:
 *                 attribs=frame['descriptor']
 */
  __pyx_t_3 = __Pyx_PyObject_Dict_GetItem(__pyx_v_gif_raw, __pyx_n_s_frames); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 57, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (likely(PyList_CheckExact(__pyx_t_3)) || PyTuple_CheckExact(__pyx_t_3)) {
    __pyx_t_4 = __pyx_t_3; __Pyx_INCREF(__pyx_t_4); __pyx_t_8 = 0;
    __pyx_t_9 = NULL;
  } else {
    __pyx_t_8 = -1; __pyx_t_4 = PyObject_GetIter(__pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 57, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_9 = Py_TYPE(__pyx_t_4)->tp_iternext; if (unlikely(!__pyx_t_9)) __PYX_ERR(1, 57, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  for (;;) {
    if (likely(!__pyx_t_9)) {
      if (likely(PyList_CheckExact(__pyx_t_4))) {
        if (__pyx_t_8 >= PyList_GET_SIZE(__pyx_t_4)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_3 = PyList_GET_ITEM(__pyx_t_4, __pyx_t_8); __Pyx_INCREF(__pyx_t_3); __pyx_t_8++; if (unlikely(0 < 0)) __PYX_ERR(1, 57, __pyx_L1_error)
        #else
        __pyx_t_3 = PySequence_ITEM(__pyx_t_4, __pyx_t_8); __pyx_t_8++; if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 57, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        #endif
      } else {
        if (__pyx_t_8 >= PyTuple_GET_SIZE(__pyx_t_4)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_3 = PyTuple_GET_ITEM(__pyx_t_4, __pyx_t_8); __Pyx_INCREF(__pyx_t_3); __pyx_t_8++; if (unlikely(0 < 0)) __PYX_ERR(1, 57, __pyx_L1_error)
        #else
        __pyx_t_3 = PySequence_ITEM(__pyx_t_4, __pyx_t_8); __pyx_t_8++; if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 57, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        #endif
      }
    } else {
      __pyx_t_3 = __pyx_t_9(__pyx_t_4);
      if (unlikely(!__pyx_t_3)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(1, 57, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_3);
    }
    __Pyx_XDECREF_SET(__pyx_v_frame, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "ttygif/tty/theme.pyx":58
 * 
 *         for frame in gif_raw['frames']:
 *             if frame['image']:             # <<<<<<<<<<<<<<
 *                 attribs=frame['descriptor']
 * 
 */
    __pyx_t_3 = __Pyx_PyObject_Dict_GetItem(__pyx_v_frame, __pyx_n_s_image); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 58, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(1, 58, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (__pyx_t_2) {

      /* "ttygif/tty/theme.pyx":59
 *         for frame in gif_raw['frames']:
 *             if frame['image']:
 *                 attribs=frame['descriptor']             # <<<<<<<<<<<<<<
 * 
 *                 # if not set auto set...
 */
      __pyx_t_3 = __Pyx_PyObject_Dict_GetItem(__pyx_v_frame, __pyx_n_s_descriptor); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 59, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_v_attribs = __pyx_t_3;
      __pyx_t_3 = 0;

      /* "ttygif/tty/theme.pyx":62
 * 
 *                 # if not set auto set...
 *                 if self.outer.top==0 and self.outer.left==0 and self.outer.right==0 and self.outer.bottom==0:             # <<<<<<<<<<<<<<
 *                     self.outer =rect(0,0,gif_width-1,gif_height-1)
 *                 if self.bounds.top==0 and self.bounds.left==0 and self.bounds.right==0 and self.bounds.bottom==0:
 */
      __pyx_t_10 = ((__pyx_v_self->outer->top == 0) != 0);
      if (__pyx_t_10) {
      } else {
        __pyx_t_2 = __pyx_t_10;
        goto __pyx_L10_bool_binop_done;
      }
      __pyx_t_10 = ((__pyx_v_self->outer->left == 0) != 0);
      if (__pyx_t_10) {
      } else {
        __pyx_t_2 = __pyx_t_10;
        goto __pyx_L10_bool_binop_done;
      }
      __pyx_t_10 = ((__pyx_v_self->outer->right == 0) != 0);
      if (__pyx_t_10) {
      } else {
        __pyx_t_2 = __pyx_t_10;
        goto __pyx_L10_bool_binop_done;
      }
      __pyx_t_10 = ((__pyx_v_self->outer->bottom == 0) != 0);
      __pyx_t_2 = __pyx_t_10;
      __pyx_L10_bool_binop_done:;
      if (__pyx_t_2) {

        /* "ttygif/tty/theme.pyx":63
 *                 # if not set auto set...
 *                 if self.outer.top==0 and self.outer.left==0 and self.outer.right==0 and self.outer.bottom==0:
 *                     self.outer =rect(0,0,gif_width-1,gif_height-1)             # <<<<<<<<<<<<<<
 *                 if self.bounds.top==0 and self.bounds.left==0 and self.bounds.right==0 and self.bounds.bottom==0:
 *                     self.bounds =rect(0,0,gif_width-1,gif_height-1)
 */
        __pyx_t_3 = __Pyx_PyInt_SubtractObjC(__pyx_v_gif_width, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 63, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_t_7 = __Pyx_PyInt_SubtractObjC(__pyx_v_gif_height, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_7)) __PYX_ERR(1, 63, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __pyx_t_5 = PyTuple_New(4); if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 63, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_INCREF(__pyx_int_0);
        __Pyx_GIVEREF(__pyx_int_0);
        PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_int_0);
        __Pyx_INCREF(__pyx_int_0);
        __Pyx_GIVEREF(__pyx_int_0);
        PyTuple_SET_ITEM(__pyx_t_5, 1, __pyx_int_0);
        __Pyx_GIVEREF(__pyx_t_3);
        PyTuple_SET_ITEM(__pyx_t_5, 2, __pyx_t_3);
        __Pyx_GIVEREF(__pyx_t_7);
        PyTuple_SET_ITEM(__pyx_t_5, 3, __pyx_t_7);
        __pyx_t_3 = 0;
        __pyx_t_7 = 0;
        __pyx_t_7 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_6ttygif_3tty_5image_rect), __pyx_t_5, NULL); if (unlikely(!__pyx_t_7)) __PYX_ERR(1, 63, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_GIVEREF(__pyx_t_7);
        __Pyx_GOTREF(__pyx_v_self->outer);
        __Pyx_DECREF(((PyObject *)__pyx_v_self->outer));
        __pyx_v_self->outer = ((struct __pyx_obj_6ttygif_3tty_5image_rect *)__pyx_t_7);
        __pyx_t_7 = 0;

        /* "ttygif/tty/theme.pyx":62
 * 
 *                 # if not set auto set...
 *                 if self.outer.top==0 and self.outer.left==0 and self.outer.right==0 and self.outer.bottom==0:             # <<<<<<<<<<<<<<
 *                     self.outer =rect(0,0,gif_width-1,gif_height-1)
 *                 if self.bounds.top==0 and self.bounds.left==0 and self.bounds.right==0 and self.bounds.bottom==0:
 */
      }

      /* "ttygif/tty/theme.pyx":64
 *                 if self.outer.top==0 and self.outer.left==0 and self.outer.right==0 and self.outer.bottom==0:
 *                     self.outer =rect(0,0,gif_width-1,gif_height-1)
 *                 if self.bounds.top==0 and self.bounds.left==0 and self.bounds.right==0 and self.bounds.bottom==0:             # <<<<<<<<<<<<<<
 *                     self.bounds =rect(0,0,gif_width-1,gif_height-1)
 * 
 */
      __pyx_t_10 = ((__pyx_v_self->bounds->top == 0) != 0);
      if (__pyx_t_10) {
      } else {
        __pyx_t_2 = __pyx_t_10;
        goto __pyx_L15_bool_binop_done;
      }
      __pyx_t_10 = ((__pyx_v_self->bounds->left == 0) != 0);
      if (__pyx_t_10) {
      } else {
        __pyx_t_2 = __pyx_t_10;
        goto __pyx_L15_bool_binop_done;
      }
      __pyx_t_10 = ((__pyx_v_self->bounds->right == 0) != 0);
      if (__pyx_t_10) {
      } else {
        __pyx_t_2 = __pyx_t_10;
        goto __pyx_L15_bool_binop_done;
      }
      __pyx_t_10 = ((__pyx_v_self->bounds->bottom == 0) != 0);
      __pyx_t_2 = __pyx_t_10;
      __pyx_L15_bool_binop_done:;
      if (__pyx_t_2) {

        /* "ttygif/tty/theme.pyx":65
 *                     self.outer =rect(0,0,gif_width-1,gif_height-1)
 *                 if self.bounds.top==0 and self.bounds.left==0 and self.bounds.right==0 and self.bounds.bottom==0:
 *                     self.bounds =rect(0,0,gif_width-1,gif_height-1)             # <<<<<<<<<<<<<<
 * 
 *                 self.image=image(1,attribs.Width,attribs.Height,array.array('B',gif_raw['global_color_table'].colors),clear_1)
 */
        __pyx_t_7 = __Pyx_PyInt_SubtractObjC(__pyx_v_gif_width, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_7)) __PYX_ERR(1, 65, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __pyx_t_5 = __Pyx_PyInt_SubtractObjC(__pyx_v_gif_height, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 65, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        __pyx_t_3 = PyTuple_New(4); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 65, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_INCREF(__pyx_int_0);
        __Pyx_GIVEREF(__pyx_int_0);
        PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_int_0);
        __Pyx_INCREF(__pyx_int_0);
        __Pyx_GIVEREF(__pyx_int_0);
        PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_int_0);
        __Pyx_GIVEREF(__pyx_t_7);
        PyTuple_SET_ITEM(__pyx_t_3, 2, __pyx_t_7);
        __Pyx_GIVEREF(__pyx_t_5);
        PyTuple_SET_ITEM(__pyx_t_3, 3, __pyx_t_5);
        __pyx_t_7 = 0;
        __pyx_t_5 = 0;
        __pyx_t_5 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_6ttygif_3tty_5image_rect), __pyx_t_3, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 65, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_GIVEREF(__pyx_t_5);
        __Pyx_GOTREF(__pyx_v_self->bounds);
        __Pyx_DECREF(((PyObject *)__pyx_v_self->bounds));
        __pyx_v_self->bounds = ((struct __pyx_obj_6ttygif_3tty_5image_rect *)__pyx_t_5);
        __pyx_t_5 = 0;

        /* "ttygif/tty/theme.pyx":64
 *                 if self.outer.top==0 and self.outer.left==0 and self.outer.right==0 and self.outer.bottom==0:
 *                     self.outer =rect(0,0,gif_width-1,gif_height-1)
 *                 if self.bounds.top==0 and self.bounds.left==0 and self.bounds.right==0 and self.bounds.bottom==0:             # <<<<<<<<<<<<<<
 *                     self.bounds =rect(0,0,gif_width-1,gif_height-1)
 * 
 */
      }

      /* "ttygif/tty/theme.pyx":67
 *                     self.bounds =rect(0,0,gif_width-1,gif_height-1)
 * 
 *                 self.image=image(1,attribs.Width,attribs.Height,array.array('B',gif_raw['global_color_table'].colors),clear_1)             # <<<<<<<<<<<<<<
 *                 self.image.data=frame['image'].data
 *                 if frame['gc']==None:
 */
      __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_attribs, __pyx_n_s_Width); if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 67, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_attribs, __pyx_n_s_Height); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 67, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_7 = __Pyx_PyObject_Dict_GetItem(__pyx_v_gif_raw, __pyx_n_s_global_color_table); if (unlikely(!__pyx_t_7)) __PYX_ERR(1, 67, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_11 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_colors); if (unlikely(!__pyx_t_11)) __PYX_ERR(1, 67, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_11);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_7 = PyTuple_New(2); if (unlikely(!__pyx_t_7)) __PYX_ERR(1, 67, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_INCREF(__pyx_n_s_B);
      __Pyx_GIVEREF(__pyx_n_s_B);
      PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_n_s_B);
      __Pyx_GIVEREF(__pyx_t_11);
      PyTuple_SET_ITEM(__pyx_t_7, 1, __pyx_t_11);
      __pyx_t_11 = 0;
      __pyx_t_11 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cpython_5array_array), __pyx_t_7, NULL); if (unlikely(!__pyx_t_11)) __PYX_ERR(1, 67, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_11);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_7 = __Pyx_PyObject_FromCString(__pyx_v_clear_1); if (unlikely(!__pyx_t_7)) __PYX_ERR(1, 67, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_12 = PyTuple_New(5); if (unlikely(!__pyx_t_12)) __PYX_ERR(1, 67, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_12);
      __Pyx_INCREF(__pyx_int_1);
      __Pyx_GIVEREF(__pyx_int_1);
      PyTuple_SET_ITEM(__pyx_t_12, 0, __pyx_int_1);
      __Pyx_GIVEREF(__pyx_t_5);
      PyTuple_SET_ITEM(__pyx_t_12, 1, __pyx_t_5);
      __Pyx_GIVEREF(__pyx_t_3);
      PyTuple_SET_ITEM(__pyx_t_12, 2, __pyx_t_3);
      __Pyx_GIVEREF(__pyx_t_11);
      PyTuple_SET_ITEM(__pyx_t_12, 3, __pyx_t_11);
      __Pyx_GIVEREF(__pyx_t_7);
      PyTuple_SET_ITEM(__pyx_t_12, 4, __pyx_t_7);
      __pyx_t_5 = 0;
      __pyx_t_3 = 0;
      __pyx_t_11 = 0;
      __pyx_t_7 = 0;
      __pyx_t_7 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_6ttygif_3tty_5image_image), __pyx_t_12, NULL); if (unlikely(!__pyx_t_7)) __PYX_ERR(1, 67, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
      __Pyx_GIVEREF(__pyx_t_7);
      __Pyx_GOTREF(__pyx_v_self->image);
      __Pyx_DECREF(((PyObject *)__pyx_v_self->image));
      __pyx_v_self->image = ((struct __pyx_obj_6ttygif_3tty_5image_image *)__pyx_t_7);
      __pyx_t_7 = 0;

      /* "ttygif/tty/theme.pyx":68
 * 
 *                 self.image=image(1,attribs.Width,attribs.Height,array.array('B',gif_raw['global_color_table'].colors),clear_1)
 *                 self.image.data=frame['image'].data             # <<<<<<<<<<<<<<
 *                 if frame['gc']==None:
 *                         self.image.transparent=-1
 */
      __pyx_t_7 = __Pyx_PyObject_Dict_GetItem(__pyx_v_frame, __pyx_n_s_image); if (unlikely(!__pyx_t_7)) __PYX_ERR(1, 68, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_12 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_data); if (unlikely(!__pyx_t_12)) __PYX_ERR(1, 68, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_12);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      if (!(likely(((__pyx_t_12) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_12, __pyx_ptype_7cpython_5array_array))))) __PYX_ERR(1, 68, __pyx_L1_error)
      __Pyx_GIVEREF(__pyx_t_12);
      __Pyx_GOTREF(__pyx_v_self->image->data);
      __Pyx_DECREF(((PyObject *)__pyx_v_self->image->data));
      __pyx_v_self->image->data = ((arrayobject *)__pyx_t_12);
      __pyx_t_12 = 0;

      /* "ttygif/tty/theme.pyx":69
 *                 self.image=image(1,attribs.Width,attribs.Height,array.array('B',gif_raw['global_color_table'].colors),clear_1)
 *                 self.image.data=frame['image'].data
 *                 if frame['gc']==None:             # <<<<<<<<<<<<<<
 *                         self.image.transparent=-1
 *                 else:
 */
      __pyx_t_12 = __Pyx_PyObject_Dict_GetItem(__pyx_v_frame, __pyx_n_s_gc); if (unlikely(!__pyx_t_12)) __PYX_ERR(1, 69, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_12);
      __pyx_t_7 = PyObject_RichCompare(__pyx_t_12, Py_None, Py_EQ); __Pyx_XGOTREF(__pyx_t_7); if (unlikely(!__pyx_t_7)) __PYX_ERR(1, 69, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
      __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_7); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(1, 69, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      if (__pyx_t_2) {

        /* "ttygif/tty/theme.pyx":70
 *                 self.image.data=frame['image'].data
 *                 if frame['gc']==None:
 *                         self.image.transparent=-1             # <<<<<<<<<<<<<<
 *                 else:
 *                     if frame['gc'].TransparentColorFlag==0:
 */
        __pyx_v_self->image->transparent = -1;

        /* "ttygif/tty/theme.pyx":69
 *                 self.image=image(1,attribs.Width,attribs.Height,array.array('B',gif_raw['global_color_table'].colors),clear_1)
 *                 self.image.data=frame['image'].data
 *                 if frame['gc']==None:             # <<<<<<<<<<<<<<
 *                         self.image.transparent=-1
 *                 else:
 */
        goto __pyx_L19;
      }

      /* "ttygif/tty/theme.pyx":72
 *                         self.image.transparent=-1
 *                 else:
 *                     if frame['gc'].TransparentColorFlag==0:             # <<<<<<<<<<<<<<
 *                         self.image.transparent=-1
 *                     if frame['gc'].TransparentColorFlag==1:
 */
      /*else*/ {
        __pyx_t_7 = __Pyx_PyObject_Dict_GetItem(__pyx_v_frame, __pyx_n_s_gc); if (unlikely(!__pyx_t_7)) __PYX_ERR(1, 72, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __pyx_t_12 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_TransparentColorFlag); if (unlikely(!__pyx_t_12)) __PYX_ERR(1, 72, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_12);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        __pyx_t_7 = __Pyx_PyInt_EqObjC(__pyx_t_12, __pyx_int_0, 0, 0); if (unlikely(!__pyx_t_7)) __PYX_ERR(1, 72, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
        __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_7); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(1, 72, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        if (__pyx_t_2) {

          /* "ttygif/tty/theme.pyx":73
 *                 else:
 *                     if frame['gc'].TransparentColorFlag==0:
 *                         self.image.transparent=-1             # <<<<<<<<<<<<<<
 *                     if frame['gc'].TransparentColorFlag==1:
 *                         self.image.transparent=frame['gc'].ColorIndex
 */
          __pyx_v_self->image->transparent = -1;

          /* "ttygif/tty/theme.pyx":72
 *                         self.image.transparent=-1
 *                 else:
 *                     if frame['gc'].TransparentColorFlag==0:             # <<<<<<<<<<<<<<
 *                         self.image.transparent=-1
 *                     if frame['gc'].TransparentColorFlag==1:
 */
        }

        /* "ttygif/tty/theme.pyx":74
 *                     if frame['gc'].TransparentColorFlag==0:
 *                         self.image.transparent=-1
 *                     if frame['gc'].TransparentColorFlag==1:             # <<<<<<<<<<<<<<
 *                         self.image.transparent=frame['gc'].ColorIndex
 *                 self.image.remap_image(palette,self.image.transparent)
 */
        __pyx_t_7 = __Pyx_PyObject_Dict_GetItem(__pyx_v_frame, __pyx_n_s_gc); if (unlikely(!__pyx_t_7)) __PYX_ERR(1, 74, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __pyx_t_12 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_TransparentColorFlag); if (unlikely(!__pyx_t_12)) __PYX_ERR(1, 74, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_12);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        __pyx_t_7 = __Pyx_PyInt_EqObjC(__pyx_t_12, __pyx_int_1, 1, 0); if (unlikely(!__pyx_t_7)) __PYX_ERR(1, 74, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
        __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_7); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(1, 74, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        if (__pyx_t_2) {

          /* "ttygif/tty/theme.pyx":75
 *                         self.image.transparent=-1
 *                     if frame['gc'].TransparentColorFlag==1:
 *                         self.image.transparent=frame['gc'].ColorIndex             # <<<<<<<<<<<<<<
 *                 self.image.remap_image(palette,self.image.transparent)
 *                 return
 */
          __pyx_t_7 = __Pyx_PyObject_Dict_GetItem(__pyx_v_frame, __pyx_n_s_gc); if (unlikely(!__pyx_t_7)) __PYX_ERR(1, 75, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_7);
          __pyx_t_12 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_ColorIndex); if (unlikely(!__pyx_t_12)) __PYX_ERR(1, 75, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_12);
          __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
          __pyx_t_6 = __Pyx_PyInt_As_int(__pyx_t_12); if (unlikely((__pyx_t_6 == (int)-1) && PyErr_Occurred())) __PYX_ERR(1, 75, __pyx_L1_error)
          __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
          __pyx_v_self->image->transparent = __pyx_t_6;

          /* "ttygif/tty/theme.pyx":74
 *                     if frame['gc'].TransparentColorFlag==0:
 *                         self.image.transparent=-1
 *                     if frame['gc'].TransparentColorFlag==1:             # <<<<<<<<<<<<<<
 *                         self.image.transparent=frame['gc'].ColorIndex
 *                 self.image.remap_image(palette,self.image.transparent)
 */
        }
      }
      __pyx_L19:;

      /* "ttygif/tty/theme.pyx":76
 *                     if frame['gc'].TransparentColorFlag==1:
 *                         self.image.transparent=frame['gc'].ColorIndex
 *                 self.image.remap_image(palette,self.image.transparent)             # <<<<<<<<<<<<<<
 *                 return
 * 
 */
      __pyx_t_12 = ((struct __pyx_vtabstruct_6ttygif_3tty_5image_image *)__pyx_v_self->image->__pyx_vtab)->remap_image(__pyx_v_self->image, __pyx_v_palette, __pyx_v_self->image->transparent); if (unlikely(!__pyx_t_12)) __PYX_ERR(1, 76, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_12);
      __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;

      /* "ttygif/tty/theme.pyx":77
 *                         self.image.transparent=frame['gc'].ColorIndex
 *                 self.image.remap_image(palette,self.image.transparent)
 *                 return             # <<<<<<<<<<<<<<
 * 
 * 
 */
      __Pyx_XDECREF(__pyx_r);
      __pyx_r = Py_None; __Pyx_INCREF(Py_None);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      goto __pyx_L0;

      /* "ttygif/tty/theme.pyx":58
 * 
 *         for frame in gif_raw['frames']:
 *             if frame['image']:             # <<<<<<<<<<<<<<
 *                 attribs=frame['descriptor']
 * 
 */
    }

    /* "ttygif/tty/theme.pyx":57
 * 
 * 
 *         for frame in gif_raw['frames']:             # <<<<<<<<<<<<<<
 *             if frame['image']:
 *                 attribs=frame['descriptor']
 */
  }
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "ttygif/tty/theme.pyx":33
 * 
 * 
 *     cdef load_file(self,array.array palette):             # <<<<<<<<<<<<<<
 *         cdef uint8_t[1] clear_1=[0]
 *         autoloader=None
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_XDECREF(__pyx_t_12);
  __Pyx_AddTraceback("ttygif.tty.theme.layer.load_file", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_autoloader);
  __Pyx_XDECREF(__pyx_v_path);
  __Pyx_XDECREF(__pyx_v_err);
  __Pyx_XDECREF(__pyx_v_underlay_image);
  __Pyx_XDECREF(__pyx_v_gif_raw);
  __Pyx_XDECREF(__pyx_v_gif_width);
  __Pyx_XDECREF(__pyx_v_gif_height);
  __Pyx_XDECREF(__pyx_v_frame);
  __Pyx_XDECREF(__pyx_v_attribs);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_TraceReturn(__pyx_r, 0);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "ttygif/tty/theme.pyx":81
 * 
 * 
 *     cdef debug(self):             # <<<<<<<<<<<<<<
 *         print("Layer")
 *         print("  name:      {0}".format(self.name))
 */

static PyObject *__pyx_f_6ttygif_3tty_5theme_5layer_debug(struct __pyx_obj_6ttygif_3tty_5theme_layer *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_TraceDeclarations
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("debug", 0);
  __Pyx_TraceCall("debug", __pyx_f[1], 81, 0, __PYX_ERR(1, 81, __pyx_L1_error));

  /* "ttygif/tty/theme.pyx":82
 * 
 *     cdef debug(self):
 *         print("Layer")             # <<<<<<<<<<<<<<
 *         print("  name:      {0}".format(self.name))
 *         print("  z_index:   {0}".format(self.z_index))
 */
  if (__Pyx_PrintOne(0, __pyx_n_s_Layer) < 0) __PYX_ERR(1, 82, __pyx_L1_error)

  /* "ttygif/tty/theme.pyx":83
 *     cdef debug(self):
 *         print("Layer")
 *         print("  name:      {0}".format(self.name))             # <<<<<<<<<<<<<<
 *         print("  z_index:   {0}".format(self.z_index))
 *         print("  file:      {0}".format(self.file))
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_kp_s_name_0, __pyx_n_s_format); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 83, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  __pyx_t_1 = (__pyx_t_3) ? __Pyx_PyObject_Call2Args(__pyx_t_2, __pyx_t_3, __pyx_v_self->name) : __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_v_self->name);
  __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 83, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__Pyx_PrintOne(0, __pyx_t_1) < 0) __PYX_ERR(1, 83, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "ttygif/tty/theme.pyx":84
 *         print("Layer")
 *         print("  name:      {0}".format(self.name))
 *         print("  z_index:   {0}".format(self.z_index))             # <<<<<<<<<<<<<<
 *         print("  file:      {0}".format(self.file))
 *         print("  mode:      {0}".format(self.mode))
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_kp_s_z_index_0, __pyx_n_s_format); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 84, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyInt_From_int16_t(__pyx_v_self->z_index); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 84, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  __pyx_t_1 = (__pyx_t_4) ? __Pyx_PyObject_Call2Args(__pyx_t_2, __pyx_t_4, __pyx_t_3) : __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 84, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__Pyx_PrintOne(0, __pyx_t_1) < 0) __PYX_ERR(1, 84, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "ttygif/tty/theme.pyx":85
 *         print("  name:      {0}".format(self.name))
 *         print("  z_index:   {0}".format(self.z_index))
 *         print("  file:      {0}".format(self.file))             # <<<<<<<<<<<<<<
 *         print("  mode:      {0}".format(self.mode))
 *         print("copy-mode:   {0}".format(self.copy_mode))
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_kp_s_file_0, __pyx_n_s_format); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 85, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  __pyx_t_1 = (__pyx_t_3) ? __Pyx_PyObject_Call2Args(__pyx_t_2, __pyx_t_3, __pyx_v_self->file) : __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_v_self->file);
  __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 85, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__Pyx_PrintOne(0, __pyx_t_1) < 0) __PYX_ERR(1, 85, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "ttygif/tty/theme.pyx":86
 *         print("  z_index:   {0}".format(self.z_index))
 *         print("  file:      {0}".format(self.file))
 *         print("  mode:      {0}".format(self.mode))             # <<<<<<<<<<<<<<
 *         print("copy-mode:   {0}".format(self.copy_mode))
 *         print("transparent: {0}".format(self.transparent))
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_kp_s_mode_0, __pyx_n_s_format); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 86, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  __pyx_t_1 = (__pyx_t_3) ? __Pyx_PyObject_Call2Args(__pyx_t_2, __pyx_t_3, __pyx_v_self->mode) : __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_v_self->mode);
  __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 86, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__Pyx_PrintOne(0, __pyx_t_1) < 0) __PYX_ERR(1, 86, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "ttygif/tty/theme.pyx":87
 *         print("  file:      {0}".format(self.file))
 *         print("  mode:      {0}".format(self.mode))
 *         print("copy-mode:   {0}".format(self.copy_mode))             # <<<<<<<<<<<<<<
 *         print("transparent: {0}".format(self.transparent))
 *         print("Outer: ")
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_kp_s_copy_mode_0, __pyx_n_s_format); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 87, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  __pyx_t_1 = (__pyx_t_3) ? __Pyx_PyObject_Call2Args(__pyx_t_2, __pyx_t_3, __pyx_v_self->copy_mode) : __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_v_self->copy_mode);
  __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 87, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__Pyx_PrintOne(0, __pyx_t_1) < 0) __PYX_ERR(1, 87, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "ttygif/tty/theme.pyx":88
 *         print("  mode:      {0}".format(self.mode))
 *         print("copy-mode:   {0}".format(self.copy_mode))
 *         print("transparent: {0}".format(self.transparent))             # <<<<<<<<<<<<<<
 *         print("Outer: ")
 *         self.outer.debug()
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_kp_s_transparent_0, __pyx_n_s_format); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 88, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyInt_From_int16_t(__pyx_v_self->transparent); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 88, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  __pyx_t_1 = (__pyx_t_4) ? __Pyx_PyObject_Call2Args(__pyx_t_2, __pyx_t_4, __pyx_t_3) : __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 88, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__Pyx_PrintOne(0, __pyx_t_1) < 0) __PYX_ERR(1, 88, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "ttygif/tty/theme.pyx":89
 *         print("copy-mode:   {0}".format(self.copy_mode))
 *         print("transparent: {0}".format(self.transparent))
 *         print("Outer: ")             # <<<<<<<<<<<<<<
 *         self.outer.debug()
 *         print("Inner: ")
 */
  if (__Pyx_PrintOne(0, __pyx_kp_s_Outer) < 0) __PYX_ERR(1, 89, __pyx_L1_error)

  /* "ttygif/tty/theme.pyx":90
 *         print("transparent: {0}".format(self.transparent))
 *         print("Outer: ")
 *         self.outer.debug()             # <<<<<<<<<<<<<<
 *         print("Inner: ")
 *         self.inner.debug()
 */
  __pyx_t_1 = ((struct __pyx_vtabstruct_6ttygif_3tty_5image_rect *)__pyx_v_self->outer->__pyx_vtab)->debug(__pyx_v_self->outer); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 90, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "ttygif/tty/theme.pyx":91
 *         print("Outer: ")
 *         self.outer.debug()
 *         print("Inner: ")             # <<<<<<<<<<<<<<
 *         self.inner.debug()
 *         print("Bounds: ")
 */
  if (__Pyx_PrintOne(0, __pyx_kp_s_Inner) < 0) __PYX_ERR(1, 91, __pyx_L1_error)

  /* "ttygif/tty/theme.pyx":92
 *         self.outer.debug()
 *         print("Inner: ")
 *         self.inner.debug()             # <<<<<<<<<<<<<<
 *         print("Bounds: ")
 *         self.bounds.debug()
 */
  __pyx_t_1 = ((struct __pyx_vtabstruct_6ttygif_3tty_5image_rect *)__pyx_v_self->inner->__pyx_vtab)->debug(__pyx_v_self->inner); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 92, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "ttygif/tty/theme.pyx":93
 *         print("Inner: ")
 *         self.inner.debug()
 *         print("Bounds: ")             # <<<<<<<<<<<<<<
 *         self.bounds.debug()
 *         print("Dst: ")
 */
  if (__Pyx_PrintOne(0, __pyx_kp_s_Bounds) < 0) __PYX_ERR(1, 93, __pyx_L1_error)

  /* "ttygif/tty/theme.pyx":94
 *         self.inner.debug()
 *         print("Bounds: ")
 *         self.bounds.debug()             # <<<<<<<<<<<<<<
 *         print("Dst: ")
 *         self.dst.debug()
 */
  __pyx_t_1 = ((struct __pyx_vtabstruct_6ttygif_3tty_5image_rect *)__pyx_v_self->bounds->__pyx_vtab)->debug(__pyx_v_self->bounds); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 94, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "ttygif/tty/theme.pyx":95
 *         print("Bounds: ")
 *         self.bounds.debug()
 *         print("Dst: ")             # <<<<<<<<<<<<<<
 *         self.dst.debug()
 * 
 */
  if (__Pyx_PrintOne(0, __pyx_kp_s_Dst) < 0) __PYX_ERR(1, 95, __pyx_L1_error)

  /* "ttygif/tty/theme.pyx":96
 *         self.bounds.debug()
 *         print("Dst: ")
 *         self.dst.debug()             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_t_1 = ((struct __pyx_vtabstruct_6ttygif_3tty_5image_rect *)__pyx_v_self->dst->__pyx_vtab)->debug(__pyx_v_self->dst); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 96, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "ttygif/tty/theme.pyx":81
 * 
 * 
 *     cdef debug(self):             # <<<<<<<<<<<<<<
 *         print("Layer")
 *         print("  name:      {0}".format(self.name))
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("ttygif.tty.theme.layer.debug", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_TraceReturn(__pyx_r, 0);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):
 */

/* Python wrapper */
static PyObject *__pyx_pw_6ttygif_3tty_5theme_5layer_3__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyMethodDef __pyx_mdef_6ttygif_3tty_5theme_5layer_3__reduce_cython__ = {"__reduce_cython__", (PyCFunction)__pyx_pw_6ttygif_3tty_5theme_5layer_3__reduce_cython__, METH_NOARGS, 0};
static PyObject *__pyx_pw_6ttygif_3tty_5theme_5layer_3__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
  __pyx_r = __pyx_pf_6ttygif_3tty_5theme_5layer_2__reduce_cython__(((struct __pyx_obj_6ttygif_3tty_5theme_layer *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6ttygif_3tty_5theme_5layer_2__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_6ttygif_3tty_5theme_layer *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_TraceDeclarations
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_TraceFrameInit(__pyx_codeobj__4)
  __Pyx_RefNannySetupContext("__reduce_cython__", 0);
  __Pyx_TraceCall("__reduce_cython__", __pyx_f[0], 1, 0, __PYX_ERR(0, 1, __pyx_L1_error));

  /* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 */
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_TypeError, __pyx_tuple__5, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_Raise(__pyx_t_1, 0, 0, 0);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __PYX_ERR(0, 2, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("ttygif.tty.theme.layer.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_TraceReturn(__pyx_r, 0);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 */

/* Python wrapper */
static PyObject *__pyx_pw_6ttygif_3tty_5theme_5layer_5__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state); /*proto*/
static PyMethodDef __pyx_mdef_6ttygif_3tty_5theme_5layer_5__setstate_cython__ = {"__setstate_cython__", (PyCFunction)__pyx_pw_6ttygif_3tty_5theme_5layer_5__setstate_cython__, METH_O, 0};
static PyObject *__pyx_pw_6ttygif_3tty_5theme_5layer_5__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
  __pyx_r = __pyx_pf_6ttygif_3tty_5theme_5layer_4__setstate_cython__(((struct __pyx_obj_6ttygif_3tty_5theme_layer *)__pyx_v_self), ((PyObject *)__pyx_v___pyx_state));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6ttygif_3tty_5theme_5layer_4__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_6ttygif_3tty_5theme_layer *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_TraceDeclarations
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_TraceFrameInit(__pyx_codeobj__6)
  __Pyx_RefNannySetupContext("__setstate_cython__", 0);
  __Pyx_TraceCall("__setstate_cython__", __pyx_f[0], 3, 0, __PYX_ERR(0, 3, __pyx_L1_error));

  /* "(tree fragment)":4
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")             # <<<<<<<<<<<<<<
 */
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_TypeError, __pyx_tuple__7, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_Raise(__pyx_t_1, 0, 0, 0);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __PYX_ERR(0, 4, __pyx_L1_error)

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("ttygif.tty.theme.layer.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_TraceReturn(__pyx_r, 0);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "ttygif/tty/theme.pyx":102
 * cdef class theme:
 * 
 *     def __cinit__(self,name,width,height):             # <<<<<<<<<<<<<<
 *         self.width=width
 *         self.height=height
 */

/* Python wrapper */
static int __pyx_pw_6ttygif_3tty_5theme_5theme_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_6ttygif_3tty_5theme_5theme_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_name = 0;
  PyObject *__pyx_v_width = 0;
  PyObject *__pyx_v_height = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__cinit__ (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_name,&__pyx_n_s_width,&__pyx_n_s_height,0};
    PyObject* values[3] = {0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_name)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_width)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__cinit__", 1, 3, 3, 1); __PYX_ERR(1, 102, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_height)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__cinit__", 1, 3, 3, 2); __PYX_ERR(1, 102, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__cinit__") < 0)) __PYX_ERR(1, 102, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 3) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
      values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
    }
    __pyx_v_name = values[0];
    __pyx_v_width = values[1];
    __pyx_v_height = values[2];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__cinit__", 1, 3, 3, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(1, 102, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("ttygif.tty.theme.theme.__cinit__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6ttygif_3tty_5theme_5theme___cinit__(((struct __pyx_obj_6ttygif_3tty_5theme_theme *)__pyx_v_self), __pyx_v_name, __pyx_v_width, __pyx_v_height);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6ttygif_3tty_5theme_5theme___cinit__(struct __pyx_obj_6ttygif_3tty_5theme_theme *__pyx_v_self, PyObject *__pyx_v_name, PyObject *__pyx_v_width, PyObject *__pyx_v_height) {
  int __pyx_r;
  __Pyx_TraceDeclarations
  __Pyx_RefNannyDeclarations
  int16_t __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__cinit__", 0);
  __Pyx_TraceCall("__cinit__", __pyx_f[1], 102, 0, __PYX_ERR(1, 102, __pyx_L1_error));

  /* "ttygif/tty/theme.pyx":103
 * 
 *     def __cinit__(self,name,width,height):
 *         self.width=width             # <<<<<<<<<<<<<<
 *         self.height=height
 *         self.name=name
 */
  __pyx_t_1 = __Pyx_PyInt_As_int16_t(__pyx_v_width); if (unlikely((__pyx_t_1 == ((int16_t)-1)) && PyErr_Occurred())) __PYX_ERR(1, 103, __pyx_L1_error)
  __pyx_v_self->width = __pyx_t_1;

  /* "ttygif/tty/theme.pyx":104
 *     def __cinit__(self,name,width,height):
 *         self.width=width
 *         self.height=height             # <<<<<<<<<<<<<<
 *         self.name=name
 *         self.background=0
 */
  __pyx_t_1 = __Pyx_PyInt_As_int16_t(__pyx_v_height); if (unlikely((__pyx_t_1 == ((int16_t)-1)) && PyErr_Occurred())) __PYX_ERR(1, 104, __pyx_L1_error)
  __pyx_v_self->height = __pyx_t_1;

  /* "ttygif/tty/theme.pyx":105
 *         self.width=width
 *         self.height=height
 *         self.name=name             # <<<<<<<<<<<<<<
 *         self.background=0
 *         self.foreground=15
 */
  if (!(likely(PyString_CheckExact(__pyx_v_name))||((__pyx_v_name) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "str", Py_TYPE(__pyx_v_name)->tp_name), 0))) __PYX_ERR(1, 105, __pyx_L1_error)
  __pyx_t_2 = __pyx_v_name;
  __Pyx_INCREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_2);
  __Pyx_GOTREF(__pyx_v_self->name);
  __Pyx_DECREF(__pyx_v_self->name);
  __pyx_v_self->name = ((PyObject*)__pyx_t_2);
  __pyx_t_2 = 0;

  /* "ttygif/tty/theme.pyx":106
 *         self.height=height
 *         self.name=name
 *         self.background=0             # <<<<<<<<<<<<<<
 *         self.foreground=15
 *         self.default_background=0
 */
  __pyx_v_self->background = 0;

  /* "ttygif/tty/theme.pyx":107
 *         self.name=name
 *         self.background=0
 *         self.foreground=15             # <<<<<<<<<<<<<<
 *         self.default_background=0
 *         self.default_foreground=15
 */
  __pyx_v_self->foreground = 15;

  /* "ttygif/tty/theme.pyx":108
 *         self.background=0
 *         self.foreground=15
 *         self.default_background=0             # <<<<<<<<<<<<<<
 *         self.default_foreground=15
 *         self.palette=array.array('B')
 */
  __pyx_v_self->default_background = 0;

  /* "ttygif/tty/theme.pyx":109
 *         self.foreground=15
 *         self.default_background=0
 *         self.default_foreground=15             # <<<<<<<<<<<<<<
 *         self.palette=array.array('B')
 *         self.padding=rect(0,0,0,0)
 */
  __pyx_v_self->default_foreground = 15;

  /* "ttygif/tty/theme.pyx":110
 *         self.default_background=0
 *         self.default_foreground=15
 *         self.palette=array.array('B')             # <<<<<<<<<<<<<<
 *         self.padding=rect(0,0,0,0)
 *         self.transparent=-1
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cpython_5array_array), __pyx_tuple__8, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 110, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_2);
  __Pyx_GOTREF(__pyx_v_self->palette);
  __Pyx_DECREF(((PyObject *)__pyx_v_self->palette));
  __pyx_v_self->palette = ((arrayobject *)__pyx_t_2);
  __pyx_t_2 = 0;

  /* "ttygif/tty/theme.pyx":111
 *         self.default_foreground=15
 *         self.palette=array.array('B')
 *         self.padding=rect(0,0,0,0)             # <<<<<<<<<<<<<<
 *         self.transparent=-1
 *         self.title_x=45
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_6ttygif_3tty_5image_rect), __pyx_tuple__2, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 111, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_2);
  __Pyx_GOTREF(__pyx_v_self->padding);
  __Pyx_DECREF(((PyObject *)__pyx_v_self->padding));
  __pyx_v_self->padding = ((struct __pyx_obj_6ttygif_3tty_5image_rect *)__pyx_t_2);
  __pyx_t_2 = 0;

  /* "ttygif/tty/theme.pyx":112
 *         self.palette=array.array('B')
 *         self.padding=rect(0,0,0,0)
 *         self.transparent=-1             # <<<<<<<<<<<<<<
 *         self.title_x=45
 *         self.title_y=13
 */
  __pyx_v_self->transparent = -1;

  /* "ttygif/tty/theme.pyx":113
 *         self.padding=rect(0,0,0,0)
 *         self.transparent=-1
 *         self.title_x=45             # <<<<<<<<<<<<<<
 *         self.title_y=13
 *         self.title_background=self.background
 */
  __pyx_v_self->title_x = 45;

  /* "ttygif/tty/theme.pyx":114
 *         self.transparent=-1
 *         self.title_x=45
 *         self.title_y=13             # <<<<<<<<<<<<<<
 *         self.title_background=self.background
 *         self.title_foreground=self.foreground
 */
  __pyx_v_self->title_y = 13;

  /* "ttygif/tty/theme.pyx":115
 *         self.title_x=45
 *         self.title_y=13
 *         self.title_background=self.background             # <<<<<<<<<<<<<<
 *         self.title_foreground=self.foreground
 *         self.title_font_size=1
 */
  __pyx_t_1 = __pyx_v_self->background;
  __pyx_v_self->title_background = __pyx_t_1;

  /* "ttygif/tty/theme.pyx":116
 *         self.title_y=13
 *         self.title_background=self.background
 *         self.title_foreground=self.foreground             # <<<<<<<<<<<<<<
 *         self.title_font_size=1
 *         self.init()
 */
  __pyx_t_1 = __pyx_v_self->foreground;
  __pyx_v_self->title_foreground = __pyx_t_1;

  /* "ttygif/tty/theme.pyx":117
 *         self.title_background=self.background
 *         self.title_foreground=self.foreground
 *         self.title_font_size=1             # <<<<<<<<<<<<<<
 *         self.init()
 * 
 */
  __pyx_v_self->title_font_size = 1.0;

  /* "ttygif/tty/theme.pyx":118
 *         self.title_foreground=self.foreground
 *         self.title_font_size=1
 *         self.init()             # <<<<<<<<<<<<<<
 * 
 *     cdef update_layer(self, layer temp):
 */
  __pyx_t_2 = ((struct __pyx_vtabstruct_6ttygif_3tty_5theme_theme *)__pyx_v_self->__pyx_vtab)->init(__pyx_v_self); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 118, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "ttygif/tty/theme.pyx":102
 * cdef class theme:
 * 
 *     def __cinit__(self,name,width,height):             # <<<<<<<<<<<<<<
 *         self.width=width
 *         self.height=height
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("ttygif.tty.theme.theme.__cinit__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_TraceReturn(Py_None, 0);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "ttygif/tty/theme.pyx":120
 *         self.init()
 * 
 *     cdef update_layer(self, layer temp):             # <<<<<<<<<<<<<<
 * 
 *         temp.load_file(self.palette)
 */

static PyObject *__pyx_f_6ttygif_3tty_5theme_5theme_update_layer(struct __pyx_obj_6ttygif_3tty_5theme_theme *__pyx_v_self, struct __pyx_obj_6ttygif_3tty_5theme_layer *__pyx_v_temp) {
  int __pyx_v_total_width;
  int __pyx_v_total_height;
  PyObject *__pyx_r = NULL;
  __Pyx_TraceDeclarations
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_t_3;
  struct __pyx_obj_6ttygif_3tty_5image_rect *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("update_layer", 0);
  __Pyx_TraceCall("update_layer", __pyx_f[1], 120, 0, __PYX_ERR(1, 120, __pyx_L1_error));

  /* "ttygif/tty/theme.pyx":122
 *     cdef update_layer(self, layer temp):
 * 
 *         temp.load_file(self.palette)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_t_1 = ((PyObject *)__pyx_v_self->palette);
  __Pyx_INCREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_6ttygif_3tty_5theme_layer *)__pyx_v_temp->__pyx_vtab)->load_file(__pyx_v_temp, ((arrayobject *)__pyx_t_1)); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 122, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "ttygif/tty/theme.pyx":125
 * 
 * 
 *         cdef int total_width =self.width -1+self.padding.left+self.padding.right             # <<<<<<<<<<<<<<
 *         cdef int total_height=self.height-1+self.padding.top +self.padding.bottom
 * 
 */
  __pyx_v_total_width = (((__pyx_v_self->width - 1) + __pyx_v_self->padding->left) + __pyx_v_self->padding->right);

  /* "ttygif/tty/theme.pyx":126
 * 
 *         cdef int total_width =self.width -1+self.padding.left+self.padding.right
 *         cdef int total_height=self.height-1+self.padding.top +self.padding.bottom             # <<<<<<<<<<<<<<
 * 
 *         # the source  rectangle's
 */
  __pyx_v_total_height = (((__pyx_v_self->height - 1) + __pyx_v_self->padding->top) + __pyx_v_self->padding->bottom);

  /* "ttygif/tty/theme.pyx":129
 * 
 *         # the source  rectangle's
 *         if temp.outer.left   <0: temp.outer.left    +=temp.image.dimentions.width             # <<<<<<<<<<<<<<
 *         if temp.outer.top    <0: temp.outer.top     +=temp.image.dimentions.height
 *         if temp.outer.right  <0: temp.outer.right   +=temp.image.dimentions.width
 */
  __pyx_t_3 = ((__pyx_v_temp->outer->left < 0) != 0);
  if (__pyx_t_3) {
    __Pyx_INCREF(((PyObject *)__pyx_v_temp->outer));
    __pyx_t_4 = __pyx_v_temp->outer;
    __pyx_t_4->left = (__pyx_t_4->left + __pyx_v_temp->image->dimentions->width);
    __Pyx_DECREF(((PyObject *)__pyx_t_4)); __pyx_t_4 = 0;
  }

  /* "ttygif/tty/theme.pyx":130
 *         # the source  rectangle's
 *         if temp.outer.left   <0: temp.outer.left    +=temp.image.dimentions.width
 *         if temp.outer.top    <0: temp.outer.top     +=temp.image.dimentions.height             # <<<<<<<<<<<<<<
 *         if temp.outer.right  <0: temp.outer.right   +=temp.image.dimentions.width
 *         if temp.outer.bottom <0: temp.outer.bottom  +=temp.image.dimentions.height
 */
  __pyx_t_3 = ((__pyx_v_temp->outer->top < 0) != 0);
  if (__pyx_t_3) {
    __Pyx_INCREF(((PyObject *)__pyx_v_temp->outer));
    __pyx_t_4 = __pyx_v_temp->outer;
    __pyx_t_4->top = (__pyx_t_4->top + __pyx_v_temp->image->dimentions->height);
    __Pyx_DECREF(((PyObject *)__pyx_t_4)); __pyx_t_4 = 0;
  }

  /* "ttygif/tty/theme.pyx":131
 *         if temp.outer.left   <0: temp.outer.left    +=temp.image.dimentions.width
 *         if temp.outer.top    <0: temp.outer.top     +=temp.image.dimentions.height
 *         if temp.outer.right  <0: temp.outer.right   +=temp.image.dimentions.width             # <<<<<<<<<<<<<<
 *         if temp.outer.bottom <0: temp.outer.bottom  +=temp.image.dimentions.height
 * 
 */
  __pyx_t_3 = ((__pyx_v_temp->outer->right < 0) != 0);
  if (__pyx_t_3) {
    __Pyx_INCREF(((PyObject *)__pyx_v_temp->outer));
    __pyx_t_4 = __pyx_v_temp->outer;
    __pyx_t_4->right = (__pyx_t_4->right + __pyx_v_temp->image->dimentions->width);
    __Pyx_DECREF(((PyObject *)__pyx_t_4)); __pyx_t_4 = 0;
  }

  /* "ttygif/tty/theme.pyx":132
 *         if temp.outer.top    <0: temp.outer.top     +=temp.image.dimentions.height
 *         if temp.outer.right  <0: temp.outer.right   +=temp.image.dimentions.width
 *         if temp.outer.bottom <0: temp.outer.bottom  +=temp.image.dimentions.height             # <<<<<<<<<<<<<<
 * 
 *         if temp.inner.left   <0: temp.inner.left    +=temp.image.dimentions.width
 */
  __pyx_t_3 = ((__pyx_v_temp->outer->bottom < 0) != 0);
  if (__pyx_t_3) {
    __Pyx_INCREF(((PyObject *)__pyx_v_temp->outer));
    __pyx_t_4 = __pyx_v_temp->outer;
    __pyx_t_4->bottom = (__pyx_t_4->bottom + __pyx_v_temp->image->dimentions->height);
    __Pyx_DECREF(((PyObject *)__pyx_t_4)); __pyx_t_4 = 0;
  }

  /* "ttygif/tty/theme.pyx":134
 *         if temp.outer.bottom <0: temp.outer.bottom  +=temp.image.dimentions.height
 * 
 *         if temp.inner.left   <0: temp.inner.left    +=temp.image.dimentions.width             # <<<<<<<<<<<<<<
 *         if temp.inner.top    <0: temp.inner.top     +=temp.image.dimentions.height
 *         if temp.inner.right  <0: temp.inner.right   +=temp.image.dimentions.width
 */
  __pyx_t_3 = ((__pyx_v_temp->inner->left < 0) != 0);
  if (__pyx_t_3) {
    __Pyx_INCREF(((PyObject *)__pyx_v_temp->inner));
    __pyx_t_4 = __pyx_v_temp->inner;
    __pyx_t_4->left = (__pyx_t_4->left + __pyx_v_temp->image->dimentions->width);
    __Pyx_DECREF(((PyObject *)__pyx_t_4)); __pyx_t_4 = 0;
  }

  /* "ttygif/tty/theme.pyx":135
 * 
 *         if temp.inner.left   <0: temp.inner.left    +=temp.image.dimentions.width
 *         if temp.inner.top    <0: temp.inner.top     +=temp.image.dimentions.height             # <<<<<<<<<<<<<<
 *         if temp.inner.right  <0: temp.inner.right   +=temp.image.dimentions.width
 *         if temp.inner.bottom <0: temp.inner.bottom  +=temp.image.dimentions.height
 */
  __pyx_t_3 = ((__pyx_v_temp->inner->top < 0) != 0);
  if (__pyx_t_3) {
    __Pyx_INCREF(((PyObject *)__pyx_v_temp->inner));
    __pyx_t_4 = __pyx_v_temp->inner;
    __pyx_t_4->top = (__pyx_t_4->top + __pyx_v_temp->image->dimentions->height);
    __Pyx_DECREF(((PyObject *)__pyx_t_4)); __pyx_t_4 = 0;
  }

  /* "ttygif/tty/theme.pyx":136
 *         if temp.inner.left   <0: temp.inner.left    +=temp.image.dimentions.width
 *         if temp.inner.top    <0: temp.inner.top     +=temp.image.dimentions.height
 *         if temp.inner.right  <0: temp.inner.right   +=temp.image.dimentions.width             # <<<<<<<<<<<<<<
 *         if temp.inner.bottom <0: temp.inner.bottom  +=temp.image.dimentions.height
 * 
 */
  __pyx_t_3 = ((__pyx_v_temp->inner->right < 0) != 0);
  if (__pyx_t_3) {
    __Pyx_INCREF(((PyObject *)__pyx_v_temp->inner));
    __pyx_t_4 = __pyx_v_temp->inner;
    __pyx_t_4->right = (__pyx_t_4->right + __pyx_v_temp->image->dimentions->width);
    __Pyx_DECREF(((PyObject *)__pyx_t_4)); __pyx_t_4 = 0;
  }

  /* "ttygif/tty/theme.pyx":137
 *         if temp.inner.top    <0: temp.inner.top     +=temp.image.dimentions.height
 *         if temp.inner.right  <0: temp.inner.right   +=temp.image.dimentions.width
 *         if temp.inner.bottom <0: temp.inner.bottom  +=temp.image.dimentions.height             # <<<<<<<<<<<<<<
 * 
 *         # the source  rectangle for COPY
 */
  __pyx_t_3 = ((__pyx_v_temp->inner->bottom < 0) != 0);
  if (__pyx_t_3) {
    __Pyx_INCREF(((PyObject *)__pyx_v_temp->inner));
    __pyx_t_4 = __pyx_v_temp->inner;
    __pyx_t_4->bottom = (__pyx_t_4->bottom + __pyx_v_temp->image->dimentions->height);
    __Pyx_DECREF(((PyObject *)__pyx_t_4)); __pyx_t_4 = 0;
  }

  /* "ttygif/tty/theme.pyx":140
 * 
 *         # the source  rectangle for COPY
 *         if temp.bounds.left  <0: temp.bounds.left   +=temp.image.dimentions.width             # <<<<<<<<<<<<<<
 *         if temp.bounds.top   <0: temp.bounds.top    +=temp.image.dimentions.height
 *         if temp.bounds.right <0: temp.bounds.right  +=temp.image.dimentions.width
 */
  __pyx_t_3 = ((__pyx_v_temp->bounds->left < 0) != 0);
  if (__pyx_t_3) {
    __Pyx_INCREF(((PyObject *)__pyx_v_temp->bounds));
    __pyx_t_4 = __pyx_v_temp->bounds;
    __pyx_t_4->left = (__pyx_t_4->left + __pyx_v_temp->image->dimentions->width);
    __Pyx_DECREF(((PyObject *)__pyx_t_4)); __pyx_t_4 = 0;
  }

  /* "ttygif/tty/theme.pyx":141
 *         # the source  rectangle for COPY
 *         if temp.bounds.left  <0: temp.bounds.left   +=temp.image.dimentions.width
 *         if temp.bounds.top   <0: temp.bounds.top    +=temp.image.dimentions.height             # <<<<<<<<<<<<<<
 *         if temp.bounds.right <0: temp.bounds.right  +=temp.image.dimentions.width
 *         if temp.bounds.bottom<0: temp.bounds.bottom +=temp.image.dimentions.height
 */
  __pyx_t_3 = ((__pyx_v_temp->bounds->top < 0) != 0);
  if (__pyx_t_3) {
    __Pyx_INCREF(((PyObject *)__pyx_v_temp->bounds));
    __pyx_t_4 = __pyx_v_temp->bounds;
    __pyx_t_4->top = (__pyx_t_4->top + __pyx_v_temp->image->dimentions->height);
    __Pyx_DECREF(((PyObject *)__pyx_t_4)); __pyx_t_4 = 0;
  }

  /* "ttygif/tty/theme.pyx":142
 *         if temp.bounds.left  <0: temp.bounds.left   +=temp.image.dimentions.width
 *         if temp.bounds.top   <0: temp.bounds.top    +=temp.image.dimentions.height
 *         if temp.bounds.right <0: temp.bounds.right  +=temp.image.dimentions.width             # <<<<<<<<<<<<<<
 *         if temp.bounds.bottom<0: temp.bounds.bottom +=temp.image.dimentions.height
 * 
 */
  __pyx_t_3 = ((__pyx_v_temp->bounds->right < 0) != 0);
  if (__pyx_t_3) {
    __Pyx_INCREF(((PyObject *)__pyx_v_temp->bounds));
    __pyx_t_4 = __pyx_v_temp->bounds;
    __pyx_t_4->right = (__pyx_t_4->right + __pyx_v_temp->image->dimentions->width);
    __Pyx_DECREF(((PyObject *)__pyx_t_4)); __pyx_t_4 = 0;
  }

  /* "ttygif/tty/theme.pyx":143
 *         if temp.bounds.top   <0: temp.bounds.top    +=temp.image.dimentions.height
 *         if temp.bounds.right <0: temp.bounds.right  +=temp.image.dimentions.width
 *         if temp.bounds.bottom<0: temp.bounds.bottom +=temp.image.dimentions.height             # <<<<<<<<<<<<<<
 * 
 *         # the destination rectangle
 */
  __pyx_t_3 = ((__pyx_v_temp->bounds->bottom < 0) != 0);
  if (__pyx_t_3) {
    __Pyx_INCREF(((PyObject *)__pyx_v_temp->bounds));
    __pyx_t_4 = __pyx_v_temp->bounds;
    __pyx_t_4->bottom = (__pyx_t_4->bottom + __pyx_v_temp->image->dimentions->height);
    __Pyx_DECREF(((PyObject *)__pyx_t_4)); __pyx_t_4 = 0;
  }

  /* "ttygif/tty/theme.pyx":146
 * 
 *         # the destination rectangle
 *         if temp.dst.right     <0 : temp.dst.right     +=total_width             # <<<<<<<<<<<<<<
 *         if temp.dst.bottom    <0 : temp.dst.bottom    +=total_height
 *         if temp.dst.left      <0 : temp.dst.left      +=total_width
 */
  __pyx_t_3 = ((__pyx_v_temp->dst->right < 0) != 0);
  if (__pyx_t_3) {
    __Pyx_INCREF(((PyObject *)__pyx_v_temp->dst));
    __pyx_t_4 = __pyx_v_temp->dst;
    __pyx_t_4->right = (__pyx_t_4->right + __pyx_v_total_width);
    __Pyx_DECREF(((PyObject *)__pyx_t_4)); __pyx_t_4 = 0;
  }

  /* "ttygif/tty/theme.pyx":147
 *         # the destination rectangle
 *         if temp.dst.right     <0 : temp.dst.right     +=total_width
 *         if temp.dst.bottom    <0 : temp.dst.bottom    +=total_height             # <<<<<<<<<<<<<<
 *         if temp.dst.left      <0 : temp.dst.left      +=total_width
 *         if temp.dst.top       <0 : temp.dst.top       +=total_height
 */
  __pyx_t_3 = ((__pyx_v_temp->dst->bottom < 0) != 0);
  if (__pyx_t_3) {
    __Pyx_INCREF(((PyObject *)__pyx_v_temp->dst));
    __pyx_t_4 = __pyx_v_temp->dst;
    __pyx_t_4->bottom = (__pyx_t_4->bottom + __pyx_v_total_height);
    __Pyx_DECREF(((PyObject *)__pyx_t_4)); __pyx_t_4 = 0;
  }

  /* "ttygif/tty/theme.pyx":148
 *         if temp.dst.right     <0 : temp.dst.right     +=total_width
 *         if temp.dst.bottom    <0 : temp.dst.bottom    +=total_height
 *         if temp.dst.left      <0 : temp.dst.left      +=total_width             # <<<<<<<<<<<<<<
 *         if temp.dst.top       <0 : temp.dst.top       +=total_height
 * 
 */
  __pyx_t_3 = ((__pyx_v_temp->dst->left < 0) != 0);
  if (__pyx_t_3) {
    __Pyx_INCREF(((PyObject *)__pyx_v_temp->dst));
    __pyx_t_4 = __pyx_v_temp->dst;
    __pyx_t_4->left = (__pyx_t_4->left + __pyx_v_total_width);
    __Pyx_DECREF(((PyObject *)__pyx_t_4)); __pyx_t_4 = 0;
  }

  /* "ttygif/tty/theme.pyx":149
 *         if temp.dst.bottom    <0 : temp.dst.bottom    +=total_height
 *         if temp.dst.left      <0 : temp.dst.left      +=total_width
 *         if temp.dst.top       <0 : temp.dst.top       +=total_height             # <<<<<<<<<<<<<<
 * 
 * #temp.outer.get_x_percent(33)
 */
  __pyx_t_3 = ((__pyx_v_temp->dst->top < 0) != 0);
  if (__pyx_t_3) {
    __Pyx_INCREF(((PyObject *)__pyx_v_temp->dst));
    __pyx_t_4 = __pyx_v_temp->dst;
    __pyx_t_4->top = (__pyx_t_4->top + __pyx_v_total_height);
    __Pyx_DECREF(((PyObject *)__pyx_t_4)); __pyx_t_4 = 0;
  }

  /* "ttygif/tty/theme.pyx":175
 * 
 * 
 *         temp.outer.update()             # <<<<<<<<<<<<<<
 *         temp.inner.update()
 *         temp.bounds.update()
 */
  __pyx_t_2 = ((struct __pyx_vtabstruct_6ttygif_3tty_5image_rect *)__pyx_v_temp->outer->__pyx_vtab)->update(__pyx_v_temp->outer); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 175, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "ttygif/tty/theme.pyx":176
 * 
 *         temp.outer.update()
 *         temp.inner.update()             # <<<<<<<<<<<<<<
 *         temp.bounds.update()
 *         temp.dst.update()
 */
  __pyx_t_2 = ((struct __pyx_vtabstruct_6ttygif_3tty_5image_rect *)__pyx_v_temp->inner->__pyx_vtab)->update(__pyx_v_temp->inner); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 176, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "ttygif/tty/theme.pyx":177
 *         temp.outer.update()
 *         temp.inner.update()
 *         temp.bounds.update()             # <<<<<<<<<<<<<<
 *         temp.dst.update()
 * 
 */
  __pyx_t_2 = ((struct __pyx_vtabstruct_6ttygif_3tty_5image_rect *)__pyx_v_temp->bounds->__pyx_vtab)->update(__pyx_v_temp->bounds); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 177, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "ttygif/tty/theme.pyx":178
 *         temp.inner.update()
 *         temp.bounds.update()
 *         temp.dst.update()             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_t_2 = ((struct __pyx_vtabstruct_6ttygif_3tty_5image_rect *)__pyx_v_temp->dst->__pyx_vtab)->update(__pyx_v_temp->dst); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 178, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "ttygif/tty/theme.pyx":120
 *         self.init()
 * 
 *     cdef update_layer(self, layer temp):             # <<<<<<<<<<<<<<
 * 
 *         temp.load_file(self.palette)
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(((PyObject *)__pyx_t_4));
  __Pyx_AddTraceback("ttygif.tty.theme.theme.update_layer", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_TraceReturn(__pyx_r, 0);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "ttygif/tty/theme.pyx":183
 * 
 * 
 *     cdef auto(self):             # <<<<<<<<<<<<<<
 *         if self.layer1:
 *             self.update_layer(self.layer1)
 */

static PyObject *__pyx_f_6ttygif_3tty_5theme_5theme_auto(struct __pyx_obj_6ttygif_3tty_5theme_theme *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_TraceDeclarations
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("auto", 0);
  __Pyx_TraceCall("auto", __pyx_f[1], 183, 0, __PYX_ERR(1, 183, __pyx_L1_error));

  /* "ttygif/tty/theme.pyx":184
 * 
 *     cdef auto(self):
 *         if self.layer1:             # <<<<<<<<<<<<<<
 *             self.update_layer(self.layer1)
 * 
 */
  __pyx_t_1 = __Pyx_PyObject_IsTrue(((PyObject *)__pyx_v_self->layer1)); if (unlikely(__pyx_t_1 < 0)) __PYX_ERR(1, 184, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "ttygif/tty/theme.pyx":185
 *     cdef auto(self):
 *         if self.layer1:
 *             self.update_layer(self.layer1)             # <<<<<<<<<<<<<<
 * 
 *         if self.layer2:
 */
    __pyx_t_2 = ((PyObject *)__pyx_v_self->layer1);
    __Pyx_INCREF(__pyx_t_2);
    __pyx_t_3 = ((struct __pyx_vtabstruct_6ttygif_3tty_5theme_theme *)__pyx_v_self->__pyx_vtab)->update_layer(__pyx_v_self, ((struct __pyx_obj_6ttygif_3tty_5theme_layer *)__pyx_t_2)); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 185, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "ttygif/tty/theme.pyx":184
 * 
 *     cdef auto(self):
 *         if self.layer1:             # <<<<<<<<<<<<<<
 *             self.update_layer(self.layer1)
 * 
 */
  }

  /* "ttygif/tty/theme.pyx":187
 *             self.update_layer(self.layer1)
 * 
 *         if self.layer2:             # <<<<<<<<<<<<<<
 *             self.update_layer(self.layer2)
 * 
 */
  __pyx_t_1 = __Pyx_PyObject_IsTrue(((PyObject *)__pyx_v_self->layer2)); if (unlikely(__pyx_t_1 < 0)) __PYX_ERR(1, 187, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "ttygif/tty/theme.pyx":188
 * 
 *         if self.layer2:
 *             self.update_layer(self.layer2)             # <<<<<<<<<<<<<<
 * 
 *         if self.layer3:
 */
    __pyx_t_3 = ((PyObject *)__pyx_v_self->layer2);
    __Pyx_INCREF(__pyx_t_3);
    __pyx_t_2 = ((struct __pyx_vtabstruct_6ttygif_3tty_5theme_theme *)__pyx_v_self->__pyx_vtab)->update_layer(__pyx_v_self, ((struct __pyx_obj_6ttygif_3tty_5theme_layer *)__pyx_t_3)); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 188, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "ttygif/tty/theme.pyx":187
 *             self.update_layer(self.layer1)
 * 
 *         if self.layer2:             # <<<<<<<<<<<<<<
 *             self.update_layer(self.layer2)
 * 
 */
  }

  /* "ttygif/tty/theme.pyx":190
 *             self.update_layer(self.layer2)
 * 
 *         if self.layer3:             # <<<<<<<<<<<<<<
 *             self.update_layer(self.layer3)
 * 
 */
  __pyx_t_1 = __Pyx_PyObject_IsTrue(((PyObject *)__pyx_v_self->layer3)); if (unlikely(__pyx_t_1 < 0)) __PYX_ERR(1, 190, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "ttygif/tty/theme.pyx":191
 * 
 *         if self.layer3:
 *             self.update_layer(self.layer3)             # <<<<<<<<<<<<<<
 * 
 *         if self.layer4:
 */
    __pyx_t_2 = ((PyObject *)__pyx_v_self->layer3);
    __Pyx_INCREF(__pyx_t_2);
    __pyx_t_3 = ((struct __pyx_vtabstruct_6ttygif_3tty_5theme_theme *)__pyx_v_self->__pyx_vtab)->update_layer(__pyx_v_self, ((struct __pyx_obj_6ttygif_3tty_5theme_layer *)__pyx_t_2)); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 191, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "ttygif/tty/theme.pyx":190
 *             self.update_layer(self.layer2)
 * 
 *         if self.layer3:             # <<<<<<<<<<<<<<
 *             self.update_layer(self.layer3)
 * 
 */
  }

  /* "ttygif/tty/theme.pyx":193
 *             self.update_layer(self.layer3)
 * 
 *         if self.layer4:             # <<<<<<<<<<<<<<
 *             self.update_layer(self.layer4)
 * 
 */
  __pyx_t_1 = __Pyx_PyObject_IsTrue(((PyObject *)__pyx_v_self->layer4)); if (unlikely(__pyx_t_1 < 0)) __PYX_ERR(1, 193, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "ttygif/tty/theme.pyx":194
 * 
 *         if self.layer4:
 *             self.update_layer(self.layer4)             # <<<<<<<<<<<<<<
 * 
 *         if self.layer5:
 */
    __pyx_t_3 = ((PyObject *)__pyx_v_self->layer4);
    __Pyx_INCREF(__pyx_t_3);
    __pyx_t_2 = ((struct __pyx_vtabstruct_6ttygif_3tty_5theme_theme *)__pyx_v_self->__pyx_vtab)->update_layer(__pyx_v_self, ((struct __pyx_obj_6ttygif_3tty_5theme_layer *)__pyx_t_3)); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 194, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "ttygif/tty/theme.pyx":193
 *             self.update_layer(self.layer3)
 * 
 *         if self.layer4:             # <<<<<<<<<<<<<<
 *             self.update_layer(self.layer4)
 * 
 */
  }

  /* "ttygif/tty/theme.pyx":196
 *             self.update_layer(self.layer4)
 * 
 *         if self.layer5:             # <<<<<<<<<<<<<<
 *             self.update_layer(self.layer5)
 * 
 */
  __pyx_t_1 = __Pyx_PyObject_IsTrue(((PyObject *)__pyx_v_self->layer5)); if (unlikely(__pyx_t_1 < 0)) __PYX_ERR(1, 196, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "ttygif/tty/theme.pyx":197
 * 
 *         if self.layer5:
 *             self.update_layer(self.layer5)             # <<<<<<<<<<<<<<
 * 
 *     cdef init(self):
 */
    __pyx_t_2 = ((PyObject *)__pyx_v_self->layer5);
    __Pyx_INCREF(__pyx_t_2);
    __pyx_t_3 = ((struct __pyx_vtabstruct_6ttygif_3tty_5theme_theme *)__pyx_v_self->__pyx_vtab)->update_layer(__pyx_v_self, ((struct __pyx_obj_6ttygif_3tty_5theme_layer *)__pyx_t_2)); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 197, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "ttygif/tty/theme.pyx":196
 *             self.update_layer(self.layer4)
 * 
 *         if self.layer5:             # <<<<<<<<<<<<<<
 *             self.update_layer(self.layer5)
 * 
 */
  }

  /* "ttygif/tty/theme.pyx":183
 * 
 * 
 *     cdef auto(self):             # <<<<<<<<<<<<<<
 *         if self.layer1:
 *             self.update_layer(self.layer1)
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("ttygif.tty.theme.theme.auto", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_TraceReturn(__pyx_r, 0);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "ttygif/tty/theme.pyx":199
 *             self.update_layer(self.layer5)
 * 
 *     cdef init(self):             # <<<<<<<<<<<<<<
 *         cdef int a,b,c,index
 *         index=0
 */

static PyObject *__pyx_f_6ttygif_3tty_5theme_5theme_init(struct __pyx_obj_6ttygif_3tty_5theme_theme *__pyx_v_self) {
  int __pyx_v_a;
  int __pyx_v_b;
  int __pyx_v_c;
  int __pyx_v_index;
  PyObject *__pyx_v_script_path = NULL;
  PyObject *__pyx_v_path = NULL;
  PyObject *__pyx_v_home = NULL;
  PyObject *__pyx_v_theme_file = NULL;
  PyObject *__pyx_v_theme_data = NULL;
  struct __pyx_obj_6ttygif_3tty_5theme_layer *__pyx_v_theme_layer = 0;
  PyObject *__pyx_v_section = NULL;
  PyObject *__pyx_v_line = NULL;
  PyObject *__pyx_v_res = NULL;
  PyObject *__pyx_v_key = NULL;
  PyObject *__pyx_v_value = NULL;
  PyObject *__pyx_v_color_table = NULL;
  long __pyx_v_i;
  PyObject *__pyx_r = NULL;
  __Pyx_TraceDeclarations
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  int __pyx_t_8;
  Py_ssize_t __pyx_t_9;
  PyObject *(*__pyx_t_10)(PyObject *);
  int __pyx_t_11;
  int16_t __pyx_t_12;
  double __pyx_t_13;
  long __pyx_t_14;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("init", 0);
  __Pyx_TraceCall("init", __pyx_f[1], 199, 0, __PYX_ERR(1, 199, __pyx_L1_error));

  /* "ttygif/tty/theme.pyx":201
 *     cdef init(self):
 *         cdef int a,b,c,index
 *         index=0             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_v_index = 0;

  /* "ttygif/tty/theme.pyx":204
 * 
 * 
 *         script_path = os.path.dirname(os.path.abspath( __file__ ))             # <<<<<<<<<<<<<<
 *         self.path=script_path
 *         path=os.path.join(script_path,'themes',self.name+".theme")
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_os); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 204, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_path); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 204, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_dirname); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 204, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_os); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 204, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_path); if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 204, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_abspath); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 204, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_file); if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 204, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_6 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_6)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_6);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
    }
  }
  __pyx_t_3 = (__pyx_t_6) ? __Pyx_PyObject_Call2Args(__pyx_t_4, __pyx_t_6, __pyx_t_5) : __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 204, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  __pyx_t_1 = (__pyx_t_4) ? __Pyx_PyObject_Call2Args(__pyx_t_2, __pyx_t_4, __pyx_t_3) : __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 204, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_script_path = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "ttygif/tty/theme.pyx":205
 * 
 *         script_path = os.path.dirname(os.path.abspath( __file__ ))
 *         self.path=script_path             # <<<<<<<<<<<<<<
 *         path=os.path.join(script_path,'themes',self.name+".theme")
 *         if os.path.exists(path)==False:
 */
  if (!(likely(PyString_CheckExact(__pyx_v_script_path))||((__pyx_v_script_path) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "str", Py_TYPE(__pyx_v_script_path)->tp_name), 0))) __PYX_ERR(1, 205, __pyx_L1_error)
  __pyx_t_1 = __pyx_v_script_path;
  __Pyx_INCREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->path);
  __Pyx_DECREF(__pyx_v_self->path);
  __pyx_v_self->path = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "ttygif/tty/theme.pyx":206
 *         script_path = os.path.dirname(os.path.abspath( __file__ ))
 *         self.path=script_path
 *         path=os.path.join(script_path,'themes',self.name+".theme")             # <<<<<<<<<<<<<<
 *         if os.path.exists(path)==False:
 *             path=os.path.join(self.name+".theme")
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_os); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 206, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_path); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 206, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_join); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 206, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = PyNumber_Add(__pyx_v_self->name, __pyx_kp_s_theme); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 206, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = NULL;
  __pyx_t_7 = 0;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_7 = 1;
    }
  }
  #if CYTHON_FAST_PYCALL
  if (PyFunction_Check(__pyx_t_2)) {
    PyObject *__pyx_temp[4] = {__pyx_t_4, __pyx_v_script_path, __pyx_n_s_themes, __pyx_t_3};
    __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_2, __pyx_temp+1-__pyx_t_7, 3+__pyx_t_7); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 206, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  } else
  #endif
  #if CYTHON_FAST_PYCCALL
  if (__Pyx_PyFastCFunction_Check(__pyx_t_2)) {
    PyObject *__pyx_temp[4] = {__pyx_t_4, __pyx_v_script_path, __pyx_n_s_themes, __pyx_t_3};
    __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_2, __pyx_temp+1-__pyx_t_7, 3+__pyx_t_7); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 206, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  } else
  #endif
  {
    __pyx_t_5 = PyTuple_New(3+__pyx_t_7); if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 206, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    if (__pyx_t_4) {
      __Pyx_GIVEREF(__pyx_t_4); PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_4); __pyx_t_4 = NULL;
    }
    __Pyx_INCREF(__pyx_v_script_path);
    __Pyx_GIVEREF(__pyx_v_script_path);
    PyTuple_SET_ITEM(__pyx_t_5, 0+__pyx_t_7, __pyx_v_script_path);
    __Pyx_INCREF(__pyx_n_s_themes);
    __Pyx_GIVEREF(__pyx_n_s_themes);
    PyTuple_SET_ITEM(__pyx_t_5, 1+__pyx_t_7, __pyx_n_s_themes);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_5, 2+__pyx_t_7, __pyx_t_3);
    __pyx_t_3 = 0;
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_5, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 206, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_path = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "ttygif/tty/theme.pyx":207
 *         self.path=script_path
 *         path=os.path.join(script_path,'themes',self.name+".theme")
 *         if os.path.exists(path)==False:             # <<<<<<<<<<<<<<
 *             path=os.path.join(self.name+".theme")
 *             if os.path.exists(path)==False:
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_os); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 207, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_path); if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 207, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_exists); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 207, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_5)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  __pyx_t_1 = (__pyx_t_5) ? __Pyx_PyObject_Call2Args(__pyx_t_2, __pyx_t_5, __pyx_v_path) : __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_v_path);
  __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 207, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyObject_RichCompare(__pyx_t_1, Py_False, Py_EQ); __Pyx_XGOTREF(__pyx_t_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 207, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_8 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely(__pyx_t_8 < 0)) __PYX_ERR(1, 207, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__pyx_t_8) {

    /* "ttygif/tty/theme.pyx":208
 *         path=os.path.join(script_path,'themes',self.name+".theme")
 *         if os.path.exists(path)==False:
 *             path=os.path.join(self.name+".theme")             # <<<<<<<<<<<<<<
 *             if os.path.exists(path)==False:
 * 
 */
    __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_os); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 208, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_path); if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 208, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_join); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 208, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_5 = PyNumber_Add(__pyx_v_self->name, __pyx_kp_s_theme); if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 208, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_3 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_1))) {
      __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_1);
      if (likely(__pyx_t_3)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
        __Pyx_INCREF(__pyx_t_3);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_1, function);
      }
    }
    __pyx_t_2 = (__pyx_t_3) ? __Pyx_PyObject_Call2Args(__pyx_t_1, __pyx_t_3, __pyx_t_5) : __Pyx_PyObject_CallOneArg(__pyx_t_1, __pyx_t_5);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 208, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF_SET(__pyx_v_path, __pyx_t_2);
    __pyx_t_2 = 0;

    /* "ttygif/tty/theme.pyx":209
 *         if os.path.exists(path)==False:
 *             path=os.path.join(self.name+".theme")
 *             if os.path.exists(path)==False:             # <<<<<<<<<<<<<<
 * 
 *                 home = os.path.join(expanduser("~"),'.ttygif')
 */
    __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_os); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 209, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_path); if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 209, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_exists); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 209, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_5 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_1))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_1);
      if (likely(__pyx_t_5)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_1, function);
      }
    }
    __pyx_t_2 = (__pyx_t_5) ? __Pyx_PyObject_Call2Args(__pyx_t_1, __pyx_t_5, __pyx_v_path) : __Pyx_PyObject_CallOneArg(__pyx_t_1, __pyx_v_path);
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 209, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = PyObject_RichCompare(__pyx_t_2, Py_False, Py_EQ); __Pyx_XGOTREF(__pyx_t_1); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 209, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_8 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_8 < 0)) __PYX_ERR(1, 209, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (__pyx_t_8) {

      /* "ttygif/tty/theme.pyx":211
 *             if os.path.exists(path)==False:
 * 
 *                 home = os.path.join(expanduser("~"),'.ttygif')             # <<<<<<<<<<<<<<
 *                 path=os.path.join(home,'themes',self.name+".theme")
 *                 self.path=home
 */
      __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_os); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 211, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_path); if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 211, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_join); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 211, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_expanduser); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 211, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_4 = NULL;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
        __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
        if (likely(__pyx_t_4)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
          __Pyx_INCREF(__pyx_t_4);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_3, function);
        }
      }
      __pyx_t_5 = (__pyx_t_4) ? __Pyx_PyObject_Call2Args(__pyx_t_3, __pyx_t_4, __pyx_kp_s__9) : __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_kp_s__9);
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 211, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_3 = NULL;
      __pyx_t_7 = 0;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
        __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
        if (likely(__pyx_t_3)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
          __Pyx_INCREF(__pyx_t_3);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_2, function);
          __pyx_t_7 = 1;
        }
      }
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_2)) {
        PyObject *__pyx_temp[3] = {__pyx_t_3, __pyx_t_5, __pyx_kp_s_ttygif};
        __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_2, __pyx_temp+1-__pyx_t_7, 2+__pyx_t_7); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 211, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_2)) {
        PyObject *__pyx_temp[3] = {__pyx_t_3, __pyx_t_5, __pyx_kp_s_ttygif};
        __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_2, __pyx_temp+1-__pyx_t_7, 2+__pyx_t_7); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 211, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      } else
      #endif
      {
        __pyx_t_4 = PyTuple_New(2+__pyx_t_7); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 211, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        if (__pyx_t_3) {
          __Pyx_GIVEREF(__pyx_t_3); PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_3); __pyx_t_3 = NULL;
        }
        __Pyx_GIVEREF(__pyx_t_5);
        PyTuple_SET_ITEM(__pyx_t_4, 0+__pyx_t_7, __pyx_t_5);
        __Pyx_INCREF(__pyx_kp_s_ttygif);
        __Pyx_GIVEREF(__pyx_kp_s_ttygif);
        PyTuple_SET_ITEM(__pyx_t_4, 1+__pyx_t_7, __pyx_kp_s_ttygif);
        __pyx_t_5 = 0;
        __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_4, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 211, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      }
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __pyx_v_home = __pyx_t_1;
      __pyx_t_1 = 0;

      /* "ttygif/tty/theme.pyx":212
 * 
 *                 home = os.path.join(expanduser("~"),'.ttygif')
 *                 path=os.path.join(home,'themes',self.name+".theme")             # <<<<<<<<<<<<<<
 *                 self.path=home
 * 
 */
      __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_os); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 212, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_path); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 212, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_join); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 212, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_4 = PyNumber_Add(__pyx_v_self->name, __pyx_kp_s_theme); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 212, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_5 = NULL;
      __pyx_t_7 = 0;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
        __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_2);
        if (likely(__pyx_t_5)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
          __Pyx_INCREF(__pyx_t_5);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_2, function);
          __pyx_t_7 = 1;
        }
      }
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_2)) {
        PyObject *__pyx_temp[4] = {__pyx_t_5, __pyx_v_home, __pyx_n_s_themes, __pyx_t_4};
        __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_2, __pyx_temp+1-__pyx_t_7, 3+__pyx_t_7); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 212, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_2)) {
        PyObject *__pyx_temp[4] = {__pyx_t_5, __pyx_v_home, __pyx_n_s_themes, __pyx_t_4};
        __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_2, __pyx_temp+1-__pyx_t_7, 3+__pyx_t_7); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 212, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      } else
      #endif
      {
        __pyx_t_3 = PyTuple_New(3+__pyx_t_7); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 212, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        if (__pyx_t_5) {
          __Pyx_GIVEREF(__pyx_t_5); PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_5); __pyx_t_5 = NULL;
        }
        __Pyx_INCREF(__pyx_v_home);
        __Pyx_GIVEREF(__pyx_v_home);
        PyTuple_SET_ITEM(__pyx_t_3, 0+__pyx_t_7, __pyx_v_home);
        __Pyx_INCREF(__pyx_n_s_themes);
        __Pyx_GIVEREF(__pyx_n_s_themes);
        PyTuple_SET_ITEM(__pyx_t_3, 1+__pyx_t_7, __pyx_n_s_themes);
        __Pyx_GIVEREF(__pyx_t_4);
        PyTuple_SET_ITEM(__pyx_t_3, 2+__pyx_t_7, __pyx_t_4);
        __pyx_t_4 = 0;
        __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 212, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      }
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF_SET(__pyx_v_path, __pyx_t_1);
      __pyx_t_1 = 0;

      /* "ttygif/tty/theme.pyx":213
 *                 home = os.path.join(expanduser("~"),'.ttygif')
 *                 path=os.path.join(home,'themes',self.name+".theme")
 *                 self.path=home             # <<<<<<<<<<<<<<
 * 
 *                 if os.path.exists(path)==False:
 */
      if (!(likely(PyString_CheckExact(__pyx_v_home))||((__pyx_v_home) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "str", Py_TYPE(__pyx_v_home)->tp_name), 0))) __PYX_ERR(1, 213, __pyx_L1_error)
      __pyx_t_1 = __pyx_v_home;
      __Pyx_INCREF(__pyx_t_1);
      __Pyx_GIVEREF(__pyx_t_1);
      __Pyx_GOTREF(__pyx_v_self->path);
      __Pyx_DECREF(__pyx_v_self->path);
      __pyx_v_self->path = ((PyObject*)__pyx_t_1);
      __pyx_t_1 = 0;

      /* "ttygif/tty/theme.pyx":215
 *                 self.path=home
 * 
 *                 if os.path.exists(path)==False:             # <<<<<<<<<<<<<<
 *                     raise Exception("Invalid theme file")
 * 
 */
      __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_os); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 215, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_path); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 215, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_exists); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 215, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_3 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
        __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
        if (likely(__pyx_t_3)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
          __Pyx_INCREF(__pyx_t_3);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_2, function);
        }
      }
      __pyx_t_1 = (__pyx_t_3) ? __Pyx_PyObject_Call2Args(__pyx_t_2, __pyx_t_3, __pyx_v_path) : __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_v_path);
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 215, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __pyx_t_2 = PyObject_RichCompare(__pyx_t_1, Py_False, Py_EQ); __Pyx_XGOTREF(__pyx_t_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 215, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_8 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely(__pyx_t_8 < 0)) __PYX_ERR(1, 215, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (unlikely(__pyx_t_8)) {

        /* "ttygif/tty/theme.pyx":216
 * 
 *                 if os.path.exists(path)==False:
 *                     raise Exception("Invalid theme file")             # <<<<<<<<<<<<<<
 * 
 *         print(" - theme: {0}".format(self.name))
 */
        __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)(&((PyTypeObject*)PyExc_Exception)[0])), __pyx_tuple__10, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 216, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_Raise(__pyx_t_2, 0, 0, 0);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __PYX_ERR(1, 216, __pyx_L1_error)

        /* "ttygif/tty/theme.pyx":215
 *                 self.path=home
 * 
 *                 if os.path.exists(path)==False:             # <<<<<<<<<<<<<<
 *                     raise Exception("Invalid theme file")
 * 
 */
      }

      /* "ttygif/tty/theme.pyx":209
 *         if os.path.exists(path)==False:
 *             path=os.path.join(self.name+".theme")
 *             if os.path.exists(path)==False:             # <<<<<<<<<<<<<<
 * 
 *                 home = os.path.join(expanduser("~"),'.ttygif')
 */
    }

    /* "ttygif/tty/theme.pyx":207
 *         self.path=script_path
 *         path=os.path.join(script_path,'themes',self.name+".theme")
 *         if os.path.exists(path)==False:             # <<<<<<<<<<<<<<
 *             path=os.path.join(self.name+".theme")
 *             if os.path.exists(path)==False:
 */
  }

  /* "ttygif/tty/theme.pyx":218
 *                     raise Exception("Invalid theme file")
 * 
 *         print(" - theme: {0}".format(self.name))             # <<<<<<<<<<<<<<
 *         theme_file=open(path)
 *         theme_data=theme_file.readlines()
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_kp_s_theme_0, __pyx_n_s_format); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 218, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_1))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_1);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_1, function);
    }
  }
  __pyx_t_2 = (__pyx_t_3) ? __Pyx_PyObject_Call2Args(__pyx_t_1, __pyx_t_3, __pyx_v_self->name) : __Pyx_PyObject_CallOneArg(__pyx_t_1, __pyx_v_self->name);
  __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 218, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__Pyx_PrintOne(0, __pyx_t_2) < 0) __PYX_ERR(1, 218, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "ttygif/tty/theme.pyx":219
 * 
 *         print(" - theme: {0}".format(self.name))
 *         theme_file=open(path)             # <<<<<<<<<<<<<<
 *         theme_data=theme_file.readlines()
 * 
 */
  __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_builtin_open, __pyx_v_path); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 219, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_v_theme_file = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "ttygif/tty/theme.pyx":220
 *         print(" - theme: {0}".format(self.name))
 *         theme_file=open(path)
 *         theme_data=theme_file.readlines()             # <<<<<<<<<<<<<<
 * 
 *         cdef layer theme_layer=None
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_theme_file, __pyx_n_s_readlines); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 220, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_1))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_1);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_1, function);
    }
  }
  __pyx_t_2 = (__pyx_t_3) ? __Pyx_PyObject_CallOneArg(__pyx_t_1, __pyx_t_3) : __Pyx_PyObject_CallNoArg(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 220, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_theme_data = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "ttygif/tty/theme.pyx":222
 *         theme_data=theme_file.readlines()
 * 
 *         cdef layer theme_layer=None             # <<<<<<<<<<<<<<
 *         section=''
 * 
 */
  __Pyx_INCREF(Py_None);
  __pyx_v_theme_layer = ((struct __pyx_obj_6ttygif_3tty_5theme_layer *)Py_None);

  /* "ttygif/tty/theme.pyx":223
 * 
 *         cdef layer theme_layer=None
 *         section=''             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_INCREF(__pyx_kp_s_);
  __pyx_v_section = __pyx_kp_s_;

  /* "ttygif/tty/theme.pyx":226
 * 
 * 
 *         for line in theme_data:             # <<<<<<<<<<<<<<
 *             res=self.get_anyvar(line)
 *             if res ==None:
 */
  if (likely(PyList_CheckExact(__pyx_v_theme_data)) || PyTuple_CheckExact(__pyx_v_theme_data)) {
    __pyx_t_2 = __pyx_v_theme_data; __Pyx_INCREF(__pyx_t_2); __pyx_t_9 = 0;
    __pyx_t_10 = NULL;
  } else {
    __pyx_t_9 = -1; __pyx_t_2 = PyObject_GetIter(__pyx_v_theme_data); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 226, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_10 = Py_TYPE(__pyx_t_2)->tp_iternext; if (unlikely(!__pyx_t_10)) __PYX_ERR(1, 226, __pyx_L1_error)
  }
  for (;;) {
    if (likely(!__pyx_t_10)) {
      if (likely(PyList_CheckExact(__pyx_t_2))) {
        if (__pyx_t_9 >= PyList_GET_SIZE(__pyx_t_2)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_1 = PyList_GET_ITEM(__pyx_t_2, __pyx_t_9); __Pyx_INCREF(__pyx_t_1); __pyx_t_9++; if (unlikely(0 < 0)) __PYX_ERR(1, 226, __pyx_L1_error)
        #else
        __pyx_t_1 = PySequence_ITEM(__pyx_t_2, __pyx_t_9); __pyx_t_9++; if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 226, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        #endif
      } else {
        if (__pyx_t_9 >= PyTuple_GET_SIZE(__pyx_t_2)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_1 = PyTuple_GET_ITEM(__pyx_t_2, __pyx_t_9); __Pyx_INCREF(__pyx_t_1); __pyx_t_9++; if (unlikely(0 < 0)) __PYX_ERR(1, 226, __pyx_L1_error)
        #else
        __pyx_t_1 = PySequence_ITEM(__pyx_t_2, __pyx_t_9); __pyx_t_9++; if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 226, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        #endif
      }
    } else {
      __pyx_t_1 = __pyx_t_10(__pyx_t_2);
      if (unlikely(!__pyx_t_1)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(1, 226, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_XDECREF_SET(__pyx_v_line, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "ttygif/tty/theme.pyx":227
 * 
 *         for line in theme_data:
 *             res=self.get_anyvar(line)             # <<<<<<<<<<<<<<
 *             if res ==None:
 *                 continue
 */
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_get_anyvar); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 227, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
      }
    }
    __pyx_t_1 = (__pyx_t_4) ? __Pyx_PyObject_Call2Args(__pyx_t_3, __pyx_t_4, __pyx_v_line) : __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_v_line);
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 227, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_XDECREF_SET(__pyx_v_res, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "ttygif/tty/theme.pyx":228
 *         for line in theme_data:
 *             res=self.get_anyvar(line)
 *             if res ==None:             # <<<<<<<<<<<<<<
 *                 continue
 *             key=res['key']
 */
    __pyx_t_1 = PyObject_RichCompare(__pyx_v_res, Py_None, Py_EQ); __Pyx_XGOTREF(__pyx_t_1); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 228, __pyx_L1_error)
    __pyx_t_8 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_8 < 0)) __PYX_ERR(1, 228, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (__pyx_t_8) {

      /* "ttygif/tty/theme.pyx":229
 *             res=self.get_anyvar(line)
 *             if res ==None:
 *                 continue             # <<<<<<<<<<<<<<
 *             key=res['key']
 *             value=None
 */
      goto __pyx_L6_continue;

      /* "ttygif/tty/theme.pyx":228
 *         for line in theme_data:
 *             res=self.get_anyvar(line)
 *             if res ==None:             # <<<<<<<<<<<<<<
 *                 continue
 *             key=res['key']
 */
    }

    /* "ttygif/tty/theme.pyx":230
 *             if res ==None:
 *                 continue
 *             key=res['key']             # <<<<<<<<<<<<<<
 *             value=None
 *             if 'value' in res:
 */
    __pyx_t_1 = __Pyx_PyObject_Dict_GetItem(__pyx_v_res, __pyx_n_s_key); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 230, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_XDECREF_SET(__pyx_v_key, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "ttygif/tty/theme.pyx":231
 *                 continue
 *             key=res['key']
 *             value=None             # <<<<<<<<<<<<<<
 *             if 'value' in res:
 *                 value=res['value']
 */
    __Pyx_INCREF(Py_None);
    __Pyx_XDECREF_SET(__pyx_v_value, Py_None);

    /* "ttygif/tty/theme.pyx":232
 *             key=res['key']
 *             value=None
 *             if 'value' in res:             # <<<<<<<<<<<<<<
 *                 value=res['value']
 *                 if value=='auto':
 */
    __pyx_t_8 = (__Pyx_PySequence_ContainsTF(__pyx_n_s_value, __pyx_v_res, Py_EQ)); if (unlikely(__pyx_t_8 < 0)) __PYX_ERR(1, 232, __pyx_L1_error)
    __pyx_t_11 = (__pyx_t_8 != 0);
    if (__pyx_t_11) {

      /* "ttygif/tty/theme.pyx":233
 *             value=None
 *             if 'value' in res:
 *                 value=res['value']             # <<<<<<<<<<<<<<
 *                 if value=='auto':
 *                     value='-1'
 */
      __pyx_t_1 = __Pyx_PyObject_Dict_GetItem(__pyx_v_res, __pyx_n_s_value); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 233, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF_SET(__pyx_v_value, __pyx_t_1);
      __pyx_t_1 = 0;

      /* "ttygif/tty/theme.pyx":234
 *             if 'value' in res:
 *                 value=res['value']
 *                 if value=='auto':             # <<<<<<<<<<<<<<
 *                     value='-1'
 * 
 */
      __pyx_t_11 = (__Pyx_PyString_Equals(__pyx_v_value, __pyx_n_s_auto, Py_EQ)); if (unlikely(__pyx_t_11 < 0)) __PYX_ERR(1, 234, __pyx_L1_error)
      if (__pyx_t_11) {

        /* "ttygif/tty/theme.pyx":235
 *                 value=res['value']
 *                 if value=='auto':
 *                     value='-1'             # <<<<<<<<<<<<<<
 * 
 *             else:
 */
        __Pyx_INCREF(__pyx_kp_s_1);
        __Pyx_DECREF_SET(__pyx_v_value, __pyx_kp_s_1);

        /* "ttygif/tty/theme.pyx":234
 *             if 'value' in res:
 *                 value=res['value']
 *                 if value=='auto':             # <<<<<<<<<<<<<<
 *                     value='-1'
 * 
 */
      }

      /* "ttygif/tty/theme.pyx":232
 *             key=res['key']
 *             value=None
 *             if 'value' in res:             # <<<<<<<<<<<<<<
 *                 value=res['value']
 *                 if value=='auto':
 */
      goto __pyx_L9;
    }

    /* "ttygif/tty/theme.pyx":238
 * 
 *             else:
 *                 section=key             # <<<<<<<<<<<<<<
 * 
 *                 if value==None and section=='layer':
 */
    /*else*/ {
      __Pyx_INCREF(__pyx_v_key);
      __Pyx_DECREF_SET(__pyx_v_section, __pyx_v_key);

      /* "ttygif/tty/theme.pyx":240
 *                 section=key
 * 
 *                 if value==None and section=='layer':             # <<<<<<<<<<<<<<
 * 
 *                     theme_layer=layer()
 */
      __pyx_t_1 = PyObject_RichCompare(__pyx_v_value, Py_None, Py_EQ); __Pyx_XGOTREF(__pyx_t_1); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 240, __pyx_L1_error)
      __pyx_t_8 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_8 < 0)) __PYX_ERR(1, 240, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      if (__pyx_t_8) {
      } else {
        __pyx_t_11 = __pyx_t_8;
        goto __pyx_L12_bool_binop_done;
      }
      __pyx_t_8 = (__Pyx_PyString_Equals(__pyx_v_section, __pyx_n_s_layer, Py_EQ)); if (unlikely(__pyx_t_8 < 0)) __PYX_ERR(1, 240, __pyx_L1_error)
      __pyx_t_11 = __pyx_t_8;
      __pyx_L12_bool_binop_done:;
      if (__pyx_t_11) {

        /* "ttygif/tty/theme.pyx":242
 *                 if value==None and section=='layer':
 * 
 *                     theme_layer=layer()             # <<<<<<<<<<<<<<
 *                     theme_layer.path=self.path
 * 
 */
        __pyx_t_1 = __Pyx_PyObject_CallNoArg(((PyObject *)__pyx_ptype_6ttygif_3tty_5theme_layer)); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 242, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF_SET(__pyx_v_theme_layer, ((struct __pyx_obj_6ttygif_3tty_5theme_layer *)__pyx_t_1));
        __pyx_t_1 = 0;

        /* "ttygif/tty/theme.pyx":243
 * 
 *                     theme_layer=layer()
 *                     theme_layer.path=self.path             # <<<<<<<<<<<<<<
 * 
 *                     if self.layer1==None:
 */
        __pyx_t_1 = __pyx_v_self->path;
        __Pyx_INCREF(__pyx_t_1);
        __Pyx_GIVEREF(__pyx_t_1);
        __Pyx_GOTREF(__pyx_v_theme_layer->path);
        __Pyx_DECREF(__pyx_v_theme_layer->path);
        __pyx_v_theme_layer->path = ((PyObject*)__pyx_t_1);
        __pyx_t_1 = 0;

        /* "ttygif/tty/theme.pyx":245
 *                     theme_layer.path=self.path
 * 
 *                     if self.layer1==None:             # <<<<<<<<<<<<<<
 *                         theme_layer.name="layer1"
 *                         self.layer1=theme_layer
 */
        __pyx_t_1 = PyObject_RichCompare(((PyObject *)__pyx_v_self->layer1), Py_None, Py_EQ); __Pyx_XGOTREF(__pyx_t_1); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 245, __pyx_L1_error)
        __pyx_t_11 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_11 < 0)) __PYX_ERR(1, 245, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        if (__pyx_t_11) {

          /* "ttygif/tty/theme.pyx":246
 * 
 *                     if self.layer1==None:
 *                         theme_layer.name="layer1"             # <<<<<<<<<<<<<<
 *                         self.layer1=theme_layer
 * 
 */
          __Pyx_INCREF(__pyx_n_s_layer1);
          __Pyx_GIVEREF(__pyx_n_s_layer1);
          __Pyx_GOTREF(__pyx_v_theme_layer->name);
          __Pyx_DECREF(__pyx_v_theme_layer->name);
          __pyx_v_theme_layer->name = __pyx_n_s_layer1;

          /* "ttygif/tty/theme.pyx":247
 *                     if self.layer1==None:
 *                         theme_layer.name="layer1"
 *                         self.layer1=theme_layer             # <<<<<<<<<<<<<<
 * 
 *                     elif self.layer2==None:
 */
          __Pyx_INCREF(((PyObject *)__pyx_v_theme_layer));
          __Pyx_GIVEREF(((PyObject *)__pyx_v_theme_layer));
          __Pyx_GOTREF(__pyx_v_self->layer1);
          __Pyx_DECREF(((PyObject *)__pyx_v_self->layer1));
          __pyx_v_self->layer1 = __pyx_v_theme_layer;

          /* "ttygif/tty/theme.pyx":245
 *                     theme_layer.path=self.path
 * 
 *                     if self.layer1==None:             # <<<<<<<<<<<<<<
 *                         theme_layer.name="layer1"
 *                         self.layer1=theme_layer
 */
          goto __pyx_L14;
        }

        /* "ttygif/tty/theme.pyx":249
 *                         self.layer1=theme_layer
 * 
 *                     elif self.layer2==None:             # <<<<<<<<<<<<<<
 *                         theme_layer.name="layer2"
 *                         self.layer2=theme_layer
 */
        __pyx_t_1 = PyObject_RichCompare(((PyObject *)__pyx_v_self->layer2), Py_None, Py_EQ); __Pyx_XGOTREF(__pyx_t_1); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 249, __pyx_L1_error)
        __pyx_t_11 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_11 < 0)) __PYX_ERR(1, 249, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        if (__pyx_t_11) {

          /* "ttygif/tty/theme.pyx":250
 * 
 *                     elif self.layer2==None:
 *                         theme_layer.name="layer2"             # <<<<<<<<<<<<<<
 *                         self.layer2=theme_layer
 *                     elif self.layer3==None:
 */
          __Pyx_INCREF(__pyx_n_s_layer2);
          __Pyx_GIVEREF(__pyx_n_s_layer2);
          __Pyx_GOTREF(__pyx_v_theme_layer->name);
          __Pyx_DECREF(__pyx_v_theme_layer->name);
          __pyx_v_theme_layer->name = __pyx_n_s_layer2;

          /* "ttygif/tty/theme.pyx":251
 *                     elif self.layer2==None:
 *                         theme_layer.name="layer2"
 *                         self.layer2=theme_layer             # <<<<<<<<<<<<<<
 *                     elif self.layer3==None:
 *                         theme_layer.name="layer3"
 */
          __Pyx_INCREF(((PyObject *)__pyx_v_theme_layer));
          __Pyx_GIVEREF(((PyObject *)__pyx_v_theme_layer));
          __Pyx_GOTREF(__pyx_v_self->layer2);
          __Pyx_DECREF(((PyObject *)__pyx_v_self->layer2));
          __pyx_v_self->layer2 = __pyx_v_theme_layer;

          /* "ttygif/tty/theme.pyx":249
 *                         self.layer1=theme_layer
 * 
 *                     elif self.layer2==None:             # <<<<<<<<<<<<<<
 *                         theme_layer.name="layer2"
 *                         self.layer2=theme_layer
 */
          goto __pyx_L14;
        }

        /* "ttygif/tty/theme.pyx":252
 *                         theme_layer.name="layer2"
 *                         self.layer2=theme_layer
 *                     elif self.layer3==None:             # <<<<<<<<<<<<<<
 *                         theme_layer.name="layer3"
 *                         self.layer3=theme_layer
 */
        __pyx_t_1 = PyObject_RichCompare(((PyObject *)__pyx_v_self->layer3), Py_None, Py_EQ); __Pyx_XGOTREF(__pyx_t_1); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 252, __pyx_L1_error)
        __pyx_t_11 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_11 < 0)) __PYX_ERR(1, 252, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        if (__pyx_t_11) {

          /* "ttygif/tty/theme.pyx":253
 *                         self.layer2=theme_layer
 *                     elif self.layer3==None:
 *                         theme_layer.name="layer3"             # <<<<<<<<<<<<<<
 *                         self.layer3=theme_layer
 *                     elif self.layer4==None:
 */
          __Pyx_INCREF(__pyx_n_s_layer3);
          __Pyx_GIVEREF(__pyx_n_s_layer3);
          __Pyx_GOTREF(__pyx_v_theme_layer->name);
          __Pyx_DECREF(__pyx_v_theme_layer->name);
          __pyx_v_theme_layer->name = __pyx_n_s_layer3;

          /* "ttygif/tty/theme.pyx":254
 *                     elif self.layer3==None:
 *                         theme_layer.name="layer3"
 *                         self.layer3=theme_layer             # <<<<<<<<<<<<<<
 *                     elif self.layer4==None:
 *                         theme_layer.name="layer4"
 */
          __Pyx_INCREF(((PyObject *)__pyx_v_theme_layer));
          __Pyx_GIVEREF(((PyObject *)__pyx_v_theme_layer));
          __Pyx_GOTREF(__pyx_v_self->layer3);
          __Pyx_DECREF(((PyObject *)__pyx_v_self->layer3));
          __pyx_v_self->layer3 = __pyx_v_theme_layer;

          /* "ttygif/tty/theme.pyx":252
 *                         theme_layer.name="layer2"
 *                         self.layer2=theme_layer
 *                     elif self.layer3==None:             # <<<<<<<<<<<<<<
 *                         theme_layer.name="layer3"
 *                         self.layer3=theme_layer
 */
          goto __pyx_L14;
        }

        /* "ttygif/tty/theme.pyx":255
 *                         theme_layer.name="layer3"
 *                         self.layer3=theme_layer
 *                     elif self.layer4==None:             # <<<<<<<<<<<<<<
 *                         theme_layer.name="layer4"
 *                         self.layer4=theme_layer
 */
        __pyx_t_1 = PyObject_RichCompare(((PyObject *)__pyx_v_self->layer4), Py_None, Py_EQ); __Pyx_XGOTREF(__pyx_t_1); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 255, __pyx_L1_error)
        __pyx_t_11 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_11 < 0)) __PYX_ERR(1, 255, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        if (__pyx_t_11) {

          /* "ttygif/tty/theme.pyx":256
 *                         self.layer3=theme_layer
 *                     elif self.layer4==None:
 *                         theme_layer.name="layer4"             # <<<<<<<<<<<<<<
 *                         self.layer4=theme_layer
 *                     elif self.layer5==None:
 */
          __Pyx_INCREF(__pyx_n_s_layer4);
          __Pyx_GIVEREF(__pyx_n_s_layer4);
          __Pyx_GOTREF(__pyx_v_theme_layer->name);
          __Pyx_DECREF(__pyx_v_theme_layer->name);
          __pyx_v_theme_layer->name = __pyx_n_s_layer4;

          /* "ttygif/tty/theme.pyx":257
 *                     elif self.layer4==None:
 *                         theme_layer.name="layer4"
 *                         self.layer4=theme_layer             # <<<<<<<<<<<<<<
 *                     elif self.layer5==None:
 *                         theme_layer.name="layer5"
 */
          __Pyx_INCREF(((PyObject *)__pyx_v_theme_layer));
          __Pyx_GIVEREF(((PyObject *)__pyx_v_theme_layer));
          __Pyx_GOTREF(__pyx_v_self->layer4);
          __Pyx_DECREF(((PyObject *)__pyx_v_self->layer4));
          __pyx_v_self->layer4 = __pyx_v_theme_layer;

          /* "ttygif/tty/theme.pyx":255
 *                         theme_layer.name="layer3"
 *                         self.layer3=theme_layer
 *                     elif self.layer4==None:             # <<<<<<<<<<<<<<
 *                         theme_layer.name="layer4"
 *                         self.layer4=theme_layer
 */
          goto __pyx_L14;
        }

        /* "ttygif/tty/theme.pyx":258
 *                         theme_layer.name="layer4"
 *                         self.layer4=theme_layer
 *                     elif self.layer5==None:             # <<<<<<<<<<<<<<
 *                         theme_layer.name="layer5"
 *                         self.layer5=theme_layer
 */
        __pyx_t_1 = PyObject_RichCompare(((PyObject *)__pyx_v_self->layer5), Py_None, Py_EQ); __Pyx_XGOTREF(__pyx_t_1); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 258, __pyx_L1_error)
        __pyx_t_11 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_11 < 0)) __PYX_ERR(1, 258, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        if (__pyx_t_11) {

          /* "ttygif/tty/theme.pyx":259
 *                         self.layer4=theme_layer
 *                     elif self.layer5==None:
 *                         theme_layer.name="layer5"             # <<<<<<<<<<<<<<
 *                         self.layer5=theme_layer
 *                 else:
 */
          __Pyx_INCREF(__pyx_n_s_layer5);
          __Pyx_GIVEREF(__pyx_n_s_layer5);
          __Pyx_GOTREF(__pyx_v_theme_layer->name);
          __Pyx_DECREF(__pyx_v_theme_layer->name);
          __pyx_v_theme_layer->name = __pyx_n_s_layer5;

          /* "ttygif/tty/theme.pyx":260
 *                     elif self.layer5==None:
 *                         theme_layer.name="layer5"
 *                         self.layer5=theme_layer             # <<<<<<<<<<<<<<
 *                 else:
 *                     theme_layer=None
 */
          __Pyx_INCREF(((PyObject *)__pyx_v_theme_layer));
          __Pyx_GIVEREF(((PyObject *)__pyx_v_theme_layer));
          __Pyx_GOTREF(__pyx_v_self->layer5);
          __Pyx_DECREF(((PyObject *)__pyx_v_self->layer5));
          __pyx_v_self->layer5 = __pyx_v_theme_layer;

          /* "ttygif/tty/theme.pyx":258
 *                         theme_layer.name="layer4"
 *                         self.layer4=theme_layer
 *                     elif self.layer5==None:             # <<<<<<<<<<<<<<
 *                         theme_layer.name="layer5"
 *                         self.layer5=theme_layer
 */
        }
        __pyx_L14:;

        /* "ttygif/tty/theme.pyx":240
 *                 section=key
 * 
 *                 if value==None and section=='layer':             # <<<<<<<<<<<<<<
 * 
 *                     theme_layer=layer()
 */
        goto __pyx_L11;
      }

      /* "ttygif/tty/theme.pyx":262
 *                         self.layer5=theme_layer
 *                 else:
 *                     theme_layer=None             # <<<<<<<<<<<<<<
 * 
 * 
 */
      /*else*/ {
        __Pyx_INCREF(Py_None);
        __Pyx_DECREF_SET(__pyx_v_theme_layer, ((struct __pyx_obj_6ttygif_3tty_5theme_layer *)Py_None));
      }
      __pyx_L11:;
    }
    __pyx_L9:;

    /* "ttygif/tty/theme.pyx":265
 * 
 * 
 *             if section=='':             # <<<<<<<<<<<<<<
 *                 if   key=='background':
 *                     self.background=int(value)
 */
    __pyx_t_11 = (__Pyx_PyString_Equals(__pyx_v_section, __pyx_kp_s_, Py_EQ)); if (unlikely(__pyx_t_11 < 0)) __PYX_ERR(1, 265, __pyx_L1_error)
    if (__pyx_t_11) {

      /* "ttygif/tty/theme.pyx":266
 * 
 *             if section=='':
 *                 if   key=='background':             # <<<<<<<<<<<<<<
 *                     self.background=int(value)
 *                 elif key=='foreground':
 */
      __pyx_t_11 = (__Pyx_PyString_Equals(__pyx_v_key, __pyx_n_s_background, Py_EQ)); if (unlikely(__pyx_t_11 < 0)) __PYX_ERR(1, 266, __pyx_L1_error)
      if (__pyx_t_11) {

        /* "ttygif/tty/theme.pyx":267
 *             if section=='':
 *                 if   key=='background':
 *                     self.background=int(value)             # <<<<<<<<<<<<<<
 *                 elif key=='foreground':
 *                     self.foreground=int(value)
 */
        __pyx_t_1 = __Pyx_PyNumber_Int(__pyx_v_value); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 267, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __pyx_t_12 = __Pyx_PyInt_As_int16_t(__pyx_t_1); if (unlikely((__pyx_t_12 == ((int16_t)-1)) && PyErr_Occurred())) __PYX_ERR(1, 267, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __pyx_v_self->background = __pyx_t_12;

        /* "ttygif/tty/theme.pyx":266
 * 
 *             if section=='':
 *                 if   key=='background':             # <<<<<<<<<<<<<<
 *                     self.background=int(value)
 *                 elif key=='foreground':
 */
        goto __pyx_L16;
      }

      /* "ttygif/tty/theme.pyx":268
 *                 if   key=='background':
 *                     self.background=int(value)
 *                 elif key=='foreground':             # <<<<<<<<<<<<<<
 *                     self.foreground=int(value)
 *                 elif key=='default_foreground':
 */
      __pyx_t_11 = (__Pyx_PyString_Equals(__pyx_v_key, __pyx_n_s_foreground, Py_EQ)); if (unlikely(__pyx_t_11 < 0)) __PYX_ERR(1, 268, __pyx_L1_error)
      if (__pyx_t_11) {

        /* "ttygif/tty/theme.pyx":269
 *                     self.background=int(value)
 *                 elif key=='foreground':
 *                     self.foreground=int(value)             # <<<<<<<<<<<<<<
 *                 elif key=='default_foreground':
 *                     self.default_foreground=int(value)
 */
        __pyx_t_1 = __Pyx_PyNumber_Int(__pyx_v_value); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 269, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __pyx_t_12 = __Pyx_PyInt_As_int16_t(__pyx_t_1); if (unlikely((__pyx_t_12 == ((int16_t)-1)) && PyErr_Occurred())) __PYX_ERR(1, 269, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __pyx_v_self->foreground = __pyx_t_12;

        /* "ttygif/tty/theme.pyx":268
 *                 if   key=='background':
 *                     self.background=int(value)
 *                 elif key=='foreground':             # <<<<<<<<<<<<<<
 *                     self.foreground=int(value)
 *                 elif key=='default_foreground':
 */
        goto __pyx_L16;
      }

      /* "ttygif/tty/theme.pyx":270
 *                 elif key=='foreground':
 *                     self.foreground=int(value)
 *                 elif key=='default_foreground':             # <<<<<<<<<<<<<<
 *                     self.default_foreground=int(value)
 *                 elif key=='default_background':
 */
      __pyx_t_11 = (__Pyx_PyString_Equals(__pyx_v_key, __pyx_n_s_default_foreground, Py_EQ)); if (unlikely(__pyx_t_11 < 0)) __PYX_ERR(1, 270, __pyx_L1_error)
      if (__pyx_t_11) {

        /* "ttygif/tty/theme.pyx":271
 *                     self.foreground=int(value)
 *                 elif key=='default_foreground':
 *                     self.default_foreground=int(value)             # <<<<<<<<<<<<<<
 *                 elif key=='default_background':
 *                     self.default_background=int(value)
 */
        __pyx_t_1 = __Pyx_PyNumber_Int(__pyx_v_value); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 271, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __pyx_t_12 = __Pyx_PyInt_As_int16_t(__pyx_t_1); if (unlikely((__pyx_t_12 == ((int16_t)-1)) && PyErr_Occurred())) __PYX_ERR(1, 271, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __pyx_v_self->default_foreground = __pyx_t_12;

        /* "ttygif/tty/theme.pyx":270
 *                 elif key=='foreground':
 *                     self.foreground=int(value)
 *                 elif key=='default_foreground':             # <<<<<<<<<<<<<<
 *                     self.default_foreground=int(value)
 *                 elif key=='default_background':
 */
        goto __pyx_L16;
      }

      /* "ttygif/tty/theme.pyx":272
 *                 elif key=='default_foreground':
 *                     self.default_foreground=int(value)
 *                 elif key=='default_background':             # <<<<<<<<<<<<<<
 *                     self.default_background=int(value)
 *                 elif key=='transparent':
 */
      __pyx_t_11 = (__Pyx_PyString_Equals(__pyx_v_key, __pyx_n_s_default_background, Py_EQ)); if (unlikely(__pyx_t_11 < 0)) __PYX_ERR(1, 272, __pyx_L1_error)
      if (__pyx_t_11) {

        /* "ttygif/tty/theme.pyx":273
 *                     self.default_foreground=int(value)
 *                 elif key=='default_background':
 *                     self.default_background=int(value)             # <<<<<<<<<<<<<<
 *                 elif key=='transparent':
 *                     self.transparent=int(value)
 */
        __pyx_t_1 = __Pyx_PyNumber_Int(__pyx_v_value); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 273, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __pyx_t_12 = __Pyx_PyInt_As_int16_t(__pyx_t_1); if (unlikely((__pyx_t_12 == ((int16_t)-1)) && PyErr_Occurred())) __PYX_ERR(1, 273, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __pyx_v_self->default_background = __pyx_t_12;

        /* "ttygif/tty/theme.pyx":272
 *                 elif key=='default_foreground':
 *                     self.default_foreground=int(value)
 *                 elif key=='default_background':             # <<<<<<<<<<<<<<
 *                     self.default_background=int(value)
 *                 elif key=='transparent':
 */
        goto __pyx_L16;
      }

      /* "ttygif/tty/theme.pyx":274
 *                 elif key=='default_background':
 *                     self.default_background=int(value)
 *                 elif key=='transparent':             # <<<<<<<<<<<<<<
 *                     self.transparent=int(value)
 *                 elif key=='font':
 */
      __pyx_t_11 = (__Pyx_PyString_Equals(__pyx_v_key, __pyx_n_s_transparent, Py_EQ)); if (unlikely(__pyx_t_11 < 0)) __PYX_ERR(1, 274, __pyx_L1_error)
      if (__pyx_t_11) {

        /* "ttygif/tty/theme.pyx":275
 *                     self.default_background=int(value)
 *                 elif key=='transparent':
 *                     self.transparent=int(value)             # <<<<<<<<<<<<<<
 *                 elif key=='font':
 *                     self.font=value
 */
        __pyx_t_1 = __Pyx_PyNumber_Int(__pyx_v_value); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 275, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __pyx_t_12 = __Pyx_PyInt_As_int16_t(__pyx_t_1); if (unlikely((__pyx_t_12 == ((int16_t)-1)) && PyErr_Occurred())) __PYX_ERR(1, 275, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __pyx_v_self->transparent = __pyx_t_12;

        /* "ttygif/tty/theme.pyx":274
 *                 elif key=='default_background':
 *                     self.default_background=int(value)
 *                 elif key=='transparent':             # <<<<<<<<<<<<<<
 *                     self.transparent=int(value)
 *                 elif key=='font':
 */
        goto __pyx_L16;
      }

      /* "ttygif/tty/theme.pyx":276
 *                 elif key=='transparent':
 *                     self.transparent=int(value)
 *                 elif key=='font':             # <<<<<<<<<<<<<<
 *                     self.font=value
 * 
 */
      __pyx_t_11 = (__Pyx_PyString_Equals(__pyx_v_key, __pyx_n_s_font, Py_EQ)); if (unlikely(__pyx_t_11 < 0)) __PYX_ERR(1, 276, __pyx_L1_error)
      if (__pyx_t_11) {

        /* "ttygif/tty/theme.pyx":277
 *                     self.transparent=int(value)
 *                 elif key=='font':
 *                     self.font=value             # <<<<<<<<<<<<<<
 * 
 *             if section=='title':
 */
        if (!(likely(PyString_CheckExact(__pyx_v_value))||((__pyx_v_value) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "str", Py_TYPE(__pyx_v_value)->tp_name), 0))) __PYX_ERR(1, 277, __pyx_L1_error)
        __pyx_t_1 = __pyx_v_value;
        __Pyx_INCREF(__pyx_t_1);
        __Pyx_GIVEREF(__pyx_t_1);
        __Pyx_GOTREF(__pyx_v_self->font);
        __Pyx_DECREF(__pyx_v_self->font);
        __pyx_v_self->font = ((PyObject*)__pyx_t_1);
        __pyx_t_1 = 0;

        /* "ttygif/tty/theme.pyx":276
 *                 elif key=='transparent':
 *                     self.transparent=int(value)
 *                 elif key=='font':             # <<<<<<<<<<<<<<
 *                     self.font=value
 * 
 */
      }
      __pyx_L16:;

      /* "ttygif/tty/theme.pyx":265
 * 
 * 
 *             if section=='':             # <<<<<<<<<<<<<<
 *                 if   key=='background':
 *                     self.background=int(value)
 */
    }

    /* "ttygif/tty/theme.pyx":279
 *                     self.font=value
 * 
 *             if section=='title':             # <<<<<<<<<<<<<<
 *                 if   key=='x':
 *                     self.title_x=int(value)
 */
    __pyx_t_11 = (__Pyx_PyString_Equals(__pyx_v_section, __pyx_n_s_title, Py_EQ)); if (unlikely(__pyx_t_11 < 0)) __PYX_ERR(1, 279, __pyx_L1_error)
    if (__pyx_t_11) {

      /* "ttygif/tty/theme.pyx":280
 * 
 *             if section=='title':
 *                 if   key=='x':             # <<<<<<<<<<<<<<
 *                     self.title_x=int(value)
 *                 elif key=='y':
 */
      __pyx_t_11 = (__Pyx_PyString_Equals(__pyx_v_key, __pyx_n_s_x, Py_EQ)); if (unlikely(__pyx_t_11 < 0)) __PYX_ERR(1, 280, __pyx_L1_error)
      if (__pyx_t_11) {

        /* "ttygif/tty/theme.pyx":281
 *             if section=='title':
 *                 if   key=='x':
 *                     self.title_x=int(value)             # <<<<<<<<<<<<<<
 *                 elif key=='y':
 *                     self.title_y=int(value)
 */
        __pyx_t_1 = __Pyx_PyNumber_Int(__pyx_v_value); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 281, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __pyx_t_12 = __Pyx_PyInt_As_int16_t(__pyx_t_1); if (unlikely((__pyx_t_12 == ((int16_t)-1)) && PyErr_Occurred())) __PYX_ERR(1, 281, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __pyx_v_self->title_x = __pyx_t_12;

        /* "ttygif/tty/theme.pyx":280
 * 
 *             if section=='title':
 *                 if   key=='x':             # <<<<<<<<<<<<<<
 *                     self.title_x=int(value)
 *                 elif key=='y':
 */
        goto __pyx_L18;
      }

      /* "ttygif/tty/theme.pyx":282
 *                 if   key=='x':
 *                     self.title_x=int(value)
 *                 elif key=='y':             # <<<<<<<<<<<<<<
 *                     self.title_y=int(value)
 *                 elif key=='foreground':
 */
      __pyx_t_11 = (__Pyx_PyString_Equals(__pyx_v_key, __pyx_n_s_y, Py_EQ)); if (unlikely(__pyx_t_11 < 0)) __PYX_ERR(1, 282, __pyx_L1_error)
      if (__pyx_t_11) {

        /* "ttygif/tty/theme.pyx":283
 *                     self.title_x=int(value)
 *                 elif key=='y':
 *                     self.title_y=int(value)             # <<<<<<<<<<<<<<
 *                 elif key=='foreground':
 *                     self.title_foreground=int(value)
 */
        __pyx_t_1 = __Pyx_PyNumber_Int(__pyx_v_value); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 283, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __pyx_t_12 = __Pyx_PyInt_As_int16_t(__pyx_t_1); if (unlikely((__pyx_t_12 == ((int16_t)-1)) && PyErr_Occurred())) __PYX_ERR(1, 283, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __pyx_v_self->title_y = __pyx_t_12;

        /* "ttygif/tty/theme.pyx":282
 *                 if   key=='x':
 *                     self.title_x=int(value)
 *                 elif key=='y':             # <<<<<<<<<<<<<<
 *                     self.title_y=int(value)
 *                 elif key=='foreground':
 */
        goto __pyx_L18;
      }

      /* "ttygif/tty/theme.pyx":284
 *                 elif key=='y':
 *                     self.title_y=int(value)
 *                 elif key=='foreground':             # <<<<<<<<<<<<<<
 *                     self.title_foreground=int(value)
 *                 elif key=='background':
 */
      __pyx_t_11 = (__Pyx_PyString_Equals(__pyx_v_key, __pyx_n_s_foreground, Py_EQ)); if (unlikely(__pyx_t_11 < 0)) __PYX_ERR(1, 284, __pyx_L1_error)
      if (__pyx_t_11) {

        /* "ttygif/tty/theme.pyx":285
 *                     self.title_y=int(value)
 *                 elif key=='foreground':
 *                     self.title_foreground=int(value)             # <<<<<<<<<<<<<<
 *                 elif key=='background':
 *                     self.title_background=int(value)
 */
        __pyx_t_1 = __Pyx_PyNumber_Int(__pyx_v_value); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 285, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __pyx_t_12 = __Pyx_PyInt_As_int16_t(__pyx_t_1); if (unlikely((__pyx_t_12 == ((int16_t)-1)) && PyErr_Occurred())) __PYX_ERR(1, 285, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __pyx_v_self->title_foreground = __pyx_t_12;

        /* "ttygif/tty/theme.pyx":284
 *                 elif key=='y':
 *                     self.title_y=int(value)
 *                 elif key=='foreground':             # <<<<<<<<<<<<<<
 *                     self.title_foreground=int(value)
 *                 elif key=='background':
 */
        goto __pyx_L18;
      }

      /* "ttygif/tty/theme.pyx":286
 *                 elif key=='foreground':
 *                     self.title_foreground=int(value)
 *                 elif key=='background':             # <<<<<<<<<<<<<<
 *                     self.title_background=int(value)
 *                 elif key=='font':
 */
      __pyx_t_11 = (__Pyx_PyString_Equals(__pyx_v_key, __pyx_n_s_background, Py_EQ)); if (unlikely(__pyx_t_11 < 0)) __PYX_ERR(1, 286, __pyx_L1_error)
      if (__pyx_t_11) {

        /* "ttygif/tty/theme.pyx":287
 *                     self.title_foreground=int(value)
 *                 elif key=='background':
 *                     self.title_background=int(value)             # <<<<<<<<<<<<<<
 *                 elif key=='font':
 *                     self.title_font=value
 */
        __pyx_t_1 = __Pyx_PyNumber_Int(__pyx_v_value); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 287, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __pyx_t_12 = __Pyx_PyInt_As_int16_t(__pyx_t_1); if (unlikely((__pyx_t_12 == ((int16_t)-1)) && PyErr_Occurred())) __PYX_ERR(1, 287, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __pyx_v_self->title_background = __pyx_t_12;

        /* "ttygif/tty/theme.pyx":286
 *                 elif key=='foreground':
 *                     self.title_foreground=int(value)
 *                 elif key=='background':             # <<<<<<<<<<<<<<
 *                     self.title_background=int(value)
 *                 elif key=='font':
 */
        goto __pyx_L18;
      }

      /* "ttygif/tty/theme.pyx":288
 *                 elif key=='background':
 *                     self.title_background=int(value)
 *                 elif key=='font':             # <<<<<<<<<<<<<<
 *                     self.title_font=value
 *                 elif key=='font_size':
 */
      __pyx_t_11 = (__Pyx_PyString_Equals(__pyx_v_key, __pyx_n_s_font, Py_EQ)); if (unlikely(__pyx_t_11 < 0)) __PYX_ERR(1, 288, __pyx_L1_error)
      if (__pyx_t_11) {

        /* "ttygif/tty/theme.pyx":289
 *                     self.title_background=int(value)
 *                 elif key=='font':
 *                     self.title_font=value             # <<<<<<<<<<<<<<
 *                 elif key=='font_size':
 *                     self.title_font_size=float(value)
 */
        __pyx_t_12 = __Pyx_PyInt_As_int16_t(__pyx_v_value); if (unlikely((__pyx_t_12 == ((int16_t)-1)) && PyErr_Occurred())) __PYX_ERR(1, 289, __pyx_L1_error)
        __pyx_v_self->title_font = __pyx_t_12;

        /* "ttygif/tty/theme.pyx":288
 *                 elif key=='background':
 *                     self.title_background=int(value)
 *                 elif key=='font':             # <<<<<<<<<<<<<<
 *                     self.title_font=value
 *                 elif key=='font_size':
 */
        goto __pyx_L18;
      }

      /* "ttygif/tty/theme.pyx":290
 *                 elif key=='font':
 *                     self.title_font=value
 *                 elif key=='font_size':             # <<<<<<<<<<<<<<
 *                     self.title_font_size=float(value)
 * 
 */
      __pyx_t_11 = (__Pyx_PyString_Equals(__pyx_v_key, __pyx_n_s_font_size, Py_EQ)); if (unlikely(__pyx_t_11 < 0)) __PYX_ERR(1, 290, __pyx_L1_error)
      if (__pyx_t_11) {

        /* "ttygif/tty/theme.pyx":291
 *                     self.title_font=value
 *                 elif key=='font_size':
 *                     self.title_font_size=float(value)             # <<<<<<<<<<<<<<
 * 
 *             elif section=='padding':
 */
        __pyx_t_13 = __Pyx_PyObject_AsDouble(__pyx_v_value); if (unlikely(__pyx_t_13 == ((double)((double)-1)) && PyErr_Occurred())) __PYX_ERR(1, 291, __pyx_L1_error)
        __pyx_v_self->title_font_size = __pyx_t_13;

        /* "ttygif/tty/theme.pyx":290
 *                 elif key=='font':
 *                     self.title_font=value
 *                 elif key=='font_size':             # <<<<<<<<<<<<<<
 *                     self.title_font_size=float(value)
 * 
 */
      }
      __pyx_L18:;

      /* "ttygif/tty/theme.pyx":279
 *                     self.font=value
 * 
 *             if section=='title':             # <<<<<<<<<<<<<<
 *                 if   key=='x':
 *                     self.title_x=int(value)
 */
      goto __pyx_L17;
    }

    /* "ttygif/tty/theme.pyx":293
 *                     self.title_font_size=float(value)
 * 
 *             elif section=='padding':             # <<<<<<<<<<<<<<
 *                 if   key=='left':
 *                     self.padding.left=int(value)
 */
    __pyx_t_11 = (__Pyx_PyString_Equals(__pyx_v_section, __pyx_n_s_padding, Py_EQ)); if (unlikely(__pyx_t_11 < 0)) __PYX_ERR(1, 293, __pyx_L1_error)
    if (__pyx_t_11) {

      /* "ttygif/tty/theme.pyx":294
 * 
 *             elif section=='padding':
 *                 if   key=='left':             # <<<<<<<<<<<<<<
 *                     self.padding.left=int(value)
 *                 elif key=='right':
 */
      __pyx_t_11 = (__Pyx_PyString_Equals(__pyx_v_key, __pyx_n_s_left, Py_EQ)); if (unlikely(__pyx_t_11 < 0)) __PYX_ERR(1, 294, __pyx_L1_error)
      if (__pyx_t_11) {

        /* "ttygif/tty/theme.pyx":295
 *             elif section=='padding':
 *                 if   key=='left':
 *                     self.padding.left=int(value)             # <<<<<<<<<<<<<<
 *                 elif key=='right':
 *                     self.padding.right=int(value)
 */
        __pyx_t_1 = __Pyx_PyNumber_Int(__pyx_v_value); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 295, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __pyx_t_7 = __Pyx_PyInt_As_int(__pyx_t_1); if (unlikely((__pyx_t_7 == (int)-1) && PyErr_Occurred())) __PYX_ERR(1, 295, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __pyx_v_self->padding->left = __pyx_t_7;

        /* "ttygif/tty/theme.pyx":294
 * 
 *             elif section=='padding':
 *                 if   key=='left':             # <<<<<<<<<<<<<<
 *                     self.padding.left=int(value)
 *                 elif key=='right':
 */
        goto __pyx_L19;
      }

      /* "ttygif/tty/theme.pyx":296
 *                 if   key=='left':
 *                     self.padding.left=int(value)
 *                 elif key=='right':             # <<<<<<<<<<<<<<
 *                     self.padding.right=int(value)
 *                 elif key=='top':
 */
      __pyx_t_11 = (__Pyx_PyString_Equals(__pyx_v_key, __pyx_n_s_right, Py_EQ)); if (unlikely(__pyx_t_11 < 0)) __PYX_ERR(1, 296, __pyx_L1_error)
      if (__pyx_t_11) {

        /* "ttygif/tty/theme.pyx":297
 *                     self.padding.left=int(value)
 *                 elif key=='right':
 *                     self.padding.right=int(value)             # <<<<<<<<<<<<<<
 *                 elif key=='top':
 *                     self.padding.top=int(value)
 */
        __pyx_t_1 = __Pyx_PyNumber_Int(__pyx_v_value); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 297, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __pyx_t_7 = __Pyx_PyInt_As_int(__pyx_t_1); if (unlikely((__pyx_t_7 == (int)-1) && PyErr_Occurred())) __PYX_ERR(1, 297, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __pyx_v_self->padding->right = __pyx_t_7;

        /* "ttygif/tty/theme.pyx":296
 *                 if   key=='left':
 *                     self.padding.left=int(value)
 *                 elif key=='right':             # <<<<<<<<<<<<<<
 *                     self.padding.right=int(value)
 *                 elif key=='top':
 */
        goto __pyx_L19;
      }

      /* "ttygif/tty/theme.pyx":298
 *                 elif key=='right':
 *                     self.padding.right=int(value)
 *                 elif key=='top':             # <<<<<<<<<<<<<<
 *                     self.padding.top=int(value)
 *                 elif key=='bottom':
 */
      __pyx_t_11 = (__Pyx_PyString_Equals(__pyx_v_key, __pyx_n_s_top, Py_EQ)); if (unlikely(__pyx_t_11 < 0)) __PYX_ERR(1, 298, __pyx_L1_error)
      if (__pyx_t_11) {

        /* "ttygif/tty/theme.pyx":299
 *                     self.padding.right=int(value)
 *                 elif key=='top':
 *                     self.padding.top=int(value)             # <<<<<<<<<<<<<<
 *                 elif key=='bottom':
 *                     self.padding.bottom=int(value)
 */
        __pyx_t_1 = __Pyx_PyNumber_Int(__pyx_v_value); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 299, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __pyx_t_7 = __Pyx_PyInt_As_int(__pyx_t_1); if (unlikely((__pyx_t_7 == (int)-1) && PyErr_Occurred())) __PYX_ERR(1, 299, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __pyx_v_self->padding->top = __pyx_t_7;

        /* "ttygif/tty/theme.pyx":298
 *                 elif key=='right':
 *                     self.padding.right=int(value)
 *                 elif key=='top':             # <<<<<<<<<<<<<<
 *                     self.padding.top=int(value)
 *                 elif key=='bottom':
 */
        goto __pyx_L19;
      }

      /* "ttygif/tty/theme.pyx":300
 *                 elif key=='top':
 *                     self.padding.top=int(value)
 *                 elif key=='bottom':             # <<<<<<<<<<<<<<
 *                     self.padding.bottom=int(value)
 * 
 */
      __pyx_t_11 = (__Pyx_PyString_Equals(__pyx_v_key, __pyx_n_s_bottom, Py_EQ)); if (unlikely(__pyx_t_11 < 0)) __PYX_ERR(1, 300, __pyx_L1_error)
      if (__pyx_t_11) {

        /* "ttygif/tty/theme.pyx":301
 *                     self.padding.top=int(value)
 *                 elif key=='bottom':
 *                     self.padding.bottom=int(value)             # <<<<<<<<<<<<<<
 * 
 *             elif section=='layer':
 */
        __pyx_t_1 = __Pyx_PyNumber_Int(__pyx_v_value); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 301, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __pyx_t_7 = __Pyx_PyInt_As_int(__pyx_t_1); if (unlikely((__pyx_t_7 == (int)-1) && PyErr_Occurred())) __PYX_ERR(1, 301, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __pyx_v_self->padding->bottom = __pyx_t_7;

        /* "ttygif/tty/theme.pyx":300
 *                 elif key=='top':
 *                     self.padding.top=int(value)
 *                 elif key=='bottom':             # <<<<<<<<<<<<<<
 *                     self.padding.bottom=int(value)
 * 
 */
      }
      __pyx_L19:;

      /* "ttygif/tty/theme.pyx":293
 *                     self.title_font_size=float(value)
 * 
 *             elif section=='padding':             # <<<<<<<<<<<<<<
 *                 if   key=='left':
 *                     self.padding.left=int(value)
 */
      goto __pyx_L17;
    }

    /* "ttygif/tty/theme.pyx":303
 *                     self.padding.bottom=int(value)
 * 
 *             elif section=='layer':             # <<<<<<<<<<<<<<
 *                 if   key=='depth':
 *                     theme_layer.z_index=int(value)
 */
    __pyx_t_11 = (__Pyx_PyString_Equals(__pyx_v_section, __pyx_n_s_layer, Py_EQ)); if (unlikely(__pyx_t_11 < 0)) __PYX_ERR(1, 303, __pyx_L1_error)
    if (__pyx_t_11) {

      /* "ttygif/tty/theme.pyx":304
 * 
 *             elif section=='layer':
 *                 if   key=='depth':             # <<<<<<<<<<<<<<
 *                     theme_layer.z_index=int(value)
 *                 elif key=='file':
 */
      __pyx_t_11 = (__Pyx_PyString_Equals(__pyx_v_key, __pyx_n_s_depth, Py_EQ)); if (unlikely(__pyx_t_11 < 0)) __PYX_ERR(1, 304, __pyx_L1_error)
      if (__pyx_t_11) {

        /* "ttygif/tty/theme.pyx":305
 *             elif section=='layer':
 *                 if   key=='depth':
 *                     theme_layer.z_index=int(value)             # <<<<<<<<<<<<<<
 *                 elif key=='file':
 *                     theme_layer.file=value
 */
        __pyx_t_1 = __Pyx_PyNumber_Int(__pyx_v_value); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 305, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __pyx_t_12 = __Pyx_PyInt_As_int16_t(__pyx_t_1); if (unlikely((__pyx_t_12 == ((int16_t)-1)) && PyErr_Occurred())) __PYX_ERR(1, 305, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __pyx_v_theme_layer->z_index = __pyx_t_12;

        /* "ttygif/tty/theme.pyx":304
 * 
 *             elif section=='layer':
 *                 if   key=='depth':             # <<<<<<<<<<<<<<
 *                     theme_layer.z_index=int(value)
 *                 elif key=='file':
 */
        goto __pyx_L20;
      }

      /* "ttygif/tty/theme.pyx":306
 *                 if   key=='depth':
 *                     theme_layer.z_index=int(value)
 *                 elif key=='file':             # <<<<<<<<<<<<<<
 *                     theme_layer.file=value
 *                 elif key=='mode':
 */
      __pyx_t_11 = (__Pyx_PyString_Equals(__pyx_v_key, __pyx_n_s_file_2, Py_EQ)); if (unlikely(__pyx_t_11 < 0)) __PYX_ERR(1, 306, __pyx_L1_error)
      if (__pyx_t_11) {

        /* "ttygif/tty/theme.pyx":307
 *                     theme_layer.z_index=int(value)
 *                 elif key=='file':
 *                     theme_layer.file=value             # <<<<<<<<<<<<<<
 *                 elif key=='mode':
 *                     theme_layer.mode=value
 */
        if (!(likely(PyString_CheckExact(__pyx_v_value))||((__pyx_v_value) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "str", Py_TYPE(__pyx_v_value)->tp_name), 0))) __PYX_ERR(1, 307, __pyx_L1_error)
        __pyx_t_1 = __pyx_v_value;
        __Pyx_INCREF(__pyx_t_1);
        __Pyx_GIVEREF(__pyx_t_1);
        __Pyx_GOTREF(__pyx_v_theme_layer->file);
        __Pyx_DECREF(__pyx_v_theme_layer->file);
        __pyx_v_theme_layer->file = ((PyObject*)__pyx_t_1);
        __pyx_t_1 = 0;

        /* "ttygif/tty/theme.pyx":306
 *                 if   key=='depth':
 *                     theme_layer.z_index=int(value)
 *                 elif key=='file':             # <<<<<<<<<<<<<<
 *                     theme_layer.file=value
 *                 elif key=='mode':
 */
        goto __pyx_L20;
      }

      /* "ttygif/tty/theme.pyx":308
 *                 elif key=='file':
 *                     theme_layer.file=value
 *                 elif key=='mode':             # <<<<<<<<<<<<<<
 *                     theme_layer.mode=value
 *                 elif key=='outer-left':
 */
      __pyx_t_11 = (__Pyx_PyString_Equals(__pyx_v_key, __pyx_n_s_mode, Py_EQ)); if (unlikely(__pyx_t_11 < 0)) __PYX_ERR(1, 308, __pyx_L1_error)
      if (__pyx_t_11) {

        /* "ttygif/tty/theme.pyx":309
 *                     theme_layer.file=value
 *                 elif key=='mode':
 *                     theme_layer.mode=value             # <<<<<<<<<<<<<<
 *                 elif key=='outer-left':
 *                     theme_layer.outer.left=int(value)
 */
        if (!(likely(PyString_CheckExact(__pyx_v_value))||((__pyx_v_value) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "str", Py_TYPE(__pyx_v_value)->tp_name), 0))) __PYX_ERR(1, 309, __pyx_L1_error)
        __pyx_t_1 = __pyx_v_value;
        __Pyx_INCREF(__pyx_t_1);
        __Pyx_GIVEREF(__pyx_t_1);
        __Pyx_GOTREF(__pyx_v_theme_layer->mode);
        __Pyx_DECREF(__pyx_v_theme_layer->mode);
        __pyx_v_theme_layer->mode = ((PyObject*)__pyx_t_1);
        __pyx_t_1 = 0;

        /* "ttygif/tty/theme.pyx":308
 *                 elif key=='file':
 *                     theme_layer.file=value
 *                 elif key=='mode':             # <<<<<<<<<<<<<<
 *                     theme_layer.mode=value
 *                 elif key=='outer-left':
 */
        goto __pyx_L20;
      }

      /* "ttygif/tty/theme.pyx":310
 *                 elif key=='mode':
 *                     theme_layer.mode=value
 *                 elif key=='outer-left':             # <<<<<<<<<<<<<<
 *                     theme_layer.outer.left=int(value)
 *                 elif key=='outer-top':
 */
      __pyx_t_11 = (__Pyx_PyString_Equals(__pyx_v_key, __pyx_kp_s_outer_left, Py_EQ)); if (unlikely(__pyx_t_11 < 0)) __PYX_ERR(1, 310, __pyx_L1_error)
      if (__pyx_t_11) {

        /* "ttygif/tty/theme.pyx":311
 *                     theme_layer.mode=value
 *                 elif key=='outer-left':
 *                     theme_layer.outer.left=int(value)             # <<<<<<<<<<<<<<
 *                 elif key=='outer-top':
 *                     theme_layer.outer.top=int(value)
 */
        __pyx_t_1 = __Pyx_PyNumber_Int(__pyx_v_value); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 311, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __pyx_t_7 = __Pyx_PyInt_As_int(__pyx_t_1); if (unlikely((__pyx_t_7 == (int)-1) && PyErr_Occurred())) __PYX_ERR(1, 311, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __pyx_v_theme_layer->outer->left = __pyx_t_7;

        /* "ttygif/tty/theme.pyx":310
 *                 elif key=='mode':
 *                     theme_layer.mode=value
 *                 elif key=='outer-left':             # <<<<<<<<<<<<<<
 *                     theme_layer.outer.left=int(value)
 *                 elif key=='outer-top':
 */
        goto __pyx_L20;
      }

      /* "ttygif/tty/theme.pyx":312
 *                 elif key=='outer-left':
 *                     theme_layer.outer.left=int(value)
 *                 elif key=='outer-top':             # <<<<<<<<<<<<<<
 *                     theme_layer.outer.top=int(value)
 *                 elif key=='outer-right':
 */
      __pyx_t_11 = (__Pyx_PyString_Equals(__pyx_v_key, __pyx_kp_s_outer_top, Py_EQ)); if (unlikely(__pyx_t_11 < 0)) __PYX_ERR(1, 312, __pyx_L1_error)
      if (__pyx_t_11) {

        /* "ttygif/tty/theme.pyx":313
 *                     theme_layer.outer.left=int(value)
 *                 elif key=='outer-top':
 *                     theme_layer.outer.top=int(value)             # <<<<<<<<<<<<<<
 *                 elif key=='outer-right':
 *                     theme_layer.outer.right=int(value)
 */
        __pyx_t_1 = __Pyx_PyNumber_Int(__pyx_v_value); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 313, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __pyx_t_7 = __Pyx_PyInt_As_int(__pyx_t_1); if (unlikely((__pyx_t_7 == (int)-1) && PyErr_Occurred())) __PYX_ERR(1, 313, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __pyx_v_theme_layer->outer->top = __pyx_t_7;

        /* "ttygif/tty/theme.pyx":312
 *                 elif key=='outer-left':
 *                     theme_layer.outer.left=int(value)
 *                 elif key=='outer-top':             # <<<<<<<<<<<<<<
 *                     theme_layer.outer.top=int(value)
 *                 elif key=='outer-right':
 */
        goto __pyx_L20;
      }

      /* "ttygif/tty/theme.pyx":314
 *                 elif key=='outer-top':
 *                     theme_layer.outer.top=int(value)
 *                 elif key=='outer-right':             # <<<<<<<<<<<<<<
 *                     theme_layer.outer.right=int(value)
 *                 elif key=='outer-bottom':
 */
      __pyx_t_11 = (__Pyx_PyString_Equals(__pyx_v_key, __pyx_kp_s_outer_right, Py_EQ)); if (unlikely(__pyx_t_11 < 0)) __PYX_ERR(1, 314, __pyx_L1_error)
      if (__pyx_t_11) {

        /* "ttygif/tty/theme.pyx":315
 *                     theme_layer.outer.top=int(value)
 *                 elif key=='outer-right':
 *                     theme_layer.outer.right=int(value)             # <<<<<<<<<<<<<<
 *                 elif key=='outer-bottom':
 *                     theme_layer.outer.bottom=int(value)
 */
        __pyx_t_1 = __Pyx_PyNumber_Int(__pyx_v_value); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 315, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __pyx_t_7 = __Pyx_PyInt_As_int(__pyx_t_1); if (unlikely((__pyx_t_7 == (int)-1) && PyErr_Occurred())) __PYX_ERR(1, 315, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __pyx_v_theme_layer->outer->right = __pyx_t_7;

        /* "ttygif/tty/theme.pyx":314
 *                 elif key=='outer-top':
 *                     theme_layer.outer.top=int(value)
 *                 elif key=='outer-right':             # <<<<<<<<<<<<<<
 *                     theme_layer.outer.right=int(value)
 *                 elif key=='outer-bottom':
 */
        goto __pyx_L20;
      }

      /* "ttygif/tty/theme.pyx":316
 *                 elif key=='outer-right':
 *                     theme_layer.outer.right=int(value)
 *                 elif key=='outer-bottom':             # <<<<<<<<<<<<<<
 *                     theme_layer.outer.bottom=int(value)
 *                 elif key=='inner-left':
 */
      __pyx_t_11 = (__Pyx_PyString_Equals(__pyx_v_key, __pyx_kp_s_outer_bottom, Py_EQ)); if (unlikely(__pyx_t_11 < 0)) __PYX_ERR(1, 316, __pyx_L1_error)
      if (__pyx_t_11) {

        /* "ttygif/tty/theme.pyx":317
 *                     theme_layer.outer.right=int(value)
 *                 elif key=='outer-bottom':
 *                     theme_layer.outer.bottom=int(value)             # <<<<<<<<<<<<<<
 *                 elif key=='inner-left':
 *                     theme_layer.inner.left=int(value)
 */
        __pyx_t_1 = __Pyx_PyNumber_Int(__pyx_v_value); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 317, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __pyx_t_7 = __Pyx_PyInt_As_int(__pyx_t_1); if (unlikely((__pyx_t_7 == (int)-1) && PyErr_Occurred())) __PYX_ERR(1, 317, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __pyx_v_theme_layer->outer->bottom = __pyx_t_7;

        /* "ttygif/tty/theme.pyx":316
 *                 elif key=='outer-right':
 *                     theme_layer.outer.right=int(value)
 *                 elif key=='outer-bottom':             # <<<<<<<<<<<<<<
 *                     theme_layer.outer.bottom=int(value)
 *                 elif key=='inner-left':
 */
        goto __pyx_L20;
      }

      /* "ttygif/tty/theme.pyx":318
 *                 elif key=='outer-bottom':
 *                     theme_layer.outer.bottom=int(value)
 *                 elif key=='inner-left':             # <<<<<<<<<<<<<<
 *                     theme_layer.inner.left=int(value)
 *                 elif key=='inner-top':
 */
      __pyx_t_11 = (__Pyx_PyString_Equals(__pyx_v_key, __pyx_kp_s_inner_left, Py_EQ)); if (unlikely(__pyx_t_11 < 0)) __PYX_ERR(1, 318, __pyx_L1_error)
      if (__pyx_t_11) {

        /* "ttygif/tty/theme.pyx":319
 *                     theme_layer.outer.bottom=int(value)
 *                 elif key=='inner-left':
 *                     theme_layer.inner.left=int(value)             # <<<<<<<<<<<<<<
 *                 elif key=='inner-top':
 *                     theme_layer.inner.top=int(value)
 */
        __pyx_t_1 = __Pyx_PyNumber_Int(__pyx_v_value); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 319, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __pyx_t_7 = __Pyx_PyInt_As_int(__pyx_t_1); if (unlikely((__pyx_t_7 == (int)-1) && PyErr_Occurred())) __PYX_ERR(1, 319, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __pyx_v_theme_layer->inner->left = __pyx_t_7;

        /* "ttygif/tty/theme.pyx":318
 *                 elif key=='outer-bottom':
 *                     theme_layer.outer.bottom=int(value)
 *                 elif key=='inner-left':             # <<<<<<<<<<<<<<
 *                     theme_layer.inner.left=int(value)
 *                 elif key=='inner-top':
 */
        goto __pyx_L20;
      }

      /* "ttygif/tty/theme.pyx":320
 *                 elif key=='inner-left':
 *                     theme_layer.inner.left=int(value)
 *                 elif key=='inner-top':             # <<<<<<<<<<<<<<
 *                     theme_layer.inner.top=int(value)
 *                 elif key=='inner-right':
 */
      __pyx_t_11 = (__Pyx_PyString_Equals(__pyx_v_key, __pyx_kp_s_inner_top, Py_EQ)); if (unlikely(__pyx_t_11 < 0)) __PYX_ERR(1, 320, __pyx_L1_error)
      if (__pyx_t_11) {

        /* "ttygif/tty/theme.pyx":321
 *                     theme_layer.inner.left=int(value)
 *                 elif key=='inner-top':
 *                     theme_layer.inner.top=int(value)             # <<<<<<<<<<<<<<
 *                 elif key=='inner-right':
 *                     theme_layer.inner.right=int(value)
 */
        __pyx_t_1 = __Pyx_PyNumber_Int(__pyx_v_value); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 321, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __pyx_t_7 = __Pyx_PyInt_As_int(__pyx_t_1); if (unlikely((__pyx_t_7 == (int)-1) && PyErr_Occurred())) __PYX_ERR(1, 321, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __pyx_v_theme_layer->inner->top = __pyx_t_7;

        /* "ttygif/tty/theme.pyx":320
 *                 elif key=='inner-left':
 *                     theme_layer.inner.left=int(value)
 *                 elif key=='inner-top':             # <<<<<<<<<<<<<<
 *                     theme_layer.inner.top=int(value)
 *                 elif key=='inner-right':
 */
        goto __pyx_L20;
      }

      /* "ttygif/tty/theme.pyx":322
 *                 elif key=='inner-top':
 *                     theme_layer.inner.top=int(value)
 *                 elif key=='inner-right':             # <<<<<<<<<<<<<<
 *                     theme_layer.inner.right=int(value)
 *                 elif key=='inner-bottom':
 */
      __pyx_t_11 = (__Pyx_PyString_Equals(__pyx_v_key, __pyx_kp_s_inner_right, Py_EQ)); if (unlikely(__pyx_t_11 < 0)) __PYX_ERR(1, 322, __pyx_L1_error)
      if (__pyx_t_11) {

        /* "ttygif/tty/theme.pyx":323
 *                     theme_layer.inner.top=int(value)
 *                 elif key=='inner-right':
 *                     theme_layer.inner.right=int(value)             # <<<<<<<<<<<<<<
 *                 elif key=='inner-bottom':
 *                     theme_layer.inner.bottom=int(value)
 */
        __pyx_t_1 = __Pyx_PyNumber_Int(__pyx_v_value); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 323, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __pyx_t_7 = __Pyx_PyInt_As_int(__pyx_t_1); if (unlikely((__pyx_t_7 == (int)-1) && PyErr_Occurred())) __PYX_ERR(1, 323, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __pyx_v_theme_layer->inner->right = __pyx_t_7;

        /* "ttygif/tty/theme.pyx":322
 *                 elif key=='inner-top':
 *                     theme_layer.inner.top=int(value)
 *                 elif key=='inner-right':             # <<<<<<<<<<<<<<
 *                     theme_layer.inner.right=int(value)
 *                 elif key=='inner-bottom':
 */
        goto __pyx_L20;
      }

      /* "ttygif/tty/theme.pyx":324
 *                 elif key=='inner-right':
 *                     theme_layer.inner.right=int(value)
 *                 elif key=='inner-bottom':             # <<<<<<<<<<<<<<
 *                     theme_layer.inner.bottom=int(value)
 *                 elif key=='left':
 */
      __pyx_t_11 = (__Pyx_PyString_Equals(__pyx_v_key, __pyx_kp_s_inner_bottom, Py_EQ)); if (unlikely(__pyx_t_11 < 0)) __PYX_ERR(1, 324, __pyx_L1_error)
      if (__pyx_t_11) {

        /* "ttygif/tty/theme.pyx":325
 *                     theme_layer.inner.right=int(value)
 *                 elif key=='inner-bottom':
 *                     theme_layer.inner.bottom=int(value)             # <<<<<<<<<<<<<<
 *                 elif key=='left':
 *                     theme_layer.bounds.left=int(value)
 */
        __pyx_t_1 = __Pyx_PyNumber_Int(__pyx_v_value); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 325, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __pyx_t_7 = __Pyx_PyInt_As_int(__pyx_t_1); if (unlikely((__pyx_t_7 == (int)-1) && PyErr_Occurred())) __PYX_ERR(1, 325, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __pyx_v_theme_layer->inner->bottom = __pyx_t_7;

        /* "ttygif/tty/theme.pyx":324
 *                 elif key=='inner-right':
 *                     theme_layer.inner.right=int(value)
 *                 elif key=='inner-bottom':             # <<<<<<<<<<<<<<
 *                     theme_layer.inner.bottom=int(value)
 *                 elif key=='left':
 */
        goto __pyx_L20;
      }

      /* "ttygif/tty/theme.pyx":326
 *                 elif key=='inner-bottom':
 *                     theme_layer.inner.bottom=int(value)
 *                 elif key=='left':             # <<<<<<<<<<<<<<
 *                     theme_layer.bounds.left=int(value)
 *                 elif key=='top':
 */
      __pyx_t_11 = (__Pyx_PyString_Equals(__pyx_v_key, __pyx_n_s_left, Py_EQ)); if (unlikely(__pyx_t_11 < 0)) __PYX_ERR(1, 326, __pyx_L1_error)
      if (__pyx_t_11) {

        /* "ttygif/tty/theme.pyx":327
 *                     theme_layer.inner.bottom=int(value)
 *                 elif key=='left':
 *                     theme_layer.bounds.left=int(value)             # <<<<<<<<<<<<<<
 *                 elif key=='top':
 *                     theme_layer.bounds.top=int(value)
 */
        __pyx_t_1 = __Pyx_PyNumber_Int(__pyx_v_value); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 327, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __pyx_t_7 = __Pyx_PyInt_As_int(__pyx_t_1); if (unlikely((__pyx_t_7 == (int)-1) && PyErr_Occurred())) __PYX_ERR(1, 327, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __pyx_v_theme_layer->bounds->left = __pyx_t_7;

        /* "ttygif/tty/theme.pyx":326
 *                 elif key=='inner-bottom':
 *                     theme_layer.inner.bottom=int(value)
 *                 elif key=='left':             # <<<<<<<<<<<<<<
 *                     theme_layer.bounds.left=int(value)
 *                 elif key=='top':
 */
        goto __pyx_L20;
      }

      /* "ttygif/tty/theme.pyx":328
 *                 elif key=='left':
 *                     theme_layer.bounds.left=int(value)
 *                 elif key=='top':             # <<<<<<<<<<<<<<
 *                     theme_layer.bounds.top=int(value)
 *                 elif key=='right':
 */
      __pyx_t_11 = (__Pyx_PyString_Equals(__pyx_v_key, __pyx_n_s_top, Py_EQ)); if (unlikely(__pyx_t_11 < 0)) __PYX_ERR(1, 328, __pyx_L1_error)
      if (__pyx_t_11) {

        /* "ttygif/tty/theme.pyx":329
 *                     theme_layer.bounds.left=int(value)
 *                 elif key=='top':
 *                     theme_layer.bounds.top=int(value)             # <<<<<<<<<<<<<<
 *                 elif key=='right':
 *                     theme_layer.bounds.right=int(value)
 */
        __pyx_t_1 = __Pyx_PyNumber_Int(__pyx_v_value); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 329, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __pyx_t_7 = __Pyx_PyInt_As_int(__pyx_t_1); if (unlikely((__pyx_t_7 == (int)-1) && PyErr_Occurred())) __PYX_ERR(1, 329, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __pyx_v_theme_layer->bounds->top = __pyx_t_7;

        /* "ttygif/tty/theme.pyx":328
 *                 elif key=='left':
 *                     theme_layer.bounds.left=int(value)
 *                 elif key=='top':             # <<<<<<<<<<<<<<
 *                     theme_layer.bounds.top=int(value)
 *                 elif key=='right':
 */
        goto __pyx_L20;
      }

      /* "ttygif/tty/theme.pyx":330
 *                 elif key=='top':
 *                     theme_layer.bounds.top=int(value)
 *                 elif key=='right':             # <<<<<<<<<<<<<<
 *                     theme_layer.bounds.right=int(value)
 *                 elif key=='bottom':
 */
      __pyx_t_11 = (__Pyx_PyString_Equals(__pyx_v_key, __pyx_n_s_right, Py_EQ)); if (unlikely(__pyx_t_11 < 0)) __PYX_ERR(1, 330, __pyx_L1_error)
      if (__pyx_t_11) {

        /* "ttygif/tty/theme.pyx":331
 *                     theme_layer.bounds.top=int(value)
 *                 elif key=='right':
 *                     theme_layer.bounds.right=int(value)             # <<<<<<<<<<<<<<
 *                 elif key=='bottom':
 *                     theme_layer.bounds.bottom=int(value)
 */
        __pyx_t_1 = __Pyx_PyNumber_Int(__pyx_v_value); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 331, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __pyx_t_7 = __Pyx_PyInt_As_int(__pyx_t_1); if (unlikely((__pyx_t_7 == (int)-1) && PyErr_Occurred())) __PYX_ERR(1, 331, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __pyx_v_theme_layer->bounds->right = __pyx_t_7;

        /* "ttygif/tty/theme.pyx":330
 *                 elif key=='top':
 *                     theme_layer.bounds.top=int(value)
 *                 elif key=='right':             # <<<<<<<<<<<<<<
 *                     theme_layer.bounds.right=int(value)
 *                 elif key=='bottom':
 */
        goto __pyx_L20;
      }

      /* "ttygif/tty/theme.pyx":332
 *                 elif key=='right':
 *                     theme_layer.bounds.right=int(value)
 *                 elif key=='bottom':             # <<<<<<<<<<<<<<
 *                     theme_layer.bounds.bottom=int(value)
 *                 elif key=='dst-left':
 */
      __pyx_t_11 = (__Pyx_PyString_Equals(__pyx_v_key, __pyx_n_s_bottom, Py_EQ)); if (unlikely(__pyx_t_11 < 0)) __PYX_ERR(1, 332, __pyx_L1_error)
      if (__pyx_t_11) {

        /* "ttygif/tty/theme.pyx":333
 *                     theme_layer.bounds.right=int(value)
 *                 elif key=='bottom':
 *                     theme_layer.bounds.bottom=int(value)             # <<<<<<<<<<<<<<
 *                 elif key=='dst-left':
 *                     theme_layer.dst.left=int(value)
 */
        __pyx_t_1 = __Pyx_PyNumber_Int(__pyx_v_value); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 333, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __pyx_t_7 = __Pyx_PyInt_As_int(__pyx_t_1); if (unlikely((__pyx_t_7 == (int)-1) && PyErr_Occurred())) __PYX_ERR(1, 333, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __pyx_v_theme_layer->bounds->bottom = __pyx_t_7;

        /* "ttygif/tty/theme.pyx":332
 *                 elif key=='right':
 *                     theme_layer.bounds.right=int(value)
 *                 elif key=='bottom':             # <<<<<<<<<<<<<<
 *                     theme_layer.bounds.bottom=int(value)
 *                 elif key=='dst-left':
 */
        goto __pyx_L20;
      }

      /* "ttygif/tty/theme.pyx":334
 *                 elif key=='bottom':
 *                     theme_layer.bounds.bottom=int(value)
 *                 elif key=='dst-left':             # <<<<<<<<<<<<<<
 *                     theme_layer.dst.left=int(value)
 *                 elif key=='dst-top':
 */
      __pyx_t_11 = (__Pyx_PyString_Equals(__pyx_v_key, __pyx_kp_s_dst_left, Py_EQ)); if (unlikely(__pyx_t_11 < 0)) __PYX_ERR(1, 334, __pyx_L1_error)
      if (__pyx_t_11) {

        /* "ttygif/tty/theme.pyx":335
 *                     theme_layer.bounds.bottom=int(value)
 *                 elif key=='dst-left':
 *                     theme_layer.dst.left=int(value)             # <<<<<<<<<<<<<<
 *                 elif key=='dst-top':
 *                     theme_layer.dst.top=int(value)
 */
        __pyx_t_1 = __Pyx_PyNumber_Int(__pyx_v_value); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 335, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __pyx_t_7 = __Pyx_PyInt_As_int(__pyx_t_1); if (unlikely((__pyx_t_7 == (int)-1) && PyErr_Occurred())) __PYX_ERR(1, 335, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __pyx_v_theme_layer->dst->left = __pyx_t_7;

        /* "ttygif/tty/theme.pyx":334
 *                 elif key=='bottom':
 *                     theme_layer.bounds.bottom=int(value)
 *                 elif key=='dst-left':             # <<<<<<<<<<<<<<
 *                     theme_layer.dst.left=int(value)
 *                 elif key=='dst-top':
 */
        goto __pyx_L20;
      }

      /* "ttygif/tty/theme.pyx":336
 *                 elif key=='dst-left':
 *                     theme_layer.dst.left=int(value)
 *                 elif key=='dst-top':             # <<<<<<<<<<<<<<
 *                     theme_layer.dst.top=int(value)
 *                 elif key=='dst-right':
 */
      __pyx_t_11 = (__Pyx_PyString_Equals(__pyx_v_key, __pyx_kp_s_dst_top, Py_EQ)); if (unlikely(__pyx_t_11 < 0)) __PYX_ERR(1, 336, __pyx_L1_error)
      if (__pyx_t_11) {

        /* "ttygif/tty/theme.pyx":337
 *                     theme_layer.dst.left=int(value)
 *                 elif key=='dst-top':
 *                     theme_layer.dst.top=int(value)             # <<<<<<<<<<<<<<
 *                 elif key=='dst-right':
 *                     theme_layer.dst.right=int(value)
 */
        __pyx_t_1 = __Pyx_PyNumber_Int(__pyx_v_value); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 337, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __pyx_t_7 = __Pyx_PyInt_As_int(__pyx_t_1); if (unlikely((__pyx_t_7 == (int)-1) && PyErr_Occurred())) __PYX_ERR(1, 337, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __pyx_v_theme_layer->dst->top = __pyx_t_7;

        /* "ttygif/tty/theme.pyx":336
 *                 elif key=='dst-left':
 *                     theme_layer.dst.left=int(value)
 *                 elif key=='dst-top':             # <<<<<<<<<<<<<<
 *                     theme_layer.dst.top=int(value)
 *                 elif key=='dst-right':
 */
        goto __pyx_L20;
      }

      /* "ttygif/tty/theme.pyx":338
 *                 elif key=='dst-top':
 *                     theme_layer.dst.top=int(value)
 *                 elif key=='dst-right':             # <<<<<<<<<<<<<<
 *                     theme_layer.dst.right=int(value)
 *                 elif key=='dst-bottom':
 */
      __pyx_t_11 = (__Pyx_PyString_Equals(__pyx_v_key, __pyx_kp_s_dst_right, Py_EQ)); if (unlikely(__pyx_t_11 < 0)) __PYX_ERR(1, 338, __pyx_L1_error)
      if (__pyx_t_11) {

        /* "ttygif/tty/theme.pyx":339
 *                     theme_layer.dst.top=int(value)
 *                 elif key=='dst-right':
 *                     theme_layer.dst.right=int(value)             # <<<<<<<<<<<<<<
 *                 elif key=='dst-bottom':
 *                     theme_layer.dst.bottom=int(value)
 */
        __pyx_t_1 = __Pyx_PyNumber_Int(__pyx_v_value); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 339, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __pyx_t_7 = __Pyx_PyInt_As_int(__pyx_t_1); if (unlikely((__pyx_t_7 == (int)-1) && PyErr_Occurred())) __PYX_ERR(1, 339, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __pyx_v_theme_layer->dst->right = __pyx_t_7;

        /* "ttygif/tty/theme.pyx":338
 *                 elif key=='dst-top':
 *                     theme_layer.dst.top=int(value)
 *                 elif key=='dst-right':             # <<<<<<<<<<<<<<
 *                     theme_layer.dst.right=int(value)
 *                 elif key=='dst-bottom':
 */
        goto __pyx_L20;
      }

      /* "ttygif/tty/theme.pyx":340
 *                 elif key=='dst-right':
 *                     theme_layer.dst.right=int(value)
 *                 elif key=='dst-bottom':             # <<<<<<<<<<<<<<
 *                     theme_layer.dst.bottom=int(value)
 *                 elif key=='center':
 */
      __pyx_t_11 = (__Pyx_PyString_Equals(__pyx_v_key, __pyx_kp_s_dst_bottom, Py_EQ)); if (unlikely(__pyx_t_11 < 0)) __PYX_ERR(1, 340, __pyx_L1_error)
      if (__pyx_t_11) {

        /* "ttygif/tty/theme.pyx":341
 *                     theme_layer.dst.right=int(value)
 *                 elif key=='dst-bottom':
 *                     theme_layer.dst.bottom=int(value)             # <<<<<<<<<<<<<<
 *                 elif key=='center':
 *                     theme_layer.center=value
 */
        __pyx_t_1 = __Pyx_PyNumber_Int(__pyx_v_value); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 341, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __pyx_t_7 = __Pyx_PyInt_As_int(__pyx_t_1); if (unlikely((__pyx_t_7 == (int)-1) && PyErr_Occurred())) __PYX_ERR(1, 341, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __pyx_v_theme_layer->dst->bottom = __pyx_t_7;

        /* "ttygif/tty/theme.pyx":340
 *                 elif key=='dst-right':
 *                     theme_layer.dst.right=int(value)
 *                 elif key=='dst-bottom':             # <<<<<<<<<<<<<<
 *                     theme_layer.dst.bottom=int(value)
 *                 elif key=='center':
 */
        goto __pyx_L20;
      }

      /* "ttygif/tty/theme.pyx":342
 *                 elif key=='dst-bottom':
 *                     theme_layer.dst.bottom=int(value)
 *                 elif key=='center':             # <<<<<<<<<<<<<<
 *                     theme_layer.center=value
 *                 elif key=='copy-mode':
 */
      __pyx_t_11 = (__Pyx_PyString_Equals(__pyx_v_key, __pyx_n_s_center, Py_EQ)); if (unlikely(__pyx_t_11 < 0)) __PYX_ERR(1, 342, __pyx_L1_error)
      if (__pyx_t_11) {

        /* "ttygif/tty/theme.pyx":343
 *                     theme_layer.dst.bottom=int(value)
 *                 elif key=='center':
 *                     theme_layer.center=value             # <<<<<<<<<<<<<<
 *                 elif key=='copy-mode':
 *                     theme_layer.copy_mode=value
 */
        if (!(likely(PyString_CheckExact(__pyx_v_value))||((__pyx_v_value) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "str", Py_TYPE(__pyx_v_value)->tp_name), 0))) __PYX_ERR(1, 343, __pyx_L1_error)
        __pyx_t_1 = __pyx_v_value;
        __Pyx_INCREF(__pyx_t_1);
        __Pyx_GIVEREF(__pyx_t_1);
        __Pyx_GOTREF(__pyx_v_theme_layer->center);
        __Pyx_DECREF(__pyx_v_theme_layer->center);
        __pyx_v_theme_layer->center = ((PyObject*)__pyx_t_1);
        __pyx_t_1 = 0;

        /* "ttygif/tty/theme.pyx":342
 *                 elif key=='dst-bottom':
 *                     theme_layer.dst.bottom=int(value)
 *                 elif key=='center':             # <<<<<<<<<<<<<<
 *                     theme_layer.center=value
 *                 elif key=='copy-mode':
 */
        goto __pyx_L20;
      }

      /* "ttygif/tty/theme.pyx":344
 *                 elif key=='center':
 *                     theme_layer.center=value
 *                 elif key=='copy-mode':             # <<<<<<<<<<<<<<
 *                     theme_layer.copy_mode=value
 *                 elif key=='transparent':
 */
      __pyx_t_11 = (__Pyx_PyString_Equals(__pyx_v_key, __pyx_kp_s_copy_mode, Py_EQ)); if (unlikely(__pyx_t_11 < 0)) __PYX_ERR(1, 344, __pyx_L1_error)
      if (__pyx_t_11) {

        /* "ttygif/tty/theme.pyx":345
 *                     theme_layer.center=value
 *                 elif key=='copy-mode':
 *                     theme_layer.copy_mode=value             # <<<<<<<<<<<<<<
 *                 elif key=='transparent':
 *                     theme_layer.transparent=int(value)
 */
        if (!(likely(PyString_CheckExact(__pyx_v_value))||((__pyx_v_value) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "str", Py_TYPE(__pyx_v_value)->tp_name), 0))) __PYX_ERR(1, 345, __pyx_L1_error)
        __pyx_t_1 = __pyx_v_value;
        __Pyx_INCREF(__pyx_t_1);
        __Pyx_GIVEREF(__pyx_t_1);
        __Pyx_GOTREF(__pyx_v_theme_layer->copy_mode);
        __Pyx_DECREF(__pyx_v_theme_layer->copy_mode);
        __pyx_v_theme_layer->copy_mode = ((PyObject*)__pyx_t_1);
        __pyx_t_1 = 0;

        /* "ttygif/tty/theme.pyx":344
 *                 elif key=='center':
 *                     theme_layer.center=value
 *                 elif key=='copy-mode':             # <<<<<<<<<<<<<<
 *                     theme_layer.copy_mode=value
 *                 elif key=='transparent':
 */
        goto __pyx_L20;
      }

      /* "ttygif/tty/theme.pyx":346
 *                 elif key=='copy-mode':
 *                     theme_layer.copy_mode=value
 *                 elif key=='transparent':             # <<<<<<<<<<<<<<
 *                     theme_layer.transparent=int(value)
 * 
 */
      __pyx_t_11 = (__Pyx_PyString_Equals(__pyx_v_key, __pyx_n_s_transparent, Py_EQ)); if (unlikely(__pyx_t_11 < 0)) __PYX_ERR(1, 346, __pyx_L1_error)
      if (__pyx_t_11) {

        /* "ttygif/tty/theme.pyx":347
 *                     theme_layer.copy_mode=value
 *                 elif key=='transparent':
 *                     theme_layer.transparent=int(value)             # <<<<<<<<<<<<<<
 * 
 * 
 */
        __pyx_t_1 = __Pyx_PyNumber_Int(__pyx_v_value); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 347, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __pyx_t_12 = __Pyx_PyInt_As_int16_t(__pyx_t_1); if (unlikely((__pyx_t_12 == ((int16_t)-1)) && PyErr_Occurred())) __PYX_ERR(1, 347, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __pyx_v_theme_layer->transparent = __pyx_t_12;

        /* "ttygif/tty/theme.pyx":346
 *                 elif key=='copy-mode':
 *                     theme_layer.copy_mode=value
 *                 elif key=='transparent':             # <<<<<<<<<<<<<<
 *                     theme_layer.transparent=int(value)
 * 
 */
      }
      __pyx_L20:;

      /* "ttygif/tty/theme.pyx":303
 *                     self.padding.bottom=int(value)
 * 
 *             elif section=='layer':             # <<<<<<<<<<<<<<
 *                 if   key=='depth':
 *                     theme_layer.z_index=int(value)
 */
      goto __pyx_L17;
    }

    /* "ttygif/tty/theme.pyx":350
 * 
 * 
 *             elif section=='palette':             # <<<<<<<<<<<<<<
 *                 if   key=='palette':
 *                     continue
 */
    __pyx_t_11 = (__Pyx_PyString_Equals(__pyx_v_section, __pyx_n_s_palette, Py_EQ)); if (unlikely(__pyx_t_11 < 0)) __PYX_ERR(1, 350, __pyx_L1_error)
    if (__pyx_t_11) {

      /* "ttygif/tty/theme.pyx":351
 * 
 *             elif section=='palette':
 *                 if   key=='palette':             # <<<<<<<<<<<<<<
 *                     continue
 *                 elif key=='colors':
 */
      __pyx_t_11 = (__Pyx_PyString_Equals(__pyx_v_key, __pyx_n_s_palette, Py_EQ)); if (unlikely(__pyx_t_11 < 0)) __PYX_ERR(1, 351, __pyx_L1_error)
      if (__pyx_t_11) {

        /* "ttygif/tty/theme.pyx":352
 *             elif section=='palette':
 *                 if   key=='palette':
 *                     continue             # <<<<<<<<<<<<<<
 *                 elif key=='colors':
 *                     self.colors=int(value)
 */
        goto __pyx_L6_continue;

        /* "ttygif/tty/theme.pyx":351
 * 
 *             elif section=='palette':
 *                 if   key=='palette':             # <<<<<<<<<<<<<<
 *                     continue
 *                 elif key=='colors':
 */
      }

      /* "ttygif/tty/theme.pyx":353
 *                 if   key=='palette':
 *                     continue
 *                 elif key=='colors':             # <<<<<<<<<<<<<<
 *                     self.colors=int(value)
 *                     array.resize(self.palette,self.colors*3)
 */
      __pyx_t_11 = (__Pyx_PyString_Equals(__pyx_v_key, __pyx_n_s_colors, Py_EQ)); if (unlikely(__pyx_t_11 < 0)) __PYX_ERR(1, 353, __pyx_L1_error)
      if (__pyx_t_11) {

        /* "ttygif/tty/theme.pyx":354
 *                     continue
 *                 elif key=='colors':
 *                     self.colors=int(value)             # <<<<<<<<<<<<<<
 *                     array.resize(self.palette,self.colors*3)
 *                 if key=='array':
 */
        __pyx_t_1 = __Pyx_PyNumber_Int(__pyx_v_value); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 354, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __pyx_t_12 = __Pyx_PyInt_As_int16_t(__pyx_t_1); if (unlikely((__pyx_t_12 == ((int16_t)-1)) && PyErr_Occurred())) __PYX_ERR(1, 354, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __pyx_v_self->colors = __pyx_t_12;

        /* "ttygif/tty/theme.pyx":355
 *                 elif key=='colors':
 *                     self.colors=int(value)
 *                     array.resize(self.palette,self.colors*3)             # <<<<<<<<<<<<<<
 *                 if key=='array':
 *                     #tokens=line.split(' ')
 */
        __pyx_t_1 = ((PyObject *)__pyx_v_self->palette);
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_7 = resize(((arrayobject *)__pyx_t_1), (__pyx_v_self->colors * 3)); if (unlikely(__pyx_t_7 == ((int)-1))) __PYX_ERR(1, 355, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

        /* "ttygif/tty/theme.pyx":353
 *                 if   key=='palette':
 *                     continue
 *                 elif key=='colors':             # <<<<<<<<<<<<<<
 *                     self.colors=int(value)
 *                     array.resize(self.palette,self.colors*3)
 */
      }

      /* "ttygif/tty/theme.pyx":356
 *                     self.colors=int(value)
 *                     array.resize(self.palette,self.colors*3)
 *                 if key=='array':             # <<<<<<<<<<<<<<
 *                     #tokens=line.split(' ')
 *                     #print line,tokens
 */
      __pyx_t_11 = (__Pyx_PyString_Equals(__pyx_v_key, __pyx_n_s_array, Py_EQ)); if (unlikely(__pyx_t_11 < 0)) __PYX_ERR(1, 356, __pyx_L1_error)
      if (__pyx_t_11) {

        /* "ttygif/tty/theme.pyx":359
 *                     #tokens=line.split(' ')
 *                     #print line,tokens
 *                     a=int(value[0])             # <<<<<<<<<<<<<<
 *                     b=int(value[1])
 *                     c=int(value[2])
 */
        __pyx_t_1 = __Pyx_GetItemInt(__pyx_v_value, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 359, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __pyx_t_3 = __Pyx_PyNumber_Int(__pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 359, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __pyx_t_7 = __Pyx_PyInt_As_int(__pyx_t_3); if (unlikely((__pyx_t_7 == (int)-1) && PyErr_Occurred())) __PYX_ERR(1, 359, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_v_a = __pyx_t_7;

        /* "ttygif/tty/theme.pyx":360
 *                     #print line,tokens
 *                     a=int(value[0])
 *                     b=int(value[1])             # <<<<<<<<<<<<<<
 *                     c=int(value[2])
 *                     self.palette[index+0]=a
 */
        __pyx_t_3 = __Pyx_GetItemInt(__pyx_v_value, 1, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 360, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_t_1 = __Pyx_PyNumber_Int(__pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 360, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_t_7 = __Pyx_PyInt_As_int(__pyx_t_1); if (unlikely((__pyx_t_7 == (int)-1) && PyErr_Occurred())) __PYX_ERR(1, 360, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __pyx_v_b = __pyx_t_7;

        /* "ttygif/tty/theme.pyx":361
 *                     a=int(value[0])
 *                     b=int(value[1])
 *                     c=int(value[2])             # <<<<<<<<<<<<<<
 *                     self.palette[index+0]=a
 *                     self.palette[index+1]=b
 */
        __pyx_t_1 = __Pyx_GetItemInt(__pyx_v_value, 2, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 361, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __pyx_t_3 = __Pyx_PyNumber_Int(__pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 361, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __pyx_t_7 = __Pyx_PyInt_As_int(__pyx_t_3); if (unlikely((__pyx_t_7 == (int)-1) && PyErr_Occurred())) __PYX_ERR(1, 361, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_v_c = __pyx_t_7;

        /* "ttygif/tty/theme.pyx":362
 *                     b=int(value[1])
 *                     c=int(value[2])
 *                     self.palette[index+0]=a             # <<<<<<<<<<<<<<
 *                     self.palette[index+1]=b
 *                     self.palette[index+2]=c
 */
        __pyx_t_3 = __Pyx_PyInt_From_int(__pyx_v_a); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 362, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_t_14 = (__pyx_v_index + 0);
        if (unlikely(__Pyx_SetItemInt(((PyObject *)__pyx_v_self->palette), __pyx_t_14, __pyx_t_3, long, 1, __Pyx_PyInt_From_long, 0, 1, 1) < 0)) __PYX_ERR(1, 362, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

        /* "ttygif/tty/theme.pyx":363
 *                     c=int(value[2])
 *                     self.palette[index+0]=a
 *                     self.palette[index+1]=b             # <<<<<<<<<<<<<<
 *                     self.palette[index+2]=c
 *                     index+=3
 */
        __pyx_t_3 = __Pyx_PyInt_From_int(__pyx_v_b); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 363, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_t_14 = (__pyx_v_index + 1);
        if (unlikely(__Pyx_SetItemInt(((PyObject *)__pyx_v_self->palette), __pyx_t_14, __pyx_t_3, long, 1, __Pyx_PyInt_From_long, 0, 1, 1) < 0)) __PYX_ERR(1, 363, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

        /* "ttygif/tty/theme.pyx":364
 *                     self.palette[index+0]=a
 *                     self.palette[index+1]=b
 *                     self.palette[index+2]=c             # <<<<<<<<<<<<<<
 *                     index+=3
 * 
 */
        __pyx_t_3 = __Pyx_PyInt_From_int(__pyx_v_c); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 364, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_t_14 = (__pyx_v_index + 2);
        if (unlikely(__Pyx_SetItemInt(((PyObject *)__pyx_v_self->palette), __pyx_t_14, __pyx_t_3, long, 1, __Pyx_PyInt_From_long, 0, 1, 1) < 0)) __PYX_ERR(1, 364, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

        /* "ttygif/tty/theme.pyx":365
 *                     self.palette[index+1]=b
 *                     self.palette[index+2]=c
 *                     index+=3             # <<<<<<<<<<<<<<
 * 
 * 
 */
        __pyx_v_index = (__pyx_v_index + 3);

        /* "ttygif/tty/theme.pyx":356
 *                     self.colors=int(value)
 *                     array.resize(self.palette,self.colors*3)
 *                 if key=='array':             # <<<<<<<<<<<<<<
 *                     #tokens=line.split(' ')
 *                     #print line,tokens
 */
      }

      /* "ttygif/tty/theme.pyx":350
 * 
 * 
 *             elif section=='palette':             # <<<<<<<<<<<<<<
 *                 if   key=='palette':
 *                     continue
 */
    }
    __pyx_L17:;

    /* "ttygif/tty/theme.pyx":226
 * 
 * 
 *         for line in theme_data:             # <<<<<<<<<<<<<<
 *             res=self.get_anyvar(line)
 *             if res ==None:
 */
    __pyx_L6_continue:;
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "ttygif/tty/theme.pyx":369
 * 
 * 
 *         if len(self.palette)==0:             # <<<<<<<<<<<<<<
 *             array.resize(self.palette,256*3)
 * 
 */
  __pyx_t_2 = ((PyObject *)__pyx_v_self->palette);
  __Pyx_INCREF(__pyx_t_2);
  if (unlikely(__pyx_t_2 == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
    __PYX_ERR(1, 369, __pyx_L1_error)
  }
  __pyx_t_9 = Py_SIZE(__pyx_t_2); if (unlikely(__pyx_t_9 == ((Py_ssize_t)-1))) __PYX_ERR(1, 369, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_11 = ((__pyx_t_9 == 0) != 0);
  if (__pyx_t_11) {

    /* "ttygif/tty/theme.pyx":370
 * 
 *         if len(self.palette)==0:
 *             array.resize(self.palette,256*3)             # <<<<<<<<<<<<<<
 * 
 *             color_table=[  # 16 System Colors
 */
    __pyx_t_2 = ((PyObject *)__pyx_v_self->palette);
    __Pyx_INCREF(__pyx_t_2);
    __pyx_t_7 = resize(((arrayobject *)__pyx_t_2), 0x300); if (unlikely(__pyx_t_7 == ((int)-1))) __PYX_ERR(1, 370, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "ttygif/tty/theme.pyx":372
 *             array.resize(self.palette,256*3)
 * 
 *             color_table=[  # 16 System Colors             # <<<<<<<<<<<<<<
 *                 0,0,0 , 128,0,0 , 0,128,0 , 128,128,0,
 *                 0,0,128 , 128,0,128 , 0,128,128 , 192,192,192,
 */
    __pyx_t_2 = PyList_New(768); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 372, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_2, 0, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_2, 1, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_2, 2, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_128);
    __Pyx_GIVEREF(__pyx_int_128);
    PyList_SET_ITEM(__pyx_t_2, 3, __pyx_int_128);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_2, 4, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_2, 5, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_2, 6, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_128);
    __Pyx_GIVEREF(__pyx_int_128);
    PyList_SET_ITEM(__pyx_t_2, 7, __pyx_int_128);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_2, 8, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_128);
    __Pyx_GIVEREF(__pyx_int_128);
    PyList_SET_ITEM(__pyx_t_2, 9, __pyx_int_128);
    __Pyx_INCREF(__pyx_int_128);
    __Pyx_GIVEREF(__pyx_int_128);
    PyList_SET_ITEM(__pyx_t_2, 10, __pyx_int_128);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_2, 11, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_2, 12, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_2, 13, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_128);
    __Pyx_GIVEREF(__pyx_int_128);
    PyList_SET_ITEM(__pyx_t_2, 14, __pyx_int_128);
    __Pyx_INCREF(__pyx_int_128);
    __Pyx_GIVEREF(__pyx_int_128);
    PyList_SET_ITEM(__pyx_t_2, 15, __pyx_int_128);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_2, 16, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_128);
    __Pyx_GIVEREF(__pyx_int_128);
    PyList_SET_ITEM(__pyx_t_2, 17, __pyx_int_128);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_2, 18, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_128);
    __Pyx_GIVEREF(__pyx_int_128);
    PyList_SET_ITEM(__pyx_t_2, 19, __pyx_int_128);
    __Pyx_INCREF(__pyx_int_128);
    __Pyx_GIVEREF(__pyx_int_128);
    PyList_SET_ITEM(__pyx_t_2, 20, __pyx_int_128);
    __Pyx_INCREF(__pyx_int_192);
    __Pyx_GIVEREF(__pyx_int_192);
    PyList_SET_ITEM(__pyx_t_2, 21, __pyx_int_192);
    __Pyx_INCREF(__pyx_int_192);
    __Pyx_GIVEREF(__pyx_int_192);
    PyList_SET_ITEM(__pyx_t_2, 22, __pyx_int_192);
    __Pyx_INCREF(__pyx_int_192);
    __Pyx_GIVEREF(__pyx_int_192);
    PyList_SET_ITEM(__pyx_t_2, 23, __pyx_int_192);
    __Pyx_INCREF(__pyx_int_128);
    __Pyx_GIVEREF(__pyx_int_128);
    PyList_SET_ITEM(__pyx_t_2, 24, __pyx_int_128);
    __Pyx_INCREF(__pyx_int_128);
    __Pyx_GIVEREF(__pyx_int_128);
    PyList_SET_ITEM(__pyx_t_2, 25, __pyx_int_128);
    __Pyx_INCREF(__pyx_int_128);
    __Pyx_GIVEREF(__pyx_int_128);
    PyList_SET_ITEM(__pyx_t_2, 26, __pyx_int_128);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_2, 27, __pyx_int_255);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_2, 28, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_2, 29, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_2, 30, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_2, 31, __pyx_int_255);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_2, 32, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_2, 33, __pyx_int_255);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_2, 34, __pyx_int_255);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_2, 35, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_2, 36, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_2, 37, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_2, 38, __pyx_int_255);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_2, 39, __pyx_int_255);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_2, 40, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_2, 41, __pyx_int_255);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_2, 42, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_2, 43, __pyx_int_255);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_2, 44, __pyx_int_255);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_2, 45, __pyx_int_255);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_2, 46, __pyx_int_255);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_2, 47, __pyx_int_255);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_2, 48, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_2, 49, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_2, 50, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_2, 51, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_2, 52, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_2, 53, __pyx_int_95);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_2, 54, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_2, 55, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_2, 56, __pyx_int_135);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_2, 57, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_2, 58, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_2, 59, __pyx_int_175);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_2, 60, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_2, 61, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_2, 62, __pyx_int_215);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_2, 63, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_2, 64, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_2, 65, __pyx_int_255);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_2, 66, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_2, 67, __pyx_int_95);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_2, 68, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_2, 69, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_2, 70, __pyx_int_95);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_2, 71, __pyx_int_95);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_2, 72, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_2, 73, __pyx_int_95);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_2, 74, __pyx_int_135);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_2, 75, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_2, 76, __pyx_int_95);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_2, 77, __pyx_int_175);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_2, 78, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_2, 79, __pyx_int_95);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_2, 80, __pyx_int_215);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_2, 81, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_2, 82, __pyx_int_95);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_2, 83, __pyx_int_255);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_2, 84, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_2, 85, __pyx_int_135);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_2, 86, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_2, 87, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_2, 88, __pyx_int_135);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_2, 89, __pyx_int_95);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_2, 90, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_2, 91, __pyx_int_135);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_2, 92, __pyx_int_135);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_2, 93, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_2, 94, __pyx_int_135);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_2, 95, __pyx_int_175);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_2, 96, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_2, 97, __pyx_int_135);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_2, 98, __pyx_int_215);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_2, 99, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_2, 100, __pyx_int_135);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_2, 101, __pyx_int_255);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_2, 102, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_2, 103, __pyx_int_175);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_2, 104, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_2, 105, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_2, 106, __pyx_int_175);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_2, 107, __pyx_int_95);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_2, 108, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_2, 109, __pyx_int_175);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_2, 110, __pyx_int_135);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_2, 111, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_2, 112, __pyx_int_175);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_2, 113, __pyx_int_175);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_2, 114, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_2, 115, __pyx_int_175);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_2, 116, __pyx_int_215);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_2, 117, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_2, 118, __pyx_int_175);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_2, 119, __pyx_int_255);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_2, 120, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_2, 121, __pyx_int_215);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_2, 122, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_2, 123, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_2, 124, __pyx_int_215);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_2, 125, __pyx_int_95);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_2, 126, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_2, 127, __pyx_int_215);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_2, 128, __pyx_int_135);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_2, 129, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_2, 130, __pyx_int_215);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_2, 131, __pyx_int_175);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_2, 132, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_2, 133, __pyx_int_215);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_2, 134, __pyx_int_215);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_2, 135, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_2, 136, __pyx_int_215);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_2, 137, __pyx_int_255);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_2, 138, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_2, 139, __pyx_int_255);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_2, 140, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_2, 141, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_2, 142, __pyx_int_255);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_2, 143, __pyx_int_95);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_2, 144, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_2, 145, __pyx_int_255);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_2, 146, __pyx_int_135);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_2, 147, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_2, 148, __pyx_int_255);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_2, 149, __pyx_int_175);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_2, 150, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_2, 151, __pyx_int_255);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_2, 152, __pyx_int_215);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_2, 153, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_2, 154, __pyx_int_255);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_2, 155, __pyx_int_255);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_2, 156, __pyx_int_95);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_2, 157, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_2, 158, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_2, 159, __pyx_int_95);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_2, 160, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_2, 161, __pyx_int_95);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_2, 162, __pyx_int_95);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_2, 163, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_2, 164, __pyx_int_135);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_2, 165, __pyx_int_95);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_2, 166, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_2, 167, __pyx_int_175);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_2, 168, __pyx_int_95);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_2, 169, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_2, 170, __pyx_int_215);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_2, 171, __pyx_int_95);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_2, 172, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_2, 173, __pyx_int_255);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_2, 174, __pyx_int_95);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_2, 175, __pyx_int_95);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_2, 176, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_2, 177, __pyx_int_95);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_2, 178, __pyx_int_95);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_2, 179, __pyx_int_95);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_2, 180, __pyx_int_95);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_2, 181, __pyx_int_95);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_2, 182, __pyx_int_135);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_2, 183, __pyx_int_95);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_2, 184, __pyx_int_95);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_2, 185, __pyx_int_175);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_2, 186, __pyx_int_95);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_2, 187, __pyx_int_95);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_2, 188, __pyx_int_215);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_2, 189, __pyx_int_95);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_2, 190, __pyx_int_95);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_2, 191, __pyx_int_255);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_2, 192, __pyx_int_95);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_2, 193, __pyx_int_135);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_2, 194, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_2, 195, __pyx_int_95);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_2, 196, __pyx_int_135);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_2, 197, __pyx_int_95);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_2, 198, __pyx_int_95);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_2, 199, __pyx_int_135);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_2, 200, __pyx_int_135);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_2, 201, __pyx_int_95);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_2, 202, __pyx_int_135);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_2, 203, __pyx_int_175);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_2, 204, __pyx_int_95);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_2, 205, __pyx_int_135);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_2, 206, __pyx_int_215);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_2, 207, __pyx_int_95);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_2, 208, __pyx_int_135);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_2, 209, __pyx_int_255);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_2, 210, __pyx_int_95);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_2, 211, __pyx_int_175);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_2, 212, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_2, 213, __pyx_int_95);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_2, 214, __pyx_int_175);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_2, 215, __pyx_int_95);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_2, 216, __pyx_int_95);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_2, 217, __pyx_int_175);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_2, 218, __pyx_int_135);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_2, 219, __pyx_int_95);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_2, 220, __pyx_int_175);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_2, 221, __pyx_int_175);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_2, 222, __pyx_int_95);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_2, 223, __pyx_int_175);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_2, 224, __pyx_int_215);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_2, 225, __pyx_int_95);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_2, 226, __pyx_int_175);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_2, 227, __pyx_int_255);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_2, 228, __pyx_int_95);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_2, 229, __pyx_int_215);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_2, 230, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_2, 231, __pyx_int_95);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_2, 232, __pyx_int_215);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_2, 233, __pyx_int_95);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_2, 234, __pyx_int_95);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_2, 235, __pyx_int_215);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_2, 236, __pyx_int_135);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_2, 237, __pyx_int_95);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_2, 238, __pyx_int_215);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_2, 239, __pyx_int_175);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_2, 240, __pyx_int_95);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_2, 241, __pyx_int_215);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_2, 242, __pyx_int_215);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_2, 243, __pyx_int_95);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_2, 244, __pyx_int_215);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_2, 245, __pyx_int_255);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_2, 246, __pyx_int_95);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_2, 247, __pyx_int_255);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_2, 248, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_2, 249, __pyx_int_95);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_2, 250, __pyx_int_255);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_2, 251, __pyx_int_95);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_2, 252, __pyx_int_95);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_2, 253, __pyx_int_255);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_2, 254, __pyx_int_135);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_2, 255, __pyx_int_95);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_2, 256, __pyx_int_255);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_2, 257, __pyx_int_175);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_2, 258, __pyx_int_95);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_2, 259, __pyx_int_255);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_2, 260, __pyx_int_215);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_2, 261, __pyx_int_95);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_2, 262, __pyx_int_255);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_2, 263, __pyx_int_255);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_2, 264, __pyx_int_135);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_2, 265, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_2, 266, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_2, 267, __pyx_int_135);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_2, 268, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_2, 269, __pyx_int_95);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_2, 270, __pyx_int_135);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_2, 271, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_2, 272, __pyx_int_135);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_2, 273, __pyx_int_135);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_2, 274, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_2, 275, __pyx_int_175);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_2, 276, __pyx_int_135);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_2, 277, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_2, 278, __pyx_int_215);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_2, 279, __pyx_int_135);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_2, 280, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_2, 281, __pyx_int_255);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_2, 282, __pyx_int_135);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_2, 283, __pyx_int_95);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_2, 284, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_2, 285, __pyx_int_135);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_2, 286, __pyx_int_95);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_2, 287, __pyx_int_95);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_2, 288, __pyx_int_135);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_2, 289, __pyx_int_95);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_2, 290, __pyx_int_135);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_2, 291, __pyx_int_135);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_2, 292, __pyx_int_95);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_2, 293, __pyx_int_175);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_2, 294, __pyx_int_135);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_2, 295, __pyx_int_95);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_2, 296, __pyx_int_215);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_2, 297, __pyx_int_135);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_2, 298, __pyx_int_95);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_2, 299, __pyx_int_255);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_2, 300, __pyx_int_135);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_2, 301, __pyx_int_135);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_2, 302, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_2, 303, __pyx_int_135);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_2, 304, __pyx_int_135);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_2, 305, __pyx_int_95);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_2, 306, __pyx_int_135);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_2, 307, __pyx_int_135);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_2, 308, __pyx_int_135);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_2, 309, __pyx_int_135);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_2, 310, __pyx_int_135);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_2, 311, __pyx_int_175);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_2, 312, __pyx_int_135);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_2, 313, __pyx_int_135);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_2, 314, __pyx_int_215);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_2, 315, __pyx_int_135);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_2, 316, __pyx_int_135);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_2, 317, __pyx_int_255);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_2, 318, __pyx_int_135);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_2, 319, __pyx_int_175);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_2, 320, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_2, 321, __pyx_int_135);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_2, 322, __pyx_int_175);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_2, 323, __pyx_int_95);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_2, 324, __pyx_int_135);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_2, 325, __pyx_int_175);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_2, 326, __pyx_int_135);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_2, 327, __pyx_int_135);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_2, 328, __pyx_int_175);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_2, 329, __pyx_int_175);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_2, 330, __pyx_int_135);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_2, 331, __pyx_int_175);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_2, 332, __pyx_int_215);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_2, 333, __pyx_int_135);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_2, 334, __pyx_int_175);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_2, 335, __pyx_int_255);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_2, 336, __pyx_int_135);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_2, 337, __pyx_int_215);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_2, 338, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_2, 339, __pyx_int_135);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_2, 340, __pyx_int_215);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_2, 341, __pyx_int_95);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_2, 342, __pyx_int_135);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_2, 343, __pyx_int_215);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_2, 344, __pyx_int_135);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_2, 345, __pyx_int_135);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_2, 346, __pyx_int_215);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_2, 347, __pyx_int_175);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_2, 348, __pyx_int_135);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_2, 349, __pyx_int_215);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_2, 350, __pyx_int_215);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_2, 351, __pyx_int_135);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_2, 352, __pyx_int_215);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_2, 353, __pyx_int_255);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_2, 354, __pyx_int_135);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_2, 355, __pyx_int_255);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_2, 356, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_2, 357, __pyx_int_135);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_2, 358, __pyx_int_255);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_2, 359, __pyx_int_95);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_2, 360, __pyx_int_135);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_2, 361, __pyx_int_255);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_2, 362, __pyx_int_135);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_2, 363, __pyx_int_135);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_2, 364, __pyx_int_255);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_2, 365, __pyx_int_175);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_2, 366, __pyx_int_135);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_2, 367, __pyx_int_255);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_2, 368, __pyx_int_215);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_2, 369, __pyx_int_135);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_2, 370, __pyx_int_255);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_2, 371, __pyx_int_255);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_2, 372, __pyx_int_175);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_2, 373, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_2, 374, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_2, 375, __pyx_int_175);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_2, 376, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_2, 377, __pyx_int_95);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_2, 378, __pyx_int_175);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_2, 379, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_2, 380, __pyx_int_135);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_2, 381, __pyx_int_175);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_2, 382, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_2, 383, __pyx_int_175);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_2, 384, __pyx_int_175);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_2, 385, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_2, 386, __pyx_int_215);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_2, 387, __pyx_int_175);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_2, 388, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_2, 389, __pyx_int_255);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_2, 390, __pyx_int_175);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_2, 391, __pyx_int_95);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_2, 392, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_2, 393, __pyx_int_175);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_2, 394, __pyx_int_95);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_2, 395, __pyx_int_95);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_2, 396, __pyx_int_175);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_2, 397, __pyx_int_95);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_2, 398, __pyx_int_135);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_2, 399, __pyx_int_175);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_2, 400, __pyx_int_95);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_2, 401, __pyx_int_175);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_2, 402, __pyx_int_175);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_2, 403, __pyx_int_95);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_2, 404, __pyx_int_215);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_2, 405, __pyx_int_175);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_2, 406, __pyx_int_95);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_2, 407, __pyx_int_255);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_2, 408, __pyx_int_175);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_2, 409, __pyx_int_135);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_2, 410, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_2, 411, __pyx_int_175);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_2, 412, __pyx_int_135);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_2, 413, __pyx_int_95);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_2, 414, __pyx_int_175);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_2, 415, __pyx_int_135);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_2, 416, __pyx_int_135);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_2, 417, __pyx_int_175);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_2, 418, __pyx_int_135);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_2, 419, __pyx_int_175);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_2, 420, __pyx_int_175);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_2, 421, __pyx_int_135);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_2, 422, __pyx_int_215);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_2, 423, __pyx_int_175);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_2, 424, __pyx_int_135);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_2, 425, __pyx_int_255);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_2, 426, __pyx_int_175);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_2, 427, __pyx_int_175);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_2, 428, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_2, 429, __pyx_int_175);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_2, 430, __pyx_int_175);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_2, 431, __pyx_int_95);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_2, 432, __pyx_int_175);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_2, 433, __pyx_int_175);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_2, 434, __pyx_int_135);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_2, 435, __pyx_int_175);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_2, 436, __pyx_int_175);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_2, 437, __pyx_int_175);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_2, 438, __pyx_int_175);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_2, 439, __pyx_int_175);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_2, 440, __pyx_int_215);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_2, 441, __pyx_int_175);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_2, 442, __pyx_int_175);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_2, 443, __pyx_int_255);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_2, 444, __pyx_int_175);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_2, 445, __pyx_int_215);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_2, 446, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_2, 447, __pyx_int_175);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_2, 448, __pyx_int_215);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_2, 449, __pyx_int_95);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_2, 450, __pyx_int_175);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_2, 451, __pyx_int_215);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_2, 452, __pyx_int_135);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_2, 453, __pyx_int_175);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_2, 454, __pyx_int_215);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_2, 455, __pyx_int_175);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_2, 456, __pyx_int_175);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_2, 457, __pyx_int_215);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_2, 458, __pyx_int_215);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_2, 459, __pyx_int_175);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_2, 460, __pyx_int_215);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_2, 461, __pyx_int_255);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_2, 462, __pyx_int_175);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_2, 463, __pyx_int_255);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_2, 464, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_2, 465, __pyx_int_175);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_2, 466, __pyx_int_255);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_2, 467, __pyx_int_95);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_2, 468, __pyx_int_175);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_2, 469, __pyx_int_255);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_2, 470, __pyx_int_135);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_2, 471, __pyx_int_175);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_2, 472, __pyx_int_255);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_2, 473, __pyx_int_175);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_2, 474, __pyx_int_175);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_2, 475, __pyx_int_255);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_2, 476, __pyx_int_215);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_2, 477, __pyx_int_175);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_2, 478, __pyx_int_255);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_2, 479, __pyx_int_255);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_2, 480, __pyx_int_215);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_2, 481, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_2, 482, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_2, 483, __pyx_int_215);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_2, 484, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_2, 485, __pyx_int_95);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_2, 486, __pyx_int_215);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_2, 487, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_2, 488, __pyx_int_135);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_2, 489, __pyx_int_215);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_2, 490, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_2, 491, __pyx_int_175);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_2, 492, __pyx_int_215);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_2, 493, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_2, 494, __pyx_int_215);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_2, 495, __pyx_int_215);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_2, 496, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_2, 497, __pyx_int_255);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_2, 498, __pyx_int_215);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_2, 499, __pyx_int_95);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_2, 500, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_2, 501, __pyx_int_215);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_2, 502, __pyx_int_95);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_2, 503, __pyx_int_95);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_2, 504, __pyx_int_215);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_2, 505, __pyx_int_95);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_2, 506, __pyx_int_135);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_2, 507, __pyx_int_215);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_2, 508, __pyx_int_95);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_2, 509, __pyx_int_175);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_2, 510, __pyx_int_215);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_2, 511, __pyx_int_95);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_2, 512, __pyx_int_215);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_2, 513, __pyx_int_215);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_2, 514, __pyx_int_95);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_2, 515, __pyx_int_255);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_2, 516, __pyx_int_215);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_2, 517, __pyx_int_135);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_2, 518, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_2, 519, __pyx_int_215);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_2, 520, __pyx_int_135);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_2, 521, __pyx_int_95);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_2, 522, __pyx_int_215);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_2, 523, __pyx_int_135);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_2, 524, __pyx_int_135);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_2, 525, __pyx_int_215);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_2, 526, __pyx_int_135);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_2, 527, __pyx_int_175);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_2, 528, __pyx_int_215);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_2, 529, __pyx_int_135);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_2, 530, __pyx_int_215);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_2, 531, __pyx_int_215);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_2, 532, __pyx_int_135);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_2, 533, __pyx_int_255);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_2, 534, __pyx_int_215);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_2, 535, __pyx_int_175);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_2, 536, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_2, 537, __pyx_int_215);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_2, 538, __pyx_int_175);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_2, 539, __pyx_int_95);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_2, 540, __pyx_int_215);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_2, 541, __pyx_int_175);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_2, 542, __pyx_int_135);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_2, 543, __pyx_int_215);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_2, 544, __pyx_int_175);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_2, 545, __pyx_int_175);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_2, 546, __pyx_int_215);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_2, 547, __pyx_int_175);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_2, 548, __pyx_int_215);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_2, 549, __pyx_int_215);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_2, 550, __pyx_int_175);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_2, 551, __pyx_int_255);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_2, 552, __pyx_int_215);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_2, 553, __pyx_int_215);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_2, 554, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_2, 555, __pyx_int_215);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_2, 556, __pyx_int_215);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_2, 557, __pyx_int_95);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_2, 558, __pyx_int_215);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_2, 559, __pyx_int_215);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_2, 560, __pyx_int_135);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_2, 561, __pyx_int_215);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_2, 562, __pyx_int_215);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_2, 563, __pyx_int_175);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_2, 564, __pyx_int_215);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_2, 565, __pyx_int_215);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_2, 566, __pyx_int_215);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_2, 567, __pyx_int_215);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_2, 568, __pyx_int_215);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_2, 569, __pyx_int_255);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_2, 570, __pyx_int_215);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_2, 571, __pyx_int_255);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_2, 572, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_2, 573, __pyx_int_215);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_2, 574, __pyx_int_255);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_2, 575, __pyx_int_95);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_2, 576, __pyx_int_215);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_2, 577, __pyx_int_255);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_2, 578, __pyx_int_135);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_2, 579, __pyx_int_215);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_2, 580, __pyx_int_255);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_2, 581, __pyx_int_175);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_2, 582, __pyx_int_215);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_2, 583, __pyx_int_255);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_2, 584, __pyx_int_215);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_2, 585, __pyx_int_215);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_2, 586, __pyx_int_255);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_2, 587, __pyx_int_255);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_2, 588, __pyx_int_255);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_2, 589, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_2, 590, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_2, 591, __pyx_int_255);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_2, 592, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_2, 593, __pyx_int_95);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_2, 594, __pyx_int_255);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_2, 595, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_2, 596, __pyx_int_135);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_2, 597, __pyx_int_255);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_2, 598, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_2, 599, __pyx_int_175);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_2, 600, __pyx_int_255);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_2, 601, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_2, 602, __pyx_int_215);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_2, 603, __pyx_int_255);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_2, 604, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_2, 605, __pyx_int_255);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_2, 606, __pyx_int_255);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_2, 607, __pyx_int_95);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_2, 608, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_2, 609, __pyx_int_255);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_2, 610, __pyx_int_95);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_2, 611, __pyx_int_95);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_2, 612, __pyx_int_255);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_2, 613, __pyx_int_95);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_2, 614, __pyx_int_135);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_2, 615, __pyx_int_255);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_2, 616, __pyx_int_95);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_2, 617, __pyx_int_175);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_2, 618, __pyx_int_255);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_2, 619, __pyx_int_95);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_2, 620, __pyx_int_215);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_2, 621, __pyx_int_255);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_2, 622, __pyx_int_95);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_2, 623, __pyx_int_255);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_2, 624, __pyx_int_255);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_2, 625, __pyx_int_135);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_2, 626, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_2, 627, __pyx_int_255);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_2, 628, __pyx_int_135);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_2, 629, __pyx_int_95);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_2, 630, __pyx_int_255);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_2, 631, __pyx_int_135);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_2, 632, __pyx_int_135);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_2, 633, __pyx_int_255);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_2, 634, __pyx_int_135);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_2, 635, __pyx_int_175);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_2, 636, __pyx_int_255);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_2, 637, __pyx_int_135);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_2, 638, __pyx_int_215);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_2, 639, __pyx_int_255);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_2, 640, __pyx_int_135);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_2, 641, __pyx_int_255);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_2, 642, __pyx_int_255);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_2, 643, __pyx_int_175);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_2, 644, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_2, 645, __pyx_int_255);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_2, 646, __pyx_int_175);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_2, 647, __pyx_int_95);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_2, 648, __pyx_int_255);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_2, 649, __pyx_int_175);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_2, 650, __pyx_int_135);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_2, 651, __pyx_int_255);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_2, 652, __pyx_int_175);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_2, 653, __pyx_int_175);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_2, 654, __pyx_int_255);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_2, 655, __pyx_int_175);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_2, 656, __pyx_int_215);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_2, 657, __pyx_int_255);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_2, 658, __pyx_int_175);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_2, 659, __pyx_int_255);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_2, 660, __pyx_int_255);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_2, 661, __pyx_int_215);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_2, 662, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_2, 663, __pyx_int_255);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_2, 664, __pyx_int_215);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_2, 665, __pyx_int_95);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_2, 666, __pyx_int_255);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_2, 667, __pyx_int_215);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_2, 668, __pyx_int_135);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_2, 669, __pyx_int_255);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_2, 670, __pyx_int_215);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_2, 671, __pyx_int_175);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_2, 672, __pyx_int_255);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_2, 673, __pyx_int_215);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_2, 674, __pyx_int_215);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_2, 675, __pyx_int_255);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_2, 676, __pyx_int_215);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_2, 677, __pyx_int_255);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_2, 678, __pyx_int_255);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_2, 679, __pyx_int_255);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_2, 680, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_2, 681, __pyx_int_255);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_2, 682, __pyx_int_255);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_2, 683, __pyx_int_95);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_2, 684, __pyx_int_255);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_2, 685, __pyx_int_255);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_2, 686, __pyx_int_135);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_2, 687, __pyx_int_255);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_2, 688, __pyx_int_255);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_2, 689, __pyx_int_175);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_2, 690, __pyx_int_255);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_2, 691, __pyx_int_255);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_2, 692, __pyx_int_215);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_2, 693, __pyx_int_255);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_2, 694, __pyx_int_255);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_2, 695, __pyx_int_255);
    __Pyx_INCREF(__pyx_int_8);
    __Pyx_GIVEREF(__pyx_int_8);
    PyList_SET_ITEM(__pyx_t_2, 696, __pyx_int_8);
    __Pyx_INCREF(__pyx_int_8);
    __Pyx_GIVEREF(__pyx_int_8);
    PyList_SET_ITEM(__pyx_t_2, 697, __pyx_int_8);
    __Pyx_INCREF(__pyx_int_8);
    __Pyx_GIVEREF(__pyx_int_8);
    PyList_SET_ITEM(__pyx_t_2, 698, __pyx_int_8);
    __Pyx_INCREF(__pyx_int_18);
    __Pyx_GIVEREF(__pyx_int_18);
    PyList_SET_ITEM(__pyx_t_2, 699, __pyx_int_18);
    __Pyx_INCREF(__pyx_int_18);
    __Pyx_GIVEREF(__pyx_int_18);
    PyList_SET_ITEM(__pyx_t_2, 700, __pyx_int_18);
    __Pyx_INCREF(__pyx_int_18);
    __Pyx_GIVEREF(__pyx_int_18);
    PyList_SET_ITEM(__pyx_t_2, 701, __pyx_int_18);
    __Pyx_INCREF(__pyx_int_28);
    __Pyx_GIVEREF(__pyx_int_28);
    PyList_SET_ITEM(__pyx_t_2, 702, __pyx_int_28);
    __Pyx_INCREF(__pyx_int_28);
    __Pyx_GIVEREF(__pyx_int_28);
    PyList_SET_ITEM(__pyx_t_2, 703, __pyx_int_28);
    __Pyx_INCREF(__pyx_int_28);
    __Pyx_GIVEREF(__pyx_int_28);
    PyList_SET_ITEM(__pyx_t_2, 704, __pyx_int_28);
    __Pyx_INCREF(__pyx_int_38);
    __Pyx_GIVEREF(__pyx_int_38);
    PyList_SET_ITEM(__pyx_t_2, 705, __pyx_int_38);
    __Pyx_INCREF(__pyx_int_38);
    __Pyx_GIVEREF(__pyx_int_38);
    PyList_SET_ITEM(__pyx_t_2, 706, __pyx_int_38);
    __Pyx_INCREF(__pyx_int_38);
    __Pyx_GIVEREF(__pyx_int_38);
    PyList_SET_ITEM(__pyx_t_2, 707, __pyx_int_38);
    __Pyx_INCREF(__pyx_int_48);
    __Pyx_GIVEREF(__pyx_int_48);
    PyList_SET_ITEM(__pyx_t_2, 708, __pyx_int_48);
    __Pyx_INCREF(__pyx_int_48);
    __Pyx_GIVEREF(__pyx_int_48);
    PyList_SET_ITEM(__pyx_t_2, 709, __pyx_int_48);
    __Pyx_INCREF(__pyx_int_48);
    __Pyx_GIVEREF(__pyx_int_48);
    PyList_SET_ITEM(__pyx_t_2, 710, __pyx_int_48);
    __Pyx_INCREF(__pyx_int_58);
    __Pyx_GIVEREF(__pyx_int_58);
    PyList_SET_ITEM(__pyx_t_2, 711, __pyx_int_58);
    __Pyx_INCREF(__pyx_int_58);
    __Pyx_GIVEREF(__pyx_int_58);
    PyList_SET_ITEM(__pyx_t_2, 712, __pyx_int_58);
    __Pyx_INCREF(__pyx_int_58);
    __Pyx_GIVEREF(__pyx_int_58);
    PyList_SET_ITEM(__pyx_t_2, 713, __pyx_int_58);
    __Pyx_INCREF(__pyx_int_68);
    __Pyx_GIVEREF(__pyx_int_68);
    PyList_SET_ITEM(__pyx_t_2, 714, __pyx_int_68);
    __Pyx_INCREF(__pyx_int_68);
    __Pyx_GIVEREF(__pyx_int_68);
    PyList_SET_ITEM(__pyx_t_2, 715, __pyx_int_68);
    __Pyx_INCREF(__pyx_int_68);
    __Pyx_GIVEREF(__pyx_int_68);
    PyList_SET_ITEM(__pyx_t_2, 716, __pyx_int_68);
    __Pyx_INCREF(__pyx_int_78);
    __Pyx_GIVEREF(__pyx_int_78);
    PyList_SET_ITEM(__pyx_t_2, 717, __pyx_int_78);
    __Pyx_INCREF(__pyx_int_78);
    __Pyx_GIVEREF(__pyx_int_78);
    PyList_SET_ITEM(__pyx_t_2, 718, __pyx_int_78);
    __Pyx_INCREF(__pyx_int_78);
    __Pyx_GIVEREF(__pyx_int_78);
    PyList_SET_ITEM(__pyx_t_2, 719, __pyx_int_78);
    __Pyx_INCREF(__pyx_int_88);
    __Pyx_GIVEREF(__pyx_int_88);
    PyList_SET_ITEM(__pyx_t_2, 720, __pyx_int_88);
    __Pyx_INCREF(__pyx_int_88);
    __Pyx_GIVEREF(__pyx_int_88);
    PyList_SET_ITEM(__pyx_t_2, 721, __pyx_int_88);
    __Pyx_INCREF(__pyx_int_88);
    __Pyx_GIVEREF(__pyx_int_88);
    PyList_SET_ITEM(__pyx_t_2, 722, __pyx_int_88);
    __Pyx_INCREF(__pyx_int_98);
    __Pyx_GIVEREF(__pyx_int_98);
    PyList_SET_ITEM(__pyx_t_2, 723, __pyx_int_98);
    __Pyx_INCREF(__pyx_int_98);
    __Pyx_GIVEREF(__pyx_int_98);
    PyList_SET_ITEM(__pyx_t_2, 724, __pyx_int_98);
    __Pyx_INCREF(__pyx_int_98);
    __Pyx_GIVEREF(__pyx_int_98);
    PyList_SET_ITEM(__pyx_t_2, 725, __pyx_int_98);
    __Pyx_INCREF(__pyx_int_108);
    __Pyx_GIVEREF(__pyx_int_108);
    PyList_SET_ITEM(__pyx_t_2, 726, __pyx_int_108);
    __Pyx_INCREF(__pyx_int_108);
    __Pyx_GIVEREF(__pyx_int_108);
    PyList_SET_ITEM(__pyx_t_2, 727, __pyx_int_108);
    __Pyx_INCREF(__pyx_int_108);
    __Pyx_GIVEREF(__pyx_int_108);
    PyList_SET_ITEM(__pyx_t_2, 728, __pyx_int_108);
    __Pyx_INCREF(__pyx_int_118);
    __Pyx_GIVEREF(__pyx_int_118);
    PyList_SET_ITEM(__pyx_t_2, 729, __pyx_int_118);
    __Pyx_INCREF(__pyx_int_118);
    __Pyx_GIVEREF(__pyx_int_118);
    PyList_SET_ITEM(__pyx_t_2, 730, __pyx_int_118);
    __Pyx_INCREF(__pyx_int_118);
    __Pyx_GIVEREF(__pyx_int_118);
    PyList_SET_ITEM(__pyx_t_2, 731, __pyx_int_118);
    __Pyx_INCREF(__pyx_int_128);
    __Pyx_GIVEREF(__pyx_int_128);
    PyList_SET_ITEM(__pyx_t_2, 732, __pyx_int_128);
    __Pyx_INCREF(__pyx_int_128);
    __Pyx_GIVEREF(__pyx_int_128);
    PyList_SET_ITEM(__pyx_t_2, 733, __pyx_int_128);
    __Pyx_INCREF(__pyx_int_128);
    __Pyx_GIVEREF(__pyx_int_128);
    PyList_SET_ITEM(__pyx_t_2, 734, __pyx_int_128);
    __Pyx_INCREF(__pyx_int_138);
    __Pyx_GIVEREF(__pyx_int_138);
    PyList_SET_ITEM(__pyx_t_2, 735, __pyx_int_138);
    __Pyx_INCREF(__pyx_int_138);
    __Pyx_GIVEREF(__pyx_int_138);
    PyList_SET_ITEM(__pyx_t_2, 736, __pyx_int_138);
    __Pyx_INCREF(__pyx_int_138);
    __Pyx_GIVEREF(__pyx_int_138);
    PyList_SET_ITEM(__pyx_t_2, 737, __pyx_int_138);
    __Pyx_INCREF(__pyx_int_148);
    __Pyx_GIVEREF(__pyx_int_148);
    PyList_SET_ITEM(__pyx_t_2, 738, __pyx_int_148);
    __Pyx_INCREF(__pyx_int_148);
    __Pyx_GIVEREF(__pyx_int_148);
    PyList_SET_ITEM(__pyx_t_2, 739, __pyx_int_148);
    __Pyx_INCREF(__pyx_int_148);
    __Pyx_GIVEREF(__pyx_int_148);
    PyList_SET_ITEM(__pyx_t_2, 740, __pyx_int_148);
    __Pyx_INCREF(__pyx_int_158);
    __Pyx_GIVEREF(__pyx_int_158);
    PyList_SET_ITEM(__pyx_t_2, 741, __pyx_int_158);
    __Pyx_INCREF(__pyx_int_158);
    __Pyx_GIVEREF(__pyx_int_158);
    PyList_SET_ITEM(__pyx_t_2, 742, __pyx_int_158);
    __Pyx_INCREF(__pyx_int_158);
    __Pyx_GIVEREF(__pyx_int_158);
    PyList_SET_ITEM(__pyx_t_2, 743, __pyx_int_158);
    __Pyx_INCREF(__pyx_int_168);
    __Pyx_GIVEREF(__pyx_int_168);
    PyList_SET_ITEM(__pyx_t_2, 744, __pyx_int_168);
    __Pyx_INCREF(__pyx_int_168);
    __Pyx_GIVEREF(__pyx_int_168);
    PyList_SET_ITEM(__pyx_t_2, 745, __pyx_int_168);
    __Pyx_INCREF(__pyx_int_168);
    __Pyx_GIVEREF(__pyx_int_168);
    PyList_SET_ITEM(__pyx_t_2, 746, __pyx_int_168);
    __Pyx_INCREF(__pyx_int_178);
    __Pyx_GIVEREF(__pyx_int_178);
    PyList_SET_ITEM(__pyx_t_2, 747, __pyx_int_178);
    __Pyx_INCREF(__pyx_int_178);
    __Pyx_GIVEREF(__pyx_int_178);
    PyList_SET_ITEM(__pyx_t_2, 748, __pyx_int_178);
    __Pyx_INCREF(__pyx_int_178);
    __Pyx_GIVEREF(__pyx_int_178);
    PyList_SET_ITEM(__pyx_t_2, 749, __pyx_int_178);
    __Pyx_INCREF(__pyx_int_188);
    __Pyx_GIVEREF(__pyx_int_188);
    PyList_SET_ITEM(__pyx_t_2, 750, __pyx_int_188);
    __Pyx_INCREF(__pyx_int_188);
    __Pyx_GIVEREF(__pyx_int_188);
    PyList_SET_ITEM(__pyx_t_2, 751, __pyx_int_188);
    __Pyx_INCREF(__pyx_int_188);
    __Pyx_GIVEREF(__pyx_int_188);
    PyList_SET_ITEM(__pyx_t_2, 752, __pyx_int_188);
    __Pyx_INCREF(__pyx_int_198);
    __Pyx_GIVEREF(__pyx_int_198);
    PyList_SET_ITEM(__pyx_t_2, 753, __pyx_int_198);
    __Pyx_INCREF(__pyx_int_198);
    __Pyx_GIVEREF(__pyx_int_198);
    PyList_SET_ITEM(__pyx_t_2, 754, __pyx_int_198);
    __Pyx_INCREF(__pyx_int_198);
    __Pyx_GIVEREF(__pyx_int_198);
    PyList_SET_ITEM(__pyx_t_2, 755, __pyx_int_198);
    __Pyx_INCREF(__pyx_int_208);
    __Pyx_GIVEREF(__pyx_int_208);
    PyList_SET_ITEM(__pyx_t_2, 756, __pyx_int_208);
    __Pyx_INCREF(__pyx_int_208);
    __Pyx_GIVEREF(__pyx_int_208);
    PyList_SET_ITEM(__pyx_t_2, 757, __pyx_int_208);
    __Pyx_INCREF(__pyx_int_208);
    __Pyx_GIVEREF(__pyx_int_208);
    PyList_SET_ITEM(__pyx_t_2, 758, __pyx_int_208);
    __Pyx_INCREF(__pyx_int_218);
    __Pyx_GIVEREF(__pyx_int_218);
    PyList_SET_ITEM(__pyx_t_2, 759, __pyx_int_218);
    __Pyx_INCREF(__pyx_int_218);
    __Pyx_GIVEREF(__pyx_int_218);
    PyList_SET_ITEM(__pyx_t_2, 760, __pyx_int_218);
    __Pyx_INCREF(__pyx_int_218);
    __Pyx_GIVEREF(__pyx_int_218);
    PyList_SET_ITEM(__pyx_t_2, 761, __pyx_int_218);
    __Pyx_INCREF(__pyx_int_228);
    __Pyx_GIVEREF(__pyx_int_228);
    PyList_SET_ITEM(__pyx_t_2, 762, __pyx_int_228);
    __Pyx_INCREF(__pyx_int_228);
    __Pyx_GIVEREF(__pyx_int_228);
    PyList_SET_ITEM(__pyx_t_2, 763, __pyx_int_228);
    __Pyx_INCREF(__pyx_int_228);
    __Pyx_GIVEREF(__pyx_int_228);
    PyList_SET_ITEM(__pyx_t_2, 764, __pyx_int_228);
    __Pyx_INCREF(__pyx_int_238);
    __Pyx_GIVEREF(__pyx_int_238);
    PyList_SET_ITEM(__pyx_t_2, 765, __pyx_int_238);
    __Pyx_INCREF(__pyx_int_238);
    __Pyx_GIVEREF(__pyx_int_238);
    PyList_SET_ITEM(__pyx_t_2, 766, __pyx_int_238);
    __Pyx_INCREF(__pyx_int_238);
    __Pyx_GIVEREF(__pyx_int_238);
    PyList_SET_ITEM(__pyx_t_2, 767, __pyx_int_238);
    __pyx_v_color_table = ((PyObject*)__pyx_t_2);
    __pyx_t_2 = 0;

    /* "ttygif/tty/theme.pyx":418
 *                 138,138,138 , 148,148,148 , 158,158,158 , 168,168,168 , 178,178,178 , 188,188,188,
 *                 198,198,198 , 208,208,208 , 218,218,218 , 228,228,228 , 238,238,238 ]
 *             for i in range(256*3):             # <<<<<<<<<<<<<<
 *                 self.palette[i]=color_table[i]
 * 
 */
    for (__pyx_t_14 = 0; __pyx_t_14 < 0x300; __pyx_t_14+=1) {
      __pyx_v_i = __pyx_t_14;

      /* "ttygif/tty/theme.pyx":419
 *                 198,198,198 , 208,208,208 , 218,218,218 , 228,228,228 , 238,238,238 ]
 *             for i in range(256*3):
 *                 self.palette[i]=color_table[i]             # <<<<<<<<<<<<<<
 * 
 *         self.auto()
 */
      __pyx_t_2 = __Pyx_GetItemInt_List(__pyx_v_color_table, __pyx_v_i, long, 1, __Pyx_PyInt_From_long, 1, 1, 1); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 419, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      if (unlikely(__Pyx_SetItemInt(((PyObject *)__pyx_v_self->palette), __pyx_v_i, __pyx_t_2, long, 1, __Pyx_PyInt_From_long, 0, 1, 1) < 0)) __PYX_ERR(1, 419, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    }

    /* "ttygif/tty/theme.pyx":369
 * 
 * 
 *         if len(self.palette)==0:             # <<<<<<<<<<<<<<
 *             array.resize(self.palette,256*3)
 * 
 */
  }

  /* "ttygif/tty/theme.pyx":421
 *                 self.palette[i]=color_table[i]
 * 
 *         self.auto()             # <<<<<<<<<<<<<<
 * 
 *         if 1==0:
 */
  __pyx_t_2 = ((struct __pyx_vtabstruct_6ttygif_3tty_5theme_theme *)__pyx_v_self->__pyx_vtab)->__pyx_auto(__pyx_v_self); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 421, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "ttygif/tty/theme.pyx":199
 *             self.update_layer(self.layer5)
 * 
 *     cdef init(self):             # <<<<<<<<<<<<<<
 *         cdef int a,b,c,index
 *         index=0
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("ttygif.tty.theme.theme.init", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_script_path);
  __Pyx_XDECREF(__pyx_v_path);
  __Pyx_XDECREF(__pyx_v_home);
  __Pyx_XDECREF(__pyx_v_theme_file);
  __Pyx_XDECREF(__pyx_v_theme_data);
  __Pyx_XDECREF((PyObject *)__pyx_v_theme_layer);
  __Pyx_XDECREF(__pyx_v_section);
  __Pyx_XDECREF(__pyx_v_line);
  __Pyx_XDECREF(__pyx_v_res);
  __Pyx_XDECREF(__pyx_v_key);
  __Pyx_XDECREF(__pyx_v_value);
  __Pyx_XDECREF(__pyx_v_color_table);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_TraceReturn(__pyx_r, 0);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "ttygif/tty/theme.pyx":443
 * 
 * 
 *     def get_var(self,line,var):             # <<<<<<<<<<<<<<
 *         index=line.find(var)
 *         if index>=0:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6ttygif_3tty_5theme_5theme_3get_var(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_6ttygif_3tty_5theme_5theme_3get_var = {"get_var", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6ttygif_3tty_5theme_5theme_3get_var, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6ttygif_3tty_5theme_5theme_3get_var(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_line = 0;
  PyObject *__pyx_v_var = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_var (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_line,&__pyx_n_s_var,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_line)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_var)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("get_var", 1, 2, 2, 1); __PYX_ERR(1, 443, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "get_var") < 0)) __PYX_ERR(1, 443, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_line = values[0];
    __pyx_v_var = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_var", 1, 2, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(1, 443, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("ttygif.tty.theme.theme.get_var", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6ttygif_3tty_5theme_5theme_2get_var(((struct __pyx_obj_6ttygif_3tty_5theme_theme *)__pyx_v_self), __pyx_v_line, __pyx_v_var);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6ttygif_3tty_5theme_5theme_2get_var(CYTHON_UNUSED struct __pyx_obj_6ttygif_3tty_5theme_theme *__pyx_v_self, PyObject *__pyx_v_line, PyObject *__pyx_v_var) {
  PyObject *__pyx_v_index = NULL;
  PyObject *__pyx_v_res = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_TraceDeclarations
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  Py_ssize_t __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_TraceFrameInit(__pyx_codeobj__11)
  __Pyx_RefNannySetupContext("get_var", 0);
  __Pyx_TraceCall("get_var", __pyx_f[1], 443, 0, __PYX_ERR(1, 443, __pyx_L1_error));

  /* "ttygif/tty/theme.pyx":444
 * 
 *     def get_var(self,line,var):
 *         index=line.find(var)             # <<<<<<<<<<<<<<
 *         if index>=0:
 *             res=line[index+len(var):]
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_line, __pyx_n_s_find); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 444, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  __pyx_t_1 = (__pyx_t_3) ? __Pyx_PyObject_Call2Args(__pyx_t_2, __pyx_t_3, __pyx_v_var) : __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_v_var);
  __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 444, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_index = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "ttygif/tty/theme.pyx":445
 *     def get_var(self,line,var):
 *         index=line.find(var)
 *         if index>=0:             # <<<<<<<<<<<<<<
 *             res=line[index+len(var):]
 *             res=res.strip()
 */
  __pyx_t_1 = PyObject_RichCompare(__pyx_v_index, __pyx_int_0, Py_GE); __Pyx_XGOTREF(__pyx_t_1); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 445, __pyx_L1_error)
  __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_4 < 0)) __PYX_ERR(1, 445, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_4) {

    /* "ttygif/tty/theme.pyx":446
 *         index=line.find(var)
 *         if index>=0:
 *             res=line[index+len(var):]             # <<<<<<<<<<<<<<
 *             res=res.strip()
 *             return res
 */
    __pyx_t_5 = PyObject_Length(__pyx_v_var); if (unlikely(__pyx_t_5 == ((Py_ssize_t)-1))) __PYX_ERR(1, 446, __pyx_L1_error)
    __pyx_t_1 = PyInt_FromSsize_t(__pyx_t_5); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 446, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = PyNumber_Add(__pyx_v_index, __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 446, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = __Pyx_PyObject_GetSlice(__pyx_v_line, 0, 0, &__pyx_t_2, NULL, NULL, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 446, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_v_res = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "ttygif/tty/theme.pyx":447
 *         if index>=0:
 *             res=line[index+len(var):]
 *             res=res.strip()             # <<<<<<<<<<<<<<
 *             return res
 *         return None
 */
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_res, __pyx_n_s_strip); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 447, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_3)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_3);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
      }
    }
    __pyx_t_1 = (__pyx_t_3) ? __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_3) : __Pyx_PyObject_CallNoArg(__pyx_t_2);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 447, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF_SET(__pyx_v_res, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "ttygif/tty/theme.pyx":448
 *             res=line[index+len(var):]
 *             res=res.strip()
 *             return res             # <<<<<<<<<<<<<<
 *         return None
 * 
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_v_res);
    __pyx_r = __pyx_v_res;
    goto __pyx_L0;

    /* "ttygif/tty/theme.pyx":445
 *     def get_var(self,line,var):
 *         index=line.find(var)
 *         if index>=0:             # <<<<<<<<<<<<<<
 *             res=line[index+len(var):]
 *             res=res.strip()
 */
  }

  /* "ttygif/tty/theme.pyx":449
 *             res=res.strip()
 *             return res
 *         return None             # <<<<<<<<<<<<<<
 * 
 *     def get_anyvar(self,line):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;

  /* "ttygif/tty/theme.pyx":443
 * 
 * 
 *     def get_var(self,line,var):             # <<<<<<<<<<<<<<
 *         index=line.find(var)
 *         if index>=0:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("ttygif.tty.theme.theme.get_var", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_index);
  __Pyx_XDECREF(__pyx_v_res);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_TraceReturn(__pyx_r, 0);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "ttygif/tty/theme.pyx":451
 *         return None
 * 
 *     def get_anyvar(self,line):             # <<<<<<<<<<<<<<
 *         # return if line none
 *         if line==None:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6ttygif_3tty_5theme_5theme_5get_anyvar(PyObject *__pyx_v_self, PyObject *__pyx_v_line); /*proto*/
static PyMethodDef __pyx_mdef_6ttygif_3tty_5theme_5theme_5get_anyvar = {"get_anyvar", (PyCFunction)__pyx_pw_6ttygif_3tty_5theme_5theme_5get_anyvar, METH_O, 0};
static PyObject *__pyx_pw_6ttygif_3tty_5theme_5theme_5get_anyvar(PyObject *__pyx_v_self, PyObject *__pyx_v_line) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_anyvar (wrapper)", 0);
  __pyx_r = __pyx_pf_6ttygif_3tty_5theme_5theme_4get_anyvar(((struct __pyx_obj_6ttygif_3tty_5theme_theme *)__pyx_v_self), ((PyObject *)__pyx_v_line));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6ttygif_3tty_5theme_5theme_4get_anyvar(CYTHON_UNUSED struct __pyx_obj_6ttygif_3tty_5theme_theme *__pyx_v_self, PyObject *__pyx_v_line) {
  PyObject *__pyx_v_tokens = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_TraceDeclarations
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  Py_ssize_t __pyx_t_3;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_TraceFrameInit(__pyx_codeobj__12)
  __Pyx_RefNannySetupContext("get_anyvar", 0);
  __Pyx_TraceCall("get_anyvar", __pyx_f[1], 451, 0, __PYX_ERR(1, 451, __pyx_L1_error));
  __Pyx_INCREF(__pyx_v_line);

  /* "ttygif/tty/theme.pyx":453
 *     def get_anyvar(self,line):
 *         # return if line none
 *         if line==None:             # <<<<<<<<<<<<<<
 *             return None
 *         # return on empty
 */
  __pyx_t_1 = PyObject_RichCompare(__pyx_v_line, Py_None, Py_EQ); __Pyx_XGOTREF(__pyx_t_1); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 453, __pyx_L1_error)
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(1, 453, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_2) {

    /* "ttygif/tty/theme.pyx":454
 *         # return if line none
 *         if line==None:
 *             return None             # <<<<<<<<<<<<<<
 *         # return on empty
 *         if len(line)<1: return None
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "ttygif/tty/theme.pyx":453
 *     def get_anyvar(self,line):
 *         # return if line none
 *         if line==None:             # <<<<<<<<<<<<<<
 *             return None
 *         # return on empty
 */
  }

  /* "ttygif/tty/theme.pyx":456
 *             return None
 *         # return on empty
 *         if len(line)<1: return None             # <<<<<<<<<<<<<<
 *         # return if comment
 *         if line[0]=='#': return None
 */
  __pyx_t_3 = PyObject_Length(__pyx_v_line); if (unlikely(__pyx_t_3 == ((Py_ssize_t)-1))) __PYX_ERR(1, 456, __pyx_L1_error)
  __pyx_t_2 = ((__pyx_t_3 < 1) != 0);
  if (__pyx_t_2) {
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;
  }

  /* "ttygif/tty/theme.pyx":458
 *         if len(line)<1: return None
 *         # return if comment
 *         if line[0]=='#': return None             # <<<<<<<<<<<<<<
 * 
 *         if not line: return None
 */
  __pyx_t_1 = __Pyx_GetItemInt(__pyx_v_line, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 458, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = (__Pyx_PyString_Equals(__pyx_t_1, __pyx_kp_s__13, Py_EQ)); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(1, 458, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_2) {
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;
  }

  /* "ttygif/tty/theme.pyx":460
 *         if line[0]=='#': return None
 * 
 *         if not line: return None             # <<<<<<<<<<<<<<
 * 
 *         line=" ".join(line.split() )
 */
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_v_line); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(1, 460, __pyx_L1_error)
  __pyx_t_4 = ((!__pyx_t_2) != 0);
  if (__pyx_t_4) {
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;
  }

  /* "ttygif/tty/theme.pyx":462
 *         if not line: return None
 * 
 *         line=" ".join(line.split() )             # <<<<<<<<<<<<<<
 *         tokens=line.split()
 * 
 */
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_line, __pyx_n_s_split); if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 462, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_6 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_5))) {
    __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_5);
    if (likely(__pyx_t_6)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
      __Pyx_INCREF(__pyx_t_6);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_5, function);
    }
  }
  __pyx_t_1 = (__pyx_t_6) ? __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_t_6) : __Pyx_PyObject_CallNoArg(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
  if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 462, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = __Pyx_PyString_Join(__pyx_kp_s__14, __pyx_t_1); if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 462, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF_SET(__pyx_v_line, __pyx_t_5);
  __pyx_t_5 = 0;

  /* "ttygif/tty/theme.pyx":463
 * 
 *         line=" ".join(line.split() )
 *         tokens=line.split()             # <<<<<<<<<<<<<<
 * 
 *         if   isinstance(tokens,list):
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_line, __pyx_n_s_split); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 463, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_6 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_1))) {
    __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_1);
    if (likely(__pyx_t_6)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
      __Pyx_INCREF(__pyx_t_6);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_1, function);
    }
  }
  __pyx_t_5 = (__pyx_t_6) ? __Pyx_PyObject_CallOneArg(__pyx_t_1, __pyx_t_6) : __Pyx_PyObject_CallNoArg(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
  if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 463, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_tokens = __pyx_t_5;
  __pyx_t_5 = 0;

  /* "ttygif/tty/theme.pyx":465
 *         tokens=line.split()
 * 
 *         if   isinstance(tokens,list):             # <<<<<<<<<<<<<<
 *             if   len(tokens)==1:
 *                 return {'key':tokens[0]}
 */
  __pyx_t_4 = PyList_Check(__pyx_v_tokens); 
  __pyx_t_2 = (__pyx_t_4 != 0);
  if (__pyx_t_2) {

    /* "ttygif/tty/theme.pyx":466
 * 
 *         if   isinstance(tokens,list):
 *             if   len(tokens)==1:             # <<<<<<<<<<<<<<
 *                 return {'key':tokens[0]}
 *             elif len(tokens)==2:
 */
    __pyx_t_3 = PyObject_Length(__pyx_v_tokens); if (unlikely(__pyx_t_3 == ((Py_ssize_t)-1))) __PYX_ERR(1, 466, __pyx_L1_error)
    __pyx_t_2 = ((__pyx_t_3 == 1) != 0);
    if (__pyx_t_2) {

      /* "ttygif/tty/theme.pyx":467
 *         if   isinstance(tokens,list):
 *             if   len(tokens)==1:
 *                 return {'key':tokens[0]}             # <<<<<<<<<<<<<<
 *             elif len(tokens)==2:
 *                 return {'key':tokens[0],'value':tokens[1]}
 */
      __Pyx_XDECREF(__pyx_r);
      __pyx_t_5 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 467, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_1 = __Pyx_GetItemInt(__pyx_v_tokens, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 467, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_key, __pyx_t_1) < 0) __PYX_ERR(1, 467, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_r = __pyx_t_5;
      __pyx_t_5 = 0;
      goto __pyx_L0;

      /* "ttygif/tty/theme.pyx":466
 * 
 *         if   isinstance(tokens,list):
 *             if   len(tokens)==1:             # <<<<<<<<<<<<<<
 *                 return {'key':tokens[0]}
 *             elif len(tokens)==2:
 */
    }

    /* "ttygif/tty/theme.pyx":468
 *             if   len(tokens)==1:
 *                 return {'key':tokens[0]}
 *             elif len(tokens)==2:             # <<<<<<<<<<<<<<
 *                 return {'key':tokens[0],'value':tokens[1]}
 *             elif len(tokens)>2:
 */
    __pyx_t_3 = PyObject_Length(__pyx_v_tokens); if (unlikely(__pyx_t_3 == ((Py_ssize_t)-1))) __PYX_ERR(1, 468, __pyx_L1_error)
    __pyx_t_2 = ((__pyx_t_3 == 2) != 0);
    if (__pyx_t_2) {

      /* "ttygif/tty/theme.pyx":469
 *                 return {'key':tokens[0]}
 *             elif len(tokens)==2:
 *                 return {'key':tokens[0],'value':tokens[1]}             # <<<<<<<<<<<<<<
 *             elif len(tokens)>2:
 *                 return {'key':'array','value':tokens}
 */
      __Pyx_XDECREF(__pyx_r);
      __pyx_t_5 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 469, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_1 = __Pyx_GetItemInt(__pyx_v_tokens, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 469, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_key, __pyx_t_1) < 0) __PYX_ERR(1, 469, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_1 = __Pyx_GetItemInt(__pyx_v_tokens, 1, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 469, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_value, __pyx_t_1) < 0) __PYX_ERR(1, 469, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_r = __pyx_t_5;
      __pyx_t_5 = 0;
      goto __pyx_L0;

      /* "ttygif/tty/theme.pyx":468
 *             if   len(tokens)==1:
 *                 return {'key':tokens[0]}
 *             elif len(tokens)==2:             # <<<<<<<<<<<<<<
 *                 return {'key':tokens[0],'value':tokens[1]}
 *             elif len(tokens)>2:
 */
    }

    /* "ttygif/tty/theme.pyx":470
 *             elif len(tokens)==2:
 *                 return {'key':tokens[0],'value':tokens[1]}
 *             elif len(tokens)>2:             # <<<<<<<<<<<<<<
 *                 return {'key':'array','value':tokens}
 *         elif isinstance(tokens,str):
 */
    __pyx_t_3 = PyObject_Length(__pyx_v_tokens); if (unlikely(__pyx_t_3 == ((Py_ssize_t)-1))) __PYX_ERR(1, 470, __pyx_L1_error)
    __pyx_t_2 = ((__pyx_t_3 > 2) != 0);
    if (__pyx_t_2) {

      /* "ttygif/tty/theme.pyx":471
 *                 return {'key':tokens[0],'value':tokens[1]}
 *             elif len(tokens)>2:
 *                 return {'key':'array','value':tokens}             # <<<<<<<<<<<<<<
 *         elif isinstance(tokens,str):
 *                 return {'key':tokens}
 */
      __Pyx_XDECREF(__pyx_r);
      __pyx_t_5 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 471, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_key, __pyx_n_s_array) < 0) __PYX_ERR(1, 471, __pyx_L1_error)
      if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_value, __pyx_v_tokens) < 0) __PYX_ERR(1, 471, __pyx_L1_error)
      __pyx_r = __pyx_t_5;
      __pyx_t_5 = 0;
      goto __pyx_L0;

      /* "ttygif/tty/theme.pyx":470
 *             elif len(tokens)==2:
 *                 return {'key':tokens[0],'value':tokens[1]}
 *             elif len(tokens)>2:             # <<<<<<<<<<<<<<
 *                 return {'key':'array','value':tokens}
 *         elif isinstance(tokens,str):
 */
    }

    /* "ttygif/tty/theme.pyx":465
 *         tokens=line.split()
 * 
 *         if   isinstance(tokens,list):             # <<<<<<<<<<<<<<
 *             if   len(tokens)==1:
 *                 return {'key':tokens[0]}
 */
    goto __pyx_L7;
  }

  /* "ttygif/tty/theme.pyx":472
 *             elif len(tokens)>2:
 *                 return {'key':'array','value':tokens}
 *         elif isinstance(tokens,str):             # <<<<<<<<<<<<<<
 *                 return {'key':tokens}
 *         return None
 */
  __pyx_t_2 = PyString_Check(__pyx_v_tokens); 
  __pyx_t_4 = (__pyx_t_2 != 0);
  if (__pyx_t_4) {

    /* "ttygif/tty/theme.pyx":473
 *                 return {'key':'array','value':tokens}
 *         elif isinstance(tokens,str):
 *                 return {'key':tokens}             # <<<<<<<<<<<<<<
 *         return None
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_5 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 473, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_key, __pyx_v_tokens) < 0) __PYX_ERR(1, 473, __pyx_L1_error)
    __pyx_r = __pyx_t_5;
    __pyx_t_5 = 0;
    goto __pyx_L0;

    /* "ttygif/tty/theme.pyx":472
 *             elif len(tokens)>2:
 *                 return {'key':'array','value':tokens}
 *         elif isinstance(tokens,str):             # <<<<<<<<<<<<<<
 *                 return {'key':tokens}
 *         return None
 */
  }
  __pyx_L7:;

  /* "ttygif/tty/theme.pyx":474
 *         elif isinstance(tokens,str):
 *                 return {'key':tokens}
 *         return None             # <<<<<<<<<<<<<<
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;

  /* "ttygif/tty/theme.pyx":451
 *         return None
 * 
 *     def get_anyvar(self,line):             # <<<<<<<<<<<<<<
 *         # return if line none
 *         if line==None:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("ttygif.tty.theme.theme.get_anyvar", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_tokens);
  __Pyx_XDECREF(__pyx_v_line);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_TraceReturn(__pyx_r, 0);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):
 */

/* Python wrapper */
static PyObject *__pyx_pw_6ttygif_3tty_5theme_5theme_7__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyMethodDef __pyx_mdef_6ttygif_3tty_5theme_5theme_7__reduce_cython__ = {"__reduce_cython__", (PyCFunction)__pyx_pw_6ttygif_3tty_5theme_5theme_7__reduce_cython__, METH_NOARGS, 0};
static PyObject *__pyx_pw_6ttygif_3tty_5theme_5theme_7__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
  __pyx_r = __pyx_pf_6ttygif_3tty_5theme_5theme_6__reduce_cython__(((struct __pyx_obj_6ttygif_3tty_5theme_theme *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6ttygif_3tty_5theme_5theme_6__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_6ttygif_3tty_5theme_theme *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_TraceDeclarations
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_TraceFrameInit(__pyx_codeobj__15)
  __Pyx_RefNannySetupContext("__reduce_cython__", 0);
  __Pyx_TraceCall("__reduce_cython__", __pyx_f[0], 1, 0, __PYX_ERR(0, 1, __pyx_L1_error));

  /* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 */
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_TypeError, __pyx_tuple__16, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_Raise(__pyx_t_1, 0, 0, 0);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __PYX_ERR(0, 2, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("ttygif.tty.theme.theme.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_TraceReturn(__pyx_r, 0);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 */

/* Python wrapper */
static PyObject *__pyx_pw_6ttygif_3tty_5theme_5theme_9__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state); /*proto*/
static PyMethodDef __pyx_mdef_6ttygif_3tty_5theme_5theme_9__setstate_cython__ = {"__setstate_cython__", (PyCFunction)__pyx_pw_6ttygif_3tty_5theme_5theme_9__setstate_cython__, METH_O, 0};
static PyObject *__pyx_pw_6ttygif_3tty_5theme_5theme_9__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
  __pyx_r = __pyx_pf_6ttygif_3tty_5theme_5theme_8__setstate_cython__(((struct __pyx_obj_6ttygif_3tty_5theme_theme *)__pyx_v_self), ((PyObject *)__pyx_v___pyx_state));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6ttygif_3tty_5theme_5theme_8__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_6ttygif_3tty_5theme_theme *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_TraceDeclarations
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_TraceFrameInit(__pyx_codeobj__17)
  __Pyx_RefNannySetupContext("__setstate_cython__", 0);
  __Pyx_TraceCall("__setstate_cython__", __pyx_f[0], 3, 0, __PYX_ERR(0, 3, __pyx_L1_error));

  /* "(tree fragment)":4
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")             # <<<<<<<<<<<<<<
 */
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_TypeError, __pyx_tuple__18, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_Raise(__pyx_t_1, 0, 0, 0);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __PYX_ERR(0, 4, __pyx_L1_error)

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("ttygif.tty.theme.theme.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_TraceReturn(__pyx_r, 0);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "array.pxd":93
 *             __data_union data
 * 
 *         def __getbuffer__(self, Py_buffer* info, int flags):             # <<<<<<<<<<<<<<
 *             # This implementation of getbuffer is geared towards Cython
 *             # requirements, and does not yet fulfill the PEP.
 */

/* Python wrapper */
static CYTHON_UNUSED int __pyx_pw_7cpython_5array_5array_1__getbuffer__(PyObject *__pyx_v_self, Py_buffer *__pyx_v_info, int __pyx_v_flags); /*proto*/
static CYTHON_UNUSED int __pyx_pw_7cpython_5array_5array_1__getbuffer__(PyObject *__pyx_v_self, Py_buffer *__pyx_v_info, int __pyx_v_flags) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__getbuffer__ (wrapper)", 0);
  __pyx_r = __pyx_pf_7cpython_5array_5array___getbuffer__(((arrayobject *)__pyx_v_self), ((Py_buffer *)__pyx_v_info), ((int)__pyx_v_flags));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_7cpython_5array_5array___getbuffer__(arrayobject *__pyx_v_self, Py_buffer *__pyx_v_info, CYTHON_UNUSED int __pyx_v_flags) {
  PyObject *__pyx_v_item_count = NULL;
  int __pyx_r;
  __Pyx_TraceDeclarations
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  char *__pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  Py_ssize_t __pyx_t_5;
  int __pyx_t_6;
  char __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  if (__pyx_v_info == NULL) {
    PyErr_SetString(PyExc_BufferError, "PyObject_GetBuffer: view==NULL argument is obsolete");
    return -1;
  }
  __Pyx_RefNannySetupContext("__getbuffer__", 0);
  __pyx_v_info->obj = Py_None; __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(__pyx_v_info->obj);
  __Pyx_TraceCall("__getbuffer__", __pyx_f[2], 93, 0, __PYX_ERR(2, 93, __pyx_L1_error));

  /* "array.pxd":98
 *             # In particular strided access is always provided regardless
 *             # of flags
 *             item_count = Py_SIZE(self)             # <<<<<<<<<<<<<<
 * 
 *             info.suboffsets = NULL
 */
  __pyx_t_1 = PyInt_FromSsize_t(Py_SIZE(((PyObject *)__pyx_v_self))); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 98, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_item_count = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "array.pxd":100
 *             item_count = Py_SIZE(self)
 * 
 *             info.suboffsets = NULL             # <<<<<<<<<<<<<<
 *             info.buf = self.data.as_chars
 *             info.readonly = 0
 */
  __pyx_v_info->suboffsets = NULL;

  /* "array.pxd":101
 * 
 *             info.suboffsets = NULL
 *             info.buf = self.data.as_chars             # <<<<<<<<<<<<<<
 *             info.readonly = 0
 *             info.ndim = 1
 */
  __pyx_t_2 = __pyx_v_self->data.as_chars;
  __pyx_v_info->buf = __pyx_t_2;

  /* "array.pxd":102
 *             info.suboffsets = NULL
 *             info.buf = self.data.as_chars
 *             info.readonly = 0             # <<<<<<<<<<<<<<
 *             info.ndim = 1
 *             info.itemsize = self.ob_descr.itemsize   # e.g. sizeof(float)
 */
  __pyx_v_info->readonly = 0;

  /* "array.pxd":103
 *             info.buf = self.data.as_chars
 *             info.readonly = 0
 *             info.ndim = 1             # <<<<<<<<<<<<<<
 *             info.itemsize = self.ob_descr.itemsize   # e.g. sizeof(float)
 *             info.len = info.itemsize * item_count
 */
  __pyx_v_info->ndim = 1;

  /* "array.pxd":104
 *             info.readonly = 0
 *             info.ndim = 1
 *             info.itemsize = self.ob_descr.itemsize   # e.g. sizeof(float)             # <<<<<<<<<<<<<<
 *             info.len = info.itemsize * item_count
 * 
 */
  __pyx_t_3 = __pyx_v_self->ob_descr->itemsize;
  __pyx_v_info->itemsize = __pyx_t_3;

  /* "array.pxd":105
 *             info.ndim = 1
 *             info.itemsize = self.ob_descr.itemsize   # e.g. sizeof(float)
 *             info.len = info.itemsize * item_count             # <<<<<<<<<<<<<<
 * 
 *             info.shape = <Py_ssize_t*> PyObject_Malloc(sizeof(Py_ssize_t) + 2)
 */
  __pyx_t_1 = PyInt_FromSsize_t(__pyx_v_info->itemsize); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 105, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_4 = PyNumber_Multiply(__pyx_t_1, __pyx_v_item_count); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 105, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_5 = __Pyx_PyIndex_AsSsize_t(__pyx_t_4); if (unlikely((__pyx_t_5 == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(2, 105, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_v_info->len = __pyx_t_5;

  /* "array.pxd":107
 *             info.len = info.itemsize * item_count
 * 
 *             info.shape = <Py_ssize_t*> PyObject_Malloc(sizeof(Py_ssize_t) + 2)             # <<<<<<<<<<<<<<
 *             if not info.shape:
 *                 raise MemoryError()
 */
  __pyx_v_info->shape = ((Py_ssize_t *)PyObject_Malloc(((sizeof(Py_ssize_t)) + 2)));

  /* "array.pxd":108
 * 
 *             info.shape = <Py_ssize_t*> PyObject_Malloc(sizeof(Py_ssize_t) + 2)
 *             if not info.shape:             # <<<<<<<<<<<<<<
 *                 raise MemoryError()
 *             info.shape[0] = item_count      # constant regardless of resizing
 */
  __pyx_t_6 = ((!(__pyx_v_info->shape != 0)) != 0);
  if (unlikely(__pyx_t_6)) {

    /* "array.pxd":109
 *             info.shape = <Py_ssize_t*> PyObject_Malloc(sizeof(Py_ssize_t) + 2)
 *             if not info.shape:
 *                 raise MemoryError()             # <<<<<<<<<<<<<<
 *             info.shape[0] = item_count      # constant regardless of resizing
 *             info.strides = &info.itemsize
 */
    PyErr_NoMemory(); __PYX_ERR(2, 109, __pyx_L1_error)

    /* "array.pxd":108
 * 
 *             info.shape = <Py_ssize_t*> PyObject_Malloc(sizeof(Py_ssize_t) + 2)
 *             if not info.shape:             # <<<<<<<<<<<<<<
 *                 raise MemoryError()
 *             info.shape[0] = item_count      # constant regardless of resizing
 */
  }

  /* "array.pxd":110
 *             if not info.shape:
 *                 raise MemoryError()
 *             info.shape[0] = item_count      # constant regardless of resizing             # <<<<<<<<<<<<<<
 *             info.strides = &info.itemsize
 * 
 */
  __pyx_t_5 = __Pyx_PyIndex_AsSsize_t(__pyx_v_item_count); if (unlikely((__pyx_t_5 == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(2, 110, __pyx_L1_error)
  (__pyx_v_info->shape[0]) = __pyx_t_5;

  /* "array.pxd":111
 *                 raise MemoryError()
 *             info.shape[0] = item_count      # constant regardless of resizing
 *             info.strides = &info.itemsize             # <<<<<<<<<<<<<<
 * 
 *             info.format = <char*> (info.shape + 1)
 */
  __pyx_v_info->strides = (&__pyx_v_info->itemsize);

  /* "array.pxd":113
 *             info.strides = &info.itemsize
 * 
 *             info.format = <char*> (info.shape + 1)             # <<<<<<<<<<<<<<
 *             info.format[0] = self.ob_descr.typecode
 *             info.format[1] = 0
 */
  __pyx_v_info->format = ((char *)(__pyx_v_info->shape + 1));

  /* "array.pxd":114
 * 
 *             info.format = <char*> (info.shape + 1)
 *             info.format[0] = self.ob_descr.typecode             # <<<<<<<<<<<<<<
 *             info.format[1] = 0
 *             info.obj = self
 */
  __pyx_t_7 = __pyx_v_self->ob_descr->typecode;
  (__pyx_v_info->format[0]) = __pyx_t_7;

  /* "array.pxd":115
 *             info.format = <char*> (info.shape + 1)
 *             info.format[0] = self.ob_descr.typecode
 *             info.format[1] = 0             # <<<<<<<<<<<<<<
 *             info.obj = self
 * 
 */
  (__pyx_v_info->format[1]) = 0;

  /* "array.pxd":116
 *             info.format[0] = self.ob_descr.typecode
 *             info.format[1] = 0
 *             info.obj = self             # <<<<<<<<<<<<<<
 * 
 *         def __releasebuffer__(self, Py_buffer* info):
 */
  __Pyx_INCREF(((PyObject *)__pyx_v_self));
  __Pyx_GIVEREF(((PyObject *)__pyx_v_self));
  __Pyx_GOTREF(__pyx_v_info->obj);
  __Pyx_DECREF(__pyx_v_info->obj);
  __pyx_v_info->obj = ((PyObject *)__pyx_v_self);

  /* "array.pxd":93
 *             __data_union data
 * 
 *         def __getbuffer__(self, Py_buffer* info, int flags):             # <<<<<<<<<<<<<<
 *             # This implementation of getbuffer is geared towards Cython
 *             # requirements, and does not yet fulfill the PEP.
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("cpython.array.array.__getbuffer__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  if (__pyx_v_info->obj != NULL) {
    __Pyx_GOTREF(__pyx_v_info->obj);
    __Pyx_DECREF(__pyx_v_info->obj); __pyx_v_info->obj = 0;
  }
  goto __pyx_L2;
  __pyx_L0:;
  if (__pyx_v_info->obj == Py_None) {
    __Pyx_GOTREF(__pyx_v_info->obj);
    __Pyx_DECREF(__pyx_v_info->obj); __pyx_v_info->obj = 0;
  }
  __pyx_L2:;
  __Pyx_XDECREF(__pyx_v_item_count);
  __Pyx_TraceReturn(Py_None, 0);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "array.pxd":118
 *             info.obj = self
 * 
 *         def __releasebuffer__(self, Py_buffer* info):             # <<<<<<<<<<<<<<
 *             PyObject_Free(info.shape)
 * 
 */

/* Python wrapper */
static CYTHON_UNUSED void __pyx_pw_7cpython_5array_5array_3__releasebuffer__(PyObject *__pyx_v_self, Py_buffer *__pyx_v_info); /*proto*/
static CYTHON_UNUSED void __pyx_pw_7cpython_5array_5array_3__releasebuffer__(PyObject *__pyx_v_self, Py_buffer *__pyx_v_info) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__releasebuffer__ (wrapper)", 0);
  __pyx_pf_7cpython_5array_5array_2__releasebuffer__(((arrayobject *)__pyx_v_self), ((Py_buffer *)__pyx_v_info));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
}

static void __pyx_pf_7cpython_5array_5array_2__releasebuffer__(CYTHON_UNUSED arrayobject *__pyx_v_self, Py_buffer *__pyx_v_info) {
  __Pyx_TraceDeclarations
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__releasebuffer__", 0);
  __Pyx_TraceCall("__releasebuffer__", __pyx_f[2], 118, 0, __PYX_ERR(2, 118, __pyx_L1_error));

  /* "array.pxd":119
 * 
 *         def __releasebuffer__(self, Py_buffer* info):
 *             PyObject_Free(info.shape)             # <<<<<<<<<<<<<<
 * 
 *     array newarrayobject(PyTypeObject* type, Py_ssize_t size, arraydescr *descr)
 */
  PyObject_Free(__pyx_v_info->shape);

  /* "array.pxd":118
 *             info.obj = self
 * 
 *         def __releasebuffer__(self, Py_buffer* info):             # <<<<<<<<<<<<<<
 *             PyObject_Free(info.shape)
 * 
 */

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_WriteUnraisable("cpython.array.array.__releasebuffer__", __pyx_clineno, __pyx_lineno, __pyx_filename, 1, 0);
  __pyx_L0:;
  __Pyx_TraceReturn(Py_None, 0);
  __Pyx_RefNannyFinishContext();
}

/* "array.pxd":130
 * 
 * 
 * cdef inline array clone(array template, Py_ssize_t length, bint zero):             # <<<<<<<<<<<<<<
 *     """ fast creation of a new array, given a template array.
 *     type will be same as template.
 */

static CYTHON_INLINE arrayobject *__pyx_f_7cpython_5array_clone(arrayobject *__pyx_v_template, Py_ssize_t __pyx_v_length, int __pyx_v_zero) {
  arrayobject *__pyx_v_op = 0;
  arrayobject *__pyx_r = NULL;
  __Pyx_TraceDeclarations
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  int __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("clone", 0);
  __Pyx_TraceCall("clone", __pyx_f[2], 130, 0, __PYX_ERR(2, 130, __pyx_L1_error));

  /* "array.pxd":134
 *     type will be same as template.
 *     if zero is true, new array will be initialized with zeroes."""
 *     cdef array op = newarrayobject(Py_TYPE(template), length, template.ob_descr)             # <<<<<<<<<<<<<<
 *     if zero and op is not None:
 *         memset(op.data.as_chars, 0, length * op.ob_descr.itemsize)
 */
  __pyx_t_1 = ((PyObject *)newarrayobject(Py_TYPE(((PyObject *)__pyx_v_template)), __pyx_v_length, __pyx_v_template->ob_descr)); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 134, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_op = ((arrayobject *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "array.pxd":135
 *     if zero is true, new array will be initialized with zeroes."""
 *     cdef array op = newarrayobject(Py_TYPE(template), length, template.ob_descr)
 *     if zero and op is not None:             # <<<<<<<<<<<<<<
 *         memset(op.data.as_chars, 0, length * op.ob_descr.itemsize)
 *     return op
 */
  __pyx_t_3 = (__pyx_v_zero != 0);
  if (__pyx_t_3) {
  } else {
    __pyx_t_2 = __pyx_t_3;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_3 = (((PyObject *)__pyx_v_op) != Py_None);
  __pyx_t_4 = (__pyx_t_3 != 0);
  __pyx_t_2 = __pyx_t_4;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_2) {

    /* "array.pxd":136
 *     cdef array op = newarrayobject(Py_TYPE(template), length, template.ob_descr)
 *     if zero and op is not None:
 *         memset(op.data.as_chars, 0, length * op.ob_descr.itemsize)             # <<<<<<<<<<<<<<
 *     return op
 * 
 */
    (void)(memset(__pyx_v_op->data.as_chars, 0, (__pyx_v_length * __pyx_v_op->ob_descr->itemsize)));

    /* "array.pxd":135
 *     if zero is true, new array will be initialized with zeroes."""
 *     cdef array op = newarrayobject(Py_TYPE(template), length, template.ob_descr)
 *     if zero and op is not None:             # <<<<<<<<<<<<<<
 *         memset(op.data.as_chars, 0, length * op.ob_descr.itemsize)
 *     return op
 */
  }

  /* "array.pxd":137
 *     if zero and op is not None:
 *         memset(op.data.as_chars, 0, length * op.ob_descr.itemsize)
 *     return op             # <<<<<<<<<<<<<<
 * 
 * cdef inline array copy(array self):
 */
  __Pyx_XDECREF(((PyObject *)__pyx_r));
  __Pyx_INCREF(((PyObject *)__pyx_v_op));
  __pyx_r = __pyx_v_op;
  goto __pyx_L0;

  /* "array.pxd":130
 * 
 * 
 * cdef inline array clone(array template, Py_ssize_t length, bint zero):             # <<<<<<<<<<<<<<
 *     """ fast creation of a new array, given a template array.
 *     type will be same as template.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("cpython.array.clone", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_op);
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_TraceReturn(__pyx_r, 0);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "array.pxd":139
 *     return op
 * 
 * cdef inline array copy(array self):             # <<<<<<<<<<<<<<
 *     """ make a copy of an array. """
 *     cdef array op = newarrayobject(Py_TYPE(self), Py_SIZE(self), self.ob_descr)
 */

static CYTHON_INLINE arrayobject *__pyx_f_7cpython_5array_copy(arrayobject *__pyx_v_self) {
  arrayobject *__pyx_v_op = 0;
  arrayobject *__pyx_r = NULL;
  __Pyx_TraceDeclarations
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("copy", 0);
  __Pyx_TraceCall("copy", __pyx_f[2], 139, 0, __PYX_ERR(2, 139, __pyx_L1_error));

  /* "array.pxd":141
 * cdef inline array copy(array self):
 *     """ make a copy of an array. """
 *     cdef array op = newarrayobject(Py_TYPE(self), Py_SIZE(self), self.ob_descr)             # <<<<<<<<<<<<<<
 *     memcpy(op.data.as_chars, self.data.as_chars, Py_SIZE(op) * op.ob_descr.itemsize)
 *     return op
 */
  __pyx_t_1 = ((PyObject *)newarrayobject(Py_TYPE(((PyObject *)__pyx_v_self)), Py_SIZE(((PyObject *)__pyx_v_self)), __pyx_v_self->ob_descr)); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 141, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_op = ((arrayobject *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "array.pxd":142
 *     """ make a copy of an array. """
 *     cdef array op = newarrayobject(Py_TYPE(self), Py_SIZE(self), self.ob_descr)
 *     memcpy(op.data.as_chars, self.data.as_chars, Py_SIZE(op) * op.ob_descr.itemsize)             # <<<<<<<<<<<<<<
 *     return op
 * 
 */
  (void)(memcpy(__pyx_v_op->data.as_chars, __pyx_v_self->data.as_chars, (Py_SIZE(((PyObject *)__pyx_v_op)) * __pyx_v_op->ob_descr->itemsize)));

  /* "array.pxd":143
 *     cdef array op = newarrayobject(Py_TYPE(self), Py_SIZE(self), self.ob_descr)
 *     memcpy(op.data.as_chars, self.data.as_chars, Py_SIZE(op) * op.ob_descr.itemsize)
 *     return op             # <<<<<<<<<<<<<<
 * 
 * cdef inline int extend_buffer(array self, char* stuff, Py_ssize_t n) except -1:
 */
  __Pyx_XDECREF(((PyObject *)__pyx_r));
  __Pyx_INCREF(((PyObject *)__pyx_v_op));
  __pyx_r = __pyx_v_op;
  goto __pyx_L0;

  /* "array.pxd":139
 *     return op
 * 
 * cdef inline array copy(array self):             # <<<<<<<<<<<<<<
 *     """ make a copy of an array. """
 *     cdef array op = newarrayobject(Py_TYPE(self), Py_SIZE(self), self.ob_descr)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("cpython.array.copy", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_op);
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_TraceReturn(__pyx_r, 0);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "array.pxd":145
 *     return op
 * 
 * cdef inline int extend_buffer(array self, char* stuff, Py_ssize_t n) except -1:             # <<<<<<<<<<<<<<
 *     """ efficient appending of new stuff of same type
 *     (e.g. of same array type)
 */

static CYTHON_INLINE int __pyx_f_7cpython_5array_extend_buffer(arrayobject *__pyx_v_self, char *__pyx_v_stuff, Py_ssize_t __pyx_v_n) {
  Py_ssize_t __pyx_v_itemsize;
  Py_ssize_t __pyx_v_origsize;
  int __pyx_r;
  __Pyx_TraceDeclarations
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("extend_buffer", 0);
  __Pyx_TraceCall("extend_buffer", __pyx_f[2], 145, 0, __PYX_ERR(2, 145, __pyx_L1_error));

  /* "array.pxd":149
 *     (e.g. of same array type)
 *     n: number of elements (not number of bytes!) """
 *     cdef Py_ssize_t itemsize = self.ob_descr.itemsize             # <<<<<<<<<<<<<<
 *     cdef Py_ssize_t origsize = Py_SIZE(self)
 *     resize_smart(self, origsize + n)
 */
  __pyx_t_1 = __pyx_v_self->ob_descr->itemsize;
  __pyx_v_itemsize = __pyx_t_1;

  /* "array.pxd":150
 *     n: number of elements (not number of bytes!) """
 *     cdef Py_ssize_t itemsize = self.ob_descr.itemsize
 *     cdef Py_ssize_t origsize = Py_SIZE(self)             # <<<<<<<<<<<<<<
 *     resize_smart(self, origsize + n)
 *     memcpy(self.data.as_chars + origsize * itemsize, stuff, n * itemsize)
 */
  __pyx_v_origsize = Py_SIZE(((PyObject *)__pyx_v_self));

  /* "array.pxd":151
 *     cdef Py_ssize_t itemsize = self.ob_descr.itemsize
 *     cdef Py_ssize_t origsize = Py_SIZE(self)
 *     resize_smart(self, origsize + n)             # <<<<<<<<<<<<<<
 *     memcpy(self.data.as_chars + origsize * itemsize, stuff, n * itemsize)
 *     return 0
 */
  __pyx_t_1 = resize_smart(__pyx_v_self, (__pyx_v_origsize + __pyx_v_n)); if (unlikely(__pyx_t_1 == ((int)-1))) __PYX_ERR(2, 151, __pyx_L1_error)

  /* "array.pxd":152
 *     cdef Py_ssize_t origsize = Py_SIZE(self)
 *     resize_smart(self, origsize + n)
 *     memcpy(self.data.as_chars + origsize * itemsize, stuff, n * itemsize)             # <<<<<<<<<<<<<<
 *     return 0
 * 
 */
  (void)(memcpy((__pyx_v_self->data.as_chars + (__pyx_v_origsize * __pyx_v_itemsize)), __pyx_v_stuff, (__pyx_v_n * __pyx_v_itemsize)));

  /* "array.pxd":153
 *     resize_smart(self, origsize + n)
 *     memcpy(self.data.as_chars + origsize * itemsize, stuff, n * itemsize)
 *     return 0             # <<<<<<<<<<<<<<
 * 
 * cdef inline int extend(array self, array other) except -1:
 */
  __pyx_r = 0;
  goto __pyx_L0;

  /* "array.pxd":145
 *     return op
 * 
 * cdef inline int extend_buffer(array self, char* stuff, Py_ssize_t n) except -1:             # <<<<<<<<<<<<<<
 *     """ efficient appending of new stuff of same type
 *     (e.g. of same array type)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("cpython.array.extend_buffer", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_TraceReturn(Py_None, 0);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "array.pxd":155
 *     return 0
 * 
 * cdef inline int extend(array self, array other) except -1:             # <<<<<<<<<<<<<<
 *     """ extend array with data from another array; types must match. """
 *     if self.ob_descr.typecode != other.ob_descr.typecode:
 */

static CYTHON_INLINE int __pyx_f_7cpython_5array_extend(arrayobject *__pyx_v_self, arrayobject *__pyx_v_other) {
  int __pyx_r;
  __Pyx_TraceDeclarations
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("extend", 0);
  __Pyx_TraceCall("extend", __pyx_f[2], 155, 0, __PYX_ERR(2, 155, __pyx_L1_error));

  /* "array.pxd":157
 * cdef inline int extend(array self, array other) except -1:
 *     """ extend array with data from another array; types must match. """
 *     if self.ob_descr.typecode != other.ob_descr.typecode:             # <<<<<<<<<<<<<<
 *         PyErr_BadArgument()
 *     return extend_buffer(self, other.data.as_chars, Py_SIZE(other))
 */
  __pyx_t_1 = ((__pyx_v_self->ob_descr->typecode != __pyx_v_other->ob_descr->typecode) != 0);
  if (__pyx_t_1) {

    /* "array.pxd":158
 *     """ extend array with data from another array; types must match. """
 *     if self.ob_descr.typecode != other.ob_descr.typecode:
 *         PyErr_BadArgument()             # <<<<<<<<<<<<<<
 *     return extend_buffer(self, other.data.as_chars, Py_SIZE(other))
 * 
 */
    __pyx_t_2 = PyErr_BadArgument(); if (unlikely(__pyx_t_2 == ((int)0))) __PYX_ERR(2, 158, __pyx_L1_error)

    /* "array.pxd":157
 * cdef inline int extend(array self, array other) except -1:
 *     """ extend array with data from another array; types must match. """
 *     if self.ob_descr.typecode != other.ob_descr.typecode:             # <<<<<<<<<<<<<<
 *         PyErr_BadArgument()
 *     return extend_buffer(self, other.data.as_chars, Py_SIZE(other))
 */
  }

  /* "array.pxd":159
 *     if self.ob_descr.typecode != other.ob_descr.typecode:
 *         PyErr_BadArgument()
 *     return extend_buffer(self, other.data.as_chars, Py_SIZE(other))             # <<<<<<<<<<<<<<
 * 
 * cdef inline void zero(array self):
 */
  __pyx_t_2 = __pyx_f_7cpython_5array_extend_buffer(__pyx_v_self, __pyx_v_other->data.as_chars, Py_SIZE(((PyObject *)__pyx_v_other))); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(2, 159, __pyx_L1_error)
  __pyx_r = __pyx_t_2;
  goto __pyx_L0;

  /* "array.pxd":155
 *     return 0
 * 
 * cdef inline int extend(array self, array other) except -1:             # <<<<<<<<<<<<<<
 *     """ extend array with data from another array; types must match. """
 *     if self.ob_descr.typecode != other.ob_descr.typecode:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("cpython.array.extend", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_TraceReturn(Py_None, 0);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "array.pxd":161
 *     return extend_buffer(self, other.data.as_chars, Py_SIZE(other))
 * 
 * cdef inline void zero(array self):             # <<<<<<<<<<<<<<
 *     """ set all elements of array to zero. """
 *     memset(self.data.as_chars, 0, Py_SIZE(self) * self.ob_descr.itemsize)
 */

static CYTHON_INLINE void __pyx_f_7cpython_5array_zero(arrayobject *__pyx_v_self) {
  __Pyx_TraceDeclarations
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("zero", 0);
  __Pyx_TraceCall("zero", __pyx_f[2], 161, 0, __PYX_ERR(2, 161, __pyx_L1_error));

  /* "array.pxd":163
 * cdef inline void zero(array self):
 *     """ set all elements of array to zero. """
 *     memset(self.data.as_chars, 0, Py_SIZE(self) * self.ob_descr.itemsize)             # <<<<<<<<<<<<<<
 */
  (void)(memset(__pyx_v_self->data.as_chars, 0, (Py_SIZE(((PyObject *)__pyx_v_self)) * __pyx_v_self->ob_descr->itemsize)));

  /* "array.pxd":161
 *     return extend_buffer(self, other.data.as_chars, Py_SIZE(other))
 * 
 * cdef inline void zero(array self):             # <<<<<<<<<<<<<<
 *     """ set all elements of array to zero. """
 *     memset(self.data.as_chars, 0, Py_SIZE(self) * self.ob_descr.itemsize)
 */

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_WriteUnraisable("cpython.array.zero", __pyx_clineno, __pyx_lineno, __pyx_filename, 1, 0);
  __pyx_L0:;
  __Pyx_TraceReturn(Py_None, 0);
  __Pyx_RefNannyFinishContext();
}
static struct __pyx_vtabstruct_6ttygif_3tty_5theme_layer __pyx_vtable_6ttygif_3tty_5theme_layer;

static PyObject *__pyx_tp_new_6ttygif_3tty_5theme_layer(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  struct __pyx_obj_6ttygif_3tty_5theme_layer *p;
  PyObject *o;
  if (likely((t->tp_flags & Py_TPFLAGS_IS_ABSTRACT) == 0)) {
    o = (*t->tp_alloc)(t, 0);
  } else {
    o = (PyObject *) PyBaseObject_Type.tp_new(t, __pyx_empty_tuple, 0);
  }
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_6ttygif_3tty_5theme_layer *)o);
  p->__pyx_vtab = __pyx_vtabptr_6ttygif_3tty_5theme_layer;
  p->file = ((PyObject*)Py_None); Py_INCREF(Py_None);
  p->path = ((PyObject*)Py_None); Py_INCREF(Py_None);
  p->mode = ((PyObject*)Py_None); Py_INCREF(Py_None);
  p->name = ((PyObject*)Py_None); Py_INCREF(Py_None);
  p->outer = ((struct __pyx_obj_6ttygif_3tty_5image_rect *)Py_None); Py_INCREF(Py_None);
  p->inner = ((struct __pyx_obj_6ttygif_3tty_5image_rect *)Py_None); Py_INCREF(Py_None);
  p->bounds = ((struct __pyx_obj_6ttygif_3tty_5image_rect *)Py_None); Py_INCREF(Py_None);
  p->dst = ((struct __pyx_obj_6ttygif_3tty_5image_rect *)Py_None); Py_INCREF(Py_None);
  p->center = ((PyObject*)Py_None); Py_INCREF(Py_None);
  p->copy_mode = ((PyObject*)Py_None); Py_INCREF(Py_None);
  p->image = ((struct __pyx_obj_6ttygif_3tty_5image_image *)Py_None); Py_INCREF(Py_None);
  if (unlikely(__pyx_pw_6ttygif_3tty_5theme_5layer_1__cinit__(o, __pyx_empty_tuple, NULL) < 0)) goto bad;
  return o;
  bad:
  Py_DECREF(o); o = 0;
  return NULL;
}

static void __pyx_tp_dealloc_6ttygif_3tty_5theme_layer(PyObject *o) {
  struct __pyx_obj_6ttygif_3tty_5theme_layer *p = (struct __pyx_obj_6ttygif_3tty_5theme_layer *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely(PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE) && Py_TYPE(o)->tp_finalize) && !_PyGC_FINALIZED(o)) {
    if (PyObject_CallFinalizerFromDealloc(o)) return;
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->file);
  Py_CLEAR(p->path);
  Py_CLEAR(p->mode);
  Py_CLEAR(p->name);
  Py_CLEAR(p->outer);
  Py_CLEAR(p->inner);
  Py_CLEAR(p->bounds);
  Py_CLEAR(p->dst);
  Py_CLEAR(p->center);
  Py_CLEAR(p->copy_mode);
  Py_CLEAR(p->image);
  (*Py_TYPE(o)->tp_free)(o);
}

static int __pyx_tp_traverse_6ttygif_3tty_5theme_layer(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_6ttygif_3tty_5theme_layer *p = (struct __pyx_obj_6ttygif_3tty_5theme_layer *)o;
  if (p->outer) {
    e = (*v)(((PyObject *)p->outer), a); if (e) return e;
  }
  if (p->inner) {
    e = (*v)(((PyObject *)p->inner), a); if (e) return e;
  }
  if (p->bounds) {
    e = (*v)(((PyObject *)p->bounds), a); if (e) return e;
  }
  if (p->dst) {
    e = (*v)(((PyObject *)p->dst), a); if (e) return e;
  }
  if (p->image) {
    e = (*v)(((PyObject *)p->image), a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_6ttygif_3tty_5theme_layer(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_6ttygif_3tty_5theme_layer *p = (struct __pyx_obj_6ttygif_3tty_5theme_layer *)o;
  tmp = ((PyObject*)p->outer);
  p->outer = ((struct __pyx_obj_6ttygif_3tty_5image_rect *)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->inner);
  p->inner = ((struct __pyx_obj_6ttygif_3tty_5image_rect *)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->bounds);
  p->bounds = ((struct __pyx_obj_6ttygif_3tty_5image_rect *)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->dst);
  p->dst = ((struct __pyx_obj_6ttygif_3tty_5image_rect *)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->image);
  p->image = ((struct __pyx_obj_6ttygif_3tty_5image_image *)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyMethodDef __pyx_methods_6ttygif_3tty_5theme_layer[] = {
  {"__reduce_cython__", (PyCFunction)__pyx_pw_6ttygif_3tty_5theme_5layer_3__reduce_cython__, METH_NOARGS, 0},
  {"__setstate_cython__", (PyCFunction)__pyx_pw_6ttygif_3tty_5theme_5layer_5__setstate_cython__, METH_O, 0},
  {0, 0, 0, 0}
};

static PyTypeObject __pyx_type_6ttygif_3tty_5theme_layer = {
  PyVarObject_HEAD_INIT(0, 0)
  "ttygif.tty.theme.layer", /*tp_name*/
  sizeof(struct __pyx_obj_6ttygif_3tty_5theme_layer), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6ttygif_3tty_5theme_layer, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_6ttygif_3tty_5theme_layer, /*tp_traverse*/
  __pyx_tp_clear_6ttygif_3tty_5theme_layer, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_6ttygif_3tty_5theme_layer, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_6ttygif_3tty_5theme_layer, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4 && PY_VERSION_HEX < 0x03090000
  0, /*tp_print*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000
  0, /*tp_pypy_flags*/
  #endif
};
static struct __pyx_vtabstruct_6ttygif_3tty_5theme_theme __pyx_vtable_6ttygif_3tty_5theme_theme;

static PyObject *__pyx_tp_new_6ttygif_3tty_5theme_theme(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_6ttygif_3tty_5theme_theme *p;
  PyObject *o;
  if (likely((t->tp_flags & Py_TPFLAGS_IS_ABSTRACT) == 0)) {
    o = (*t->tp_alloc)(t, 0);
  } else {
    o = (PyObject *) PyBaseObject_Type.tp_new(t, __pyx_empty_tuple, 0);
  }
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_6ttygif_3tty_5theme_theme *)o);
  p->__pyx_vtab = __pyx_vtabptr_6ttygif_3tty_5theme_theme;
  p->name = ((PyObject*)Py_None); Py_INCREF(Py_None);
  p->path = ((PyObject*)Py_None); Py_INCREF(Py_None);
  p->font = ((PyObject*)Py_None); Py_INCREF(Py_None);
  p->palette = ((arrayobject *)Py_None); Py_INCREF(Py_None);
  p->padding = ((struct __pyx_obj_6ttygif_3tty_5image_rect *)Py_None); Py_INCREF(Py_None);
  p->layer1 = ((struct __pyx_obj_6ttygif_3tty_5theme_layer *)Py_None); Py_INCREF(Py_None);
  p->layer2 = ((struct __pyx_obj_6ttygif_3tty_5theme_layer *)Py_None); Py_INCREF(Py_None);
  p->layer3 = ((struct __pyx_obj_6ttygif_3tty_5theme_layer *)Py_None); Py_INCREF(Py_None);
  p->layer4 = ((struct __pyx_obj_6ttygif_3tty_5theme_layer *)Py_None); Py_INCREF(Py_None);
  p->layer5 = ((struct __pyx_obj_6ttygif_3tty_5theme_layer *)Py_None); Py_INCREF(Py_None);
  if (unlikely(__pyx_pw_6ttygif_3tty_5theme_5theme_1__cinit__(o, a, k) < 0)) goto bad;
  return o;
  bad:
  Py_DECREF(o); o = 0;
  return NULL;
}

static void __pyx_tp_dealloc_6ttygif_3tty_5theme_theme(PyObject *o) {
  struct __pyx_obj_6ttygif_3tty_5theme_theme *p = (struct __pyx_obj_6ttygif_3tty_5theme_theme *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely(PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE) && Py_TYPE(o)->tp_finalize) && !_PyGC_FINALIZED(o)) {
    if (PyObject_CallFinalizerFromDealloc(o)) return;
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->name);
  Py_CLEAR(p->path);
  Py_CLEAR(p->font);
  Py_CLEAR(p->palette);
  Py_CLEAR(p->padding);
  Py_CLEAR(p->layer1);
  Py_CLEAR(p->layer2);
  Py_CLEAR(p->layer3);
  Py_CLEAR(p->layer4);
  Py_CLEAR(p->layer5);
  (*Py_TYPE(o)->tp_free)(o);
}

static int __pyx_tp_traverse_6ttygif_3tty_5theme_theme(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_6ttygif_3tty_5theme_theme *p = (struct __pyx_obj_6ttygif_3tty_5theme_theme *)o;
  if (p->palette) {
    e = (*v)(((PyObject *)p->palette), a); if (e) return e;
  }
  if (p->padding) {
    e = (*v)(((PyObject *)p->padding), a); if (e) return e;
  }
  if (p->layer1) {
    e = (*v)(((PyObject *)p->layer1), a); if (e) return e;
  }
  if (p->layer2) {
    e = (*v)(((PyObject *)p->layer2), a); if (e) return e;
  }
  if (p->layer3) {
    e = (*v)(((PyObject *)p->layer3), a); if (e) return e;
  }
  if (p->layer4) {
    e = (*v)(((PyObject *)p->layer4), a); if (e) return e;
  }
  if (p->layer5) {
    e = (*v)(((PyObject *)p->layer5), a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_6ttygif_3tty_5theme_theme(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_6ttygif_3tty_5theme_theme *p = (struct __pyx_obj_6ttygif_3tty_5theme_theme *)o;
  tmp = ((PyObject*)p->palette);
  p->palette = ((arrayobject *)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->padding);
  p->padding = ((struct __pyx_obj_6ttygif_3tty_5image_rect *)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->layer1);
  p->layer1 = ((struct __pyx_obj_6ttygif_3tty_5theme_layer *)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->layer2);
  p->layer2 = ((struct __pyx_obj_6ttygif_3tty_5theme_layer *)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->layer3);
  p->layer3 = ((struct __pyx_obj_6ttygif_3tty_5theme_layer *)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->layer4);
  p->layer4 = ((struct __pyx_obj_6ttygif_3tty_5theme_layer *)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->layer5);
  p->layer5 = ((struct __pyx_obj_6ttygif_3tty_5theme_layer *)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyMethodDef __pyx_methods_6ttygif_3tty_5theme_theme[] = {
  {"get_var", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6ttygif_3tty_5theme_5theme_3get_var, METH_VARARGS|METH_KEYWORDS, 0},
  {"get_anyvar", (PyCFunction)__pyx_pw_6ttygif_3tty_5theme_5theme_5get_anyvar, METH_O, 0},
  {"__reduce_cython__", (PyCFunction)__pyx_pw_6ttygif_3tty_5theme_5theme_7__reduce_cython__, METH_NOARGS, 0},
  {"__setstate_cython__", (PyCFunction)__pyx_pw_6ttygif_3tty_5theme_5theme_9__setstate_cython__, METH_O, 0},
  {0, 0, 0, 0}
};

static PyTypeObject __pyx_type_6ttygif_3tty_5theme_theme = {
  PyVarObject_HEAD_INIT(0, 0)
  "ttygif.tty.theme.theme", /*tp_name*/
  sizeof(struct __pyx_obj_6ttygif_3tty_5theme_theme), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6ttygif_3tty_5theme_theme, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_6ttygif_3tty_5theme_theme, /*tp_traverse*/
  __pyx_tp_clear_6ttygif_3tty_5theme_theme, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_6ttygif_3tty_5theme_theme, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_6ttygif_3tty_5theme_theme, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4 && PY_VERSION_HEX < 0x03090000
  0, /*tp_print*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000
  0, /*tp_pypy_flags*/
  #endif
};

static PyMethodDef __pyx_methods[] = {
  {0, 0, 0, 0}
};

#if PY_MAJOR_VERSION >= 3
#if CYTHON_PEP489_MULTI_PHASE_INIT
static PyObject* __pyx_pymod_create(PyObject *spec, PyModuleDef *def); /*proto*/
static int __pyx_pymod_exec_theme(PyObject* module); /*proto*/
static PyModuleDef_Slot __pyx_moduledef_slots[] = {
  {Py_mod_create, (void*)__pyx_pymod_create},
  {Py_mod_exec, (void*)__pyx_pymod_exec_theme},
  {0, NULL}
};
#endif

static struct PyModuleDef __pyx_moduledef = {
    PyModuleDef_HEAD_INIT,
    "theme",
    0, /* m_doc */
  #if CYTHON_PEP489_MULTI_PHASE_INIT
    0, /* m_size */
  #else
    -1, /* m_size */
  #endif
    __pyx_methods /* m_methods */,
  #if CYTHON_PEP489_MULTI_PHASE_INIT
    __pyx_moduledef_slots, /* m_slots */
  #else
    NULL, /* m_reload */
  #endif
    NULL, /* m_traverse */
    NULL, /* m_clear */
    NULL /* m_free */
};
#endif
#ifndef CYTHON_SMALL_CODE
#if defined(__clang__)
    #define CYTHON_SMALL_CODE
#elif defined(__GNUC__) && (__GNUC__ > 4 || (__GNUC__ == 4 && __GNUC_MINOR__ >= 3))
    #define CYTHON_SMALL_CODE __attribute__((cold))
#else
    #define CYTHON_SMALL_CODE
#endif
#endif

static __Pyx_StringTabEntry __pyx_string_tab[] = {
  {&__pyx_kp_s_, __pyx_k_, sizeof(__pyx_k_), 0, 0, 1, 0},
  {&__pyx_kp_s_1, __pyx_k_1, sizeof(__pyx_k_1), 0, 0, 1, 0},
  {&__pyx_n_s_B, __pyx_k_B, sizeof(__pyx_k_B), 0, 0, 1, 1},
  {&__pyx_kp_s_Bounds, __pyx_k_Bounds, sizeof(__pyx_k_Bounds), 0, 0, 1, 0},
  {&__pyx_n_s_ColorIndex, __pyx_k_ColorIndex, sizeof(__pyx_k_ColorIndex), 0, 0, 1, 1},
  {&__pyx_kp_s_Dst, __pyx_k_Dst, sizeof(__pyx_k_Dst), 0, 0, 1, 0},
  {&__pyx_n_s_Height, __pyx_k_Height, sizeof(__pyx_k_Height), 0, 0, 1, 1},
  {&__pyx_kp_s_Inner, __pyx_k_Inner, sizeof(__pyx_k_Inner), 0, 0, 1, 0},
  {&__pyx_kp_s_Invalid_image_file_0, __pyx_k_Invalid_image_file_0, sizeof(__pyx_k_Invalid_image_file_0), 0, 0, 1, 0},
  {&__pyx_kp_s_Invalid_theme_file, __pyx_k_Invalid_theme_file, sizeof(__pyx_k_Invalid_theme_file), 0, 0, 1, 0},
  {&__pyx_n_s_Layer, __pyx_k_Layer, sizeof(__pyx_k_Layer), 0, 0, 1, 1},
  {&__pyx_n_s_MemoryError, __pyx_k_MemoryError, sizeof(__pyx_k_MemoryError), 0, 0, 1, 1},
  {&__pyx_kp_s_Outer, __pyx_k_Outer, sizeof(__pyx_k_Outer), 0, 0, 1, 0},
  {&__pyx_n_s_ScreenHeight, __pyx_k_ScreenHeight, sizeof(__pyx_k_ScreenHeight), 0, 0, 1, 1},
  {&__pyx_n_s_ScreenWidth, __pyx_k_ScreenWidth, sizeof(__pyx_k_ScreenWidth), 0, 0, 1, 1},
  {&__pyx_n_s_TransparentColorFlag, __pyx_k_TransparentColorFlag, sizeof(__pyx_k_TransparentColorFlag), 0, 0, 1, 1},
  {&__pyx_n_s_TypeError, __pyx_k_TypeError, sizeof(__pyx_k_TypeError), 0, 0, 1, 1},
  {&__pyx_n_s_Width, __pyx_k_Width, sizeof(__pyx_k_Width), 0, 0, 1, 1},
  {&__pyx_kp_s__13, __pyx_k__13, sizeof(__pyx_k__13), 0, 0, 1, 0},
  {&__pyx_kp_s__14, __pyx_k__14, sizeof(__pyx_k__14), 0, 0, 1, 0},
  {&__pyx_kp_s__9, __pyx_k__9, sizeof(__pyx_k__9), 0, 0, 1, 0},
  {&__pyx_n_s_abspath, __pyx_k_abspath, sizeof(__pyx_k_abspath), 0, 0, 1, 1},
  {&__pyx_n_s_array, __pyx_k_array, sizeof(__pyx_k_array), 0, 0, 1, 1},
  {&__pyx_n_s_auto, __pyx_k_auto, sizeof(__pyx_k_auto), 0, 0, 1, 1},
  {&__pyx_n_s_background, __pyx_k_background, sizeof(__pyx_k_background), 0, 0, 1, 1},
  {&__pyx_n_s_bottom, __pyx_k_bottom, sizeof(__pyx_k_bottom), 0, 0, 1, 1},
  {&__pyx_n_s_center, __pyx_k_center, sizeof(__pyx_k_center), 0, 0, 1, 1},
  {&__pyx_n_s_cline_in_traceback, __pyx_k_cline_in_traceback, sizeof(__pyx_k_cline_in_traceback), 0, 0, 1, 1},
  {&__pyx_n_s_colors, __pyx_k_colors, sizeof(__pyx_k_colors), 0, 0, 1, 1},
  {&__pyx_kp_s_copy_mode, __pyx_k_copy_mode, sizeof(__pyx_k_copy_mode), 0, 0, 1, 0},
  {&__pyx_kp_s_copy_mode_0, __pyx_k_copy_mode_0, sizeof(__pyx_k_copy_mode_0), 0, 0, 1, 0},
  {&__pyx_n_s_data, __pyx_k_data, sizeof(__pyx_k_data), 0, 0, 1, 1},
  {&__pyx_n_s_decode, __pyx_k_decode, sizeof(__pyx_k_decode), 0, 0, 1, 1},
  {&__pyx_n_s_default_background, __pyx_k_default_background, sizeof(__pyx_k_default_background), 0, 0, 1, 1},
  {&__pyx_n_s_default_foreground, __pyx_k_default_foreground, sizeof(__pyx_k_default_foreground), 0, 0, 1, 1},
  {&__pyx_n_s_depth, __pyx_k_depth, sizeof(__pyx_k_depth), 0, 0, 1, 1},
  {&__pyx_n_s_descriptor, __pyx_k_descriptor, sizeof(__pyx_k_descriptor), 0, 0, 1, 1},
  {&__pyx_n_s_dirname, __pyx_k_dirname, sizeof(__pyx_k_dirname), 0, 0, 1, 1},
  {&__pyx_kp_s_dst_bottom, __pyx_k_dst_bottom, sizeof(__pyx_k_dst_bottom), 0, 0, 1, 0},
  {&__pyx_kp_s_dst_left, __pyx_k_dst_left, sizeof(__pyx_k_dst_left), 0, 0, 1, 0},
  {&__pyx_kp_s_dst_right, __pyx_k_dst_right, sizeof(__pyx_k_dst_right), 0, 0, 1, 0},
  {&__pyx_kp_s_dst_top, __pyx_k_dst_top, sizeof(__pyx_k_dst_top), 0, 0, 1, 0},
  {&__pyx_n_s_end, __pyx_k_end, sizeof(__pyx_k_end), 0, 0, 1, 1},
  {&__pyx_n_s_exists, __pyx_k_exists, sizeof(__pyx_k_exists), 0, 0, 1, 1},
  {&__pyx_n_s_expanduser, __pyx_k_expanduser, sizeof(__pyx_k_expanduser), 0, 0, 1, 1},
  {&__pyx_n_s_file, __pyx_k_file, sizeof(__pyx_k_file), 0, 0, 1, 1},
  {&__pyx_kp_s_file_0, __pyx_k_file_0, sizeof(__pyx_k_file_0), 0, 0, 1, 0},
  {&__pyx_n_s_file_2, __pyx_k_file_2, sizeof(__pyx_k_file_2), 0, 0, 1, 1},
  {&__pyx_n_s_find, __pyx_k_find, sizeof(__pyx_k_find), 0, 0, 1, 1},
  {&__pyx_n_s_font, __pyx_k_font, sizeof(__pyx_k_font), 0, 0, 1, 1},
  {&__pyx_n_s_font_size, __pyx_k_font_size, sizeof(__pyx_k_font_size), 0, 0, 1, 1},
  {&__pyx_n_s_foreground, __pyx_k_foreground, sizeof(__pyx_k_foreground), 0, 0, 1, 1},
  {&__pyx_n_s_format, __pyx_k_format, sizeof(__pyx_k_format), 0, 0, 1, 1},
  {&__pyx_n_s_frames, __pyx_k_frames, sizeof(__pyx_k_frames), 0, 0, 1, 1},
  {&__pyx_n_s_gc, __pyx_k_gc, sizeof(__pyx_k_gc), 0, 0, 1, 1},
  {&__pyx_n_s_get, __pyx_k_get, sizeof(__pyx_k_get), 0, 0, 1, 1},
  {&__pyx_n_s_get_anyvar, __pyx_k_get_anyvar, sizeof(__pyx_k_get_anyvar), 0, 0, 1, 1},
  {&__pyx_n_s_get_var, __pyx_k_get_var, sizeof(__pyx_k_get_var), 0, 0, 1, 1},
  {&__pyx_n_s_getstate, __pyx_k_getstate, sizeof(__pyx_k_getstate), 0, 0, 1, 1},
  {&__pyx_n_s_gif_decode, __pyx_k_gif_decode, sizeof(__pyx_k_gif_decode), 0, 0, 1, 1},
  {&__pyx_n_s_global_color_table, __pyx_k_global_color_table, sizeof(__pyx_k_global_color_table), 0, 0, 1, 1},
  {&__pyx_n_s_header, __pyx_k_header, sizeof(__pyx_k_header), 0, 0, 1, 1},
  {&__pyx_n_s_height, __pyx_k_height, sizeof(__pyx_k_height), 0, 0, 1, 1},
  {&__pyx_n_s_image, __pyx_k_image, sizeof(__pyx_k_image), 0, 0, 1, 1},
  {&__pyx_n_s_import, __pyx_k_import, sizeof(__pyx_k_import), 0, 0, 1, 1},
  {&__pyx_n_s_index, __pyx_k_index, sizeof(__pyx_k_index), 0, 0, 1, 1},
  {&__pyx_kp_s_inner_bottom, __pyx_k_inner_bottom, sizeof(__pyx_k_inner_bottom), 0, 0, 1, 0},
  {&__pyx_kp_s_inner_left, __pyx_k_inner_left, sizeof(__pyx_k_inner_left), 0, 0, 1, 0},
  {&__pyx_kp_s_inner_right, __pyx_k_inner_right, sizeof(__pyx_k_inner_right), 0, 0, 1, 0},
  {&__pyx_kp_s_inner_top, __pyx_k_inner_top, sizeof(__pyx_k_inner_top), 0, 0, 1, 0},
  {&__pyx_n_s_isdir, __pyx_k_isdir, sizeof(__pyx_k_isdir), 0, 0, 1, 1},
  {&__pyx_n_s_join, __pyx_k_join, sizeof(__pyx_k_join), 0, 0, 1, 1},
  {&__pyx_n_s_key, __pyx_k_key, sizeof(__pyx_k_key), 0, 0, 1, 1},
  {&__pyx_n_s_layer, __pyx_k_layer, sizeof(__pyx_k_layer), 0, 0, 1, 1},
  {&__pyx_n_s_layer1, __pyx_k_layer1, sizeof(__pyx_k_layer1), 0, 0, 1, 1},
  {&__pyx_n_s_layer2, __pyx_k_layer2, sizeof(__pyx_k_layer2), 0, 0, 1, 1},
  {&__pyx_n_s_layer3, __pyx_k_layer3, sizeof(__pyx_k_layer3), 0, 0, 1, 1},
  {&__pyx_n_s_layer4, __pyx_k_layer4, sizeof(__pyx_k_layer4), 0, 0, 1, 1},
  {&__pyx_n_s_layer5, __pyx_k_layer5, sizeof(__pyx_k_layer5), 0, 0, 1, 1},
  {&__pyx_n_s_layer___reduce_cython, __pyx_k_layer___reduce_cython, sizeof(__pyx_k_layer___reduce_cython), 0, 0, 1, 1},
  {&__pyx_n_s_layer___setstate_cython, __pyx_k_layer___setstate_cython, sizeof(__pyx_k_layer___setstate_cython), 0, 0, 1, 1},
  {&__pyx_n_s_layers, __pyx_k_layers, sizeof(__pyx_k_layers), 0, 0, 1, 1},
  {&__pyx_n_s_left, __pyx_k_left, sizeof(__pyx_k_left), 0, 0, 1, 1},
  {&__pyx_n_s_line, __pyx_k_line, sizeof(__pyx_k_line), 0, 0, 1, 1},
  {&__pyx_n_s_main, __pyx_k_main, sizeof(__pyx_k_main), 0, 0, 1, 1},
  {&__pyx_n_s_mode, __pyx_k_mode, sizeof(__pyx_k_mode), 0, 0, 1, 1},
  {&__pyx_kp_s_mode_0, __pyx_k_mode_0, sizeof(__pyx_k_mode_0), 0, 0, 1, 0},
  {&__pyx_n_s_name, __pyx_k_name, sizeof(__pyx_k_name), 0, 0, 1, 1},
  {&__pyx_kp_s_name_0, __pyx_k_name_0, sizeof(__pyx_k_name_0), 0, 0, 1, 0},
  {&__pyx_n_s_name_2, __pyx_k_name_2, sizeof(__pyx_k_name_2), 0, 0, 1, 1},
  {&__pyx_kp_s_no_default___reduce___due_to_non, __pyx_k_no_default___reduce___due_to_non, sizeof(__pyx_k_no_default___reduce___due_to_non), 0, 0, 1, 0},
  {&__pyx_n_s_open, __pyx_k_open, sizeof(__pyx_k_open), 0, 0, 1, 1},
  {&__pyx_n_s_os, __pyx_k_os, sizeof(__pyx_k_os), 0, 0, 1, 1},
  {&__pyx_n_s_os_path, __pyx_k_os_path, sizeof(__pyx_k_os_path), 0, 0, 1, 1},
  {&__pyx_kp_s_outer_bottom, __pyx_k_outer_bottom, sizeof(__pyx_k_outer_bottom), 0, 0, 1, 0},
  {&__pyx_kp_s_outer_left, __pyx_k_outer_left, sizeof(__pyx_k_outer_left), 0, 0, 1, 0},
  {&__pyx_kp_s_outer_right, __pyx_k_outer_right, sizeof(__pyx_k_outer_right), 0, 0, 1, 0},
  {&__pyx_kp_s_outer_top, __pyx_k_outer_top, sizeof(__pyx_k_outer_top), 0, 0, 1, 0},
  {&__pyx_n_s_padding, __pyx_k_padding, sizeof(__pyx_k_padding), 0, 0, 1, 1},
  {&__pyx_n_s_palette, __pyx_k_palette, sizeof(__pyx_k_palette), 0, 0, 1, 1},
  {&__pyx_n_s_path, __pyx_k_path, sizeof(__pyx_k_path), 0, 0, 1, 1},
  {&__pyx_n_s_print, __pyx_k_print, sizeof(__pyx_k_print), 0, 0, 1, 1},
  {&__pyx_n_s_pyx_state, __pyx_k_pyx_state, sizeof(__pyx_k_pyx_state), 0, 0, 1, 1},
  {&__pyx_n_s_pyx_vtable, __pyx_k_pyx_vtable, sizeof(__pyx_k_pyx_vtable), 0, 0, 1, 1},
  {&__pyx_n_s_range, __pyx_k_range, sizeof(__pyx_k_range), 0, 0, 1, 1},
  {&__pyx_n_s_readlines, __pyx_k_readlines, sizeof(__pyx_k_readlines), 0, 0, 1, 1},
  {&__pyx_n_s_reduce, __pyx_k_reduce, sizeof(__pyx_k_reduce), 0, 0, 1, 1},
  {&__pyx_n_s_reduce_cython, __pyx_k_reduce_cython, sizeof(__pyx_k_reduce_cython), 0, 0, 1, 1},
  {&__pyx_n_s_reduce_ex, __pyx_k_reduce_ex, sizeof(__pyx_k_reduce_ex), 0, 0, 1, 1},
  {&__pyx_n_s_res, __pyx_k_res, sizeof(__pyx_k_res), 0, 0, 1, 1},
  {&__pyx_n_s_right, __pyx_k_right, sizeof(__pyx_k_right), 0, 0, 1, 1},
  {&__pyx_n_s_scale, __pyx_k_scale, sizeof(__pyx_k_scale), 0, 0, 1, 1},
  {&__pyx_n_s_self, __pyx_k_self, sizeof(__pyx_k_self), 0, 0, 1, 1},
  {&__pyx_n_s_setstate, __pyx_k_setstate, sizeof(__pyx_k_setstate), 0, 0, 1, 1},
  {&__pyx_n_s_setstate_cython, __pyx_k_setstate_cython, sizeof(__pyx_k_setstate_cython), 0, 0, 1, 1},
  {&__pyx_n_s_split, __pyx_k_split, sizeof(__pyx_k_split), 0, 0, 1, 1},
  {&__pyx_kp_s_stringsource, __pyx_k_stringsource, sizeof(__pyx_k_stringsource), 0, 0, 1, 0},
  {&__pyx_n_s_strip, __pyx_k_strip, sizeof(__pyx_k_strip), 0, 0, 1, 1},
  {&__pyx_n_s_test, __pyx_k_test, sizeof(__pyx_k_test), 0, 0, 1, 1},
  {&__pyx_kp_s_theme, __pyx_k_theme, sizeof(__pyx_k_theme), 0, 0, 1, 0},
  {&__pyx_kp_s_theme_0, __pyx_k_theme_0, sizeof(__pyx_k_theme_0), 0, 0, 1, 0},
  {&__pyx_n_s_theme_2, __pyx_k_theme_2, sizeof(__pyx_k_theme_2), 0, 0, 1, 1},
  {&__pyx_n_s_theme___reduce_cython, __pyx_k_theme___reduce_cython, sizeof(__pyx_k_theme___reduce_cython), 0, 0, 1, 1},
  {&__pyx_n_s_theme___setstate_cython, __pyx_k_theme___setstate_cython, sizeof(__pyx_k_theme___setstate_cython), 0, 0, 1, 1},
  {&__pyx_n_s_theme_get_anyvar, __pyx_k_theme_get_anyvar, sizeof(__pyx_k_theme_get_anyvar), 0, 0, 1, 1},
  {&__pyx_n_s_theme_get_var, __pyx_k_theme_get_var, sizeof(__pyx_k_theme_get_var), 0, 0, 1, 1},
  {&__pyx_n_s_themes, __pyx_k_themes, sizeof(__pyx_k_themes), 0, 0, 1, 1},
  {&__pyx_n_s_title, __pyx_k_title, sizeof(__pyx_k_title), 0, 0, 1, 1},
  {&__pyx_n_s_tokens, __pyx_k_tokens, sizeof(__pyx_k_tokens), 0, 0, 1, 1},
  {&__pyx_n_s_top, __pyx_k_top, sizeof(__pyx_k_top), 0, 0, 1, 1},
  {&__pyx_n_s_transparent, __pyx_k_transparent, sizeof(__pyx_k_transparent), 0, 0, 1, 1},
  {&__pyx_kp_s_transparent_0, __pyx_k_transparent_0, sizeof(__pyx_k_transparent_0), 0, 0, 1, 0},
  {&__pyx_kp_s_ttygif, __pyx_k_ttygif, sizeof(__pyx_k_ttygif), 0, 0, 1, 0},
  {&__pyx_n_s_ttygif_tty_theme, __pyx_k_ttygif_tty_theme, sizeof(__pyx_k_ttygif_tty_theme), 0, 0, 1, 1},
  {&__pyx_kp_s_ttygif_tty_theme_pyx, __pyx_k_ttygif_tty_theme_pyx, sizeof(__pyx_k_ttygif_tty_theme_pyx), 0, 0, 1, 0},
  {&__pyx_n_s_types, __pyx_k_types, sizeof(__pyx_k_types), 0, 0, 1, 1},
  {&__pyx_n_s_value, __pyx_k_value, sizeof(__pyx_k_value), 0, 0, 1, 1},
  {&__pyx_n_s_var, __pyx_k_var, sizeof(__pyx_k_var), 0, 0, 1, 1},
  {&__pyx_n_s_width, __pyx_k_width, sizeof(__pyx_k_width), 0, 0, 1, 1},
  {&__pyx_n_s_x, __pyx_k_x, sizeof(__pyx_k_x), 0, 0, 1, 1},
  {&__pyx_n_s_y, __pyx_k_y, sizeof(__pyx_k_y), 0, 0, 1, 1},
  {&__pyx_kp_s_z_index_0, __pyx_k_z_index_0, sizeof(__pyx_k_z_index_0), 0, 0, 1, 0},
  {0, 0, 0, 0, 0, 0, 0}
};
static CYTHON_SMALL_CODE int __Pyx_InitCachedBuiltins(void) {
  __pyx_builtin_TypeError = __Pyx_GetBuiltinName(__pyx_n_s_TypeError); if (!__pyx_builtin_TypeError) __PYX_ERR(0, 2, __pyx_L1_error)
  __pyx_builtin_open = __Pyx_GetBuiltinName(__pyx_n_s_open); if (!__pyx_builtin_open) __PYX_ERR(1, 219, __pyx_L1_error)
  __pyx_builtin_range = __Pyx_GetBuiltinName(__pyx_n_s_range); if (!__pyx_builtin_range) __PYX_ERR(1, 418, __pyx_L1_error)
  __pyx_builtin_MemoryError = __Pyx_GetBuiltinName(__pyx_n_s_MemoryError); if (!__pyx_builtin_MemoryError) __PYX_ERR(2, 109, __pyx_L1_error)
  return 0;
  __pyx_L1_error:;
  return -1;
}

static CYTHON_SMALL_CODE int __Pyx_InitCachedConstants(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_InitCachedConstants", 0);

  /* "ttygif/tty/theme.pyx":24
 *         self.file=None
 *         self.mode='scale'
 *         self.outer =rect(0,0,0,0)             # <<<<<<<<<<<<<<
 *         self.inner =rect(0,0,0,0)
 *         self.bounds=rect(0,0,0,0)
 */
  __pyx_tuple__2 = PyTuple_Pack(4, __pyx_int_0, __pyx_int_0, __pyx_int_0, __pyx_int_0); if (unlikely(!__pyx_tuple__2)) __PYX_ERR(1, 24, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__2);
  __Pyx_GIVEREF(__pyx_tuple__2);

  /* "ttygif/tty/theme.pyx":27
 *         self.inner =rect(0,0,0,0)
 *         self.bounds=rect(0,0,0,0)
 *         self.dst   =rect(0,0,-1,-1)             # <<<<<<<<<<<<<<
 *         self.transparent=-1
 *         self.path  =None
 */
  __pyx_tuple__3 = PyTuple_Pack(4, __pyx_int_0, __pyx_int_0, __pyx_int_neg_1, __pyx_int_neg_1); if (unlikely(!__pyx_tuple__3)) __PYX_ERR(1, 27, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__3);
  __Pyx_GIVEREF(__pyx_tuple__3);

  /* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 */
  __pyx_tuple__5 = PyTuple_Pack(1, __pyx_kp_s_no_default___reduce___due_to_non); if (unlikely(!__pyx_tuple__5)) __PYX_ERR(0, 2, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__5);
  __Pyx_GIVEREF(__pyx_tuple__5);

  /* "(tree fragment)":4
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")             # <<<<<<<<<<<<<<
 */
  __pyx_tuple__7 = PyTuple_Pack(1, __pyx_kp_s_no_default___reduce___due_to_non); if (unlikely(!__pyx_tuple__7)) __PYX_ERR(0, 4, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__7);
  __Pyx_GIVEREF(__pyx_tuple__7);

  /* "ttygif/tty/theme.pyx":110
 *         self.default_background=0
 *         self.default_foreground=15
 *         self.palette=array.array('B')             # <<<<<<<<<<<<<<
 *         self.padding=rect(0,0,0,0)
 *         self.transparent=-1
 */
  __pyx_tuple__8 = PyTuple_Pack(1, __pyx_n_s_B); if (unlikely(!__pyx_tuple__8)) __PYX_ERR(1, 110, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__8);
  __Pyx_GIVEREF(__pyx_tuple__8);

  /* "ttygif/tty/theme.pyx":216
 * 
 *                 if os.path.exists(path)==False:
 *                     raise Exception("Invalid theme file")             # <<<<<<<<<<<<<<
 * 
 *         print(" - theme: {0}".format(self.name))
 */
  __pyx_tuple__10 = PyTuple_Pack(1, __pyx_kp_s_Invalid_theme_file); if (unlikely(!__pyx_tuple__10)) __PYX_ERR(1, 216, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__10);
  __Pyx_GIVEREF(__pyx_tuple__10);

  /* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 */
  __pyx_tuple__16 = PyTuple_Pack(1, __pyx_kp_s_no_default___reduce___due_to_non); if (unlikely(!__pyx_tuple__16)) __PYX_ERR(0, 2, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__16);
  __Pyx_GIVEREF(__pyx_tuple__16);

  /* "(tree fragment)":4
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")             # <<<<<<<<<<<<<<
 */
  __pyx_tuple__18 = PyTuple_Pack(1, __pyx_kp_s_no_default___reduce___due_to_non); if (unlikely(!__pyx_tuple__18)) __PYX_ERR(0, 4, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__18);
  __Pyx_GIVEREF(__pyx_tuple__18);

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):
 */
  __pyx_tuple__19 = PyTuple_Pack(1, __pyx_n_s_self); if (unlikely(!__pyx_tuple__19)) __PYX_ERR(0, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__19);
  __Pyx_GIVEREF(__pyx_tuple__19);
  __pyx_codeobj__4 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__19, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_stringsource, __pyx_n_s_reduce_cython, 1, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__4)) __PYX_ERR(0, 1, __pyx_L1_error)

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 */
  __pyx_tuple__20 = PyTuple_Pack(2, __pyx_n_s_self, __pyx_n_s_pyx_state); if (unlikely(!__pyx_tuple__20)) __PYX_ERR(0, 3, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__20);
  __Pyx_GIVEREF(__pyx_tuple__20);
  __pyx_codeobj__6 = (PyObject*)__Pyx_PyCode_New(2, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__20, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_stringsource, __pyx_n_s_setstate_cython, 3, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__6)) __PYX_ERR(0, 3, __pyx_L1_error)

  /* "ttygif/tty/theme.pyx":443
 * 
 * 
 *     def get_var(self,line,var):             # <<<<<<<<<<<<<<
 *         index=line.find(var)
 *         if index>=0:
 */
  __pyx_tuple__21 = PyTuple_Pack(5, __pyx_n_s_self, __pyx_n_s_line, __pyx_n_s_var, __pyx_n_s_index, __pyx_n_s_res); if (unlikely(!__pyx_tuple__21)) __PYX_ERR(1, 443, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__21);
  __Pyx_GIVEREF(__pyx_tuple__21);
  __pyx_codeobj__11 = (PyObject*)__Pyx_PyCode_New(3, 0, 5, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__21, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_ttygif_tty_theme_pyx, __pyx_n_s_get_var, 443, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__11)) __PYX_ERR(1, 443, __pyx_L1_error)

  /* "ttygif/tty/theme.pyx":451
 *         return None
 * 
 *     def get_anyvar(self,line):             # <<<<<<<<<<<<<<
 *         # return if line none
 *         if line==None:
 */
  __pyx_tuple__22 = PyTuple_Pack(3, __pyx_n_s_self, __pyx_n_s_line, __pyx_n_s_tokens); if (unlikely(!__pyx_tuple__22)) __PYX_ERR(1, 451, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__22);
  __Pyx_GIVEREF(__pyx_tuple__22);
  __pyx_codeobj__12 = (PyObject*)__Pyx_PyCode_New(2, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__22, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_ttygif_tty_theme_pyx, __pyx_n_s_get_anyvar, 451, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__12)) __PYX_ERR(1, 451, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):
 */
  __pyx_tuple__23 = PyTuple_Pack(1, __pyx_n_s_self); if (unlikely(!__pyx_tuple__23)) __PYX_ERR(0, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__23);
  __Pyx_GIVEREF(__pyx_tuple__23);
  __pyx_codeobj__15 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__23, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_stringsource, __pyx_n_s_reduce_cython, 1, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__15)) __PYX_ERR(0, 1, __pyx_L1_error)

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 */
  __pyx_tuple__24 = PyTuple_Pack(2, __pyx_n_s_self, __pyx_n_s_pyx_state); if (unlikely(!__pyx_tuple__24)) __PYX_ERR(0, 3, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__24);
  __Pyx_GIVEREF(__pyx_tuple__24);
  __pyx_codeobj__17 = (PyObject*)__Pyx_PyCode_New(2, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_stringsource, __pyx_n_s_setstate_cython, 3, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__17)) __PYX_ERR(0, 3, __pyx_L1_error)
  __Pyx_RefNannyFinishContext();
  return 0;
  __pyx_L1_error:;
  __Pyx_RefNannyFinishContext();
  return -1;
}

static CYTHON_SMALL_CODE int __Pyx_InitGlobals(void) {
  if (__Pyx_InitStrings(__pyx_string_tab) < 0) __PYX_ERR(1, 1, __pyx_L1_error);
  __pyx_int_0 = PyInt_FromLong(0); if (unlikely(!__pyx_int_0)) __PYX_ERR(1, 1, __pyx_L1_error)
  __pyx_int_1 = PyInt_FromLong(1); if (unlikely(!__pyx_int_1)) __PYX_ERR(1, 1, __pyx_L1_error)
  __pyx_int_8 = PyInt_FromLong(8); if (unlikely(!__pyx_int_8)) __PYX_ERR(1, 1, __pyx_L1_error)
  __pyx_int_18 = PyInt_FromLong(18); if (unlikely(!__pyx_int_18)) __PYX_ERR(1, 1, __pyx_L1_error)
  __pyx_int_28 = PyInt_FromLong(28); if (unlikely(!__pyx_int_28)) __PYX_ERR(1, 1, __pyx_L1_error)
  __pyx_int_38 = PyInt_FromLong(38); if (unlikely(!__pyx_int_38)) __PYX_ERR(1, 1, __pyx_L1_error)
  __pyx_int_48 = PyInt_FromLong(48); if (unlikely(!__pyx_int_48)) __PYX_ERR(1, 1, __pyx_L1_error)
  __pyx_int_58 = PyInt_FromLong(58); if (unlikely(!__pyx_int_58)) __PYX_ERR(1, 1, __pyx_L1_error)
  __pyx_int_68 = PyInt_FromLong(68); if (unlikely(!__pyx_int_68)) __PYX_ERR(1, 1, __pyx_L1_error)
  __pyx_int_78 = PyInt_FromLong(78); if (unlikely(!__pyx_int_78)) __PYX_ERR(1, 1, __pyx_L1_error)
  __pyx_int_88 = PyInt_FromLong(88); if (unlikely(!__pyx_int_88)) __PYX_ERR(1, 1, __pyx_L1_error)
  __pyx_int_95 = PyInt_FromLong(95); if (unlikely(!__pyx_int_95)) __PYX_ERR(1, 1, __pyx_L1_error)
  __pyx_int_98 = PyInt_FromLong(98); if (unlikely(!__pyx_int_98)) __PYX_ERR(1, 1, __pyx_L1_error)
  __pyx_int_108 = PyInt_FromLong(108); if (unlikely(!__pyx_int_108)) __PYX_ERR(1, 1, __pyx_L1_error)
  __pyx_int_118 = PyInt_FromLong(118); if (unlikely(!__pyx_int_118)) __PYX_ERR(1, 1, __pyx_L1_error)
  __pyx_int_128 = PyInt_FromLong(128); if (unlikely(!__pyx_int_128)) __PYX_ERR(1, 1, __pyx_L1_error)
  __pyx_int_135 = PyInt_FromLong(135); if (unlikely(!__pyx_int_135)) __PYX_ERR(1, 1, __pyx_L1_error)
  __pyx_int_138 = PyInt_FromLong(138); if (unlikely(!__pyx_int_138)) __PYX_ERR(1, 1, __pyx_L1_error)
  __pyx_int_148 = PyInt_FromLong(148); if (unlikely(!__pyx_int_148)) __PYX_ERR(1, 1, __pyx_L1_error)
  __pyx_int_158 = PyInt_FromLong(158); if (unlikely(!__pyx_int_158)) __PYX_ERR(1, 1, __pyx_L1_error)
  __pyx_int_168 = PyInt_FromLong(168); if (unlikely(!__pyx_int_168)) __PYX_ERR(1, 1, __pyx_L1_error)
  __pyx_int_175 = PyInt_FromLong(175); if (unlikely(!__pyx_int_175)) __PYX_ERR(1, 1, __pyx_L1_error)
  __pyx_int_178 = PyInt_FromLong(178); if (unlikely(!__pyx_int_178)) __PYX_ERR(1, 1, __pyx_L1_error)
  __pyx_int_188 = PyInt_FromLong(188); if (unlikely(!__pyx_int_188)) __PYX_ERR(1, 1, __pyx_L1_error)
  __pyx_int_192 = PyInt_FromLong(192); if (unlikely(!__pyx_int_192)) __PYX_ERR(1, 1, __pyx_L1_error)
  __pyx_int_198 = PyInt_FromLong(198); if (unlikely(!__pyx_int_198)) __PYX_ERR(1, 1, __pyx_L1_error)
  __pyx_int_208 = PyInt_FromLong(208); if (unlikely(!__pyx_int_208)) __PYX_ERR(1, 1, __pyx_L1_error)
  __pyx_int_215 = PyInt_FromLong(215); if (unlikely(!__pyx_int_215)) __PYX_ERR(1, 1, __pyx_L1_error)
  __pyx_int_218 = PyInt_FromLong(218); if (unlikely(!__pyx_int_218)) __PYX_ERR(1, 1, __pyx_L1_error)
  __pyx_int_228 = PyInt_FromLong(228); if (unlikely(!__pyx_int_228)) __PYX_ERR(1, 1, __pyx_L1_error)
  __pyx_int_238 = PyInt_FromLong(238); if (unlikely(!__pyx_int_238)) __PYX_ERR(1, 1, __pyx_L1_error)
  __pyx_int_255 = PyInt_FromLong(255); if (unlikely(!__pyx_int_255)) __PYX_ERR(1, 1, __pyx_L1_error)
  __pyx_int_neg_1 = PyInt_FromLong(-1); if (unlikely(!__pyx_int_neg_1)) __PYX_ERR(1, 1, __pyx_L1_error)
  return 0;
  __pyx_L1_error:;
  return -1;
}

static CYTHON_SMALL_CODE int __Pyx_modinit_global_init_code(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_variable_export_code(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_function_export_code(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_type_init_code(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_type_import_code(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_variable_import_code(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_function_import_code(void); /*proto*/

static int __Pyx_modinit_global_init_code(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_modinit_global_init_code", 0);
  /*--- Global init code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}

static int __Pyx_modinit_variable_export_code(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_modinit_variable_export_code", 0);
  /*--- Variable export code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}

static int __Pyx_modinit_function_export_code(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_modinit_function_export_code", 0);
  /*--- Function export code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}

static int __Pyx_modinit_type_init_code(void) {
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__Pyx_modinit_type_init_code", 0);
  /*--- Type init code ---*/
  __pyx_vtabptr_6ttygif_3tty_5theme_layer = &__pyx_vtable_6ttygif_3tty_5theme_layer;
  __pyx_vtable_6ttygif_3tty_5theme_layer.debug = (PyObject *(*)(struct __pyx_obj_6ttygif_3tty_5theme_layer *))__pyx_f_6ttygif_3tty_5theme_5layer_debug;
  __pyx_vtable_6ttygif_3tty_5theme_layer.load_file = (PyObject *(*)(struct __pyx_obj_6ttygif_3tty_5theme_layer *, arrayobject *))__pyx_f_6ttygif_3tty_5theme_5layer_load_file;
  if (PyType_Ready(&__pyx_type_6ttygif_3tty_5theme_layer) < 0) __PYX_ERR(1, 18, __pyx_L1_error)
  #if PY_VERSION_HEX < 0x030800B1
  __pyx_type_6ttygif_3tty_5theme_layer.tp_print = 0;
  #endif
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_type_6ttygif_3tty_5theme_layer.tp_dictoffset && __pyx_type_6ttygif_3tty_5theme_layer.tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_type_6ttygif_3tty_5theme_layer.tp_getattro = __Pyx_PyObject_GenericGetAttr;
  }
  if (__Pyx_SetVtable(__pyx_type_6ttygif_3tty_5theme_layer.tp_dict, __pyx_vtabptr_6ttygif_3tty_5theme_layer) < 0) __PYX_ERR(1, 18, __pyx_L1_error)
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s_layer, (PyObject *)&__pyx_type_6ttygif_3tty_5theme_layer) < 0) __PYX_ERR(1, 18, __pyx_L1_error)
  if (__Pyx_setup_reduce((PyObject*)&__pyx_type_6ttygif_3tty_5theme_layer) < 0) __PYX_ERR(1, 18, __pyx_L1_error)
  __pyx_ptype_6ttygif_3tty_5theme_layer = &__pyx_type_6ttygif_3tty_5theme_layer;
  __pyx_vtabptr_6ttygif_3tty_5theme_theme = &__pyx_vtable_6ttygif_3tty_5theme_theme;
  __pyx_vtable_6ttygif_3tty_5theme_theme.init = (PyObject *(*)(struct __pyx_obj_6ttygif_3tty_5theme_theme *))__pyx_f_6ttygif_3tty_5theme_5theme_init;
  __pyx_vtable_6ttygif_3tty_5theme_theme.update_layer = (PyObject *(*)(struct __pyx_obj_6ttygif_3tty_5theme_theme *, struct __pyx_obj_6ttygif_3tty_5theme_layer *))__pyx_f_6ttygif_3tty_5theme_5theme_update_layer;
  __pyx_vtable_6ttygif_3tty_5theme_theme.__pyx_auto = (PyObject *(*)(struct __pyx_obj_6ttygif_3tty_5theme_theme *))__pyx_f_6ttygif_3tty_5theme_5theme_auto;
  if (PyType_Ready(&__pyx_type_6ttygif_3tty_5theme_theme) < 0) __PYX_ERR(1, 100, __pyx_L1_error)
  #if PY_VERSION_HEX < 0x030800B1
  __pyx_type_6ttygif_3tty_5theme_theme.tp_print = 0;
  #endif
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_type_6ttygif_3tty_5theme_theme.tp_dictoffset && __pyx_type_6ttygif_3tty_5theme_theme.tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_type_6ttygif_3tty_5theme_theme.tp_getattro = __Pyx_PyObject_GenericGetAttr;
  }
  if (__Pyx_SetVtable(__pyx_type_6ttygif_3tty_5theme_theme.tp_dict, __pyx_vtabptr_6ttygif_3tty_5theme_theme) < 0) __PYX_ERR(1, 100, __pyx_L1_error)
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s_theme_2, (PyObject *)&__pyx_type_6ttygif_3tty_5theme_theme) < 0) __PYX_ERR(1, 100, __pyx_L1_error)
  if (__Pyx_setup_reduce((PyObject*)&__pyx_type_6ttygif_3tty_5theme_theme) < 0) __PYX_ERR(1, 100, __pyx_L1_error)
  __pyx_ptype_6ttygif_3tty_5theme_theme = &__pyx_type_6ttygif_3tty_5theme_theme;
  __Pyx_RefNannyFinishContext();
  return 0;
  __pyx_L1_error:;
  __Pyx_RefNannyFinishContext();
  return -1;
}

static int __Pyx_modinit_type_import_code(void) {
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__Pyx_modinit_type_import_code", 0);
  /*--- Type import code ---*/
  __pyx_t_1 = PyImport_ImportModule(__Pyx_BUILTIN_MODULE_NAME); if (unlikely(!__pyx_t_1)) __PYX_ERR(3, 9, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_7cpython_4type_type = __Pyx_ImportType(__pyx_t_1, __Pyx_BUILTIN_MODULE_NAME, "type", 
  #if defined(PYPY_VERSION_NUM) && PYPY_VERSION_NUM < 0x050B0000
  sizeof(PyTypeObject),
  #else
  sizeof(PyHeapTypeObject),
  #endif
  __Pyx_ImportType_CheckSize_Warn);
   if (!__pyx_ptype_7cpython_4type_type) __PYX_ERR(3, 9, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyImport_ImportModule(__Pyx_BUILTIN_MODULE_NAME); if (unlikely(!__pyx_t_1)) __PYX_ERR(4, 8, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_7cpython_4bool_bool = __Pyx_ImportType(__pyx_t_1, __Pyx_BUILTIN_MODULE_NAME, "bool", sizeof(PyBoolObject), __Pyx_ImportType_CheckSize_Warn);
   if (!__pyx_ptype_7cpython_4bool_bool) __PYX_ERR(4, 8, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyImport_ImportModule(__Pyx_BUILTIN_MODULE_NAME); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 15, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_7cpython_7complex_complex = __Pyx_ImportType(__pyx_t_1, __Pyx_BUILTIN_MODULE_NAME, "complex", sizeof(PyComplexObject), __Pyx_ImportType_CheckSize_Warn);
   if (!__pyx_ptype_7cpython_7complex_complex) __PYX_ERR(5, 15, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyImport_ImportModule("array"); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 58, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_7cpython_5array_array = __Pyx_ImportType(__pyx_t_1, "array", "array", sizeof(arrayobject), __Pyx_ImportType_CheckSize_Warn);
   if (!__pyx_ptype_7cpython_5array_array) __PYX_ERR(2, 58, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyImport_ImportModule("ttygif.tty.image"); if (unlikely(!__pyx_t_1)) __PYX_ERR(6, 10, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_6ttygif_3tty_5image_bounds = __Pyx_ImportType(__pyx_t_1, "ttygif.tty.image", "bounds", sizeof(struct __pyx_obj_6ttygif_3tty_5image_bounds), __Pyx_ImportType_CheckSize_Warn);
   if (!__pyx_ptype_6ttygif_3tty_5image_bounds) __PYX_ERR(6, 10, __pyx_L1_error)
  __pyx_vtabptr_6ttygif_3tty_5image_bounds = (struct __pyx_vtabstruct_6ttygif_3tty_5image_bounds*)__Pyx_GetVtable(__pyx_ptype_6ttygif_3tty_5image_bounds->tp_dict); if (unlikely(!__pyx_vtabptr_6ttygif_3tty_5image_bounds)) __PYX_ERR(6, 10, __pyx_L1_error)
  __pyx_ptype_6ttygif_3tty_5image_point = __Pyx_ImportType(__pyx_t_1, "ttygif.tty.image", "point", sizeof(struct __pyx_obj_6ttygif_3tty_5image_point), __Pyx_ImportType_CheckSize_Warn);
   if (!__pyx_ptype_6ttygif_3tty_5image_point) __PYX_ERR(6, 18, __pyx_L1_error)
  __pyx_vtabptr_6ttygif_3tty_5image_point = (struct __pyx_vtabstruct_6ttygif_3tty_5image_point*)__Pyx_GetVtable(__pyx_ptype_6ttygif_3tty_5image_point->tp_dict); if (unlikely(!__pyx_vtabptr_6ttygif_3tty_5image_point)) __PYX_ERR(6, 18, __pyx_L1_error)
  __pyx_ptype_6ttygif_3tty_5image_rect = __Pyx_ImportType(__pyx_t_1, "ttygif.tty.image", "rect", sizeof(struct __pyx_obj_6ttygif_3tty_5image_rect), __Pyx_ImportType_CheckSize_Warn);
   if (!__pyx_ptype_6ttygif_3tty_5image_rect) __PYX_ERR(6, 24, __pyx_L1_error)
  __pyx_vtabptr_6ttygif_3tty_5image_rect = (struct __pyx_vtabstruct_6ttygif_3tty_5image_rect*)__Pyx_GetVtable(__pyx_ptype_6ttygif_3tty_5image_rect->tp_dict); if (unlikely(!__pyx_vtabptr_6ttygif_3tty_5image_rect)) __PYX_ERR(6, 24, __pyx_L1_error)
  __pyx_ptype_6ttygif_3tty_5image_image = __Pyx_ImportType(__pyx_t_1, "ttygif.tty.image", "image", sizeof(struct __pyx_obj_6ttygif_3tty_5image_image), __Pyx_ImportType_CheckSize_Warn);
   if (!__pyx_ptype_6ttygif_3tty_5image_image) __PYX_ERR(6, 40, __pyx_L1_error)
  __pyx_vtabptr_6ttygif_3tty_5image_image = (struct __pyx_vtabstruct_6ttygif_3tty_5image_image*)__Pyx_GetVtable(__pyx_ptype_6ttygif_3tty_5image_image->tp_dict); if (unlikely(!__pyx_vtabptr_6ttygif_3tty_5image_image)) __PYX_ERR(6, 40, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_RefNannyFinishContext();
  return 0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_RefNannyFinishContext();
  return -1;
}

static int __Pyx_modinit_variable_import_code(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_modinit_variable_import_code", 0);
  /*--- Variable import code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}

static int __Pyx_modinit_function_import_code(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_modinit_function_import_code", 0);
  /*--- Function import code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}


#ifndef CYTHON_NO_PYINIT_EXPORT
#define __Pyx_PyMODINIT_FUNC PyMODINIT_FUNC
#elif PY_MAJOR_VERSION < 3
#ifdef __cplusplus
#define __Pyx_PyMODINIT_FUNC extern "C" void
#else
#define __Pyx_PyMODINIT_FUNC void
#endif
#else
#ifdef __cplusplus
#define __Pyx_PyMODINIT_FUNC extern "C" PyObject *
#else
#define __Pyx_PyMODINIT_FUNC PyObject *
#endif
#endif


#if PY_MAJOR_VERSION < 3
__Pyx_PyMODINIT_FUNC inittheme(void) CYTHON_SMALL_CODE; /*proto*/
__Pyx_PyMODINIT_FUNC inittheme(void)
#else
__Pyx_PyMODINIT_FUNC PyInit_theme(void) CYTHON_SMALL_CODE; /*proto*/
__Pyx_PyMODINIT_FUNC PyInit_theme(void)
#if CYTHON_PEP489_MULTI_PHASE_INIT
{
  return PyModuleDef_Init(&__pyx_moduledef);
}
static CYTHON_SMALL_CODE int __Pyx_check_single_interpreter(void) {
    #if PY_VERSION_HEX >= 0x030700A1
    static PY_INT64_T main_interpreter_id = -1;
    PY_INT64_T current_id = PyInterpreterState_GetID(PyThreadState_Get()->interp);
    if (main_interpreter_id == -1) {
        main_interpreter_id = current_id;
        return (unlikely(current_id == -1)) ? -1 : 0;
    } else if (unlikely(main_interpreter_id != current_id))
    #else
    static PyInterpreterState *main_interpreter = NULL;
    PyInterpreterState *current_interpreter = PyThreadState_Get()->interp;
    if (!main_interpreter) {
        main_interpreter = current_interpreter;
    } else if (unlikely(main_interpreter != current_interpreter))
    #endif
    {
        PyErr_SetString(
            PyExc_ImportError,
            "Interpreter change detected - this module can only be loaded into one interpreter per process.");
        return -1;
    }
    return 0;
}
static CYTHON_SMALL_CODE int __Pyx_copy_spec_to_module(PyObject *spec, PyObject *moddict, const char* from_name, const char* to_name, int allow_none) {
    PyObject *value = PyObject_GetAttrString(spec, from_name);
    int result = 0;
    if (likely(value)) {
        if (allow_none || value != Py_None) {
            result = PyDict_SetItemString(moddict, to_name, value);
        }
        Py_DECREF(value);
    } else if (PyErr_ExceptionMatches(PyExc_AttributeError)) {
        PyErr_Clear();
    } else {
        result = -1;
    }
    return result;
}
static CYTHON_SMALL_CODE PyObject* __pyx_pymod_create(PyObject *spec, CYTHON_UNUSED PyModuleDef *def) {
    PyObject *module = NULL, *moddict, *modname;
    if (__Pyx_check_single_interpreter())
        return NULL;
    if (__pyx_m)
        return __Pyx_NewRef(__pyx_m);
    modname = PyObject_GetAttrString(spec, "name");
    if (unlikely(!modname)) goto bad;
    module = PyModule_NewObject(modname);
    Py_DECREF(modname);
    if (unlikely(!module)) goto bad;
    moddict = PyModule_GetDict(module);
    if (unlikely(!moddict)) goto bad;
    if (unlikely(__Pyx_copy_spec_to_module(spec, moddict, "loader", "__loader__", 1) < 0)) goto bad;
    if (unlikely(__Pyx_copy_spec_to_module(spec, moddict, "origin", "__file__", 1) < 0)) goto bad;
    if (unlikely(__Pyx_copy_spec_to_module(spec, moddict, "parent", "__package__", 1) < 0)) goto bad;
    if (unlikely(__Pyx_copy_spec_to_module(spec, moddict, "submodule_search_locations", "__path__", 0) < 0)) goto bad;
    return module;
bad:
    Py_XDECREF(module);
    return NULL;
}


static CYTHON_SMALL_CODE int __pyx_pymod_exec_theme(PyObject *__pyx_pyinit_module)
#endif
#endif
{
  __Pyx_TraceDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannyDeclarations
  #if CYTHON_PEP489_MULTI_PHASE_INIT
  if (__pyx_m) {
    if (__pyx_m == __pyx_pyinit_module) return 0;
    PyErr_SetString(PyExc_RuntimeError, "Module 'theme' has already been imported. Re-initialisation is not supported.");
    return -1;
  }
  #elif PY_MAJOR_VERSION >= 3
  if (__pyx_m) return __Pyx_NewRef(__pyx_m);
  #endif
  #if CYTHON_REFNANNY
__Pyx_RefNanny = __Pyx_RefNannyImportAPI("refnanny");
if (!__Pyx_RefNanny) {
  PyErr_Clear();
  __Pyx_RefNanny = __Pyx_RefNannyImportAPI("Cython.Runtime.refnanny");
  if (!__Pyx_RefNanny)
      Py_FatalError("failed to import 'refnanny' module");
}
#endif
  __Pyx_RefNannySetupContext("__Pyx_PyMODINIT_FUNC PyInit_theme(void)", 0);
  if (__Pyx_check_binary_version() < 0) __PYX_ERR(1, 1, __pyx_L1_error)
  #ifdef __Pxy_PyFrame_Initialize_Offsets
  __Pxy_PyFrame_Initialize_Offsets();
  #endif
  __pyx_empty_tuple = PyTuple_New(0); if (unlikely(!__pyx_empty_tuple)) __PYX_ERR(1, 1, __pyx_L1_error)
  __pyx_empty_bytes = PyBytes_FromStringAndSize("", 0); if (unlikely(!__pyx_empty_bytes)) __PYX_ERR(1, 1, __pyx_L1_error)
  __pyx_empty_unicode = PyUnicode_FromStringAndSize("", 0); if (unlikely(!__pyx_empty_unicode)) __PYX_ERR(1, 1, __pyx_L1_error)
  #ifdef __Pyx_CyFunction_USED
  if (__pyx_CyFunction_init() < 0) __PYX_ERR(1, 1, __pyx_L1_error)
  #endif
  #ifdef __Pyx_FusedFunction_USED
  if (__pyx_FusedFunction_init() < 0) __PYX_ERR(1, 1, __pyx_L1_error)
  #endif
  #ifdef __Pyx_Coroutine_USED
  if (__pyx_Coroutine_init() < 0) __PYX_ERR(1, 1, __pyx_L1_error)
  #endif
  #ifdef __Pyx_Generator_USED
  if (__pyx_Generator_init() < 0) __PYX_ERR(1, 1, __pyx_L1_error)
  #endif
  #ifdef __Pyx_AsyncGen_USED
  if (__pyx_AsyncGen_init() < 0) __PYX_ERR(1, 1, __pyx_L1_error)
  #endif
  #ifdef __Pyx_StopAsyncIteration_USED
  if (__pyx_StopAsyncIteration_init() < 0) __PYX_ERR(1, 1, __pyx_L1_error)
  #endif
  /*--- Library function declarations ---*/
  /*--- Threads initialization code ---*/
  #if defined(WITH_THREAD) && PY_VERSION_HEX < 0x030700F0 && defined(__PYX_FORCE_INIT_THREADS) && __PYX_FORCE_INIT_THREADS
  PyEval_InitThreads();
  #endif
  /*--- Module creation code ---*/
  #if CYTHON_PEP489_MULTI_PHASE_INIT
  __pyx_m = __pyx_pyinit_module;
  Py_INCREF(__pyx_m);
  #else
  #if PY_MAJOR_VERSION < 3
  __pyx_m = Py_InitModule4("theme", __pyx_methods, 0, 0, PYTHON_API_VERSION); Py_XINCREF(__pyx_m);
  #else
  __pyx_m = PyModule_Create(&__pyx_moduledef);
  #endif
  if (unlikely(!__pyx_m)) __PYX_ERR(1, 1, __pyx_L1_error)
  #endif
  __pyx_d = PyModule_GetDict(__pyx_m); if (unlikely(!__pyx_d)) __PYX_ERR(1, 1, __pyx_L1_error)
  Py_INCREF(__pyx_d);
  __pyx_b = PyImport_AddModule(__Pyx_BUILTIN_MODULE_NAME); if (unlikely(!__pyx_b)) __PYX_ERR(1, 1, __pyx_L1_error)
  Py_INCREF(__pyx_b);
  __pyx_cython_runtime = PyImport_AddModule((char *) "cython_runtime"); if (unlikely(!__pyx_cython_runtime)) __PYX_ERR(1, 1, __pyx_L1_error)
  Py_INCREF(__pyx_cython_runtime);
  if (PyObject_SetAttrString(__pyx_m, "__builtins__", __pyx_b) < 0) __PYX_ERR(1, 1, __pyx_L1_error);
  /*--- Initialize various global constants etc. ---*/
  if (__Pyx_InitGlobals() < 0) __PYX_ERR(1, 1, __pyx_L1_error)
  #if PY_MAJOR_VERSION < 3 && (__PYX_DEFAULT_STRING_ENCODING_IS_ASCII || __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT)
  if (__Pyx_init_sys_getdefaultencoding_params() < 0) __PYX_ERR(1, 1, __pyx_L1_error)
  #endif
  if (__pyx_module_is_main_ttygif__tty__theme) {
    if (PyObject_SetAttr(__pyx_m, __pyx_n_s_name_2, __pyx_n_s_main) < 0) __PYX_ERR(1, 1, __pyx_L1_error)
  }
  #if PY_MAJOR_VERSION >= 3
  {
    PyObject *modules = PyImport_GetModuleDict(); if (unlikely(!modules)) __PYX_ERR(1, 1, __pyx_L1_error)
    if (!PyDict_GetItemString(modules, "ttygif.tty.theme")) {
      if (unlikely(PyDict_SetItemString(modules, "ttygif.tty.theme", __pyx_m) < 0)) __PYX_ERR(1, 1, __pyx_L1_error)
    }
  }
  #endif
  /*--- Builtin init code ---*/
  if (__Pyx_InitCachedBuiltins() < 0) __PYX_ERR(1, 1, __pyx_L1_error)
  /*--- Constants init code ---*/
  if (__Pyx_InitCachedConstants() < 0) __PYX_ERR(1, 1, __pyx_L1_error)
  /*--- Global type/function init code ---*/
  (void)__Pyx_modinit_global_init_code();
  (void)__Pyx_modinit_variable_export_code();
  (void)__Pyx_modinit_function_export_code();
  if (unlikely(__Pyx_modinit_type_init_code() < 0)) __PYX_ERR(1, 1, __pyx_L1_error)
  if (unlikely(__Pyx_modinit_type_import_code() < 0)) __PYX_ERR(1, 1, __pyx_L1_error)
  (void)__Pyx_modinit_variable_import_code();
  (void)__Pyx_modinit_function_import_code();
  /*--- Execution code ---*/
  #if defined(__Pyx_Generator_USED) || defined(__Pyx_Coroutine_USED)
  if (__Pyx_patch_abc() < 0) __PYX_ERR(1, 1, __pyx_L1_error)
  #endif
  __Pyx_TraceCall("__Pyx_PyMODINIT_FUNC PyInit_theme(void)", __pyx_f[1], 1, 0, __PYX_ERR(1, 1, __pyx_L1_error));

  /* "ttygif/tty/theme.pyx":7
 * from cpython cimport array
 * from image cimport rect,point
 * import os             # <<<<<<<<<<<<<<
 * import types
 * from os.path import expanduser
 */
  __pyx_t_1 = __Pyx_Import(__pyx_n_s_os, 0, -1); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 7, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_os, __pyx_t_1) < 0) __PYX_ERR(1, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "ttygif/tty/theme.pyx":8
 * from image cimport rect,point
 * import os
 * import types             # <<<<<<<<<<<<<<
 * from os.path import expanduser
 * from ..gif.decode import decode
 */
  __pyx_t_1 = __Pyx_Import(__pyx_n_s_types, 0, -1); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 8, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_types, __pyx_t_1) < 0) __PYX_ERR(1, 8, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "ttygif/tty/theme.pyx":9
 * import os
 * import types
 * from os.path import expanduser             # <<<<<<<<<<<<<<
 * from ..gif.decode import decode
 * from image import image
 */
  __pyx_t_1 = PyList_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 9, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_n_s_expanduser);
  __Pyx_GIVEREF(__pyx_n_s_expanduser);
  PyList_SET_ITEM(__pyx_t_1, 0, __pyx_n_s_expanduser);
  __pyx_t_2 = __Pyx_Import(__pyx_n_s_os_path, __pyx_t_1, -1); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 9, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_ImportFrom(__pyx_t_2, __pyx_n_s_expanduser); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 9, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_expanduser, __pyx_t_1) < 0) __PYX_ERR(1, 9, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "ttygif/tty/theme.pyx":10
 * import types
 * from os.path import expanduser
 * from ..gif.decode import decode             # <<<<<<<<<<<<<<
 * from image import image
 * from libc.stdint cimport uint32_t, int64_t,uint16_t,uint8_t,int32_t,int16_t
 */
  __pyx_t_2 = PyList_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 10, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(__pyx_n_s_decode);
  __Pyx_GIVEREF(__pyx_n_s_decode);
  PyList_SET_ITEM(__pyx_t_2, 0, __pyx_n_s_decode);
  __pyx_t_1 = __Pyx_Import(__pyx_n_s_gif_decode, __pyx_t_2, 2); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 10, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_ImportFrom(__pyx_t_1, __pyx_n_s_decode); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 10, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_decode, __pyx_t_2) < 0) __PYX_ERR(1, 10, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "ttygif/tty/theme.pyx":11
 * from os.path import expanduser
 * from ..gif.decode import decode
 * from image import image             # <<<<<<<<<<<<<<
 * from libc.stdint cimport uint32_t, int64_t,uint16_t,uint8_t,int32_t,int16_t
 * 
 */
  __pyx_t_1 = PyList_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 11, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_n_s_image);
  __Pyx_GIVEREF(__pyx_n_s_image);
  PyList_SET_ITEM(__pyx_t_1, 0, __pyx_n_s_image);
  __pyx_t_2 = __Pyx_Import(__pyx_n_s_image, __pyx_t_1, -1); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 11, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6ttygif_3tty_5theme_5layer_3__reduce_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_layer___reduce_cython, NULL, __pyx_n_s_ttygif_tty_theme, __pyx_d, ((PyObject *)__pyx_codeobj__4)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_reduce_cython, __pyx_t_2) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6ttygif_3tty_5theme_5layer_5__setstate_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_layer___setstate_cython, NULL, __pyx_n_s_ttygif_tty_theme, __pyx_d, ((PyObject *)__pyx_codeobj__6)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_setstate_cython, __pyx_t_2) < 0) __PYX_ERR(0, 3, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "ttygif/tty/theme.pyx":443
 * 
 * 
 *     def get_var(self,line,var):             # <<<<<<<<<<<<<<
 *         index=line.find(var)
 *         if index>=0:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6ttygif_3tty_5theme_5theme_3get_var, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_theme_get_var, NULL, __pyx_n_s_ttygif_tty_theme, __pyx_d, ((PyObject *)__pyx_codeobj__11)); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 443, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem((PyObject *)__pyx_ptype_6ttygif_3tty_5theme_theme->tp_dict, __pyx_n_s_get_var, __pyx_t_2) < 0) __PYX_ERR(1, 443, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6ttygif_3tty_5theme_theme);

  /* "ttygif/tty/theme.pyx":451
 *         return None
 * 
 *     def get_anyvar(self,line):             # <<<<<<<<<<<<<<
 *         # return if line none
 *         if line==None:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6ttygif_3tty_5theme_5theme_5get_anyvar, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_theme_get_anyvar, NULL, __pyx_n_s_ttygif_tty_theme, __pyx_d, ((PyObject *)__pyx_codeobj__12)); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 451, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem((PyObject *)__pyx_ptype_6ttygif_3tty_5theme_theme->tp_dict, __pyx_n_s_get_anyvar, __pyx_t_2) < 0) __PYX_ERR(1, 451, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6ttygif_3tty_5theme_theme);

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6ttygif_3tty_5theme_5theme_7__reduce_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_theme___reduce_cython, NULL, __pyx_n_s_ttygif_tty_theme, __pyx_d, ((PyObject *)__pyx_codeobj__15)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_reduce_cython, __pyx_t_2) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6ttygif_3tty_5theme_5theme_9__setstate_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_theme___setstate_cython, NULL, __pyx_n_s_ttygif_tty_theme, __pyx_d, ((PyObject *)__pyx_codeobj__17)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_setstate_cython, __pyx_t_2) < 0) __PYX_ERR(0, 3, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "ttygif/tty/theme.pyx":1
 * # cython: profile=True             # <<<<<<<<<<<<<<
 * # cython: binding=True
 * # cython: language_level=2
 */
  __pyx_t_2 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_test, __pyx_t_2) < 0) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "array.pxd":161
 *     return extend_buffer(self, other.data.as_chars, Py_SIZE(other))
 * 
 * cdef inline void zero(array self):             # <<<<<<<<<<<<<<
 *     """ set all elements of array to zero. """
 *     memset(self.data.as_chars, 0, Py_SIZE(self) * self.ob_descr.itemsize)
 */
  __Pyx_TraceReturn(Py_None, 0);

  /*--- Wrapped vars code ---*/

  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  if (__pyx_m) {
    if (__pyx_d) {
      __Pyx_AddTraceback("init ttygif.tty.theme", __pyx_clineno, __pyx_lineno, __pyx_filename);
    }
    Py_CLEAR(__pyx_m);
  } else if (!PyErr_Occurred()) {
    PyErr_SetString(PyExc_ImportError, "init ttygif.tty.theme");
  }
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  #if CYTHON_PEP489_MULTI_PHASE_INIT
  return (__pyx_m != NULL) ? 0 : -1;
  #elif PY_MAJOR_VERSION >= 3
  return __pyx_m;
  #else
  return;
  #endif
}

/* --- Runtime support code --- */
/* Refnanny */
#if CYTHON_REFNANNY
static __Pyx_RefNannyAPIStruct *__Pyx_RefNannyImportAPI(const char *modname) {
    PyObject *m = NULL, *p = NULL;
    void *r = NULL;
    m = PyImport_ImportModule(modname);
    if (!m) goto end;
    p = PyObject_GetAttrString(m, "RefNannyAPI");
    if (!p) goto end;
    r = PyLong_AsVoidPtr(p);
end:
    Py_XDECREF(p);
    Py_XDECREF(m);
    return (__Pyx_RefNannyAPIStruct *)r;
}
#endif

/* PyObjectGetAttrStr */
#if CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetAttrStr(PyObject* obj, PyObject* attr_name) {
    PyTypeObject* tp = Py_TYPE(obj);
    if (likely(tp->tp_getattro))
        return tp->tp_getattro(obj, attr_name);
#if PY_MAJOR_VERSION < 3
    if (likely(tp->tp_getattr))
        return tp->tp_getattr(obj, PyString_AS_STRING(attr_name));
#endif
    return PyObject_GetAttr(obj, attr_name);
}
#endif

/* GetBuiltinName */
static PyObject *__Pyx_GetBuiltinName(PyObject *name) {
    PyObject* result = __Pyx_PyObject_GetAttrStr(__pyx_b, name);
    if (unlikely(!result)) {
        PyErr_Format(PyExc_NameError,
#if PY_MAJOR_VERSION >= 3
            "name '%U' is not defined", name);
#else
            "name '%.200s' is not defined", PyString_AS_STRING(name));
#endif
    }
    return result;
}

/* RaiseArgTupleInvalid */
static void __Pyx_RaiseArgtupleInvalid(
    const char* func_name,
    int exact,
    Py_ssize_t num_min,
    Py_ssize_t num_max,
    Py_ssize_t num_found)
{
    Py_ssize_t num_expected;
    const char *more_or_less;
    if (num_found < num_min) {
        num_expected = num_min;
        more_or_less = "at least";
    } else {
        num_expected = num_max;
        more_or_less = "at most";
    }
    if (exact) {
        more_or_less = "exactly";
    }
    PyErr_Format(PyExc_TypeError,
                 "%.200s() takes %.8s %" CYTHON_FORMAT_SSIZE_T "d positional argument%.1s (%" CYTHON_FORMAT_SSIZE_T "d given)",
                 func_name, more_or_less, num_expected,
                 (num_expected == 1) ? "" : "s", num_found);
}

/* KeywordStringCheck */
static int __Pyx_CheckKeywordStrings(
    PyObject *kwdict,
    const char* function_name,
    int kw_allowed)
{
    PyObject* key = 0;
    Py_ssize_t pos = 0;
#if CYTHON_COMPILING_IN_PYPY
    if (!kw_allowed && PyDict_Next(kwdict, &pos, &key, 0))
        goto invalid_keyword;
    return 1;
#else
    while (PyDict_Next(kwdict, &pos, &key, 0)) {
        #if PY_MAJOR_VERSION < 3
        if (unlikely(!PyString_Check(key)))
        #endif
            if (unlikely(!PyUnicode_Check(key)))
                goto invalid_keyword_type;
    }
    if ((!kw_allowed) && unlikely(key))
        goto invalid_keyword;
    return 1;
invalid_keyword_type:
    PyErr_Format(PyExc_TypeError,
        "%.200s() keywords must be strings", function_name);
    return 0;
#endif
invalid_keyword:
    PyErr_Format(PyExc_TypeError,
    #if PY_MAJOR_VERSION < 3
        "%.200s() got an unexpected keyword argument '%.200s'",
        function_name, PyString_AsString(key));
    #else
        "%s() got an unexpected keyword argument '%U'",
        function_name, key);
    #endif
    return 0;
}

/* PyErrFetchRestore */
#if CYTHON_FAST_THREAD_STATE
static CYTHON_INLINE void __Pyx_ErrRestoreInState(PyThreadState *tstate, PyObject *type, PyObject *value, PyObject *tb) {
    PyObject *tmp_type, *tmp_value, *tmp_tb;
    tmp_type = tstate->curexc_type;
    tmp_value = tstate->curexc_value;
    tmp_tb = tstate->curexc_traceback;
    tstate->curexc_type = type;
    tstate->curexc_value = value;
    tstate->curexc_traceback = tb;
    Py_XDECREF(tmp_type);
    Py_XDECREF(tmp_value);
    Py_XDECREF(tmp_tb);
}
static CYTHON_INLINE void __Pyx_ErrFetchInState(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb) {
    *type = tstate->curexc_type;
    *value = tstate->curexc_value;
    *tb = tstate->curexc_traceback;
    tstate->curexc_type = 0;
    tstate->curexc_value = 0;
    tstate->curexc_traceback = 0;
}
#endif

/* Profile */
#if CYTHON_PROFILE
static int __Pyx_TraceSetupAndCall(PyCodeObject** code,
                                   PyFrameObject** frame,
                                   PyThreadState* tstate,
                                   const char *funcname,
                                   const char *srcfile,
                                   int firstlineno) {
    PyObject *type, *value, *traceback;
    int retval;
    if (*frame == NULL || !CYTHON_PROFILE_REUSE_FRAME) {
        if (*code == NULL) {
            *code = __Pyx_createFrameCodeObject(funcname, srcfile, firstlineno);
            if (*code == NULL) return 0;
        }
        *frame = PyFrame_New(
            tstate,                          /*PyThreadState *tstate*/
            *code,                           /*PyCodeObject *code*/
            __pyx_d,                  /*PyObject *globals*/
            0                                /*PyObject *locals*/
        );
        if (*frame == NULL) return 0;
        if (CYTHON_TRACE && (*frame)->f_trace == NULL) {
            Py_INCREF(Py_None);
            (*frame)->f_trace = Py_None;
        }
#if PY_VERSION_HEX < 0x030400B1
    } else {
        (*frame)->f_tstate = tstate;
#endif
    }
    __Pyx_PyFrame_SetLineNumber(*frame, firstlineno);
    retval = 1;
    __Pyx_EnterTracing(tstate);
    __Pyx_ErrFetchInState(tstate, &type, &value, &traceback);
    #if CYTHON_TRACE
    if (tstate->c_tracefunc)
        retval = tstate->c_tracefunc(tstate->c_traceobj, *frame, PyTrace_CALL, NULL) == 0;
    if (retval && tstate->c_profilefunc)
    #endif
        retval = tstate->c_profilefunc(tstate->c_profileobj, *frame, PyTrace_CALL, NULL) == 0;
    __Pyx_LeaveTracing(tstate);
    if (retval) {
        __Pyx_ErrRestoreInState(tstate, type, value, traceback);
        return __Pyx_IsTracing(tstate, 0, 0) && retval;
    } else {
        Py_XDECREF(type);
        Py_XDECREF(value);
        Py_XDECREF(traceback);
        return -1;
    }
}
static PyCodeObject *__Pyx_createFrameCodeObject(const char *funcname, const char *srcfile, int firstlineno) {
    PyCodeObject *py_code = 0;
#if PY_MAJOR_VERSION >= 3
    py_code = PyCode_NewEmpty(srcfile, funcname, firstlineno);
    if (likely(py_code)) {
        py_code->co_flags |= CO_OPTIMIZED | CO_NEWLOCALS;
    }
#else
    PyObject *py_srcfile = 0;
    PyObject *py_funcname = 0;
    py_funcname = PyString_FromString(funcname);
    if (unlikely(!py_funcname)) goto bad;
    py_srcfile = PyString_FromString(srcfile);
    if (unlikely(!py_srcfile)) goto bad;
    py_code = PyCode_New(
        0,
        0,
        0,
        CO_OPTIMIZED | CO_NEWLOCALS,
        __pyx_empty_bytes,     /*PyObject *code,*/
        __pyx_empty_tuple,     /*PyObject *consts,*/
        __pyx_empty_tuple,     /*PyObject *names,*/
        __pyx_empty_tuple,     /*PyObject *varnames,*/
        __pyx_empty_tuple,     /*PyObject *freevars,*/
        __pyx_empty_tuple,     /*PyObject *cellvars,*/
        py_srcfile,       /*PyObject *filename,*/
        py_funcname,      /*PyObject *name,*/
        firstlineno,
        __pyx_empty_bytes      /*PyObject *lnotab*/
    );
bad:
    Py_XDECREF(py_srcfile);
    Py_XDECREF(py_funcname);
#endif
    return py_code;
}
#endif

/* PyObjectCall */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_Call(PyObject *func, PyObject *arg, PyObject *kw) {
    PyObject *result;
    ternaryfunc call = Py_TYPE(func)->tp_call;
    if (unlikely(!call))
        return PyObject_Call(func, arg, kw);
    if (unlikely(Py_EnterRecursiveCall((char*)" while calling a Python object")))
        return NULL;
    result = (*call)(func, arg, kw);
    Py_LeaveRecursiveCall();
    if (unlikely(!result) && unlikely(!PyErr_Occurred())) {
        PyErr_SetString(
            PyExc_SystemError,
            "NULL result without error in PyObject_Call");
    }
    return result;
}
#endif

/* PyDictVersioning */
#if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE PY_UINT64_T __Pyx_get_tp_dict_version(PyObject *obj) {
    PyObject *dict = Py_TYPE(obj)->tp_dict;
    return likely(dict) ? __PYX_GET_DICT_VERSION(dict) : 0;
}
static CYTHON_INLINE PY_UINT64_T __Pyx_get_object_dict_version(PyObject *obj) {
    PyObject **dictptr = NULL;
    Py_ssize_t offset = Py_TYPE(obj)->tp_dictoffset;
    if (offset) {
#if CYTHON_COMPILING_IN_CPYTHON
        dictptr = (likely(offset > 0)) ? (PyObject **) ((char *)obj + offset) : _PyObject_GetDictPtr(obj);
#else
        dictptr = _PyObject_GetDictPtr(obj);
#endif
    }
    return (dictptr && *dictptr) ? __PYX_GET_DICT_VERSION(*dictptr) : 0;
}
static CYTHON_INLINE int __Pyx_object_dict_version_matches(PyObject* obj, PY_UINT64_T tp_dict_version, PY_UINT64_T obj_dict_version) {
    PyObject *dict = Py_TYPE(obj)->tp_dict;
    if (unlikely(!dict) || unlikely(tp_dict_version != __PYX_GET_DICT_VERSION(dict)))
        return 0;
    return obj_dict_version == __Pyx_get_object_dict_version(obj);
}
#endif

/* GetModuleGlobalName */
#if CYTHON_USE_DICT_VERSIONS
static PyObject *__Pyx__GetModuleGlobalName(PyObject *name, PY_UINT64_T *dict_version, PyObject **dict_cached_value)
#else
static CYTHON_INLINE PyObject *__Pyx__GetModuleGlobalName(PyObject *name)
#endif
{
    PyObject *result;
#if !CYTHON_AVOID_BORROWED_REFS
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030500A1
    result = _PyDict_GetItem_KnownHash(__pyx_d, name, ((PyASCIIObject *) name)->hash);
    __PYX_UPDATE_DICT_CACHE(__pyx_d, result, *dict_cached_value, *dict_version)
    if (likely(result)) {
        return __Pyx_NewRef(result);
    } else if (unlikely(PyErr_Occurred())) {
        return NULL;
    }
#else
    result = PyDict_GetItem(__pyx_d, name);
    __PYX_UPDATE_DICT_CACHE(__pyx_d, result, *dict_cached_value, *dict_version)
    if (likely(result)) {
        return __Pyx_NewRef(result);
    }
#endif
#else
    result = PyObject_GetItem(__pyx_d, name);
    __PYX_UPDATE_DICT_CACHE(__pyx_d, result, *dict_cached_value, *dict_version)
    if (likely(result)) {
        return __Pyx_NewRef(result);
    }
    PyErr_Clear();
#endif
    return __Pyx_GetBuiltinName(name);
}

/* PyCFunctionFastCall */
#if CYTHON_FAST_PYCCALL
static CYTHON_INLINE PyObject * __Pyx_PyCFunction_FastCall(PyObject *func_obj, PyObject **args, Py_ssize_t nargs) {
    PyCFunctionObject *func = (PyCFunctionObject*)func_obj;
    PyCFunction meth = PyCFunction_GET_FUNCTION(func);
    PyObject *self = PyCFunction_GET_SELF(func);
    int flags = PyCFunction_GET_FLAGS(func);
    assert(PyCFunction_Check(func));
    assert(METH_FASTCALL == (flags & ~(METH_CLASS | METH_STATIC | METH_COEXIST | METH_KEYWORDS | METH_STACKLESS)));
    assert(nargs >= 0);
    assert(nargs == 0 || args != NULL);
    /* _PyCFunction_FastCallDict() must not be called with an exception set,
       because it may clear it (directly or indirectly) and so the
       caller loses its exception */
    assert(!PyErr_Occurred());
    if ((PY_VERSION_HEX < 0x030700A0) || unlikely(flags & METH_KEYWORDS)) {
        return (*((__Pyx_PyCFunctionFastWithKeywords)(void*)meth)) (self, args, nargs, NULL);
    } else {
        return (*((__Pyx_PyCFunctionFast)(void*)meth)) (self, args, nargs);
    }
}
#endif

/* PyFunctionFastCall */
#if CYTHON_FAST_PYCALL
static PyObject* __Pyx_PyFunction_FastCallNoKw(PyCodeObject *co, PyObject **args, Py_ssize_t na,
                                               PyObject *globals) {
    PyFrameObject *f;
    PyThreadState *tstate = __Pyx_PyThreadState_Current;
    PyObject **fastlocals;
    Py_ssize_t i;
    PyObject *result;
    assert(globals != NULL);
    /* XXX Perhaps we should create a specialized
       PyFrame_New() that doesn't take locals, but does
       take builtins without sanity checking them.
       */
    assert(tstate != NULL);
    f = PyFrame_New(tstate, co, globals, NULL);
    if (f == NULL) {
        return NULL;
    }
    fastlocals = __Pyx_PyFrame_GetLocalsplus(f);
    for (i = 0; i < na; i++) {
        Py_INCREF(*args);
        fastlocals[i] = *args++;
    }
    result = PyEval_EvalFrameEx(f,0);
    ++tstate->recursion_depth;
    Py_DECREF(f);
    --tstate->recursion_depth;
    return result;
}
#if 1 || PY_VERSION_HEX < 0x030600B1
static PyObject *__Pyx_PyFunction_FastCallDict(PyObject *func, PyObject **args, Py_ssize_t nargs, PyObject *kwargs) {
    PyCodeObject *co = (PyCodeObject *)PyFunction_GET_CODE(func);
    PyObject *globals = PyFunction_GET_GLOBALS(func);
    PyObject *argdefs = PyFunction_GET_DEFAULTS(func);
    PyObject *closure;
#if PY_MAJOR_VERSION >= 3
    PyObject *kwdefs;
#endif
    PyObject *kwtuple, **k;
    PyObject **d;
    Py_ssize_t nd;
    Py_ssize_t nk;
    PyObject *result;
    assert(kwargs == NULL || PyDict_Check(kwargs));
    nk = kwargs ? PyDict_Size(kwargs) : 0;
    if (Py_EnterRecursiveCall((char*)" while calling a Python object")) {
        return NULL;
    }
    if (
#if PY_MAJOR_VERSION >= 3
            co->co_kwonlyargcount == 0 &&
#endif
            likely(kwargs == NULL || nk == 0) &&
            co->co_flags == (CO_OPTIMIZED | CO_NEWLOCALS | CO_NOFREE)) {
        if (argdefs == NULL && co->co_argcount == nargs) {
            result = __Pyx_PyFunction_FastCallNoKw(co, args, nargs, globals);
            goto done;
        }
        else if (nargs == 0 && argdefs != NULL
                 && co->co_argcount == Py_SIZE(argdefs)) {
            /* function called with no arguments, but all parameters have
               a default value: use default values as arguments .*/
            args = &PyTuple_GET_ITEM(argdefs, 0);
            result =__Pyx_PyFunction_FastCallNoKw(co, args, Py_SIZE(argdefs), globals);
            goto done;
        }
    }
    if (kwargs != NULL) {
        Py_ssize_t pos, i;
        kwtuple = PyTuple_New(2 * nk);
        if (kwtuple == NULL) {
            result = NULL;
            goto done;
        }
        k = &PyTuple_GET_ITEM(kwtuple, 0);
        pos = i = 0;
        while (PyDict_Next(kwargs, &pos, &k[i], &k[i+1])) {
            Py_INCREF(k[i]);
            Py_INCREF(k[i+1]);
            i += 2;
        }
        nk = i / 2;
    }
    else {
        kwtuple = NULL;
        k = NULL;
    }
    closure = PyFunction_GET_CLOSURE(func);
#if PY_MAJOR_VERSION >= 3
    kwdefs = PyFunction_GET_KW_DEFAULTS(func);
#endif
    if (argdefs != NULL) {
        d = &PyTuple_GET_ITEM(argdefs, 0);
        nd = Py_SIZE(argdefs);
    }
    else {
        d = NULL;
        nd = 0;
    }
#if PY_MAJOR_VERSION >= 3
    result = PyEval_EvalCodeEx((PyObject*)co, globals, (PyObject *)NULL,
                               args, (int)nargs,
                               k, (int)nk,
                               d, (int)nd, kwdefs, closure);
#else
    result = PyEval_EvalCodeEx(co, globals, (PyObject *)NULL,
                               args, (int)nargs,
                               k, (int)nk,
                               d, (int)nd, closure);
#endif
    Py_XDECREF(kwtuple);
done:
    Py_LeaveRecursiveCall();
    return result;
}
#endif
#endif

/* PyObjectCall2Args */
static CYTHON_UNUSED PyObject* __Pyx_PyObject_Call2Args(PyObject* function, PyObject* arg1, PyObject* arg2) {
    PyObject *args, *result = NULL;
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(function)) {
        PyObject *args[2] = {arg1, arg2};
        return __Pyx_PyFunction_FastCall(function, args, 2);
    }
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(function)) {
        PyObject *args[2] = {arg1, arg2};
        return __Pyx_PyCFunction_FastCall(function, args, 2);
    }
    #endif
    args = PyTuple_New(2);
    if (unlikely(!args)) goto done;
    Py_INCREF(arg1);
    PyTuple_SET_ITEM(args, 0, arg1);
    Py_INCREF(arg2);
    PyTuple_SET_ITEM(args, 1, arg2);
    Py_INCREF(function);
    result = __Pyx_PyObject_Call(function, args, NULL);
    Py_DECREF(args);
    Py_DECREF(function);
done:
    return result;
}

/* PyObjectCallMethO */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallMethO(PyObject *func, PyObject *arg) {
    PyObject *self, *result;
    PyCFunction cfunc;
    cfunc = PyCFunction_GET_FUNCTION(func);
    self = PyCFunction_GET_SELF(func);
    if (unlikely(Py_EnterRecursiveCall((char*)" while calling a Python object")))
        return NULL;
    result = cfunc(self, arg);
    Py_LeaveRecursiveCall();
    if (unlikely(!result) && unlikely(!PyErr_Occurred())) {
        PyErr_SetString(
            PyExc_SystemError,
            "NULL result without error in PyObject_Call");
    }
    return result;
}
#endif

/* PyObjectCallOneArg */
#if CYTHON_COMPILING_IN_CPYTHON
static PyObject* __Pyx__PyObject_CallOneArg(PyObject *func, PyObject *arg) {
    PyObject *result;
    PyObject *args = PyTuple_New(1);
    if (unlikely(!args)) return NULL;
    Py_INCREF(arg);
    PyTuple_SET_ITEM(args, 0, arg);
    result = __Pyx_PyObject_Call(func, args, NULL);
    Py_DECREF(args);
    return result;
}
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallOneArg(PyObject *func, PyObject *arg) {
#if CYTHON_FAST_PYCALL
    if (PyFunction_Check(func)) {
        return __Pyx_PyFunction_FastCall(func, &arg, 1);
    }
#endif
    if (likely(PyCFunction_Check(func))) {
        if (likely(PyCFunction_GET_FLAGS(func) & METH_O)) {
            return __Pyx_PyObject_CallMethO(func, arg);
#if CYTHON_FAST_PYCCALL
        } else if (__Pyx_PyFastCFunction_Check(func)) {
            return __Pyx_PyCFunction_FastCall(func, &arg, 1);
#endif
        }
    }
    return __Pyx__PyObject_CallOneArg(func, arg);
}
#else
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallOneArg(PyObject *func, PyObject *arg) {
    PyObject *result;
    PyObject *args = PyTuple_Pack(1, arg);
    if (unlikely(!args)) return NULL;
    result = __Pyx_PyObject_Call(func, args, NULL);
    Py_DECREF(args);
    return result;
}
#endif

/* RaiseException */
#if PY_MAJOR_VERSION < 3
static void __Pyx_Raise(PyObject *type, PyObject *value, PyObject *tb,
                        CYTHON_UNUSED PyObject *cause) {
    __Pyx_PyThreadState_declare
    Py_XINCREF(type);
    if (!value || value == Py_None)
        value = NULL;
    else
        Py_INCREF(value);
    if (!tb || tb == Py_None)
        tb = NULL;
    else {
        Py_INCREF(tb);
        if (!PyTraceBack_Check(tb)) {
            PyErr_SetString(PyExc_TypeError,
                "raise: arg 3 must be a traceback or None");
            goto raise_error;
        }
    }
    if (PyType_Check(type)) {
#if CYTHON_COMPILING_IN_PYPY
        if (!value) {
            Py_INCREF(Py_None);
            value = Py_None;
        }
#endif
        PyErr_NormalizeException(&type, &value, &tb);
    } else {
        if (value) {
            PyErr_SetString(PyExc_TypeError,
                "instance exception may not have a separate value");
            goto raise_error;
        }
        value = type;
        type = (PyObject*) Py_TYPE(type);
        Py_INCREF(type);
        if (!PyType_IsSubtype((PyTypeObject *)type, (PyTypeObject *)PyExc_BaseException)) {
            PyErr_SetString(PyExc_TypeError,
                "raise: exception class must be a subclass of BaseException");
            goto raise_error;
        }
    }
    __Pyx_PyThreadState_assign
    __Pyx_ErrRestore(type, value, tb);
    return;
raise_error:
    Py_XDECREF(value);
    Py_XDECREF(type);
    Py_XDECREF(tb);
    return;
}
#else
static void __Pyx_Raise(PyObject *type, PyObject *value, PyObject *tb, PyObject *cause) {
    PyObject* owned_instance = NULL;
    if (tb == Py_None) {
        tb = 0;
    } else if (tb && !PyTraceBack_Check(tb)) {
        PyErr_SetString(PyExc_TypeError,
            "raise: arg 3 must be a traceback or None");
        goto bad;
    }
    if (value == Py_None)
        value = 0;
    if (PyExceptionInstance_Check(type)) {
        if (value) {
            PyErr_SetString(PyExc_TypeError,
                "instance exception may not have a separate value");
            goto bad;
        }
        value = type;
        type = (PyObject*) Py_TYPE(value);
    } else if (PyExceptionClass_Check(type)) {
        PyObject *instance_class = NULL;
        if (value && PyExceptionInstance_Check(value)) {
            instance_class = (PyObject*) Py_TYPE(value);
            if (instance_class != type) {
                int is_subclass = PyObject_IsSubclass(instance_class, type);
                if (!is_subclass) {
                    instance_class = NULL;
                } else if (unlikely(is_subclass == -1)) {
                    goto bad;
                } else {
                    type = instance_class;
                }
            }
        }
        if (!instance_class) {
            PyObject *args;
            if (!value)
                args = PyTuple_New(0);
            else if (PyTuple_Check(value)) {
                Py_INCREF(value);
                args = value;
            } else
                args = PyTuple_Pack(1, value);
            if (!args)
                goto bad;
            owned_instance = PyObject_Call(type, args, NULL);
            Py_DECREF(args);
            if (!owned_instance)
                goto bad;
            value = owned_instance;
            if (!PyExceptionInstance_Check(value)) {
                PyErr_Format(PyExc_TypeError,
                             "calling %R should have returned an instance of "
                             "BaseException, not %R",
                             type, Py_TYPE(value));
                goto bad;
            }
        }
    } else {
        PyErr_SetString(PyExc_TypeError,
            "raise: exception class must be a subclass of BaseException");
        goto bad;
    }
    if (cause) {
        PyObject *fixed_cause;
        if (cause == Py_None) {
            fixed_cause = NULL;
        } else if (PyExceptionClass_Check(cause)) {
            fixed_cause = PyObject_CallObject(cause, NULL);
            if (fixed_cause == NULL)
                goto bad;
        } else if (PyExceptionInstance_Check(cause)) {
            fixed_cause = cause;
            Py_INCREF(fixed_cause);
        } else {
            PyErr_SetString(PyExc_TypeError,
                            "exception causes must derive from "
                            "BaseException");
            goto bad;
        }
        PyException_SetCause(value, fixed_cause);
    }
    PyErr_SetObject(type, value);
    if (tb) {
#if CYTHON_COMPILING_IN_PYPY
        PyObject *tmp_type, *tmp_value, *tmp_tb;
        PyErr_Fetch(&tmp_type, &tmp_value, &tmp_tb);
        Py_INCREF(tb);
        PyErr_Restore(tmp_type, tmp_value, tb);
        Py_XDECREF(tmp_tb);
#else
        PyThreadState *tstate = __Pyx_PyThreadState_Current;
        PyObject* tmp_tb = tstate->curexc_traceback;
        if (tb != tmp_tb) {
            Py_INCREF(tb);
            tstate->curexc_traceback = tb;
            Py_XDECREF(tmp_tb);
        }
#endif
    }
bad:
    Py_XDECREF(owned_instance);
    return;
}
#endif

/* None */
static CYTHON_INLINE void __Pyx_RaiseUnboundLocalError(const char *varname) {
    PyErr_Format(PyExc_UnboundLocalError, "local variable '%s' referenced before assignment", varname);
}

/* PyObjectCallNoArg */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallNoArg(PyObject *func) {
#if CYTHON_FAST_PYCALL
    if (PyFunction_Check(func)) {
        return __Pyx_PyFunction_FastCall(func, NULL, 0);
    }
#endif
#ifdef __Pyx_CyFunction_USED
    if (likely(PyCFunction_Check(func) || __Pyx_CyFunction_Check(func)))
#else
    if (likely(PyCFunction_Check(func)))
#endif
    {
        if (likely(PyCFunction_GET_FLAGS(func) & METH_NOARGS)) {
            return __Pyx_PyObject_CallMethO(func, NULL);
        }
    }
    return __Pyx_PyObject_Call(func, __pyx_empty_tuple, NULL);
}
#endif

/* DictGetItem */
#if PY_MAJOR_VERSION >= 3 && !CYTHON_COMPILING_IN_PYPY
static PyObject *__Pyx_PyDict_GetItem(PyObject *d, PyObject* key) {
    PyObject *value;
    value = PyDict_GetItemWithError(d, key);
    if (unlikely(!value)) {
        if (!PyErr_Occurred()) {
            if (unlikely(PyTuple_Check(key))) {
                PyObject* args = PyTuple_Pack(1, key);
                if (likely(args)) {
                    PyErr_SetObject(PyExc_KeyError, args);
                    Py_DECREF(args);
                }
            } else {
                PyErr_SetObject(PyExc_KeyError, key);
            }
        }
        return NULL;
    }
    Py_INCREF(value);
    return value;
}
#endif

/* PyIntBinop */
#if !CYTHON_COMPILING_IN_PYPY
static PyObject* __Pyx_PyInt_SubtractObjC(PyObject *op1, PyObject *op2, CYTHON_UNUSED long intval, int inplace, int zerodivision_check) {
    (void)inplace;
    (void)zerodivision_check;
    #if PY_MAJOR_VERSION < 3
    if (likely(PyInt_CheckExact(op1))) {
        const long b = intval;
        long x;
        long a = PyInt_AS_LONG(op1);
            x = (long)((unsigned long)a - b);
            if (likely((x^a) >= 0 || (x^~b) >= 0))
                return PyInt_FromLong(x);
            return PyLong_Type.tp_as_number->nb_subtract(op1, op2);
    }
    #endif
    #if CYTHON_USE_PYLONG_INTERNALS
    if (likely(PyLong_CheckExact(op1))) {
        const long b = intval;
        long a, x;
#ifdef HAVE_LONG_LONG
        const PY_LONG_LONG llb = intval;
        PY_LONG_LONG lla, llx;
#endif
        const digit* digits = ((PyLongObject*)op1)->ob_digit;
        const Py_ssize_t size = Py_SIZE(op1);
        if (likely(__Pyx_sst_abs(size) <= 1)) {
            a = likely(size) ? digits[0] : 0;
            if (size == -1) a = -a;
        } else {
            switch (size) {
                case -2:
                    if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                        a = -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
#ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 2 * PyLong_SHIFT) {
                        lla = -(PY_LONG_LONG) (((((unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
#endif
                    }
                    CYTHON_FALLTHROUGH;
                case 2:
                    if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                        a = (long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
#ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 2 * PyLong_SHIFT) {
                        lla = (PY_LONG_LONG) (((((unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
#endif
                    }
                    CYTHON_FALLTHROUGH;
                case -3:
                    if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                        a = -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
#ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 3 * PyLong_SHIFT) {
                        lla = -(PY_LONG_LONG) (((((((unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
#endif
                    }
                    CYTHON_FALLTHROUGH;
                case 3:
                    if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                        a = (long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
#ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 3 * PyLong_SHIFT) {
                        lla = (PY_LONG_LONG) (((((((unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
#endif
                    }
                    CYTHON_FALLTHROUGH;
                case -4:
                    if (8 * sizeof(long) - 1 > 4 * PyLong_SHIFT) {
                        a = -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
#ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 4 * PyLong_SHIFT) {
                        lla = -(PY_LONG_LONG) (((((((((unsigned PY_LONG_LONG)digits[3]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
#endif
                    }
                    CYTHON_FALLTHROUGH;
                case 4:
                    if (8 * sizeof(long) - 1 > 4 * PyLong_SHIFT) {
                        a = (long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
#ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 4 * PyLong_SHIFT) {
                        lla = (PY_LONG_LONG) (((((((((unsigned PY_LONG_LONG)digits[3]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
#endif
                    }
                    CYTHON_FALLTHROUGH;
                default: return PyLong_Type.tp_as_number->nb_subtract(op1, op2);
            }
        }
                x = a - b;
            return PyLong_FromLong(x);
#ifdef HAVE_LONG_LONG
        long_long:
                llx = lla - llb;
            return PyLong_FromLongLong(llx);
#endif
        
        
    }
    #endif
    if (PyFloat_CheckExact(op1)) {
        const long b = intval;
        double a = PyFloat_AS_DOUBLE(op1);
            double result;
            PyFPE_START_PROTECT("subtract", return NULL)
            result = ((double)a) - (double)b;
            PyFPE_END_PROTECT(result)
            return PyFloat_FromDouble(result);
    }
    return (inplace ? PyNumber_InPlaceSubtract : PyNumber_Subtract)(op1, op2);
}
#endif

/* ExtTypeTest */
static CYTHON_INLINE int __Pyx_TypeTest(PyObject *obj, PyTypeObject *type) {
    if (unlikely(!type)) {
        PyErr_SetString(PyExc_SystemError, "Missing type object");
        return 0;
    }
    if (likely(__Pyx_TypeCheck(obj, type)))
        return 1;
    PyErr_Format(PyExc_TypeError, "Cannot convert %.200s to %.200s",
                 Py_TYPE(obj)->tp_name, type->tp_name);
    return 0;
}

/* PyIntCompare */
static CYTHON_INLINE PyObject* __Pyx_PyInt_EqObjC(PyObject *op1, PyObject *op2, CYTHON_UNUSED long intval, CYTHON_UNUSED long inplace) {
    if (op1 == op2) {
        Py_RETURN_TRUE;
    }
    #if PY_MAJOR_VERSION < 3
    if (likely(PyInt_CheckExact(op1))) {
        const long b = intval;
        long a = PyInt_AS_LONG(op1);
        if (a == b) Py_RETURN_TRUE; else Py_RETURN_FALSE;
    }
    #endif
    #if CYTHON_USE_PYLONG_INTERNALS
    if (likely(PyLong_CheckExact(op1))) {
        int unequal;
        unsigned long uintval;
        Py_ssize_t size = Py_SIZE(op1);
        const digit* digits = ((PyLongObject*)op1)->ob_digit;
        if (intval == 0) {
            if (size == 0) Py_RETURN_TRUE; else Py_RETURN_FALSE;
        } else if (intval < 0) {
            if (size >= 0)
                Py_RETURN_FALSE;
            intval = -intval;
            size = -size;
        } else {
            if (size <= 0)
                Py_RETURN_FALSE;
        }
        uintval = (unsigned long) intval;
#if PyLong_SHIFT * 4 < SIZEOF_LONG*8
        if (uintval >> (PyLong_SHIFT * 4)) {
            unequal = (size != 5) || (digits[0] != (uintval & (unsigned long) PyLong_MASK))
                 | (digits[1] != ((uintval >> (1 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK)) | (digits[2] != ((uintval >> (2 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK)) | (digits[3] != ((uintval >> (3 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK)) | (digits[4] != ((uintval >> (4 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK));
        } else
#endif
#if PyLong_SHIFT * 3 < SIZEOF_LONG*8
        if (uintval >> (PyLong_SHIFT * 3)) {
            unequal = (size != 4) || (digits[0] != (uintval & (unsigned long) PyLong_MASK))
                 | (digits[1] != ((uintval >> (1 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK)) | (digits[2] != ((uintval >> (2 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK)) | (digits[3] != ((uintval >> (3 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK));
        } else
#endif
#if PyLong_SHIFT * 2 < SIZEOF_LONG*8
        if (uintval >> (PyLong_SHIFT * 2)) {
            unequal = (size != 3) || (digits[0] != (uintval & (unsigned long) PyLong_MASK))
                 | (digits[1] != ((uintval >> (1 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK)) | (digits[2] != ((uintval >> (2 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK));
        } else
#endif
#if PyLong_SHIFT * 1 < SIZEOF_LONG*8
        if (uintval >> (PyLong_SHIFT * 1)) {
            unequal = (size != 2) || (digits[0] != (uintval & (unsigned long) PyLong_MASK))
                 | (digits[1] != ((uintval >> (1 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK));
        } else
#endif
            unequal = (size != 1) || (((unsigned long) digits[0]) != (uintval & (unsigned long) PyLong_MASK));
        if (unequal == 0) Py_RETURN_TRUE; else Py_RETURN_FALSE;
    }
    #endif
    if (PyFloat_CheckExact(op1)) {
        const long b = intval;
        double a = PyFloat_AS_DOUBLE(op1);
        if ((double)a == (double)b) Py_RETURN_TRUE; else Py_RETURN_FALSE;
    }
    return (
        PyObject_RichCompare(op1, op2, Py_EQ));
}

/* RaiseDoubleKeywords */
static void __Pyx_RaiseDoubleKeywordsError(
    const char* func_name,
    PyObject* kw_name)
{
    PyErr_Format(PyExc_TypeError,
        #if PY_MAJOR_VERSION >= 3
        "%s() got multiple values for keyword argument '%U'", func_name, kw_name);
        #else
        "%s() got multiple values for keyword argument '%s'", func_name,
        PyString_AsString(kw_name));
        #endif
}

/* ParseKeywords */
static int __Pyx_ParseOptionalKeywords(
    PyObject *kwds,
    PyObject **argnames[],
    PyObject *kwds2,
    PyObject *values[],
    Py_ssize_t num_pos_args,
    const char* function_name)
{
    PyObject *key = 0, *value = 0;
    Py_ssize_t pos = 0;
    PyObject*** name;
    PyObject*** first_kw_arg = argnames + num_pos_args;
    while (PyDict_Next(kwds, &pos, &key, &value)) {
        name = first_kw_arg;
        while (*name && (**name != key)) name++;
        if (*name) {
            values[name-argnames] = value;
            continue;
        }
        name = first_kw_arg;
        #if PY_MAJOR_VERSION < 3
        if (likely(PyString_Check(key))) {
            while (*name) {
                if ((CYTHON_COMPILING_IN_PYPY || PyString_GET_SIZE(**name) == PyString_GET_SIZE(key))
                        && _PyString_Eq(**name, key)) {
                    values[name-argnames] = value;
                    break;
                }
                name++;
            }
            if (*name) continue;
            else {
                PyObject*** argname = argnames;
                while (argname != first_kw_arg) {
                    if ((**argname == key) || (
                            (CYTHON_COMPILING_IN_PYPY || PyString_GET_SIZE(**argname) == PyString_GET_SIZE(key))
                             && _PyString_Eq(**argname, key))) {
                        goto arg_passed_twice;
                    }
                    argname++;
                }
            }
        } else
        #endif
        if (likely(PyUnicode_Check(key))) {
            while (*name) {
                int cmp = (**name == key) ? 0 :
                #if !CYTHON_COMPILING_IN_PYPY && PY_MAJOR_VERSION >= 3
                    (__Pyx_PyUnicode_GET_LENGTH(**name) != __Pyx_PyUnicode_GET_LENGTH(key)) ? 1 :
                #endif
                    PyUnicode_Compare(**name, key);
                if (cmp < 0 && unlikely(PyErr_Occurred())) goto bad;
                if (cmp == 0) {
                    values[name-argnames] = value;
                    break;
                }
                name++;
            }
            if (*name) continue;
            else {
                PyObject*** argname = argnames;
                while (argname != first_kw_arg) {
                    int cmp = (**argname == key) ? 0 :
                    #if !CYTHON_COMPILING_IN_PYPY && PY_MAJOR_VERSION >= 3
                        (__Pyx_PyUnicode_GET_LENGTH(**argname) != __Pyx_PyUnicode_GET_LENGTH(key)) ? 1 :
                    #endif
                        PyUnicode_Compare(**argname, key);
                    if (cmp < 0 && unlikely(PyErr_Occurred())) goto bad;
                    if (cmp == 0) goto arg_passed_twice;
                    argname++;
                }
            }
        } else
            goto invalid_keyword_type;
        if (kwds2) {
            if (unlikely(PyDict_SetItem(kwds2, key, value))) goto bad;
        } else {
            goto invalid_keyword;
        }
    }
    return 0;
arg_passed_twice:
    __Pyx_RaiseDoubleKeywordsError(function_name, key);
    goto bad;
invalid_keyword_type:
    PyErr_Format(PyExc_TypeError,
        "%.200s() keywords must be strings", function_name);
    goto bad;
invalid_keyword:
    PyErr_Format(PyExc_TypeError,
    #if PY_MAJOR_VERSION < 3
        "%.200s() got an unexpected keyword argument '%.200s'",
        function_name, PyString_AsString(key));
    #else
        "%s() got an unexpected keyword argument '%U'",
        function_name, key);
    #endif
bad:
    return -1;
}

/* BytesEquals */
static CYTHON_INLINE int __Pyx_PyBytes_Equals(PyObject* s1, PyObject* s2, int equals) {
#if CYTHON_COMPILING_IN_PYPY
    return PyObject_RichCompareBool(s1, s2, equals);
#else
    if (s1 == s2) {
        return (equals == Py_EQ);
    } else if (PyBytes_CheckExact(s1) & PyBytes_CheckExact(s2)) {
        const char *ps1, *ps2;
        Py_ssize_t length = PyBytes_GET_SIZE(s1);
        if (length != PyBytes_GET_SIZE(s2))
            return (equals == Py_NE);
        ps1 = PyBytes_AS_STRING(s1);
        ps2 = PyBytes_AS_STRING(s2);
        if (ps1[0] != ps2[0]) {
            return (equals == Py_NE);
        } else if (length == 1) {
            return (equals == Py_EQ);
        } else {
            int result;
#if CYTHON_USE_UNICODE_INTERNALS && (PY_VERSION_HEX < 0x030B0000)
            Py_hash_t hash1, hash2;
            hash1 = ((PyBytesObject*)s1)->ob_shash;
            hash2 = ((PyBytesObject*)s2)->ob_shash;
            if (hash1 != hash2 && hash1 != -1 && hash2 != -1) {
                return (equals == Py_NE);
            }
#endif
            result = memcmp(ps1, ps2, (size_t)length);
            return (equals == Py_EQ) ? (result == 0) : (result != 0);
        }
    } else if ((s1 == Py_None) & PyBytes_CheckExact(s2)) {
        return (equals == Py_NE);
    } else if ((s2 == Py_None) & PyBytes_CheckExact(s1)) {
        return (equals == Py_NE);
    } else {
        int result;
        PyObject* py_result = PyObject_RichCompare(s1, s2, equals);
        if (!py_result)
            return -1;
        result = __Pyx_PyObject_IsTrue(py_result);
        Py_DECREF(py_result);
        return result;
    }
#endif
}

/* UnicodeEquals */
static CYTHON_INLINE int __Pyx_PyUnicode_Equals(PyObject* s1, PyObject* s2, int equals) {
#if CYTHON_COMPILING_IN_PYPY
    return PyObject_RichCompareBool(s1, s2, equals);
#else
#if PY_MAJOR_VERSION < 3
    PyObject* owned_ref = NULL;
#endif
    int s1_is_unicode, s2_is_unicode;
    if (s1 == s2) {
        goto return_eq;
    }
    s1_is_unicode = PyUnicode_CheckExact(s1);
    s2_is_unicode = PyUnicode_CheckExact(s2);
#if PY_MAJOR_VERSION < 3
    if ((s1_is_unicode & (!s2_is_unicode)) && PyString_CheckExact(s2)) {
        owned_ref = PyUnicode_FromObject(s2);
        if (unlikely(!owned_ref))
            return -1;
        s2 = owned_ref;
        s2_is_unicode = 1;
    } else if ((s2_is_unicode & (!s1_is_unicode)) && PyString_CheckExact(s1)) {
        owned_ref = PyUnicode_FromObject(s1);
        if (unlikely(!owned_ref))
            return -1;
        s1 = owned_ref;
        s1_is_unicode = 1;
    } else if (((!s2_is_unicode) & (!s1_is_unicode))) {
        return __Pyx_PyBytes_Equals(s1, s2, equals);
    }
#endif
    if (s1_is_unicode & s2_is_unicode) {
        Py_ssize_t length;
        int kind;
        void *data1, *data2;
        if (unlikely(__Pyx_PyUnicode_READY(s1) < 0) || unlikely(__Pyx_PyUnicode_READY(s2) < 0))
            return -1;
        length = __Pyx_PyUnicode_GET_LENGTH(s1);
        if (length != __Pyx_PyUnicode_GET_LENGTH(s2)) {
            goto return_ne;
        }
#if CYTHON_USE_UNICODE_INTERNALS
        {
            Py_hash_t hash1, hash2;
        #if CYTHON_PEP393_ENABLED
            hash1 = ((PyASCIIObject*)s1)->hash;
            hash2 = ((PyASCIIObject*)s2)->hash;
        #else
            hash1 = ((PyUnicodeObject*)s1)->hash;
            hash2 = ((PyUnicodeObject*)s2)->hash;
        #endif
            if (hash1 != hash2 && hash1 != -1 && hash2 != -1) {
                goto return_ne;
            }
        }
#endif
        kind = __Pyx_PyUnicode_KIND(s1);
        if (kind != __Pyx_PyUnicode_KIND(s2)) {
            goto return_ne;
        }
        data1 = __Pyx_PyUnicode_DATA(s1);
        data2 = __Pyx_PyUnicode_DATA(s2);
        if (__Pyx_PyUnicode_READ(kind, data1, 0) != __Pyx_PyUnicode_READ(kind, data2, 0)) {
            goto return_ne;
        } else if (length == 1) {
            goto return_eq;
        } else {
            int result = memcmp(data1, data2, (size_t)(length * kind));
            #if PY_MAJOR_VERSION < 3
            Py_XDECREF(owned_ref);
            #endif
            return (equals == Py_EQ) ? (result == 0) : (result != 0);
        }
    } else if ((s1 == Py_None) & s2_is_unicode) {
        goto return_ne;
    } else if ((s2 == Py_None) & s1_is_unicode) {
        goto return_ne;
    } else {
        int result;
        PyObject* py_result = PyObject_RichCompare(s1, s2, equals);
        #if PY_MAJOR_VERSION < 3
        Py_XDECREF(owned_ref);
        #endif
        if (!py_result)
            return -1;
        result = __Pyx_PyObject_IsTrue(py_result);
        Py_DECREF(py_result);
        return result;
    }
return_eq:
    #if PY_MAJOR_VERSION < 3
    Py_XDECREF(owned_ref);
    #endif
    return (equals == Py_EQ);
return_ne:
    #if PY_MAJOR_VERSION < 3
    Py_XDECREF(owned_ref);
    #endif
    return (equals == Py_NE);
#endif
}

/* pyobject_as_double */
static double __Pyx__PyObject_AsDouble(PyObject* obj) {
    PyObject* float_value;
#if !CYTHON_USE_TYPE_SLOTS
    float_value = PyNumber_Float(obj);  if ((0)) goto bad;
#else
    PyNumberMethods *nb = Py_TYPE(obj)->tp_as_number;
    if (likely(nb) && likely(nb->nb_float)) {
        float_value = nb->nb_float(obj);
        if (likely(float_value) && unlikely(!PyFloat_Check(float_value))) {
            PyErr_Format(PyExc_TypeError,
                "__float__ returned non-float (type %.200s)",
                Py_TYPE(float_value)->tp_name);
            Py_DECREF(float_value);
            goto bad;
        }
    } else if (PyUnicode_CheckExact(obj) || PyBytes_CheckExact(obj)) {
#if PY_MAJOR_VERSION >= 3
        float_value = PyFloat_FromString(obj);
#else
        float_value = PyFloat_FromString(obj, 0);
#endif
    } else {
        PyObject* args = PyTuple_New(1);
        if (unlikely(!args)) goto bad;
        PyTuple_SET_ITEM(args, 0, obj);
        float_value = PyObject_Call((PyObject*)&PyFloat_Type, args, 0);
        PyTuple_SET_ITEM(args, 0, 0);
        Py_DECREF(args);
    }
#endif
    if (likely(float_value)) {
        double value = PyFloat_AS_DOUBLE(float_value);
        Py_DECREF(float_value);
        return value;
    }
bad:
    return (double)-1;
}

/* GetItemInt */
static PyObject *__Pyx_GetItemInt_Generic(PyObject *o, PyObject* j) {
    PyObject *r;
    if (!j) return NULL;
    r = PyObject_GetItem(o, j);
    Py_DECREF(j);
    return r;
}
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_List_Fast(PyObject *o, Py_ssize_t i,
                                                              CYTHON_NCP_UNUSED int wraparound,
                                                              CYTHON_NCP_UNUSED int boundscheck) {
#if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    Py_ssize_t wrapped_i = i;
    if (wraparound & unlikely(i < 0)) {
        wrapped_i += PyList_GET_SIZE(o);
    }
    if ((!boundscheck) || likely(__Pyx_is_valid_index(wrapped_i, PyList_GET_SIZE(o)))) {
        PyObject *r = PyList_GET_ITEM(o, wrapped_i);
        Py_INCREF(r);
        return r;
    }
    return __Pyx_GetItemInt_Generic(o, PyInt_FromSsize_t(i));
#else
    return PySequence_GetItem(o, i);
#endif
}
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Tuple_Fast(PyObject *o, Py_ssize_t i,
                                                              CYTHON_NCP_UNUSED int wraparound,
                                                              CYTHON_NCP_UNUSED int boundscheck) {
#if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    Py_ssize_t wrapped_i = i;
    if (wraparound & unlikely(i < 0)) {
        wrapped_i += PyTuple_GET_SIZE(o);
    }
    if ((!boundscheck) || likely(__Pyx_is_valid_index(wrapped_i, PyTuple_GET_SIZE(o)))) {
        PyObject *r = PyTuple_GET_ITEM(o, wrapped_i);
        Py_INCREF(r);
        return r;
    }
    return __Pyx_GetItemInt_Generic(o, PyInt_FromSsize_t(i));
#else
    return PySequence_GetItem(o, i);
#endif
}
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Fast(PyObject *o, Py_ssize_t i, int is_list,
                                                     CYTHON_NCP_UNUSED int wraparound,
                                                     CYTHON_NCP_UNUSED int boundscheck) {
#if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS && CYTHON_USE_TYPE_SLOTS
    if (is_list || PyList_CheckExact(o)) {
        Py_ssize_t n = ((!wraparound) | likely(i >= 0)) ? i : i + PyList_GET_SIZE(o);
        if ((!boundscheck) || (likely(__Pyx_is_valid_index(n, PyList_GET_SIZE(o))))) {
            PyObject *r = PyList_GET_ITEM(o, n);
            Py_INCREF(r);
            return r;
        }
    }
    else if (PyTuple_CheckExact(o)) {
        Py_ssize_t n = ((!wraparound) | likely(i >= 0)) ? i : i + PyTuple_GET_SIZE(o);
        if ((!boundscheck) || likely(__Pyx_is_valid_index(n, PyTuple_GET_SIZE(o)))) {
            PyObject *r = PyTuple_GET_ITEM(o, n);
            Py_INCREF(r);
            return r;
        }
    } else {
        PySequenceMethods *m = Py_TYPE(o)->tp_as_sequence;
        if (likely(m && m->sq_item)) {
            if (wraparound && unlikely(i < 0) && likely(m->sq_length)) {
                Py_ssize_t l = m->sq_length(o);
                if (likely(l >= 0)) {
                    i += l;
                } else {
                    if (!PyErr_ExceptionMatches(PyExc_OverflowError))
                        return NULL;
                    PyErr_Clear();
                }
            }
            return m->sq_item(o, i);
        }
    }
#else
    if (is_list || PySequence_Check(o)) {
        return PySequence_GetItem(o, i);
    }
#endif
    return __Pyx_GetItemInt_Generic(o, PyInt_FromSsize_t(i));
}

/* SetItemInt */
static int __Pyx_SetItemInt_Generic(PyObject *o, PyObject *j, PyObject *v) {
    int r;
    if (!j) return -1;
    r = PyObject_SetItem(o, j, v);
    Py_DECREF(j);
    return r;
}
static CYTHON_INLINE int __Pyx_SetItemInt_Fast(PyObject *o, Py_ssize_t i, PyObject *v, int is_list,
                                               CYTHON_NCP_UNUSED int wraparound, CYTHON_NCP_UNUSED int boundscheck) {
#if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS && CYTHON_USE_TYPE_SLOTS
    if (is_list || PyList_CheckExact(o)) {
        Py_ssize_t n = (!wraparound) ? i : ((likely(i >= 0)) ? i : i + PyList_GET_SIZE(o));
        if ((!boundscheck) || likely(__Pyx_is_valid_index(n, PyList_GET_SIZE(o)))) {
            PyObject* old = PyList_GET_ITEM(o, n);
            Py_INCREF(v);
            PyList_SET_ITEM(o, n, v);
            Py_DECREF(old);
            return 1;
        }
    } else {
        PySequenceMethods *m = Py_TYPE(o)->tp_as_sequence;
        if (likely(m && m->sq_ass_item)) {
            if (wraparound && unlikely(i < 0) && likely(m->sq_length)) {
                Py_ssize_t l = m->sq_length(o);
                if (likely(l >= 0)) {
                    i += l;
                } else {
                    if (!PyErr_ExceptionMatches(PyExc_OverflowError))
                        return -1;
                    PyErr_Clear();
                }
            }
            return m->sq_ass_item(o, i, v);
        }
    }
#else
#if CYTHON_COMPILING_IN_PYPY
    if (is_list || (PySequence_Check(o) && !PyDict_Check(o)))
#else
    if (is_list || PySequence_Check(o))
#endif
    {
        return PySequence_SetItem(o, i, v);
    }
#endif
    return __Pyx_SetItemInt_Generic(o, PyInt_FromSsize_t(i), v);
}

/* SliceObject */
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetSlice(PyObject* obj,
        Py_ssize_t cstart, Py_ssize_t cstop,
        PyObject** _py_start, PyObject** _py_stop, PyObject** _py_slice,
        int has_cstart, int has_cstop, CYTHON_UNUSED int wraparound) {
#if CYTHON_USE_TYPE_SLOTS
    PyMappingMethods* mp;
#if PY_MAJOR_VERSION < 3
    PySequenceMethods* ms = Py_TYPE(obj)->tp_as_sequence;
    if (likely(ms && ms->sq_slice)) {
        if (!has_cstart) {
            if (_py_start && (*_py_start != Py_None)) {
                cstart = __Pyx_PyIndex_AsSsize_t(*_py_start);
                if ((cstart == (Py_ssize_t)-1) && PyErr_Occurred()) goto bad;
            } else
                cstart = 0;
        }
        if (!has_cstop) {
            if (_py_stop && (*_py_stop != Py_None)) {
                cstop = __Pyx_PyIndex_AsSsize_t(*_py_stop);
                if ((cstop == (Py_ssize_t)-1) && PyErr_Occurred()) goto bad;
            } else
                cstop = PY_SSIZE_T_MAX;
        }
        if (wraparound && unlikely((cstart < 0) | (cstop < 0)) && likely(ms->sq_length)) {
            Py_ssize_t l = ms->sq_length(obj);
            if (likely(l >= 0)) {
                if (cstop < 0) {
                    cstop += l;
                    if (cstop < 0) cstop = 0;
                }
                if (cstart < 0) {
                    cstart += l;
                    if (cstart < 0) cstart = 0;
                }
            } else {
                if (!PyErr_ExceptionMatches(PyExc_OverflowError))
                    goto bad;
                PyErr_Clear();
            }
        }
        return ms->sq_slice(obj, cstart, cstop);
    }
#endif
    mp = Py_TYPE(obj)->tp_as_mapping;
    if (likely(mp && mp->mp_subscript))
#endif
    {
        PyObject* result;
        PyObject *py_slice, *py_start, *py_stop;
        if (_py_slice) {
            py_slice = *_py_slice;
        } else {
            PyObject* owned_start = NULL;
            PyObject* owned_stop = NULL;
            if (_py_start) {
                py_start = *_py_start;
            } else {
                if (has_cstart) {
                    owned_start = py_start = PyInt_FromSsize_t(cstart);
                    if (unlikely(!py_start)) goto bad;
                } else
                    py_start = Py_None;
            }
            if (_py_stop) {
                py_stop = *_py_stop;
            } else {
                if (has_cstop) {
                    owned_stop = py_stop = PyInt_FromSsize_t(cstop);
                    if (unlikely(!py_stop)) {
                        Py_XDECREF(owned_start);
                        goto bad;
                    }
                } else
                    py_stop = Py_None;
            }
            py_slice = PySlice_New(py_start, py_stop, Py_None);
            Py_XDECREF(owned_start);
            Py_XDECREF(owned_stop);
            if (unlikely(!py_slice)) goto bad;
        }
#if CYTHON_USE_TYPE_SLOTS
        result = mp->mp_subscript(obj, py_slice);
#else
        result = PyObject_GetItem(obj, py_slice);
#endif
        if (!_py_slice) {
            Py_DECREF(py_slice);
        }
        return result;
    }
    PyErr_Format(PyExc_TypeError,
        "'%.200s' object is unsliceable", Py_TYPE(obj)->tp_name);
bad:
    return NULL;
}

/* StringJoin */
#if !CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyBytes_Join(PyObject* sep, PyObject* values) {
    return PyObject_CallMethodObjArgs(sep, __pyx_n_s_join, values, NULL);
}
#endif

/* WriteUnraisableException */
static void __Pyx_WriteUnraisable(const char *name, CYTHON_UNUSED int clineno,
                                  CYTHON_UNUSED int lineno, CYTHON_UNUSED const char *filename,
                                  int full_traceback, CYTHON_UNUSED int nogil) {
    PyObject *old_exc, *old_val, *old_tb;
    PyObject *ctx;
    __Pyx_PyThreadState_declare
#ifdef WITH_THREAD
    PyGILState_STATE state;
    if (nogil)
        state = PyGILState_Ensure();
#ifdef _MSC_VER
    else state = (PyGILState_STATE)-1;
#endif
#endif
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&old_exc, &old_val, &old_tb);
    if (full_traceback) {
        Py_XINCREF(old_exc);
        Py_XINCREF(old_val);
        Py_XINCREF(old_tb);
        __Pyx_ErrRestore(old_exc, old_val, old_tb);
        PyErr_PrintEx(1);
    }
    #if PY_MAJOR_VERSION < 3
    ctx = PyString_FromString(name);
    #else
    ctx = PyUnicode_FromString(name);
    #endif
    __Pyx_ErrRestore(old_exc, old_val, old_tb);
    if (!ctx) {
        PyErr_WriteUnraisable(Py_None);
    } else {
        PyErr_WriteUnraisable(ctx);
        Py_DECREF(ctx);
    }
#ifdef WITH_THREAD
    if (nogil)
        PyGILState_Release(state);
#endif
}

/* PyObject_GenericGetAttrNoDict */
#if CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP && PY_VERSION_HEX < 0x03070000
static PyObject *__Pyx_RaiseGenericGetAttributeError(PyTypeObject *tp, PyObject *attr_name) {
    PyErr_Format(PyExc_AttributeError,
#if PY_MAJOR_VERSION >= 3
                 "'%.50s' object has no attribute '%U'",
                 tp->tp_name, attr_name);
#else
                 "'%.50s' object has no attribute '%.400s'",
                 tp->tp_name, PyString_AS_STRING(attr_name));
#endif
    return NULL;
}
static CYTHON_INLINE PyObject* __Pyx_PyObject_GenericGetAttrNoDict(PyObject* obj, PyObject* attr_name) {
    PyObject *descr;
    PyTypeObject *tp = Py_TYPE(obj);
    if (unlikely(!PyString_Check(attr_name))) {
        return PyObject_GenericGetAttr(obj, attr_name);
    }
    assert(!tp->tp_dictoffset);
    descr = _PyType_Lookup(tp, attr_name);
    if (unlikely(!descr)) {
        return __Pyx_RaiseGenericGetAttributeError(tp, attr_name);
    }
    Py_INCREF(descr);
    #if PY_MAJOR_VERSION < 3
    if (likely(PyType_HasFeature(Py_TYPE(descr), Py_TPFLAGS_HAVE_CLASS)))
    #endif
    {
        descrgetfunc f = Py_TYPE(descr)->tp_descr_get;
        if (unlikely(f)) {
            PyObject *res = f(descr, obj, (PyObject *)tp);
            Py_DECREF(descr);
            return res;
        }
    }
    return descr;
}
#endif

/* PyObject_GenericGetAttr */
#if CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP && PY_VERSION_HEX < 0x03070000
static PyObject* __Pyx_PyObject_GenericGetAttr(PyObject* obj, PyObject* attr_name) {
    if (unlikely(Py_TYPE(obj)->tp_dictoffset)) {
        return PyObject_GenericGetAttr(obj, attr_name);
    }
    return __Pyx_PyObject_GenericGetAttrNoDict(obj, attr_name);
}
#endif

/* SetVTable */
static int __Pyx_SetVtable(PyObject *dict, void *vtable) {
#if PY_VERSION_HEX >= 0x02070000
    PyObject *ob = PyCapsule_New(vtable, 0, 0);
#else
    PyObject *ob = PyCObject_FromVoidPtr(vtable, 0);
#endif
    if (!ob)
        goto bad;
    if (PyDict_SetItem(dict, __pyx_n_s_pyx_vtable, ob) < 0)
        goto bad;
    Py_DECREF(ob);
    return 0;
bad:
    Py_XDECREF(ob);
    return -1;
}

/* PyErrExceptionMatches */
#if CYTHON_FAST_THREAD_STATE
static int __Pyx_PyErr_ExceptionMatchesTuple(PyObject *exc_type, PyObject *tuple) {
    Py_ssize_t i, n;
    n = PyTuple_GET_SIZE(tuple);
#if PY_MAJOR_VERSION >= 3
    for (i=0; i<n; i++) {
        if (exc_type == PyTuple_GET_ITEM(tuple, i)) return 1;
    }
#endif
    for (i=0; i<n; i++) {
        if (__Pyx_PyErr_GivenExceptionMatches(exc_type, PyTuple_GET_ITEM(tuple, i))) return 1;
    }
    return 0;
}
static CYTHON_INLINE int __Pyx_PyErr_ExceptionMatchesInState(PyThreadState* tstate, PyObject* err) {
    PyObject *exc_type = tstate->curexc_type;
    if (exc_type == err) return 1;
    if (unlikely(!exc_type)) return 0;
    if (unlikely(PyTuple_Check(err)))
        return __Pyx_PyErr_ExceptionMatchesTuple(exc_type, err);
    return __Pyx_PyErr_GivenExceptionMatches(exc_type, err);
}
#endif

/* PyObjectGetAttrStrNoError */
static void __Pyx_PyObject_GetAttrStr_ClearAttributeError(void) {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    if (likely(__Pyx_PyErr_ExceptionMatches(PyExc_AttributeError)))
        __Pyx_PyErr_Clear();
}
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetAttrStrNoError(PyObject* obj, PyObject* attr_name) {
    PyObject *result;
#if CYTHON_COMPILING_IN_CPYTHON && CYTHON_USE_TYPE_SLOTS && PY_VERSION_HEX >= 0x030700B1
    PyTypeObject* tp = Py_TYPE(obj);
    if (likely(tp->tp_getattro == PyObject_GenericGetAttr)) {
        return _PyObject_GenericGetAttrWithDict(obj, attr_name, NULL, 1);
    }
#endif
    result = __Pyx_PyObject_GetAttrStr(obj, attr_name);
    if (unlikely(!result)) {
        __Pyx_PyObject_GetAttrStr_ClearAttributeError();
    }
    return result;
}

/* SetupReduce */
static int __Pyx_setup_reduce_is_named(PyObject* meth, PyObject* name) {
  int ret;
  PyObject *name_attr;
  name_attr = __Pyx_PyObject_GetAttrStr(meth, __pyx_n_s_name_2);
  if (likely(name_attr)) {
      ret = PyObject_RichCompareBool(name_attr, name, Py_EQ);
  } else {
      ret = -1;
  }
  if (unlikely(ret < 0)) {
      PyErr_Clear();
      ret = 0;
  }
  Py_XDECREF(name_attr);
  return ret;
}
static int __Pyx_setup_reduce(PyObject* type_obj) {
    int ret = 0;
    PyObject *object_reduce = NULL;
    PyObject *object_getstate = NULL;
    PyObject *object_reduce_ex = NULL;
    PyObject *reduce = NULL;
    PyObject *reduce_ex = NULL;
    PyObject *reduce_cython = NULL;
    PyObject *setstate = NULL;
    PyObject *setstate_cython = NULL;
    PyObject *getstate = NULL;
#if CYTHON_USE_PYTYPE_LOOKUP
    getstate = _PyType_Lookup((PyTypeObject*)type_obj, __pyx_n_s_getstate);
#else
    getstate = __Pyx_PyObject_GetAttrStrNoError(type_obj, __pyx_n_s_getstate);
    if (!getstate && PyErr_Occurred()) {
        goto __PYX_BAD;
    }
#endif
    if (getstate) {
#if CYTHON_USE_PYTYPE_LOOKUP
        object_getstate = _PyType_Lookup(&PyBaseObject_Type, __pyx_n_s_getstate);
#else
        object_getstate = __Pyx_PyObject_GetAttrStrNoError((PyObject*)&PyBaseObject_Type, __pyx_n_s_getstate);
        if (!object_getstate && PyErr_Occurred()) {
            goto __PYX_BAD;
        }
#endif
        if (object_getstate != getstate) {
            goto __PYX_GOOD;
        }
    }
#if CYTHON_USE_PYTYPE_LOOKUP
    object_reduce_ex = _PyType_Lookup(&PyBaseObject_Type, __pyx_n_s_reduce_ex); if (!object_reduce_ex) goto __PYX_BAD;
#else
    object_reduce_ex = __Pyx_PyObject_GetAttrStr((PyObject*)&PyBaseObject_Type, __pyx_n_s_reduce_ex); if (!object_reduce_ex) goto __PYX_BAD;
#endif
    reduce_ex = __Pyx_PyObject_GetAttrStr(type_obj, __pyx_n_s_reduce_ex); if (unlikely(!reduce_ex)) goto __PYX_BAD;
    if (reduce_ex == object_reduce_ex) {
#if CYTHON_USE_PYTYPE_LOOKUP
        object_reduce = _PyType_Lookup(&PyBaseObject_Type, __pyx_n_s_reduce); if (!object_reduce) goto __PYX_BAD;
#else
        object_reduce = __Pyx_PyObject_GetAttrStr((PyObject*)&PyBaseObject_Type, __pyx_n_s_reduce); if (!object_reduce) goto __PYX_BAD;
#endif
        reduce = __Pyx_PyObject_GetAttrStr(type_obj, __pyx_n_s_reduce); if (unlikely(!reduce)) goto __PYX_BAD;
        if (reduce == object_reduce || __Pyx_setup_reduce_is_named(reduce, __pyx_n_s_reduce_cython)) {
            reduce_cython = __Pyx_PyObject_GetAttrStrNoError(type_obj, __pyx_n_s_reduce_cython);
            if (likely(reduce_cython)) {
                ret = PyDict_SetItem(((PyTypeObject*)type_obj)->tp_dict, __pyx_n_s_reduce, reduce_cython); if (unlikely(ret < 0)) goto __PYX_BAD;
                ret = PyDict_DelItem(((PyTypeObject*)type_obj)->tp_dict, __pyx_n_s_reduce_cython); if (unlikely(ret < 0)) goto __PYX_BAD;
            } else if (reduce == object_reduce || PyErr_Occurred()) {
                goto __PYX_BAD;
            }
            setstate = __Pyx_PyObject_GetAttrStr(type_obj, __pyx_n_s_setstate);
            if (!setstate) PyErr_Clear();
            if (!setstate || __Pyx_setup_reduce_is_named(setstate, __pyx_n_s_setstate_cython)) {
                setstate_cython = __Pyx_PyObject_GetAttrStrNoError(type_obj, __pyx_n_s_setstate_cython);
                if (likely(setstate_cython)) {
                    ret = PyDict_SetItem(((PyTypeObject*)type_obj)->tp_dict, __pyx_n_s_setstate, setstate_cython); if (unlikely(ret < 0)) goto __PYX_BAD;
                    ret = PyDict_DelItem(((PyTypeObject*)type_obj)->tp_dict, __pyx_n_s_setstate_cython); if (unlikely(ret < 0)) goto __PYX_BAD;
                } else if (!setstate || PyErr_Occurred()) {
                    goto __PYX_BAD;
                }
            }
            PyType_Modified((PyTypeObject*)type_obj);
        }
    }
    goto __PYX_GOOD;
__PYX_BAD:
    if (!PyErr_Occurred())
        PyErr_Format(PyExc_RuntimeError, "Unable to initialize pickling for %s", ((PyTypeObject*)type_obj)->tp_name);
    ret = -1;
__PYX_GOOD:
#if !CYTHON_USE_PYTYPE_LOOKUP
    Py_XDECREF(object_reduce);
    Py_XDECREF(object_reduce_ex);
    Py_XDECREF(object_getstate);
    Py_XDECREF(getstate);
#endif
    Py_XDECREF(reduce);
    Py_XDECREF(reduce_ex);
    Py_XDECREF(reduce_cython);
    Py_XDECREF(setstate);
    Py_XDECREF(setstate_cython);
    return ret;
}

/* TypeImport */
#ifndef __PYX_HAVE_RT_ImportType
#define __PYX_HAVE_RT_ImportType
static PyTypeObject *__Pyx_ImportType(PyObject *module, const char *module_name, const char *class_name,
    size_t size, enum __Pyx_ImportType_CheckSize check_size)
{
    PyObject *result = 0;
    char warning[200];
    Py_ssize_t basicsize;
#ifdef Py_LIMITED_API
    PyObject *py_basicsize;
#endif
    result = PyObject_GetAttrString(module, class_name);
    if (!result)
        goto bad;
    if (!PyType_Check(result)) {
        PyErr_Format(PyExc_TypeError,
            "%.200s.%.200s is not a type object",
            module_name, class_name);
        goto bad;
    }
#ifndef Py_LIMITED_API
    basicsize = ((PyTypeObject *)result)->tp_basicsize;
#else
    py_basicsize = PyObject_GetAttrString(result, "__basicsize__");
    if (!py_basicsize)
        goto bad;
    basicsize = PyLong_AsSsize_t(py_basicsize);
    Py_DECREF(py_basicsize);
    py_basicsize = 0;
    if (basicsize == (Py_ssize_t)-1 && PyErr_Occurred())
        goto bad;
#endif
    if ((size_t)basicsize < size) {
        PyErr_Format(PyExc_ValueError,
            "%.200s.%.200s size changed, may indicate binary incompatibility. "
            "Expected %zd from C header, got %zd from PyObject",
            module_name, class_name, size, basicsize);
        goto bad;
    }
    if (check_size == __Pyx_ImportType_CheckSize_Error && (size_t)basicsize != size) {
        PyErr_Format(PyExc_ValueError,
            "%.200s.%.200s size changed, may indicate binary incompatibility. "
            "Expected %zd from C header, got %zd from PyObject",
            module_name, class_name, size, basicsize);
        goto bad;
    }
    else if (check_size == __Pyx_ImportType_CheckSize_Warn && (size_t)basicsize > size) {
        PyOS_snprintf(warning, sizeof(warning),
            "%s.%s size changed, may indicate binary incompatibility. "
            "Expected %zd from C header, got %zd from PyObject",
            module_name, class_name, size, basicsize);
        if (PyErr_WarnEx(NULL, warning, 0) < 0) goto bad;
    }
    return (PyTypeObject *)result;
bad:
    Py_XDECREF(result);
    return NULL;
}
#endif

/* GetVTable */
static void* __Pyx_GetVtable(PyObject *dict) {
    void* ptr;
    PyObject *ob = PyObject_GetItem(dict, __pyx_n_s_pyx_vtable);
    if (!ob)
        goto bad;
#if PY_VERSION_HEX >= 0x02070000
    ptr = PyCapsule_GetPointer(ob, 0);
#else
    ptr = PyCObject_AsVoidPtr(ob);
#endif
    if (!ptr && !PyErr_Occurred())
        PyErr_SetString(PyExc_RuntimeError, "invalid vtable found for imported type");
    Py_DECREF(ob);
    return ptr;
bad:
    Py_XDECREF(ob);
    return NULL;
}

/* Import */
static PyObject *__Pyx_Import(PyObject *name, PyObject *from_list, int level) {
    PyObject *empty_list = 0;
    PyObject *module = 0;
    PyObject *global_dict = 0;
    PyObject *empty_dict = 0;
    PyObject *list;
    #if PY_MAJOR_VERSION < 3
    PyObject *py_import;
    py_import = __Pyx_PyObject_GetAttrStr(__pyx_b, __pyx_n_s_import);
    if (!py_import)
        goto bad;
    #endif
    if (from_list)
        list = from_list;
    else {
        empty_list = PyList_New(0);
        if (!empty_list)
            goto bad;
        list = empty_list;
    }
    global_dict = PyModule_GetDict(__pyx_m);
    if (!global_dict)
        goto bad;
    empty_dict = PyDict_New();
    if (!empty_dict)
        goto bad;
    {
        #if PY_MAJOR_VERSION >= 3
        if (level == -1) {
            if ((1) && (strchr(__Pyx_MODULE_NAME, '.'))) {
                module = PyImport_ImportModuleLevelObject(
                    name, global_dict, empty_dict, list, 1);
                if (!module) {
                    if (!PyErr_ExceptionMatches(PyExc_ImportError))
                        goto bad;
                    PyErr_Clear();
                }
            }
            level = 0;
        }
        #endif
        if (!module) {
            #if PY_MAJOR_VERSION < 3
            PyObject *py_level = PyInt_FromLong(level);
            if (!py_level)
                goto bad;
            module = PyObject_CallFunctionObjArgs(py_import,
                name, global_dict, empty_dict, list, py_level, (PyObject *)NULL);
            Py_DECREF(py_level);
            #else
            module = PyImport_ImportModuleLevelObject(
                name, global_dict, empty_dict, list, level);
            #endif
        }
    }
bad:
    #if PY_MAJOR_VERSION < 3
    Py_XDECREF(py_import);
    #endif
    Py_XDECREF(empty_list);
    Py_XDECREF(empty_dict);
    return module;
}

/* ImportFrom */
static PyObject* __Pyx_ImportFrom(PyObject* module, PyObject* name) {
    PyObject* value = __Pyx_PyObject_GetAttrStr(module, name);
    if (unlikely(!value) && PyErr_ExceptionMatches(PyExc_AttributeError)) {
        PyErr_Format(PyExc_ImportError,
        #if PY_MAJOR_VERSION < 3
            "cannot import name %.230s", PyString_AS_STRING(name));
        #else
            "cannot import name %S", name);
        #endif
    }
    return value;
}

/* FetchCommonType */
static PyTypeObject* __Pyx_FetchCommonType(PyTypeObject* type) {
    PyObject* fake_module;
    PyTypeObject* cached_type = NULL;
    fake_module = PyImport_AddModule((char*) "_cython_" CYTHON_ABI);
    if (!fake_module) return NULL;
    Py_INCREF(fake_module);
    cached_type = (PyTypeObject*) PyObject_GetAttrString(fake_module, type->tp_name);
    if (cached_type) {
        if (!PyType_Check((PyObject*)cached_type)) {
            PyErr_Format(PyExc_TypeError,
                "Shared Cython type %.200s is not a type object",
                type->tp_name);
            goto bad;
        }
        if (cached_type->tp_basicsize != type->tp_basicsize) {
            PyErr_Format(PyExc_TypeError,
                "Shared Cython type %.200s has the wrong size, try recompiling",
                type->tp_name);
            goto bad;
        }
    } else {
        if (!PyErr_ExceptionMatches(PyExc_AttributeError)) goto bad;
        PyErr_Clear();
        if (PyType_Ready(type) < 0) goto bad;
        if (PyObject_SetAttrString(fake_module, type->tp_name, (PyObject*) type) < 0)
            goto bad;
        Py_INCREF(type);
        cached_type = type;
    }
done:
    Py_DECREF(fake_module);
    return cached_type;
bad:
    Py_XDECREF(cached_type);
    cached_type = NULL;
    goto done;
}

/* CythonFunctionShared */
#include <structmember.h>
static PyObject *
__Pyx_CyFunction_get_doc(__pyx_CyFunctionObject *op, CYTHON_UNUSED void *closure)
{
    if (unlikely(op->func_doc == NULL)) {
        if (op->func.m_ml->ml_doc) {
#if PY_MAJOR_VERSION >= 3
            op->func_doc = PyUnicode_FromString(op->func.m_ml->ml_doc);
#else
            op->func_doc = PyString_FromString(op->func.m_ml->ml_doc);
#endif
            if (unlikely(op->func_doc == NULL))
                return NULL;
        } else {
            Py_INCREF(Py_None);
            return Py_None;
        }
    }
    Py_INCREF(op->func_doc);
    return op->func_doc;
}
static int
__Pyx_CyFunction_set_doc(__pyx_CyFunctionObject *op, PyObject *value, CYTHON_UNUSED void *context)
{
    PyObject *tmp = op->func_doc;
    if (value == NULL) {
        value = Py_None;
    }
    Py_INCREF(value);
    op->func_doc = value;
    Py_XDECREF(tmp);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_name(__pyx_CyFunctionObject *op, CYTHON_UNUSED void *context)
{
    if (unlikely(op->func_name == NULL)) {
#if PY_MAJOR_VERSION >= 3
        op->func_name = PyUnicode_InternFromString(op->func.m_ml->ml_name);
#else
        op->func_name = PyString_InternFromString(op->func.m_ml->ml_name);
#endif
        if (unlikely(op->func_name == NULL))
            return NULL;
    }
    Py_INCREF(op->func_name);
    return op->func_name;
}
static int
__Pyx_CyFunction_set_name(__pyx_CyFunctionObject *op, PyObject *value, CYTHON_UNUSED void *context)
{
    PyObject *tmp;
#if PY_MAJOR_VERSION >= 3
    if (unlikely(value == NULL || !PyUnicode_Check(value)))
#else
    if (unlikely(value == NULL || !PyString_Check(value)))
#endif
    {
        PyErr_SetString(PyExc_TypeError,
                        "__name__ must be set to a string object");
        return -1;
    }
    tmp = op->func_name;
    Py_INCREF(value);
    op->func_name = value;
    Py_XDECREF(tmp);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_qualname(__pyx_CyFunctionObject *op, CYTHON_UNUSED void *context)
{
    Py_INCREF(op->func_qualname);
    return op->func_qualname;
}
static int
__Pyx_CyFunction_set_qualname(__pyx_CyFunctionObject *op, PyObject *value, CYTHON_UNUSED void *context)
{
    PyObject *tmp;
#if PY_MAJOR_VERSION >= 3
    if (unlikely(value == NULL || !PyUnicode_Check(value)))
#else
    if (unlikely(value == NULL || !PyString_Check(value)))
#endif
    {
        PyErr_SetString(PyExc_TypeError,
                        "__qualname__ must be set to a string object");
        return -1;
    }
    tmp = op->func_qualname;
    Py_INCREF(value);
    op->func_qualname = value;
    Py_XDECREF(tmp);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_self(__pyx_CyFunctionObject *m, CYTHON_UNUSED void *closure)
{
    PyObject *self;
    self = m->func_closure;
    if (self == NULL)
        self = Py_None;
    Py_INCREF(self);
    return self;
}
static PyObject *
__Pyx_CyFunction_get_dict(__pyx_CyFunctionObject *op, CYTHON_UNUSED void *context)
{
    if (unlikely(op->func_dict == NULL)) {
        op->func_dict = PyDict_New();
        if (unlikely(op->func_dict == NULL))
            return NULL;
    }
    Py_INCREF(op->func_dict);
    return op->func_dict;
}
static int
__Pyx_CyFunction_set_dict(__pyx_CyFunctionObject *op, PyObject *value, CYTHON_UNUSED void *context)
{
    PyObject *tmp;
    if (unlikely(value == NULL)) {
        PyErr_SetString(PyExc_TypeError,
               "function's dictionary may not be deleted");
        return -1;
    }
    if (unlikely(!PyDict_Check(value))) {
        PyErr_SetString(PyExc_TypeError,
               "setting function's dictionary to a non-dict");
        return -1;
    }
    tmp = op->func_dict;
    Py_INCREF(value);
    op->func_dict = value;
    Py_XDECREF(tmp);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_globals(__pyx_CyFunctionObject *op, CYTHON_UNUSED void *context)
{
    Py_INCREF(op->func_globals);
    return op->func_globals;
}
static PyObject *
__Pyx_CyFunction_get_closure(CYTHON_UNUSED __pyx_CyFunctionObject *op, CYTHON_UNUSED void *context)
{
    Py_INCREF(Py_None);
    return Py_None;
}
static PyObject *
__Pyx_CyFunction_get_code(__pyx_CyFunctionObject *op, CYTHON_UNUSED void *context)
{
    PyObject* result = (op->func_code) ? op->func_code : Py_None;
    Py_INCREF(result);
    return result;
}
static int
__Pyx_CyFunction_init_defaults(__pyx_CyFunctionObject *op) {
    int result = 0;
    PyObject *res = op->defaults_getter((PyObject *) op);
    if (unlikely(!res))
        return -1;
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    op->defaults_tuple = PyTuple_GET_ITEM(res, 0);
    Py_INCREF(op->defaults_tuple);
    op->defaults_kwdict = PyTuple_GET_ITEM(res, 1);
    Py_INCREF(op->defaults_kwdict);
    #else
    op->defaults_tuple = PySequence_ITEM(res, 0);
    if (unlikely(!op->defaults_tuple)) result = -1;
    else {
        op->defaults_kwdict = PySequence_ITEM(res, 1);
        if (unlikely(!op->defaults_kwdict)) result = -1;
    }
    #endif
    Py_DECREF(res);
    return result;
}
static int
__Pyx_CyFunction_set_defaults(__pyx_CyFunctionObject *op, PyObject* value, CYTHON_UNUSED void *context) {
    PyObject* tmp;
    if (!value) {
        value = Py_None;
    } else if (value != Py_None && !PyTuple_Check(value)) {
        PyErr_SetString(PyExc_TypeError,
                        "__defaults__ must be set to a tuple object");
        return -1;
    }
    Py_INCREF(value);
    tmp = op->defaults_tuple;
    op->defaults_tuple = value;
    Py_XDECREF(tmp);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_defaults(__pyx_CyFunctionObject *op, CYTHON_UNUSED void *context) {
    PyObject* result = op->defaults_tuple;
    if (unlikely(!result)) {
        if (op->defaults_getter) {
            if (__Pyx_CyFunction_init_defaults(op) < 0) return NULL;
            result = op->defaults_tuple;
        } else {
            result = Py_None;
        }
    }
    Py_INCREF(result);
    return result;
}
static int
__Pyx_CyFunction_set_kwdefaults(__pyx_CyFunctionObject *op, PyObject* value, CYTHON_UNUSED void *context) {
    PyObject* tmp;
    if (!value) {
        value = Py_None;
    } else if (value != Py_None && !PyDict_Check(value)) {
        PyErr_SetString(PyExc_TypeError,
                        "__kwdefaults__ must be set to a dict object");
        return -1;
    }
    Py_INCREF(value);
    tmp = op->defaults_kwdict;
    op->defaults_kwdict = value;
    Py_XDECREF(tmp);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_kwdefaults(__pyx_CyFunctionObject *op, CYTHON_UNUSED void *context) {
    PyObject* result = op->defaults_kwdict;
    if (unlikely(!result)) {
        if (op->defaults_getter) {
            if (__Pyx_CyFunction_init_defaults(op) < 0) return NULL;
            result = op->defaults_kwdict;
        } else {
            result = Py_None;
        }
    }
    Py_INCREF(result);
    return result;
}
static int
__Pyx_CyFunction_set_annotations(__pyx_CyFunctionObject *op, PyObject* value, CYTHON_UNUSED void *context) {
    PyObject* tmp;
    if (!value || value == Py_None) {
        value = NULL;
    } else if (!PyDict_Check(value)) {
        PyErr_SetString(PyExc_TypeError,
                        "__annotations__ must be set to a dict object");
        return -1;
    }
    Py_XINCREF(value);
    tmp = op->func_annotations;
    op->func_annotations = value;
    Py_XDECREF(tmp);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_annotations(__pyx_CyFunctionObject *op, CYTHON_UNUSED void *context) {
    PyObject* result = op->func_annotations;
    if (unlikely(!result)) {
        result = PyDict_New();
        if (unlikely(!result)) return NULL;
        op->func_annotations = result;
    }
    Py_INCREF(result);
    return result;
}
static PyGetSetDef __pyx_CyFunction_getsets[] = {
    {(char *) "func_doc", (getter)__Pyx_CyFunction_get_doc, (setter)__Pyx_CyFunction_set_doc, 0, 0},
    {(char *) "__doc__",  (getter)__Pyx_CyFunction_get_doc, (setter)__Pyx_CyFunction_set_doc, 0, 0},
    {(char *) "func_name", (getter)__Pyx_CyFunction_get_name, (setter)__Pyx_CyFunction_set_name, 0, 0},
    {(char *) "__name__", (getter)__Pyx_CyFunction_get_name, (setter)__Pyx_CyFunction_set_name, 0, 0},
    {(char *) "__qualname__", (getter)__Pyx_CyFunction_get_qualname, (setter)__Pyx_CyFunction_set_qualname, 0, 0},
    {(char *) "__self__", (getter)__Pyx_CyFunction_get_self, 0, 0, 0},
    {(char *) "func_dict", (getter)__Pyx_CyFunction_get_dict, (setter)__Pyx_CyFunction_set_dict, 0, 0},
    {(char *) "__dict__", (getter)__Pyx_CyFunction_get_dict, (setter)__Pyx_CyFunction_set_dict, 0, 0},
    {(char *) "func_globals", (getter)__Pyx_CyFunction_get_globals, 0, 0, 0},
    {(char *) "__globals__", (getter)__Pyx_CyFunction_get_globals, 0, 0, 0},
    {(char *) "func_closure", (getter)__Pyx_CyFunction_get_closure, 0, 0, 0},
    {(char *) "__closure__", (getter)__Pyx_CyFunction_get_closure, 0, 0, 0},
    {(char *) "func_code", (getter)__Pyx_CyFunction_get_code, 0, 0, 0},
    {(char *) "__code__", (getter)__Pyx_CyFunction_get_code, 0, 0, 0},
    {(char *) "func_defaults", (getter)__Pyx_CyFunction_get_defaults, (setter)__Pyx_CyFunction_set_defaults, 0, 0},
    {(char *) "__defaults__", (getter)__Pyx_CyFunction_get_defaults, (setter)__Pyx_CyFunction_set_defaults, 0, 0},
    {(char *) "__kwdefaults__", (getter)__Pyx_CyFunction_get_kwdefaults, (setter)__Pyx_CyFunction_set_kwdefaults, 0, 0},
    {(char *) "__annotations__", (getter)__Pyx_CyFunction_get_annotations, (setter)__Pyx_CyFunction_set_annotations, 0, 0},
    {0, 0, 0, 0, 0}
};
static PyMemberDef __pyx_CyFunction_members[] = {
    {(char *) "__module__", T_OBJECT, offsetof(PyCFunctionObject, m_module), PY_WRITE_RESTRICTED, 0},
    {0, 0, 0,  0, 0}
};
static PyObject *
__Pyx_CyFunction_reduce(__pyx_CyFunctionObject *m, CYTHON_UNUSED PyObject *args)
{
#if PY_MAJOR_VERSION >= 3
    Py_INCREF(m->func_qualname);
    return m->func_qualname;
#else
    return PyString_FromString(m->func.m_ml->ml_name);
#endif
}
static PyMethodDef __pyx_CyFunction_methods[] = {
    {"__reduce__", (PyCFunction)__Pyx_CyFunction_reduce, METH_VARARGS, 0},
    {0, 0, 0, 0}
};
#if PY_VERSION_HEX < 0x030500A0
#define __Pyx_CyFunction_weakreflist(cyfunc) ((cyfunc)->func_weakreflist)
#else
#define __Pyx_CyFunction_weakreflist(cyfunc) ((cyfunc)->func.m_weakreflist)
#endif
static PyObject *__Pyx_CyFunction_Init(__pyx_CyFunctionObject *op, PyMethodDef *ml, int flags, PyObject* qualname,
                                       PyObject *closure, PyObject *module, PyObject* globals, PyObject* code) {
    if (unlikely(op == NULL))
        return NULL;
    op->flags = flags;
    __Pyx_CyFunction_weakreflist(op) = NULL;
    op->func.m_ml = ml;
    op->func.m_self = (PyObject *) op;
    Py_XINCREF(closure);
    op->func_closure = closure;
    Py_XINCREF(module);
    op->func.m_module = module;
    op->func_dict = NULL;
    op->func_name = NULL;
    Py_INCREF(qualname);
    op->func_qualname = qualname;
    op->func_doc = NULL;
    op->func_classobj = NULL;
    op->func_globals = globals;
    Py_INCREF(op->func_globals);
    Py_XINCREF(code);
    op->func_code = code;
    op->defaults_pyobjects = 0;
    op->defaults_size = 0;
    op->defaults = NULL;
    op->defaults_tuple = NULL;
    op->defaults_kwdict = NULL;
    op->defaults_getter = NULL;
    op->func_annotations = NULL;
    return (PyObject *) op;
}
static int
__Pyx_CyFunction_clear(__pyx_CyFunctionObject *m)
{
    Py_CLEAR(m->func_closure);
    Py_CLEAR(m->func.m_module);
    Py_CLEAR(m->func_dict);
    Py_CLEAR(m->func_name);
    Py_CLEAR(m->func_qualname);
    Py_CLEAR(m->func_doc);
    Py_CLEAR(m->func_globals);
    Py_CLEAR(m->func_code);
    Py_CLEAR(m->func_classobj);
    Py_CLEAR(m->defaults_tuple);
    Py_CLEAR(m->defaults_kwdict);
    Py_CLEAR(m->func_annotations);
    if (m->defaults) {
        PyObject **pydefaults = __Pyx_CyFunction_Defaults(PyObject *, m);
        int i;
        for (i = 0; i < m->defaults_pyobjects; i++)
            Py_XDECREF(pydefaults[i]);
        PyObject_Free(m->defaults);
        m->defaults = NULL;
    }
    return 0;
}
static void __Pyx__CyFunction_dealloc(__pyx_CyFunctionObject *m)
{
    if (__Pyx_CyFunction_weakreflist(m) != NULL)
        PyObject_ClearWeakRefs((PyObject *) m);
    __Pyx_CyFunction_clear(m);
    PyObject_GC_Del(m);
}
static void __Pyx_CyFunction_dealloc(__pyx_CyFunctionObject *m)
{
    PyObject_GC_UnTrack(m);
    __Pyx__CyFunction_dealloc(m);
}
static int __Pyx_CyFunction_traverse(__pyx_CyFunctionObject *m, visitproc visit, void *arg)
{
    Py_VISIT(m->func_closure);
    Py_VISIT(m->func.m_module);
    Py_VISIT(m->func_dict);
    Py_VISIT(m->func_name);
    Py_VISIT(m->func_qualname);
    Py_VISIT(m->func_doc);
    Py_VISIT(m->func_globals);
    Py_VISIT(m->func_code);
    Py_VISIT(m->func_classobj);
    Py_VISIT(m->defaults_tuple);
    Py_VISIT(m->defaults_kwdict);
    if (m->defaults) {
        PyObject **pydefaults = __Pyx_CyFunction_Defaults(PyObject *, m);
        int i;
        for (i = 0; i < m->defaults_pyobjects; i++)
            Py_VISIT(pydefaults[i]);
    }
    return 0;
}
static PyObject *__Pyx_CyFunction_descr_get(PyObject *func, PyObject *obj, PyObject *type)
{
#if PY_MAJOR_VERSION < 3
    __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *) func;
    if (m->flags & __Pyx_CYFUNCTION_STATICMETHOD) {
        Py_INCREF(func);
        return func;
    }
    if (m->flags & __Pyx_CYFUNCTION_CLASSMETHOD) {
        if (type == NULL)
            type = (PyObject *)(Py_TYPE(obj));
        return __Pyx_PyMethod_New(func, type, (PyObject *)(Py_TYPE(type)));
    }
    if (obj == Py_None)
        obj = NULL;
#endif
    return __Pyx_PyMethod_New(func, obj, type);
}
static PyObject*
__Pyx_CyFunction_repr(__pyx_CyFunctionObject *op)
{
#if PY_MAJOR_VERSION >= 3
    return PyUnicode_FromFormat("<cyfunction %U at %p>",
                                op->func_qualname, (void *)op);
#else
    return PyString_FromFormat("<cyfunction %s at %p>",
                               PyString_AsString(op->func_qualname), (void *)op);
#endif
}
static PyObject * __Pyx_CyFunction_CallMethod(PyObject *func, PyObject *self, PyObject *arg, PyObject *kw) {
    PyCFunctionObject* f = (PyCFunctionObject*)func;
    PyCFunction meth = f->m_ml->ml_meth;
    Py_ssize_t size;
    switch (f->m_ml->ml_flags & (METH_VARARGS | METH_KEYWORDS | METH_NOARGS | METH_O)) {
    case METH_VARARGS:
        if (likely(kw == NULL || PyDict_Size(kw) == 0))
            return (*meth)(self, arg);
        break;
    case METH_VARARGS | METH_KEYWORDS:
        return (*(PyCFunctionWithKeywords)(void*)meth)(self, arg, kw);
    case METH_NOARGS:
        if (likely(kw == NULL || PyDict_Size(kw) == 0)) {
            size = PyTuple_GET_SIZE(arg);
            if (likely(size == 0))
                return (*meth)(self, NULL);
            PyErr_Format(PyExc_TypeError,
                "%.200s() takes no arguments (%" CYTHON_FORMAT_SSIZE_T "d given)",
                f->m_ml->ml_name, size);
            return NULL;
        }
        break;
    case METH_O:
        if (likely(kw == NULL || PyDict_Size(kw) == 0)) {
            size = PyTuple_GET_SIZE(arg);
            if (likely(size == 1)) {
                PyObject *result, *arg0;
                #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
                arg0 = PyTuple_GET_ITEM(arg, 0);
                #else
                arg0 = PySequence_ITEM(arg, 0); if (unlikely(!arg0)) return NULL;
                #endif
                result = (*meth)(self, arg0);
                #if !(CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS)
                Py_DECREF(arg0);
                #endif
                return result;
            }
            PyErr_Format(PyExc_TypeError,
                "%.200s() takes exactly one argument (%" CYTHON_FORMAT_SSIZE_T "d given)",
                f->m_ml->ml_name, size);
            return NULL;
        }
        break;
    default:
        PyErr_SetString(PyExc_SystemError, "Bad call flags in "
                        "__Pyx_CyFunction_Call. METH_OLDARGS is no "
                        "longer supported!");
        return NULL;
    }
    PyErr_Format(PyExc_TypeError, "%.200s() takes no keyword arguments",
                 f->m_ml->ml_name);
    return NULL;
}
static CYTHON_INLINE PyObject *__Pyx_CyFunction_Call(PyObject *func, PyObject *arg, PyObject *kw) {
    return __Pyx_CyFunction_CallMethod(func, ((PyCFunctionObject*)func)->m_self, arg, kw);
}
static PyObject *__Pyx_CyFunction_CallAsMethod(PyObject *func, PyObject *args, PyObject *kw) {
    PyObject *result;
    __pyx_CyFunctionObject *cyfunc = (__pyx_CyFunctionObject *) func;
    if ((cyfunc->flags & __Pyx_CYFUNCTION_CCLASS) && !(cyfunc->flags & __Pyx_CYFUNCTION_STATICMETHOD)) {
        Py_ssize_t argc;
        PyObject *new_args;
        PyObject *self;
        argc = PyTuple_GET_SIZE(args);
        new_args = PyTuple_GetSlice(args, 1, argc);
        if (unlikely(!new_args))
            return NULL;
        self = PyTuple_GetItem(args, 0);
        if (unlikely(!self)) {
            Py_DECREF(new_args);
            PyErr_Format(PyExc_TypeError,
                         "unbound method %.200S() needs an argument",
                         cyfunc->func_qualname);
            return NULL;
        }
        result = __Pyx_CyFunction_CallMethod(func, self, new_args, kw);
        Py_DECREF(new_args);
    } else {
        result = __Pyx_CyFunction_Call(func, args, kw);
    }
    return result;
}
static PyTypeObject __pyx_CyFunctionType_type = {
    PyVarObject_HEAD_INIT(0, 0)
    "cython_function_or_method",
    sizeof(__pyx_CyFunctionObject),
    0,
    (destructor) __Pyx_CyFunction_dealloc,
    0,
    0,
    0,
#if PY_MAJOR_VERSION < 3
    0,
#else
    0,
#endif
    (reprfunc) __Pyx_CyFunction_repr,
    0,
    0,
    0,
    0,
    __Pyx_CyFunction_CallAsMethod,
    0,
    0,
    0,
    0,
    Py_TPFLAGS_DEFAULT | Py_TPFLAGS_HAVE_GC,
    0,
    (traverseproc) __Pyx_CyFunction_traverse,
    (inquiry) __Pyx_CyFunction_clear,
    0,
#if PY_VERSION_HEX < 0x030500A0
    offsetof(__pyx_CyFunctionObject, func_weakreflist),
#else
    offsetof(PyCFunctionObject, m_weakreflist),
#endif
    0,
    0,
    __pyx_CyFunction_methods,
    __pyx_CyFunction_members,
    __pyx_CyFunction_getsets,
    0,
    0,
    __Pyx_CyFunction_descr_get,
    0,
    offsetof(__pyx_CyFunctionObject, func_dict),
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
#if PY_VERSION_HEX >= 0x030400a1
    0,
#endif
#if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
    0,
#endif
#if PY_VERSION_HEX >= 0x030800b4 && PY_VERSION_HEX < 0x03090000
    0,
#endif
#if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000
    0,
#endif
};
static int __pyx_CyFunction_init(void) {
    __pyx_CyFunctionType = __Pyx_FetchCommonType(&__pyx_CyFunctionType_type);
    if (unlikely(__pyx_CyFunctionType == NULL)) {
        return -1;
    }
    return 0;
}
static CYTHON_INLINE void *__Pyx_CyFunction_InitDefaults(PyObject *func, size_t size, int pyobjects) {
    __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *) func;
    m->defaults = PyObject_Malloc(size);
    if (unlikely(!m->defaults))
        return PyErr_NoMemory();
    memset(m->defaults, 0, size);
    m->defaults_pyobjects = pyobjects;
    m->defaults_size = size;
    return m->defaults;
}
static CYTHON_INLINE void __Pyx_CyFunction_SetDefaultsTuple(PyObject *func, PyObject *tuple) {
    __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *) func;
    m->defaults_tuple = tuple;
    Py_INCREF(tuple);
}
static CYTHON_INLINE void __Pyx_CyFunction_SetDefaultsKwDict(PyObject *func, PyObject *dict) {
    __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *) func;
    m->defaults_kwdict = dict;
    Py_INCREF(dict);
}
static CYTHON_INLINE void __Pyx_CyFunction_SetAnnotationsDict(PyObject *func, PyObject *dict) {
    __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *) func;
    m->func_annotations = dict;
    Py_INCREF(dict);
}

/* CythonFunction */
static PyObject *__Pyx_CyFunction_New(PyMethodDef *ml, int flags, PyObject* qualname,
                                      PyObject *closure, PyObject *module, PyObject* globals, PyObject* code) {
    PyObject *op = __Pyx_CyFunction_Init(
        PyObject_GC_New(__pyx_CyFunctionObject, __pyx_CyFunctionType),
        ml, flags, qualname, closure, module, globals, code
    );
    if (likely(op)) {
        PyObject_GC_Track(op);
    }
    return op;
}

/* CLineInTraceback */
#ifndef CYTHON_CLINE_IN_TRACEBACK
static int __Pyx_CLineForTraceback(CYTHON_NCP_UNUSED PyThreadState *tstate, int c_line) {
    PyObject *use_cline;
    PyObject *ptype, *pvalue, *ptraceback;
#if CYTHON_COMPILING_IN_CPYTHON
    PyObject **cython_runtime_dict;
#endif
    if (unlikely(!__pyx_cython_runtime)) {
        return c_line;
    }
    __Pyx_ErrFetchInState(tstate, &ptype, &pvalue, &ptraceback);
#if CYTHON_COMPILING_IN_CPYTHON
    cython_runtime_dict = _PyObject_GetDictPtr(__pyx_cython_runtime);
    if (likely(cython_runtime_dict)) {
        __PYX_PY_DICT_LOOKUP_IF_MODIFIED(
            use_cline, *cython_runtime_dict,
            __Pyx_PyDict_GetItemStr(*cython_runtime_dict, __pyx_n_s_cline_in_traceback))
    } else
#endif
    {
      PyObject *use_cline_obj = __Pyx_PyObject_GetAttrStr(__pyx_cython_runtime, __pyx_n_s_cline_in_traceback);
      if (use_cline_obj) {
        use_cline = PyObject_Not(use_cline_obj) ? Py_False : Py_True;
        Py_DECREF(use_cline_obj);
      } else {
        PyErr_Clear();
        use_cline = NULL;
      }
    }
    if (!use_cline) {
        c_line = 0;
        (void) PyObject_SetAttr(__pyx_cython_runtime, __pyx_n_s_cline_in_traceback, Py_False);
    }
    else if (use_cline == Py_False || (use_cline != Py_True && PyObject_Not(use_cline) != 0)) {
        c_line = 0;
    }
    __Pyx_ErrRestoreInState(tstate, ptype, pvalue, ptraceback);
    return c_line;
}
#endif

/* CodeObjectCache */
static int __pyx_bisect_code_objects(__Pyx_CodeObjectCacheEntry* entries, int count, int code_line) {
    int start = 0, mid = 0, end = count - 1;
    if (end >= 0 && code_line > entries[end].code_line) {
        return count;
    }
    while (start < end) {
        mid = start + (end - start) / 2;
        if (code_line < entries[mid].code_line) {
            end = mid;
        } else if (code_line > entries[mid].code_line) {
             start = mid + 1;
        } else {
            return mid;
        }
    }
    if (code_line <= entries[mid].code_line) {
        return mid;
    } else {
        return mid + 1;
    }
}
static PyCodeObject *__pyx_find_code_object(int code_line) {
    PyCodeObject* code_object;
    int pos;
    if (unlikely(!code_line) || unlikely(!__pyx_code_cache.entries)) {
        return NULL;
    }
    pos = __pyx_bisect_code_objects(__pyx_code_cache.entries, __pyx_code_cache.count, code_line);
    if (unlikely(pos >= __pyx_code_cache.count) || unlikely(__pyx_code_cache.entries[pos].code_line != code_line)) {
        return NULL;
    }
    code_object = __pyx_code_cache.entries[pos].code_object;
    Py_INCREF(code_object);
    return code_object;
}
static void __pyx_insert_code_object(int code_line, PyCodeObject* code_object) {
    int pos, i;
    __Pyx_CodeObjectCacheEntry* entries = __pyx_code_cache.entries;
    if (unlikely(!code_line)) {
        return;
    }
    if (unlikely(!entries)) {
        entries = (__Pyx_CodeObjectCacheEntry*)PyMem_Malloc(64*sizeof(__Pyx_CodeObjectCacheEntry));
        if (likely(entries)) {
            __pyx_code_cache.entries = entries;
            __pyx_code_cache.max_count = 64;
            __pyx_code_cache.count = 1;
            entries[0].code_line = code_line;
            entries[0].code_object = code_object;
            Py_INCREF(code_object);
        }
        return;
    }
    pos = __pyx_bisect_code_objects(__pyx_code_cache.entries, __pyx_code_cache.count, code_line);
    if ((pos < __pyx_code_cache.count) && unlikely(__pyx_code_cache.entries[pos].code_line == code_line)) {
        PyCodeObject* tmp = entries[pos].code_object;
        entries[pos].code_object = code_object;
        Py_DECREF(tmp);
        return;
    }
    if (__pyx_code_cache.count == __pyx_code_cache.max_count) {
        int new_max = __pyx_code_cache.max_count + 64;
        entries = (__Pyx_CodeObjectCacheEntry*)PyMem_Realloc(
            __pyx_code_cache.entries, ((size_t)new_max) * sizeof(__Pyx_CodeObjectCacheEntry));
        if (unlikely(!entries)) {
            return;
        }
        __pyx_code_cache.entries = entries;
        __pyx_code_cache.max_count = new_max;
    }
    for (i=__pyx_code_cache.count; i>pos; i--) {
        entries[i] = entries[i-1];
    }
    entries[pos].code_line = code_line;
    entries[pos].code_object = code_object;
    __pyx_code_cache.count++;
    Py_INCREF(code_object);
}

/* AddTraceback */
#include "compile.h"
#include "frameobject.h"
#include "traceback.h"
#if PY_VERSION_HEX >= 0x030b00a6
  #ifndef Py_BUILD_CORE
    #define Py_BUILD_CORE 1
  #endif
  #include "internal/pycore_frame.h"
#endif
static PyCodeObject* __Pyx_CreateCodeObjectForTraceback(
            const char *funcname, int c_line,
            int py_line, const char *filename) {
    PyCodeObject *py_code = NULL;
    PyObject *py_funcname = NULL;
    #if PY_MAJOR_VERSION < 3
    PyObject *py_srcfile = NULL;
    py_srcfile = PyString_FromString(filename);
    if (!py_srcfile) goto bad;
    #endif
    if (c_line) {
        #if PY_MAJOR_VERSION < 3
        py_funcname = PyString_FromFormat( "%s (%s:%d)", funcname, __pyx_cfilenm, c_line);
        if (!py_funcname) goto bad;
        #else
        py_funcname = PyUnicode_FromFormat( "%s (%s:%d)", funcname, __pyx_cfilenm, c_line);
        if (!py_funcname) goto bad;
        funcname = PyUnicode_AsUTF8(py_funcname);
        if (!funcname) goto bad;
        #endif
    }
    else {
        #if PY_MAJOR_VERSION < 3
        py_funcname = PyString_FromString(funcname);
        if (!py_funcname) goto bad;
        #endif
    }
    #if PY_MAJOR_VERSION < 3
    py_code = __Pyx_PyCode_New(
        0,
        0,
        0,
        0,
        0,
        __pyx_empty_bytes, /*PyObject *code,*/
        __pyx_empty_tuple, /*PyObject *consts,*/
        __pyx_empty_tuple, /*PyObject *names,*/
        __pyx_empty_tuple, /*PyObject *varnames,*/
        __pyx_empty_tuple, /*PyObject *freevars,*/
        __pyx_empty_tuple, /*PyObject *cellvars,*/
        py_srcfile,   /*PyObject *filename,*/
        py_funcname,  /*PyObject *name,*/
        py_line,
        __pyx_empty_bytes  /*PyObject *lnotab*/
    );
    Py_DECREF(py_srcfile);
    #else
    py_code = PyCode_NewEmpty(filename, funcname, py_line);
    #endif
    Py_XDECREF(py_funcname);  // XDECREF since it's only set on Py3 if cline
    return py_code;
bad:
    Py_XDECREF(py_funcname);
    #if PY_MAJOR_VERSION < 3
    Py_XDECREF(py_srcfile);
    #endif
    return NULL;
}
static void __Pyx_AddTraceback(const char *funcname, int c_line,
                               int py_line, const char *filename) {
    PyCodeObject *py_code = 0;
    PyFrameObject *py_frame = 0;
    PyThreadState *tstate = __Pyx_PyThreadState_Current;
    PyObject *ptype, *pvalue, *ptraceback;
    if (c_line) {
        c_line = __Pyx_CLineForTraceback(tstate, c_line);
    }
    py_code = __pyx_find_code_object(c_line ? -c_line : py_line);
    if (!py_code) {
        __Pyx_ErrFetchInState(tstate, &ptype, &pvalue, &ptraceback);
        py_code = __Pyx_CreateCodeObjectForTraceback(
            funcname, c_line, py_line, filename);
        if (!py_code) {
            /* If the code object creation fails, then we should clear the
               fetched exception references and propagate the new exception */
            Py_XDECREF(ptype);
            Py_XDECREF(pvalue);
            Py_XDECREF(ptraceback);
            goto bad;
        }
        __Pyx_ErrRestoreInState(tstate, ptype, pvalue, ptraceback);
        __pyx_insert_code_object(c_line ? -c_line : py_line, py_code);
    }
    py_frame = PyFrame_New(
        tstate,            /*PyThreadState *tstate,*/
        py_code,           /*PyCodeObject *code,*/
        __pyx_d,    /*PyObject *globals,*/
        0                  /*PyObject *locals*/
    );
    if (!py_frame) goto bad;
    __Pyx_PyFrame_SetLineNumber(py_frame, py_line);
    PyTraceBack_Here(py_frame);
bad:
    Py_XDECREF(py_code);
    Py_XDECREF(py_frame);
}

/* CIntFromPyVerify */
#define __PYX_VERIFY_RETURN_INT(target_type, func_type, func_value)\
    __PYX__VERIFY_RETURN_INT(target_type, func_type, func_value, 0)
#define __PYX_VERIFY_RETURN_INT_EXC(target_type, func_type, func_value)\
    __PYX__VERIFY_RETURN_INT(target_type, func_type, func_value, 1)
#define __PYX__VERIFY_RETURN_INT(target_type, func_type, func_value, exc)\
    {\
        func_type value = func_value;\
        if (sizeof(target_type) < sizeof(func_type)) {\
            if (unlikely(value != (func_type) (target_type) value)) {\
                func_type zero = 0;\
                if (exc && unlikely(value == (func_type)-1 && PyErr_Occurred()))\
                    return (target_type) -1;\
                if (is_unsigned && unlikely(value < zero))\
                    goto raise_neg_overflow;\
                else\
                    goto raise_overflow;\
            }\
        }\
        return (target_type) value;\
    }

/* Print */
#if !CYTHON_COMPILING_IN_PYPY && PY_MAJOR_VERSION < 3
static PyObject *__Pyx_GetStdout(void) {
    PyObject *f = PySys_GetObject((char *)"stdout");
    if (!f) {
        PyErr_SetString(PyExc_RuntimeError, "lost sys.stdout");
    }
    return f;
}
static int __Pyx_Print(PyObject* f, PyObject *arg_tuple, int newline) {
    int i;
    if (!f) {
        if (!(f = __Pyx_GetStdout()))
            return -1;
    }
    Py_INCREF(f);
    for (i=0; i < PyTuple_GET_SIZE(arg_tuple); i++) {
        PyObject* v;
        if (PyFile_SoftSpace(f, 1)) {
            if (PyFile_WriteString(" ", f) < 0)
                goto error;
        }
        v = PyTuple_GET_ITEM(arg_tuple, i);
        if (PyFile_WriteObject(v, f, Py_PRINT_RAW) < 0)
            goto error;
        if (PyString_Check(v)) {
            char *s = PyString_AsString(v);
            Py_ssize_t len = PyString_Size(v);
            if (len > 0) {
                switch (s[len-1]) {
                    case ' ': break;
                    case '\f': case '\r': case '\n': case '\t': case '\v':
                        PyFile_SoftSpace(f, 0);
                        break;
                    default:  break;
                }
            }
        }
    }
    if (newline) {
        if (PyFile_WriteString("\n", f) < 0)
            goto error;
        PyFile_SoftSpace(f, 0);
    }
    Py_DECREF(f);
    return 0;
error:
    Py_DECREF(f);
    return -1;
}
#else
static int __Pyx_Print(PyObject* stream, PyObject *arg_tuple, int newline) {
    PyObject* kwargs = 0;
    PyObject* result = 0;
    PyObject* end_string;
    if (unlikely(!__pyx_print)) {
        __pyx_print = PyObject_GetAttr(__pyx_b, __pyx_n_s_print);
        if (!__pyx_print)
            return -1;
    }
    if (stream) {
        kwargs = PyDict_New();
        if (unlikely(!kwargs))
            return -1;
        if (unlikely(PyDict_SetItem(kwargs, __pyx_n_s_file_2, stream) < 0))
            goto bad;
        if (!newline) {
            end_string = PyUnicode_FromStringAndSize(" ", 1);
            if (unlikely(!end_string))
                goto bad;
            if (PyDict_SetItem(kwargs, __pyx_n_s_end, end_string) < 0) {
                Py_DECREF(end_string);
                goto bad;
            }
            Py_DECREF(end_string);
        }
    } else if (!newline) {
        if (unlikely(!__pyx_print_kwargs)) {
            __pyx_print_kwargs = PyDict_New();
            if (unlikely(!__pyx_print_kwargs))
                return -1;
            end_string = PyUnicode_FromStringAndSize(" ", 1);
            if (unlikely(!end_string))
                return -1;
            if (PyDict_SetItem(__pyx_print_kwargs, __pyx_n_s_end, end_string) < 0) {
                Py_DECREF(end_string);
                return -1;
            }
            Py_DECREF(end_string);
        }
        kwargs = __pyx_print_kwargs;
    }
    result = PyObject_Call(__pyx_print, arg_tuple, kwargs);
    if (unlikely(kwargs) && (kwargs != __pyx_print_kwargs))
        Py_DECREF(kwargs);
    if (!result)
        return -1;
    Py_DECREF(result);
    return 0;
bad:
    if (kwargs != __pyx_print_kwargs)
        Py_XDECREF(kwargs);
    return -1;
}
#endif

/* CIntFromPy */
static CYTHON_INLINE int __Pyx_PyInt_As_int(PyObject *x) {
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const int neg_one = (int) -1, const_zero = (int) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
#if PY_MAJOR_VERSION < 3
    if (likely(PyInt_Check(x))) {
        if (sizeof(int) < sizeof(long)) {
            __PYX_VERIFY_RETURN_INT(int, long, PyInt_AS_LONG(x))
        } else {
            long val = PyInt_AS_LONG(x);
            if (is_unsigned && unlikely(val < 0)) {
                goto raise_neg_overflow;
            }
            return (int) val;
        }
    } else
#endif
    if (likely(PyLong_Check(x))) {
        if (is_unsigned) {
#if CYTHON_USE_PYLONG_INTERNALS
            const digit* digits = ((PyLongObject*)x)->ob_digit;
            switch (Py_SIZE(x)) {
                case  0: return (int) 0;
                case  1: __PYX_VERIFY_RETURN_INT(int, digit, digits[0])
                case 2:
                    if (8 * sizeof(int) > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) >= 2 * PyLong_SHIFT) {
                            return (int) (((((int)digits[1]) << PyLong_SHIFT) | (int)digits[0]));
                        }
                    }
                    break;
                case 3:
                    if (8 * sizeof(int) > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) >= 3 * PyLong_SHIFT) {
                            return (int) (((((((int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0]));
                        }
                    }
                    break;
                case 4:
                    if (8 * sizeof(int) > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) >= 4 * PyLong_SHIFT) {
                            return (int) (((((((((int)digits[3]) << PyLong_SHIFT) | (int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0]));
                        }
                    }
                    break;
            }
#endif
#if CYTHON_COMPILING_IN_CPYTHON
            if (unlikely(Py_SIZE(x) < 0)) {
                goto raise_neg_overflow;
            }
#else
            {
                int result = PyObject_RichCompareBool(x, Py_False, Py_LT);
                if (unlikely(result < 0))
                    return (int) -1;
                if (unlikely(result == 1))
                    goto raise_neg_overflow;
            }
#endif
            if (sizeof(int) <= sizeof(unsigned long)) {
                __PYX_VERIFY_RETURN_INT_EXC(int, unsigned long, PyLong_AsUnsignedLong(x))
#ifdef HAVE_LONG_LONG
            } else if (sizeof(int) <= sizeof(unsigned PY_LONG_LONG)) {
                __PYX_VERIFY_RETURN_INT_EXC(int, unsigned PY_LONG_LONG, PyLong_AsUnsignedLongLong(x))
#endif
            }
        } else {
#if CYTHON_USE_PYLONG_INTERNALS
            const digit* digits = ((PyLongObject*)x)->ob_digit;
            switch (Py_SIZE(x)) {
                case  0: return (int) 0;
                case -1: __PYX_VERIFY_RETURN_INT(int, sdigit, (sdigit) (-(sdigit)digits[0]))
                case  1: __PYX_VERIFY_RETURN_INT(int,  digit, +digits[0])
                case -2:
                    if (8 * sizeof(int) - 1 > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, long, -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) - 1 > 2 * PyLong_SHIFT) {
                            return (int) (((int)-1)*(((((int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case 2:
                    if (8 * sizeof(int) > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) - 1 > 2 * PyLong_SHIFT) {
                            return (int) ((((((int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case -3:
                    if (8 * sizeof(int) - 1 > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, long, -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) - 1 > 3 * PyLong_SHIFT) {
                            return (int) (((int)-1)*(((((((int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case 3:
                    if (8 * sizeof(int) > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) - 1 > 3 * PyLong_SHIFT) {
                            return (int) ((((((((int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case -4:
                    if (8 * sizeof(int) - 1 > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, long, -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) - 1 > 4 * PyLong_SHIFT) {
                            return (int) (((int)-1)*(((((((((int)digits[3]) << PyLong_SHIFT) | (int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case 4:
                    if (8 * sizeof(int) > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) - 1 > 4 * PyLong_SHIFT) {
                            return (int) ((((((((((int)digits[3]) << PyLong_SHIFT) | (int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
            }
#endif
            if (sizeof(int) <= sizeof(long)) {
                __PYX_VERIFY_RETURN_INT_EXC(int, long, PyLong_AsLong(x))
#ifdef HAVE_LONG_LONG
            } else if (sizeof(int) <= sizeof(PY_LONG_LONG)) {
                __PYX_VERIFY_RETURN_INT_EXC(int, PY_LONG_LONG, PyLong_AsLongLong(x))
#endif
            }
        }
        {
#if CYTHON_COMPILING_IN_PYPY && !defined(_PyLong_AsByteArray)
            PyErr_SetString(PyExc_RuntimeError,
                            "_PyLong_AsByteArray() not available in PyPy, cannot convert large numbers");
#else
            int val;
            PyObject *v = __Pyx_PyNumber_IntOrLong(x);
 #if PY_MAJOR_VERSION < 3
            if (likely(v) && !PyLong_Check(v)) {
                PyObject *tmp = v;
                v = PyNumber_Long(tmp);
                Py_DECREF(tmp);
            }
 #endif
            if (likely(v)) {
                int one = 1; int is_little = (int)*(unsigned char *)&one;
                unsigned char *bytes = (unsigned char *)&val;
                int ret = _PyLong_AsByteArray((PyLongObject *)v,
                                              bytes, sizeof(val),
                                              is_little, !is_unsigned);
                Py_DECREF(v);
                if (likely(!ret))
                    return val;
            }
#endif
            return (int) -1;
        }
    } else {
        int val;
        PyObject *tmp = __Pyx_PyNumber_IntOrLong(x);
        if (!tmp) return (int) -1;
        val = __Pyx_PyInt_As_int(tmp);
        Py_DECREF(tmp);
        return val;
    }
raise_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "value too large to convert to int");
    return (int) -1;
raise_neg_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "can't convert negative value to int");
    return (int) -1;
}

/* PrintOne */
#if !CYTHON_COMPILING_IN_PYPY && PY_MAJOR_VERSION < 3
static int __Pyx_PrintOne(PyObject* f, PyObject *o) {
    if (!f) {
        if (!(f = __Pyx_GetStdout()))
            return -1;
    }
    Py_INCREF(f);
    if (PyFile_SoftSpace(f, 0)) {
        if (PyFile_WriteString(" ", f) < 0)
            goto error;
    }
    if (PyFile_WriteObject(o, f, Py_PRINT_RAW) < 0)
        goto error;
    if (PyFile_WriteString("\n", f) < 0)
        goto error;
    Py_DECREF(f);
    return 0;
error:
    Py_DECREF(f);
    return -1;
    /* the line below is just to avoid C compiler
     * warnings about unused functions */
    return __Pyx_Print(f, NULL, 0);
}
#else
static int __Pyx_PrintOne(PyObject* stream, PyObject *o) {
    int res;
    PyObject* arg_tuple = PyTuple_Pack(1, o);
    if (unlikely(!arg_tuple))
        return -1;
    res = __Pyx_Print(stream, arg_tuple, 1);
    Py_DECREF(arg_tuple);
    return res;
}
#endif

/* CIntToPy */
static CYTHON_INLINE PyObject* __Pyx_PyInt_From_int16_t(int16_t value) {
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const int16_t neg_one = (int16_t) -1, const_zero = (int16_t) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
    if (is_unsigned) {
        if (sizeof(int16_t) < sizeof(long)) {
            return PyInt_FromLong((long) value);
        } else if (sizeof(int16_t) <= sizeof(unsigned long)) {
            return PyLong_FromUnsignedLong((unsigned long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(int16_t) <= sizeof(unsigned PY_LONG_LONG)) {
            return PyLong_FromUnsignedLongLong((unsigned PY_LONG_LONG) value);
#endif
        }
    } else {
        if (sizeof(int16_t) <= sizeof(long)) {
            return PyInt_FromLong((long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(int16_t) <= sizeof(PY_LONG_LONG)) {
            return PyLong_FromLongLong((PY_LONG_LONG) value);
#endif
        }
    }
    {
        int one = 1; int little = (int)*(unsigned char *)&one;
        unsigned char *bytes = (unsigned char *)&value;
        return _PyLong_FromByteArray(bytes, sizeof(int16_t),
                                     little, !is_unsigned);
    }
}

/* CIntFromPy */
static CYTHON_INLINE int16_t __Pyx_PyInt_As_int16_t(PyObject *x) {
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const int16_t neg_one = (int16_t) -1, const_zero = (int16_t) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
#if PY_MAJOR_VERSION < 3
    if (likely(PyInt_Check(x))) {
        if (sizeof(int16_t) < sizeof(long)) {
            __PYX_VERIFY_RETURN_INT(int16_t, long, PyInt_AS_LONG(x))
        } else {
            long val = PyInt_AS_LONG(x);
            if (is_unsigned && unlikely(val < 0)) {
                goto raise_neg_overflow;
            }
            return (int16_t) val;
        }
    } else
#endif
    if (likely(PyLong_Check(x))) {
        if (is_unsigned) {
#if CYTHON_USE_PYLONG_INTERNALS
            const digit* digits = ((PyLongObject*)x)->ob_digit;
            switch (Py_SIZE(x)) {
                case  0: return (int16_t) 0;
                case  1: __PYX_VERIFY_RETURN_INT(int16_t, digit, digits[0])
                case 2:
                    if (8 * sizeof(int16_t) > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int16_t, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int16_t) >= 2 * PyLong_SHIFT) {
                            return (int16_t) (((((int16_t)digits[1]) << PyLong_SHIFT) | (int16_t)digits[0]));
                        }
                    }
                    break;
                case 3:
                    if (8 * sizeof(int16_t) > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int16_t, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int16_t) >= 3 * PyLong_SHIFT) {
                            return (int16_t) (((((((int16_t)digits[2]) << PyLong_SHIFT) | (int16_t)digits[1]) << PyLong_SHIFT) | (int16_t)digits[0]));
                        }
                    }
                    break;
                case 4:
                    if (8 * sizeof(int16_t) > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int16_t, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int16_t) >= 4 * PyLong_SHIFT) {
                            return (int16_t) (((((((((int16_t)digits[3]) << PyLong_SHIFT) | (int16_t)digits[2]) << PyLong_SHIFT) | (int16_t)digits[1]) << PyLong_SHIFT) | (int16_t)digits[0]));
                        }
                    }
                    break;
            }
#endif
#if CYTHON_COMPILING_IN_CPYTHON
            if (unlikely(Py_SIZE(x) < 0)) {
                goto raise_neg_overflow;
            }
#else
            {
                int result = PyObject_RichCompareBool(x, Py_False, Py_LT);
                if (unlikely(result < 0))
                    return (int16_t) -1;
                if (unlikely(result == 1))
                    goto raise_neg_overflow;
            }
#endif
            if (sizeof(int16_t) <= sizeof(unsigned long)) {
                __PYX_VERIFY_RETURN_INT_EXC(int16_t, unsigned long, PyLong_AsUnsignedLong(x))
#ifdef HAVE_LONG_LONG
            } else if (sizeof(int16_t) <= sizeof(unsigned PY_LONG_LONG)) {
                __PYX_VERIFY_RETURN_INT_EXC(int16_t, unsigned PY_LONG_LONG, PyLong_AsUnsignedLongLong(x))
#endif
            }
        } else {
#if CYTHON_USE_PYLONG_INTERNALS
            const digit* digits = ((PyLongObject*)x)->ob_digit;
            switch (Py_SIZE(x)) {
                case  0: return (int16_t) 0;
                case -1: __PYX_VERIFY_RETURN_INT(int16_t, sdigit, (sdigit) (-(sdigit)digits[0]))
                case  1: __PYX_VERIFY_RETURN_INT(int16_t,  digit, +digits[0])
                case -2:
                    if (8 * sizeof(int16_t) - 1 > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int16_t, long, -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int16_t) - 1 > 2 * PyLong_SHIFT) {
                            return (int16_t) (((int16_t)-1)*(((((int16_t)digits[1]) << PyLong_SHIFT) | (int16_t)digits[0])));
                        }
                    }
                    break;
                case 2:
                    if (8 * sizeof(int16_t) > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int16_t, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int16_t) - 1 > 2 * PyLong_SHIFT) {
                            return (int16_t) ((((((int16_t)digits[1]) << PyLong_SHIFT) | (int16_t)digits[0])));
                        }
                    }
                    break;
                case -3:
                    if (8 * sizeof(int16_t) - 1 > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int16_t, long, -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int16_t) - 1 > 3 * PyLong_SHIFT) {
                            return (int16_t) (((int16_t)-1)*(((((((int16_t)digits[2]) << PyLong_SHIFT) | (int16_t)digits[1]) << PyLong_SHIFT) | (int16_t)digits[0])));
                        }
                    }
                    break;
                case 3:
                    if (8 * sizeof(int16_t) > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int16_t, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int16_t) - 1 > 3 * PyLong_SHIFT) {
                            return (int16_t) ((((((((int16_t)digits[2]) << PyLong_SHIFT) | (int16_t)digits[1]) << PyLong_SHIFT) | (int16_t)digits[0])));
                        }
                    }
                    break;
                case -4:
                    if (8 * sizeof(int16_t) - 1 > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int16_t, long, -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int16_t) - 1 > 4 * PyLong_SHIFT) {
                            return (int16_t) (((int16_t)-1)*(((((((((int16_t)digits[3]) << PyLong_SHIFT) | (int16_t)digits[2]) << PyLong_SHIFT) | (int16_t)digits[1]) << PyLong_SHIFT) | (int16_t)digits[0])));
                        }
                    }
                    break;
                case 4:
                    if (8 * sizeof(int16_t) > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int16_t, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int16_t) - 1 > 4 * PyLong_SHIFT) {
                            return (int16_t) ((((((((((int16_t)digits[3]) << PyLong_SHIFT) | (int16_t)digits[2]) << PyLong_SHIFT) | (int16_t)digits[1]) << PyLong_SHIFT) | (int16_t)digits[0])));
                        }
                    }
                    break;
            }
#endif
            if (sizeof(int16_t) <= sizeof(long)) {
                __PYX_VERIFY_RETURN_INT_EXC(int16_t, long, PyLong_AsLong(x))
#ifdef HAVE_LONG_LONG
            } else if (sizeof(int16_t) <= sizeof(PY_LONG_LONG)) {
                __PYX_VERIFY_RETURN_INT_EXC(int16_t, PY_LONG_LONG, PyLong_AsLongLong(x))
#endif
            }
        }
        {
#if CYTHON_COMPILING_IN_PYPY && !defined(_PyLong_AsByteArray)
            PyErr_SetString(PyExc_RuntimeError,
                            "_PyLong_AsByteArray() not available in PyPy, cannot convert large numbers");
#else
            int16_t val;
            PyObject *v = __Pyx_PyNumber_IntOrLong(x);
 #if PY_MAJOR_VERSION < 3
            if (likely(v) && !PyLong_Check(v)) {
                PyObject *tmp = v;
                v = PyNumber_Long(tmp);
                Py_DECREF(tmp);
            }
 #endif
            if (likely(v)) {
                int one = 1; int is_little = (int)*(unsigned char *)&one;
                unsigned char *bytes = (unsigned char *)&val;
                int ret = _PyLong_AsByteArray((PyLongObject *)v,
                                              bytes, sizeof(val),
                                              is_little, !is_unsigned);
                Py_DECREF(v);
                if (likely(!ret))
                    return val;
            }
#endif
            return (int16_t) -1;
        }
    } else {
        int16_t val;
        PyObject *tmp = __Pyx_PyNumber_IntOrLong(x);
        if (!tmp) return (int16_t) -1;
        val = __Pyx_PyInt_As_int16_t(tmp);
        Py_DECREF(tmp);
        return val;
    }
raise_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "value too large to convert to int16_t");
    return (int16_t) -1;
raise_neg_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "can't convert negative value to int16_t");
    return (int16_t) -1;
}

/* CIntToPy */
static CYTHON_INLINE PyObject* __Pyx_PyInt_From_long(long value) {
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const long neg_one = (long) -1, const_zero = (long) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
    if (is_unsigned) {
        if (sizeof(long) < sizeof(long)) {
            return PyInt_FromLong((long) value);
        } else if (sizeof(long) <= sizeof(unsigned long)) {
            return PyLong_FromUnsignedLong((unsigned long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(long) <= sizeof(unsigned PY_LONG_LONG)) {
            return PyLong_FromUnsignedLongLong((unsigned PY_LONG_LONG) value);
#endif
        }
    } else {
        if (sizeof(long) <= sizeof(long)) {
            return PyInt_FromLong((long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(long) <= sizeof(PY_LONG_LONG)) {
            return PyLong_FromLongLong((PY_LONG_LONG) value);
#endif
        }
    }
    {
        int one = 1; int little = (int)*(unsigned char *)&one;
        unsigned char *bytes = (unsigned char *)&value;
        return _PyLong_FromByteArray(bytes, sizeof(long),
                                     little, !is_unsigned);
    }
}

/* CIntToPy */
static CYTHON_INLINE PyObject* __Pyx_PyInt_From_int(int value) {
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const int neg_one = (int) -1, const_zero = (int) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
    if (is_unsigned) {
        if (sizeof(int) < sizeof(long)) {
            return PyInt_FromLong((long) value);
        } else if (sizeof(int) <= sizeof(unsigned long)) {
            return PyLong_FromUnsignedLong((unsigned long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(int) <= sizeof(unsigned PY_LONG_LONG)) {
            return PyLong_FromUnsignedLongLong((unsigned PY_LONG_LONG) value);
#endif
        }
    } else {
        if (sizeof(int) <= sizeof(long)) {
            return PyInt_FromLong((long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(int) <= sizeof(PY_LONG_LONG)) {
            return PyLong_FromLongLong((PY_LONG_LONG) value);
#endif
        }
    }
    {
        int one = 1; int little = (int)*(unsigned char *)&one;
        unsigned char *bytes = (unsigned char *)&value;
        return _PyLong_FromByteArray(bytes, sizeof(int),
                                     little, !is_unsigned);
    }
}

/* CIntFromPy */
static CYTHON_INLINE long __Pyx_PyInt_As_long(PyObject *x) {
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const long neg_one = (long) -1, const_zero = (long) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
#if PY_MAJOR_VERSION < 3
    if (likely(PyInt_Check(x))) {
        if (sizeof(long) < sizeof(long)) {
            __PYX_VERIFY_RETURN_INT(long, long, PyInt_AS_LONG(x))
        } else {
            long val = PyInt_AS_LONG(x);
            if (is_unsigned && unlikely(val < 0)) {
                goto raise_neg_overflow;
            }
            return (long) val;
        }
    } else
#endif
    if (likely(PyLong_Check(x))) {
        if (is_unsigned) {
#if CYTHON_USE_PYLONG_INTERNALS
            const digit* digits = ((PyLongObject*)x)->ob_digit;
            switch (Py_SIZE(x)) {
                case  0: return (long) 0;
                case  1: __PYX_VERIFY_RETURN_INT(long, digit, digits[0])
                case 2:
                    if (8 * sizeof(long) > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) >= 2 * PyLong_SHIFT) {
                            return (long) (((((long)digits[1]) << PyLong_SHIFT) | (long)digits[0]));
                        }
                    }
                    break;
                case 3:
                    if (8 * sizeof(long) > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) >= 3 * PyLong_SHIFT) {
                            return (long) (((((((long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0]));
                        }
                    }
                    break;
                case 4:
                    if (8 * sizeof(long) > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) >= 4 * PyLong_SHIFT) {
                            return (long) (((((((((long)digits[3]) << PyLong_SHIFT) | (long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0]));
                        }
                    }
                    break;
            }
#endif
#if CYTHON_COMPILING_IN_CPYTHON
            if (unlikely(Py_SIZE(x) < 0)) {
                goto raise_neg_overflow;
            }
#else
            {
                int result = PyObject_RichCompareBool(x, Py_False, Py_LT);
                if (unlikely(result < 0))
                    return (long) -1;
                if (unlikely(result == 1))
                    goto raise_neg_overflow;
            }
#endif
            if (sizeof(long) <= sizeof(unsigned long)) {
                __PYX_VERIFY_RETURN_INT_EXC(long, unsigned long, PyLong_AsUnsignedLong(x))
#ifdef HAVE_LONG_LONG
            } else if (sizeof(long) <= sizeof(unsigned PY_LONG_LONG)) {
                __PYX_VERIFY_RETURN_INT_EXC(long, unsigned PY_LONG_LONG, PyLong_AsUnsignedLongLong(x))
#endif
            }
        } else {
#if CYTHON_USE_PYLONG_INTERNALS
            const digit* digits = ((PyLongObject*)x)->ob_digit;
            switch (Py_SIZE(x)) {
                case  0: return (long) 0;
                case -1: __PYX_VERIFY_RETURN_INT(long, sdigit, (sdigit) (-(sdigit)digits[0]))
                case  1: __PYX_VERIFY_RETURN_INT(long,  digit, +digits[0])
                case -2:
                    if (8 * sizeof(long) - 1 > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, long, -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                            return (long) (((long)-1)*(((((long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case 2:
                    if (8 * sizeof(long) > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                            return (long) ((((((long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case -3:
                    if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, long, -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                            return (long) (((long)-1)*(((((((long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case 3:
                    if (8 * sizeof(long) > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                            return (long) ((((((((long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case -4:
                    if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, long, -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) - 1 > 4 * PyLong_SHIFT) {
                            return (long) (((long)-1)*(((((((((long)digits[3]) << PyLong_SHIFT) | (long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case 4:
                    if (8 * sizeof(long) > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) - 1 > 4 * PyLong_SHIFT) {
                            return (long) ((((((((((long)digits[3]) << PyLong_SHIFT) | (long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
            }
#endif
            if (sizeof(long) <= sizeof(long)) {
                __PYX_VERIFY_RETURN_INT_EXC(long, long, PyLong_AsLong(x))
#ifdef HAVE_LONG_LONG
            } else if (sizeof(long) <= sizeof(PY_LONG_LONG)) {
                __PYX_VERIFY_RETURN_INT_EXC(long, PY_LONG_LONG, PyLong_AsLongLong(x))
#endif
            }
        }
        {
#if CYTHON_COMPILING_IN_PYPY && !defined(_PyLong_AsByteArray)
            PyErr_SetString(PyExc_RuntimeError,
                            "_PyLong_AsByteArray() not available in PyPy, cannot convert large numbers");
#else
            long val;
            PyObject *v = __Pyx_PyNumber_IntOrLong(x);
 #if PY_MAJOR_VERSION < 3
            if (likely(v) && !PyLong_Check(v)) {
                PyObject *tmp = v;
                v = PyNumber_Long(tmp);
                Py_DECREF(tmp);
            }
 #endif
            if (likely(v)) {
                int one = 1; int is_little = (int)*(unsigned char *)&one;
                unsigned char *bytes = (unsigned char *)&val;
                int ret = _PyLong_AsByteArray((PyLongObject *)v,
                                              bytes, sizeof(val),
                                              is_little, !is_unsigned);
                Py_DECREF(v);
                if (likely(!ret))
                    return val;
            }
#endif
            return (long) -1;
        }
    } else {
        long val;
        PyObject *tmp = __Pyx_PyNumber_IntOrLong(x);
        if (!tmp) return (long) -1;
        val = __Pyx_PyInt_As_long(tmp);
        Py_DECREF(tmp);
        return val;
    }
raise_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "value too large to convert to long");
    return (long) -1;
raise_neg_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "can't convert negative value to long");
    return (long) -1;
}

/* FastTypeChecks */
#if CYTHON_COMPILING_IN_CPYTHON
static int __Pyx_InBases(PyTypeObject *a, PyTypeObject *b) {
    while (a) {
        a = a->tp_base;
        if (a == b)
            return 1;
    }
    return b == &PyBaseObject_Type;
}
static CYTHON_INLINE int __Pyx_IsSubtype(PyTypeObject *a, PyTypeObject *b) {
    PyObject *mro;
    if (a == b) return 1;
    mro = a->tp_mro;
    if (likely(mro)) {
        Py_ssize_t i, n;
        n = PyTuple_GET_SIZE(mro);
        for (i = 0; i < n; i++) {
            if (PyTuple_GET_ITEM(mro, i) == (PyObject *)b)
                return 1;
        }
        return 0;
    }
    return __Pyx_InBases(a, b);
}
#if PY_MAJOR_VERSION == 2
static int __Pyx_inner_PyErr_GivenExceptionMatches2(PyObject *err, PyObject* exc_type1, PyObject* exc_type2) {
    PyObject *exception, *value, *tb;
    int res;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&exception, &value, &tb);
    res = exc_type1 ? PyObject_IsSubclass(err, exc_type1) : 0;
    if (unlikely(res == -1)) {
        PyErr_WriteUnraisable(err);
        res = 0;
    }
    if (!res) {
        res = PyObject_IsSubclass(err, exc_type2);
        if (unlikely(res == -1)) {
            PyErr_WriteUnraisable(err);
            res = 0;
        }
    }
    __Pyx_ErrRestore(exception, value, tb);
    return res;
}
#else
static CYTHON_INLINE int __Pyx_inner_PyErr_GivenExceptionMatches2(PyObject *err, PyObject* exc_type1, PyObject *exc_type2) {
    int res = exc_type1 ? __Pyx_IsSubtype((PyTypeObject*)err, (PyTypeObject*)exc_type1) : 0;
    if (!res) {
        res = __Pyx_IsSubtype((PyTypeObject*)err, (PyTypeObject*)exc_type2);
    }
    return res;
}
#endif
static int __Pyx_PyErr_GivenExceptionMatchesTuple(PyObject *exc_type, PyObject *tuple) {
    Py_ssize_t i, n;
    assert(PyExceptionClass_Check(exc_type));
    n = PyTuple_GET_SIZE(tuple);
#if PY_MAJOR_VERSION >= 3
    for (i=0; i<n; i++) {
        if (exc_type == PyTuple_GET_ITEM(tuple, i)) return 1;
    }
#endif
    for (i=0; i<n; i++) {
        PyObject *t = PyTuple_GET_ITEM(tuple, i);
        #if PY_MAJOR_VERSION < 3
        if (likely(exc_type == t)) return 1;
        #endif
        if (likely(PyExceptionClass_Check(t))) {
            if (__Pyx_inner_PyErr_GivenExceptionMatches2(exc_type, NULL, t)) return 1;
        } else {
        }
    }
    return 0;
}
static CYTHON_INLINE int __Pyx_PyErr_GivenExceptionMatches(PyObject *err, PyObject* exc_type) {
    if (likely(err == exc_type)) return 1;
    if (likely(PyExceptionClass_Check(err))) {
        if (likely(PyExceptionClass_Check(exc_type))) {
            return __Pyx_inner_PyErr_GivenExceptionMatches2(err, NULL, exc_type);
        } else if (likely(PyTuple_Check(exc_type))) {
            return __Pyx_PyErr_GivenExceptionMatchesTuple(err, exc_type);
        } else {
        }
    }
    return PyErr_GivenExceptionMatches(err, exc_type);
}
static CYTHON_INLINE int __Pyx_PyErr_GivenExceptionMatches2(PyObject *err, PyObject *exc_type1, PyObject *exc_type2) {
    assert(PyExceptionClass_Check(exc_type1));
    assert(PyExceptionClass_Check(exc_type2));
    if (likely(err == exc_type1 || err == exc_type2)) return 1;
    if (likely(PyExceptionClass_Check(err))) {
        return __Pyx_inner_PyErr_GivenExceptionMatches2(err, exc_type1, exc_type2);
    }
    return (PyErr_GivenExceptionMatches(err, exc_type1) || PyErr_GivenExceptionMatches(err, exc_type2));
}
#endif

/* CheckBinaryVersion */
static int __Pyx_check_binary_version(void) {
    char ctversion[5];
    int same=1, i, found_dot;
    const char* rt_from_call = Py_GetVersion();
    PyOS_snprintf(ctversion, 5, "%d.%d", PY_MAJOR_VERSION, PY_MINOR_VERSION);
    found_dot = 0;
    for (i = 0; i < 4; i++) {
        if (!ctversion[i]) {
            same = (rt_from_call[i] < '0' || rt_from_call[i] > '9');
            break;
        }
        if (rt_from_call[i] != ctversion[i]) {
            same = 0;
            break;
        }
    }
    if (!same) {
        char rtversion[5] = {'\0'};
        char message[200];
        for (i=0; i<4; ++i) {
            if (rt_from_call[i] == '.') {
                if (found_dot) break;
                found_dot = 1;
            } else if (rt_from_call[i] < '0' || rt_from_call[i] > '9') {
                break;
            }
            rtversion[i] = rt_from_call[i];
        }
        PyOS_snprintf(message, sizeof(message),
                      "compiletime version %s of module '%.100s' "
                      "does not match runtime version %s",
                      ctversion, __Pyx_MODULE_NAME, rtversion);
        return PyErr_WarnEx(NULL, message, 1);
    }
    return 0;
}

/* InitStrings */
static int __Pyx_InitStrings(__Pyx_StringTabEntry *t) {
    while (t->p) {
        #if PY_MAJOR_VERSION < 3
        if (t->is_unicode) {
            *t->p = PyUnicode_DecodeUTF8(t->s, t->n - 1, NULL);
        } else if (t->intern) {
            *t->p = PyString_InternFromString(t->s);
        } else {
            *t->p = PyString_FromStringAndSize(t->s, t->n - 1);
        }
        #else
        if (t->is_unicode | t->is_str) {
            if (t->intern) {
                *t->p = PyUnicode_InternFromString(t->s);
            } else if (t->encoding) {
                *t->p = PyUnicode_Decode(t->s, t->n - 1, t->encoding, NULL);
            } else {
                *t->p = PyUnicode_FromStringAndSize(t->s, t->n - 1);
            }
        } else {
            *t->p = PyBytes_FromStringAndSize(t->s, t->n - 1);
        }
        #endif
        if (!*t->p)
            return -1;
        if (PyObject_Hash(*t->p) == -1)
            return -1;
        ++t;
    }
    return 0;
}

static CYTHON_INLINE PyObject* __Pyx_PyUnicode_FromString(const char* c_str) {
    return __Pyx_PyUnicode_FromStringAndSize(c_str, (Py_ssize_t)strlen(c_str));
}
static CYTHON_INLINE const char* __Pyx_PyObject_AsString(PyObject* o) {
    Py_ssize_t ignore;
    return __Pyx_PyObject_AsStringAndSize(o, &ignore);
}
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII || __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT
#if !CYTHON_PEP393_ENABLED
static const char* __Pyx_PyUnicode_AsStringAndSize(PyObject* o, Py_ssize_t *length) {
    char* defenc_c;
    PyObject* defenc = _PyUnicode_AsDefaultEncodedString(o, NULL);
    if (!defenc) return NULL;
    defenc_c = PyBytes_AS_STRING(defenc);
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
    {
        char* end = defenc_c + PyBytes_GET_SIZE(defenc);
        char* c;
        for (c = defenc_c; c < end; c++) {
            if ((unsigned char) (*c) >= 128) {
                PyUnicode_AsASCIIString(o);
                return NULL;
            }
        }
    }
#endif
    *length = PyBytes_GET_SIZE(defenc);
    return defenc_c;
}
#else
static CYTHON_INLINE const char* __Pyx_PyUnicode_AsStringAndSize(PyObject* o, Py_ssize_t *length) {
    if (unlikely(__Pyx_PyUnicode_READY(o) == -1)) return NULL;
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
    if (likely(PyUnicode_IS_ASCII(o))) {
        *length = PyUnicode_GET_LENGTH(o);
        return PyUnicode_AsUTF8(o);
    } else {
        PyUnicode_AsASCIIString(o);
        return NULL;
    }
#else
    return PyUnicode_AsUTF8AndSize(o, length);
#endif
}
#endif
#endif
static CYTHON_INLINE const char* __Pyx_PyObject_AsStringAndSize(PyObject* o, Py_ssize_t *length) {
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII || __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT
    if (
#if PY_MAJOR_VERSION < 3 && __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
            __Pyx_sys_getdefaultencoding_not_ascii &&
#endif
            PyUnicode_Check(o)) {
        return __Pyx_PyUnicode_AsStringAndSize(o, length);
    } else
#endif
#if (!CYTHON_COMPILING_IN_PYPY) || (defined(PyByteArray_AS_STRING) && defined(PyByteArray_GET_SIZE))
    if (PyByteArray_Check(o)) {
        *length = PyByteArray_GET_SIZE(o);
        return PyByteArray_AS_STRING(o);
    } else
#endif
    {
        char* result;
        int r = PyBytes_AsStringAndSize(o, &result, length);
        if (unlikely(r < 0)) {
            return NULL;
        } else {
            return result;
        }
    }
}
static CYTHON_INLINE int __Pyx_PyObject_IsTrue(PyObject* x) {
   int is_true = x == Py_True;
   if (is_true | (x == Py_False) | (x == Py_None)) return is_true;
   else return PyObject_IsTrue(x);
}
static CYTHON_INLINE int __Pyx_PyObject_IsTrueAndDecref(PyObject* x) {
    int retval;
    if (unlikely(!x)) return -1;
    retval = __Pyx_PyObject_IsTrue(x);
    Py_DECREF(x);
    return retval;
}
static PyObject* __Pyx_PyNumber_IntOrLongWrongResultType(PyObject* result, const char* type_name) {
#if PY_MAJOR_VERSION >= 3
    if (PyLong_Check(result)) {
        if (PyErr_WarnFormat(PyExc_DeprecationWarning, 1,
                "__int__ returned non-int (type %.200s).  "
                "The ability to return an instance of a strict subclass of int "
                "is deprecated, and may be removed in a future version of Python.",
                Py_TYPE(result)->tp_name)) {
            Py_DECREF(result);
            return NULL;
        }
        return result;
    }
#endif
    PyErr_Format(PyExc_TypeError,
                 "__%.4s__ returned non-%.4s (type %.200s)",
                 type_name, type_name, Py_TYPE(result)->tp_name);
    Py_DECREF(result);
    return NULL;
}
static CYTHON_INLINE PyObject* __Pyx_PyNumber_IntOrLong(PyObject* x) {
#if CYTHON_USE_TYPE_SLOTS
  PyNumberMethods *m;
#endif
  const char *name = NULL;
  PyObject *res = NULL;
#if PY_MAJOR_VERSION < 3
  if (likely(PyInt_Check(x) || PyLong_Check(x)))
#else
  if (likely(PyLong_Check(x)))
#endif
    return __Pyx_NewRef(x);
#if CYTHON_USE_TYPE_SLOTS
  m = Py_TYPE(x)->tp_as_number;
  #if PY_MAJOR_VERSION < 3
  if (m && m->nb_int) {
    name = "int";
    res = m->nb_int(x);
  }
  else if (m && m->nb_long) {
    name = "long";
    res = m->nb_long(x);
  }
  #else
  if (likely(m && m->nb_int)) {
    name = "int";
    res = m->nb_int(x);
  }
  #endif
#else
  if (!PyBytes_CheckExact(x) && !PyUnicode_CheckExact(x)) {
    res = PyNumber_Int(x);
  }
#endif
  if (likely(res)) {
#if PY_MAJOR_VERSION < 3
    if (unlikely(!PyInt_Check(res) && !PyLong_Check(res))) {
#else
    if (unlikely(!PyLong_CheckExact(res))) {
#endif
        return __Pyx_PyNumber_IntOrLongWrongResultType(res, name);
    }
  }
  else if (!PyErr_Occurred()) {
    PyErr_SetString(PyExc_TypeError,
                    "an integer is required");
  }
  return res;
}
static CYTHON_INLINE Py_ssize_t __Pyx_PyIndex_AsSsize_t(PyObject* b) {
  Py_ssize_t ival;
  PyObject *x;
#if PY_MAJOR_VERSION < 3
  if (likely(PyInt_CheckExact(b))) {
    if (sizeof(Py_ssize_t) >= sizeof(long))
        return PyInt_AS_LONG(b);
    else
        return PyInt_AsSsize_t(b);
  }
#endif
  if (likely(PyLong_CheckExact(b))) {
    #if CYTHON_USE_PYLONG_INTERNALS
    const digit* digits = ((PyLongObject*)b)->ob_digit;
    const Py_ssize_t size = Py_SIZE(b);
    if (likely(__Pyx_sst_abs(size) <= 1)) {
        ival = likely(size) ? digits[0] : 0;
        if (size == -1) ival = -ival;
        return ival;
    } else {
      switch (size) {
         case 2:
           if (8 * sizeof(Py_ssize_t) > 2 * PyLong_SHIFT) {
             return (Py_ssize_t) (((((size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case -2:
           if (8 * sizeof(Py_ssize_t) > 2 * PyLong_SHIFT) {
             return -(Py_ssize_t) (((((size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case 3:
           if (8 * sizeof(Py_ssize_t) > 3 * PyLong_SHIFT) {
             return (Py_ssize_t) (((((((size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case -3:
           if (8 * sizeof(Py_ssize_t) > 3 * PyLong_SHIFT) {
             return -(Py_ssize_t) (((((((size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case 4:
           if (8 * sizeof(Py_ssize_t) > 4 * PyLong_SHIFT) {
             return (Py_ssize_t) (((((((((size_t)digits[3]) << PyLong_SHIFT) | (size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case -4:
           if (8 * sizeof(Py_ssize_t) > 4 * PyLong_SHIFT) {
             return -(Py_ssize_t) (((((((((size_t)digits[3]) << PyLong_SHIFT) | (size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
      }
    }
    #endif
    return PyLong_AsSsize_t(b);
  }
  x = PyNumber_Index(b);
  if (!x) return -1;
  ival = PyInt_AsSsize_t(x);
  Py_DECREF(x);
  return ival;
}
static CYTHON_INLINE Py_hash_t __Pyx_PyIndex_AsHash_t(PyObject* o) {
  if (sizeof(Py_hash_t) == sizeof(Py_ssize_t)) {
    return (Py_hash_t) __Pyx_PyIndex_AsSsize_t(o);
#if PY_MAJOR_VERSION < 3
  } else if (likely(PyInt_CheckExact(o))) {
    return PyInt_AS_LONG(o);
#endif
  } else {
    Py_ssize_t ival;
    PyObject *x;
    x = PyNumber_Index(o);
    if (!x) return -1;
    ival = PyInt_AsLong(x);
    Py_DECREF(x);
    return ival;
  }
}
static CYTHON_INLINE PyObject * __Pyx_PyBool_FromLong(long b) {
  return b ? __Pyx_NewRef(Py_True) : __Pyx_NewRef(Py_False);
}
static CYTHON_INLINE PyObject * __Pyx_PyInt_FromSize_t(size_t ival) {
    return PyInt_FromSize_t(ival);
}


#endif /* Py_PYTHON_H */
